<?php

/**
 * SocialEngine
 *
 * @category   Application_Extensions
 * @package    Sitegateway
 * @copyright  Copyright 2017-2018 BigStep Technologies Pvt. Ltd.
 * @license    http://www.socialengineaddons.com/license/
 * @version    Mollie.php 2017-06-07 00:00:00Z SocialEngineAddOns $
 * @author     SocialEngineAddOns
 */
class Engine_Payment_Gateway_Mollie extends Engine_Payment_Gateway {

    /**
     * Add the currency codes supported by this gateway.
     * 
     */
    protected $_supportedCurrencies = array(
        'EUR'
    ); 
    /**
     * Add the language codes supported by this gateway if required.
     * 
     */
    protected $_supportedLanguages = array(
        'de', 'en', 'es', 'fr', 'nl'
    );

    /**
     * Add the region codes supported by this gateway if required.
     * 
     */
    protected $_supportedRegions = array(
        'DE', 'US', 'ES', 'FR', 'BE', 'NL'
    );

    /**
     * Add the billing cycles supported by this gateway for recurring payments.
     * 
     */
    protected $_supportedBillingCycles = array(
         'Day', 'Week', 'Month'
    );

    /**
     * Add the minimum allowed amount for this gateway.
     * 
     */
    protected $_minimumAllowedAmount = 0.38;
    
    protected $_transactionMap = array(
        Engine_Payment_Transaction::RETURN_URL => 'RETURNURL',
        Engine_Payment_Transaction::CANCEL_URL => 'CANCELURL',
        Engine_Payment_Transaction::IPN_URL => 'NOTIFYURL',
        Engine_Payment_Transaction::VENDOR_ORDER_ID => 'INVNUM',
        Engine_Payment_Transaction::CURRENCY => 'CURRENCYCODE',
    );

    /**
     * Constructor
     *
     * @param array $options
     */
    public function __construct(array $options = null) {
        parent::__construct($options);

        if (null === $this->getGatewayMethod()) {
            $this->setGatewayMethod('GET');
        }
    }

    /**
     * return the minimum allowed amount for this gateway.
     * 
     */
    public function getAllowedAmount()
    {  
      return $this->_minimumAllowedAmount;
    }

    /**
     * Get the service API
     *
     * @return Engine_Service_Mollie
     */
    public function getService() {

        if (null === $this->_service) {
            $this->_service = new Engine_Service_Mollie(array_merge(
                            $this->getConfig(), array(
                        'testMode' => $this->getTestMode(),
                        'log' => ( true ? $this->getLog() : null ),
                            )
            ));
        }

        return $this->_service;
    }

    /*
     * Add the code which will redirect an users for payment processing. You can take a reference from Stripe or PayPal code available at same file path with same function name.
     */

    public function getGatewayUrl() { 

        //EVENT PACKAGES ORDER
        $payment_order_id = isset($_SESSION['Payment_Siteevent']['order_id']) ? $_SESSION['Payment_Siteevent']['order_id'] : NULL;

        //EVENT TICKET ORDER
        if (empty($payment_order_id)) {
            $payment_order_id = isset($_SESSION['Payment_Siteeventticket']['order_id']) ? $_SESSION['Payment_Siteeventticket']['order_id'] : NULL;
        }

        //PAYMENT BY ADMIN FOR EVENT OWNER
        if (empty($payment_order_id)) {
            $payment_order_id = isset($_SESSION['Payment_Siteeventtickets']['order_id']) ? $_SESSION['Payment_Siteeventtickets']['order_id'] : NULL;
        }

        //COMMISSION PAYMENT
        if (empty($payment_order_id)) {
            $payment_order_id = isset($_SESSION['Event_Bill_Payment_Siteeventticket']['order_id']) ? $_SESSION['Event_Bill_Payment_Siteeventticket']['order_id'] : NULL;
        }

        //STORE PRODUCT ORDER
        if (empty($payment_order_id)) {
            $payment_order_id = isset($_SESSION['Payment_Sitestoreproduct']['order_id']) ? $_SESSION['Payment_Sitestoreproduct']['order_id'] : NULL;
        }

        //PAYMENT BY ADMIN FOR STORE OWNER
        if (empty($payment_order_id)) {
            $payment_order_id = isset($_SESSION['Payment_Sitestoreproducts']['order_id']) ? $_SESSION['Payment_Sitestoreproducts']['order_id'] : NULL;
        }

        //COMMISSION PAYMENT
        if (empty($payment_order_id)) {
            $payment_order_id = isset($_SESSION['Store_Bill_Payment_Sitestoreproduct']['order_id']) ? $_SESSION['Store_Bill_Payment_Sitestoreproduct']['order_id'] : NULL;
        } 
        
        if (empty($payment_order_id)) {
            //LISTING PACKAGES ORDER
            $payment_order_id = isset($_SESSION['Payment_Sitereview']['order_id']) ? $_SESSION['Payment_Sitereview']['order_id'] : NULL;
        }

        if (empty($payment_order_id)) {
            //SUBSCRIPTION PACKAGES ORDER
            $payment_order_id = isset($_SESSION['Payment_Subscription']['order_id']) ? $_SESSION['Payment_Subscription']['order_id'] : NULL;
        }

        if (empty($payment_order_id)) {
            //PAGE PACKAGES ORDER
            $payment_order_id = isset($_SESSION['Payment_Sitepage']['order_id']) ? $_SESSION['Payment_Sitepage']['order_id'] : NULL;
        }

        if (empty($payment_order_id)) {
            //BUSINESS PACKAGES ORDER
            $payment_order_id = isset($_SESSION['Payment_Sitebusiness']['order_id']) ? $_SESSION['Payment_Sitebusiness']['order_id'] : NULL;
        }

        if (empty($payment_order_id)) {
            //GROUP PACKAGES ORDER
            $payment_order_id = isset($_SESSION['Payment_Sitegroup']['order_id']) ? $_SESSION['Payment_Sitegroup']['order_id'] : NULL;
        }

        if (empty($payment_order_id)) {
            //STORE PACKAGES ORDER
            $payment_order_id = isset($_SESSION['Payment_Sitestore']['order_id']) ? $_SESSION['Payment_Sitestore']['order_id'] : NULL;
        } 
        if ($payment_order_id) {
            $session = new Zend_Session_Namespace('mollie_payment_begin');
            $session->order_id = $payment_order_id;
        }
       // Manual
        if (null !== $this->_gatewayUrl) {
            return $this->_gatewayUrl;
        }

        $data = $_SESSION['transaction_data']; 
        $source_id =  $data['source_id']; 
        $source_type =  $data['source_type']; 
        $order_id = $data['metadata']['order_id'];
        $order = Engine_Api::_()->getItem('payment_order', $order_id);  

        if (empty($source_type) || empty($source_id) || empty($order_id) || empty($data['amount'])) {
            return $this->_helper->redirector->gotoRoute(array(), "default", true);
        }

        $sitegatewayPaymentAction = Zend_Registry::isRegistered('sitegatewayPaymentAction') ? Zend_Registry::get('sitegatewayPaymentAction') : null; 
        
        if (empty($sitegatewayPaymentAction)) {
            return $this->_helper->redirector->gotoRoute(array(), "default", true);
        }

        $product = Engine_Api::_()->getItem($source_type, $source_id);  
        $isGetPackageMethodExist = method_exists($product, 'getPackage'); 

        $isOneTimeMethodExist = null;
        if($isGetPackageMethodExist){
            $package = $product->getPackage(); 
            $isOneTimeMethodExist = method_exists($package, 'isOneTime'); 
        }  
        $viewer = Engine_Api::_()->user()->getViewer();  

        //WHEN USER IS LOGGED IN 
        if($viewer->getIdentity()) {
            $name = $viewer->displayname;
            $email = $viewer->email; 
        } else { //WHEN USER NOT LOGGED IN YET - IN SIGN UP CASE 
            $user = Engine_Api::_()->getItem('user', $order->user_id); 
            $name = $user->displayname;
            $email = $user->email;  
        } 
        $paymentParams = array(
            'amount'      => $data['amount'],
            'description' => $data['description'],
            'redirectUrl' => $data['redirectUrl'],
            'metadata'    => $data['metadata']  
        ); 

        //IF THE RESOURCE IS PACKAGE AND HAVE RECURRING PAYMENT THAN CREATE CUSTOMER
        if ($isOneTimeMethodExist && !$package->isOneTime()) {  
            $customerParams = array(
                "name" => $name,
                "email" => $email
            ); 
            $customer = $this->getService()->createCustomer($customerParams); 
            $paymentParams = array_merge($paymentParams, array( 
                'recurringType' => 'first',
                'customerId' => $customer->id 
            )); 
        } 
         
        //CREATE THE PAYMENT
        $payment = $this->getService()->createPayment($paymentParams); 

        //STORE THE TRANSACTION ID IN ORDERS TABLE OF PAYMENT
        $ordersTable = Engine_Api::_()->getDbtable('orders', 'payment');
        $order_id = $data['metadata']['order_id'];
        //SAVE THE PAYMENT ID IN gateway_order_id BECAUSE WE'LL SAVE subscription_id IN gateway_transaction_id 
        $ordersTable->update(array('gateway_order_id' => $payment->id), array('order_id =?' => $order_id));  

        $processUrl = $payment->getPaymentUrl(); 
        return $processUrl; 
    }

    /**
     * If required, add the code here for IPN/Webhooks handling. This method will be responsible to receive the notifications (IPN/Webhooks) from this gateway and notification data sholuld be return as an array.
     */
    public function processIpn(Engine_Payment_Ipn $ipn) {
        
         // Get raw data
        $rawData = $ipn->getRawData();  
        // Log raw data
        $this->_log(print_r($rawData, true), Zend_Log::DEBUG); 
        if (!empty($rawData)) {
            $this->_log('IPN Validation Succeeded');
            return $rawData;
        }

        return false;
    }

    /**
     * Add the code here for Process the transactions of your new payment gateway. 
     */
    public function processTransaction(Engine_Payment_Transaction $transaction) {

        $data = array();
        $rawData = $transaction->getRawData();  

        $data['amount'] = $rawData['amount'];
        if( empty($data['amount']) ) {
            $this->_throw(sprintf('Missing parameter: %1$s', 'amount'));
            return false;
        }  

        $data['description'] = $rawData['product_info'];
        if( empty($data['description']) ) {
            $this->_throw(sprintf('Missing parameter: %1$s', 'Product Info'));
            return false;
        }

        $data['redirectUrl'] = $rawData['return_url'];
        if( empty($data['redirectUrl']) ) {
            $this->_throw(sprintf('Missing parameter: %1$s', 'Return URL'));
            return false;
        }

        $data['api_key']=$rawData['merchant_key'];
        if( empty($data['api_key']) ) {
            $this->_throw(sprintf('Missing parameter: %1$s', 'Merchant Key'));
            return false;
        } 

        $data['metadata'] = array('order_id' => $rawData['vendor_order_id'], 'hookURL' => $rawData['ipn_url']);
        if( empty($data['metadata']) ) {
            $this->_throw(sprintf('Missing parameter: %1$s', 'Metadata like order ID'));
            return false;
        }  
        if (!empty($transaction->vendor_order_id)) {
            $order = Engine_Api::_()->getItem('payment_order', $transaction->vendor_order_id);
            $data['source_type'] = $order->source_type;
            $data['source_id'] = $order->source_id;
        }
        $_SESSION['transaction_data'] = $data; 
        return $data;
    }
 


    /**
     * Add the code to authenticate the new payment gateway credentials.
     */
    public function test() { 

        if (isset($_POST['additionalGatewayDetailArray']['mollieGatewayDetail'])) {
            @parse_str($_POST['additionalGatewayDetailArray']['mollieGatewayDetail'], $mollieDetails);
        } elseif (isset($_POST['gatewayCredentials'])) {
            @parse_str($_POST['gatewayCredentials'], $mollieDetails);
        }

        $merchant_key = isset($_POST['merchant_key']) ? $_POST['merchant_key'] : $mollieDetails['merchant_key']; 

        $testMode = isset($_POST['test_mode']) ? $_POST['test_mode'] : $mollieDetails['test_mode'];

        $integrationKeyError = Zend_Registry::get('Zend_Translate')->_('Please provide valid integration key.');
        
        if ($testMode) {
            $integrationKeyError = Zend_Registry::get('Zend_Translate')->_('Please provide valid integration key for test mode.'); 
        }  
        
        $merchant_key = trim($merchant_key); 
    try{    
           $this->getService()->paymentMethods($merchant_key);   
       }catch(Exception $e){
            throw new Mollie_API_Exception("Invalid API key: '{$merchant_key}'.{$integrationKeyError}");
       }
        return true; 
    }

    /**
     * Add the code to create products/subscription plans/packages in this gateway. You need to write the code accordingly in this method if you have enabled SocialEngine subscription plans and / or packages for any SocialEngineAddOns plugin. You can also leave this method as defined here and write the code in method "createProduct" at "application/libraries/Engine/Service/Mollie.php"
     */
    public function createProduct($params = array()) {
        return $this->getService()->createProduct($params);
    }

    /**
     * Add the code to edit products/subscriptions plans/packages created in this gateway. You need to write the code accordingly in this method if you have enabled SocialEngine subscription plans and / or packages for any SocialEngineAddOns plugin. You can also leave this method as defined here and write the code in method "editProduct" at "application/libraries/Engine/Service/Mollie.php"
     */
    public function editProduct($productId, $params = array()) {
        return $this->getService()->updateProduct($productId, $params);
    }

    /**
     * Add the code to delete created products/subscription plans/packages in this gateway. You need to write the code accordingly in this method if you have enabled SocialEngine subscription plans and / or packages for any SocialEngineAddOns plugin. You can also leave this method as defined here and write the code in method "deleteProduct" at "application/libraries/Engine/Service/Mollie.php"
     */
    public function deleteProduct($productId) {
        return $this->getService()->deleteProduct($productId);
    }

    /**
     * Add the code to get detail about created products/subscription plans/packages in this gateway. You need to write the code accordingly in this method if you have enabled SocialEngine subscription plans and / or packages for any SocialEngineAddOns plugin. You can also leave this method as defined here and write the code in method "detailProduct" at "application/libraries/Engine/Service/Mollie.php"
     */
    public function detailProduct($productId) {
        return $this->getService()->detailProduct($productId);
    }

    /**
     * Gets product details by vendor product id. You need to write the code accordingly in this method if you have enabled SocialEngine subscription plans and / or packages for any SocialEngineAddOns plugin. You can also leave this method as defined here and write the code in method "detailVendorProduct" at "application/libraries/Engine/Service/Mollie.php"
     */    
    public function detailVendorProduct($productId) {
        return $this->getService()->detailVendorProduct($productId);
    }
    
    /**
     * Write the coupon creation code if this gateway provide discount coupon feature and you have installed the SocialEngineAddOns - Discount Coupons Plugin at your site. You can also leave this method as defined here and write the code in method "createCoupon" at "application/libraries/Engine/Service/Mollie.php"
     */     
    public function createCoupon($params = array()) {
        return $this->getService()->createCoupon($params);
    }    
    
    /**
     * Write the coupon edit code if this gateway provide discount coupon feature and you have installed the SocialEngineAddOns - Discount Coupons Plugin at your site. You can also leave this method as defined here and write the code in method "updateCoupon" at "application/libraries/Engine/Service/Mollie.php"
     */      
    public function updateCoupon($couponCode, $params = array()) {
        return $this->getService()->updateCoupon($couponCode, $params);
    }    
    
    /**
     * Write the coupon deletetion code if this gateway provide discount coupon feature and you have installed the SocialEngineAddOns - Discount Coupons Plugin at your site. You can also leave this method as defined here and write the code in method "deleteCoupon" at "application/libraries/Engine/Service/Mollie.php"
     */      
    public function deleteCoupon($couponCode) {
        return $this->getService()->deleteCoupon($couponCode);
    } 

    public function getWebHookDatas() {
        return $this->getService()->getWebHookDatas();
    }       

}
