<?php
/**
 * SocialEngine
 *
 * @category   Application_Extensions
 * @package    Album
 * @copyright  Copyright 2006-2020 Webligo Developments
 * @license    http://www.socialengine.com/license/
 * @version    $Id: AdminSettingsController.php 9747 2012-07-26 02:08:08Z john $
 * @author     Jung
 */

/**
 * @category   Application_Extensions
 * @package    Album
 * @copyright  Copyright 2006-2020 Webligo Developments
 * @license    http://www.socialengine.com/license/
 */
class Album_AdminSettingsController extends Core_Controller_Action_Admin
{
  public function indexAction()
  {
    $this->view->navigation = $navigation = Engine_Api::_()->getApi('menus', 'core')
      ->getNavigation('album_admin_main', array(), 'album_admin_main_settings');

    $settings = Engine_Api::_()->getApi('settings', 'core');

    $this->view->form = $form = new Album_Form_Admin_Global();
    $form->album_page->setValue($settings->getSetting('album_page', 25));
    $form->album_searchable->setValue($settings->getSetting('album_searchable', 0));
    $form->album_defaultsearch->setValue($settings->getSetting('album_defaultsearch', 0));
    if( $this->getRequest()->isPost() && $form->isValid($this->getRequest()->getPost()) ) {
      $values = $form->getValues();
      foreach( $values as $key => $value ) {
        Engine_Api::_()->getApi('settings', 'core')->setSetting($key, $value);
      }
      $form->addNotice('Your changes have been saved.');
    }
  }
  
  public function categoriesAction()
  {
    $this->view->navigation = $navigation = Engine_Api::_()->getApi('menus', 'core')
      ->getNavigation('album_admin_main', array(), 'album_admin_main_categories');

    $categoriesTable = Engine_Api::_()->getDbtable('categories', 'album');
    $this->view->categories = $categoriesTable->fetchAll();
  }
  
  public function addCategoryAction()
  {
    // In smoothbox
    $this->_helper->layout->setLayout('admin-simple');

    // Generate and assign form
    $form = $this->view->form = new Album_Form_Admin_Category();
    $form->setAction($this->view->url(array()));
    
    
    if( !$this->getRequest()->isPost() ) {
      // Output
      $this->renderScript('admin-settings/form.tpl');
      return;
    }
    
    if( !$form->isValid($this->getRequest()->getPost()) ) {
      // Output
      $this->renderScript('admin-settings/form.tpl');
      return;
    }
    
    // Process
    $values = $form->getValues();
    
    $categoriesTable = Engine_Api::_()->getDbtable('categories', 'album');
    $db = $categoriesTable->getAdapter();
    $db->beginTransaction();
    
    try {
      $categoriesTable->insert(array(
        'user_id' => Engine_Api::_()->user()->getViewer()->getIdentity(),
        'category_name' => $values['label'],
      ));
      
      $db->commit();
    } catch( Exception $e ) {
      $db->rollBack();
      throw $e;
    }

    return $this->_forward('success', 'utility', 'core', array(
      'smoothboxClose' => 10,
      'parentRefresh'=> 10,
      'messages' => array('')
    ));
  }

  public function deleteCategoryAction()
  {
    // In smoothbox
    $this->_helper->layout->setLayout('admin-simple');
    $category_id = $this->_getParam('id');
    $this->view->album_id = $this->view->category_id = $id;
    $categoriesTable = Engine_Api::_()->getDbtable('categories', 'album');
    $category = $categoriesTable->find($category_id)->current();
    
    if( !$category ) {
      return $this->_forward('success', 'utility', 'core', array(
        'smoothboxClose' => 10,
        'parentRefresh'=> 10,
        'messages' => array('')
      ));
    } else {
      $category_id = $category->getIdentity();
    }
    
    if( !$this->getRequest()->isPost() ) {
      // Output
      $this->renderScript('admin-settings/delete.tpl');
      return;
    }
    
    // Process
    $db = $categoriesTable->getAdapter();
    $db->beginTransaction();
    
    try {
      
      $category->delete();
      
      $albumTable = Engine_Api::_()->getDbtable('albums', 'album');
      $albumTable->update(array(
        'category_id' => 0,
      ), array(
        'category_id = ?' => $category_id,
      ));
      
      $db->commit();
    } catch( Exception $e ) {
      $db->rollBack();
      throw $e;
    }
    
    return $this->_forward('success', 'utility', 'core', array(
      'smoothboxClose' => 10,
      'parentRefresh'=> 10,
      'messages' => array('')
    ));
  }

  public function editCategoryAction()
  {
    // In smoothbox
    $this->_helper->layout->setLayout('admin-simple');
    $category_id = $this->_getParam('id');
    $this->view->album_id = $this->view->category_id = $category_id;
    $categoriesTable = Engine_Api::_()->getDbtable('categories', 'album');
    $category = $categoriesTable->find($category_id)->current();
    
    if( !$category ) {
      return $this->_forward('success', 'utility', 'core', array(
        'smoothboxClose' => 10,
        'parentRefresh'=> 10,
        'messages' => array('')
      ));
    } else {
      $category_id = $category->getIdentity();
    }
    
    $this->view->form = $form = new Album_Form_Admin_Category();
    $form->setAction($this->view->url(array()));
    $form->setField($category);
    
    if( !$this->getRequest()->isPost() ) {
      // Output
      $this->renderScript('admin-settings/form.tpl');
      return;
    }
    
    if( !$form->isValid($this->getRequest()->getPost()) ) {
      // Output
      $this->renderScript('admin-settings/form.tpl');
      return;
    }
    
    // Process
    $values = $form->getValues();
    
    $db = $categoriesTable->getAdapter();
    $db->beginTransaction();
    
    try {
      $category->category_name = $values['label'];
      $category->save();
      
      $db->commit();
    } catch( Exception $e ) {
      $db->rollBack();
      throw $e;
    }

    return $this->_forward('success', 'utility', 'core', array(
      'smoothboxClose' => 10,
      'parentRefresh'=> 10,
      'messages' => array('')
    ));
  }

  public function flushPhotoAction() {
    $this->view->form = $form = new Album_Form_Admin_Settings_FlushAlbum();
    $this->_helper->layout->setLayout('admin-simple');
    if( !$this->getRequest()->isPost() )
    {
      return;
    }
    $dbObject = Engine_Db_Table::getDefaultAdapter();
    try {
      $dbObject->query('DELETE  FROM `engine4_album_photos` WHERE (album_id =0) AND (DATE(NOW()) != DATE(creation_date))');
    }catch(Exception $e){
      throw $e;
    }
    $this->view->message = Zend_Registry::get('Zend_Translate')->_("Unmapped photos remove successfully.");
    return 
    $this->_forward('success' ,'utility', 'core', array(
      'parentRedirect' => Zend_Controller_Front::getInstance()->getRouter()->assemble(array('module' => 'album', 'controller' => 'settings', 'action' => 'index'), 'admin_default', true),
      'messages' => Array($this->view->message)
    ));
  }
}
