<?php
/**
 * SocialEngine
 *
 * @category   Application_Extensions
 * @package    Calendar
 * @copyright  Copyright 2015-2016 BigStep Technologies Pvt. Ltd.
 * @license    http://www.socialengineaddons.com/license/
 * @version    $Id: AdminBannerController.php 6590 2016-07-07 00:00:00Z SocialEngineAddOns $
 * @author     SocialEngineAddOns
 */

class Calendar_GroupController extends Core_Controller_Action_Standard
{
    public function init() {
        if( !$this->_helper->requireUser()->isValid() ) return;
    }

    public function indexAction()
    {
        $this->view->viewer = $viewer = Engine_Api::_()->user()->getViewer();

        $this->view->navigation = Engine_Api::_()->getApi('menus', 'core')
                ->getNavigation('calendar_main_groups', array(), 'calendar_main_manage_index');
        // Render
        $this->_helper->content
                //->setNoRender()
            ->setEnabled()
                ;
        // Get all calendars
        $page = $this->_getParam('page', 1);
        $groups = Engine_Api::_()->getDbtable('groups', 'calendar')->getBrowseGroups();
        if($groups != NULL){
            $this->view->paginator = $paginator = Zend_Paginator::factory($groups);
            $this->view->paginator->setItemCountPerPage(12);
            $this->view->paginator->setCurrentPageNumber($page);
            $this->view->totalItemCount = $this->view->paginator->getTotalItemCount();
        }
        else
            $this->view->totalItemCount = 0;
    }

    public function manageAction()
    {
        $this->view->viewer = $viewer = Engine_Api::_()->user()->getViewer();

    	$this->view->navigation = Engine_Api::_()->getApi('menus', 'core')
                ->getNavigation('calendar_main_groups', array(), 'calendar_main_manage_groups');

        // Render
        $this->_helper->content
            //->setNoRender()
            ->setEnabled()
            ;
        // Get all groups
        $page = $this->_getParam('page', 1);
        $groups = Engine_Api::_()->getDbtable('groups', 'calendar')->getAllGroups();
        $this->view->paginator = $paginator = Zend_Paginator::factory($groups);
        $this->view->paginator->setItemCountPerPage(12);
        $this->view->paginator->setCurrentPageNumber($page);
        $this->view->totalItemCount = $this->view->paginator->getTotalItemCount();
    }

    public function viewAction()
    {

        $viewer = Engine_Api::_()->user()->getViewer();
        $group = Engine_Api::_()->getItem('calendar_group', $this->_getParam('group_id'));
        if( $group ) {
            Engine_Api::_()->core()->setSubject($group);
        }

        if( !$this->_helper->requireSubject()->isValid() ) {
            return;
        }

        if( !$group) {
            return $this->_helper->requireSubject->forward();
        }

        // Render
        $this->_helper->content
                //->setNoRender()
            ->setEnabled()
                ;

        $this->view->group = $group;
        $this->view->owner = $owner = $group->getOwner();
        $this->view->viewer = $viewer;

        // Get all members
        $this->view->members = $members = Engine_Api::_()->getItemTable('calendar_groupmember')->getAllMembers($this->_getParam('group_id'));
    }

    public function createAction()
    {

        $viewer = Engine_Api::_()->user()->getViewer();

        $this->view->navigation = Engine_Api::_()->getApi('menus', 'core')
                ->getNavigation('calendar_main_groups', array(), 'calendar_main_group_create');
    
        // Render
        $this->_helper->content
            //->setNoRender()
            ->setEnabled()
            ;

        // Prepare form
        $this->view->form = $form = new Calendar_Form_Group_Create();

        // check duplicacy of title
        if($this->_getParam('isAjax')){
            $calendarGroupTable = Engine_Api::_()->getDbtable('groups', 'calendar');
            $title = $this->_getParam('title');
            $groups = $calendarGroupTable->fetchRow($calendarGroupTable->select()->where("title LIKE ?", $title));

            $flag = true;
            if(!empty($groups)){
                $flag = false;
            }
            $check['flag'] = $flag;
            return $this->_helper->json($check);
        }

        // If not post or form not valid, return
        if( !$this->getRequest()->isPost() ) {
            return;
        }

        if( !$form->isValid($this->getRequest()->getPost()) ) {
            return;
        }

        // Process
        $table = Engine_Api::_()->getDbtable('groups', 'calendar');
        $memberTable = Engine_Api::_()->getDbtable('groupmembers', 'calendar');
        $db = $table->getAdapter();
        $db->beginTransaction();

        try {
            // Create Calendar
            $viewer = Engine_Api::_()->user()->getViewer();
            $formValues = $form->getValues();
            $groups = $table->fetchRow($table->select()->where('title LIKE ?',$formValues['title']));

            if(!empty($groups)){
                return $form->addError('Title: This title is already taken, please try another');
            }
            $members = explode(",",$formValues['toValues']);
            $non_members = explode(',', $formValues['non_members']);
            $resources = array_unique (array_merge ($members, $non_members));

            $values = array_merge($formValues, array(
                'owner_id' => $viewer->getIdentity(),
            ));

            $group = $table->createRow();
            $group->setFromArray($values);
            $group->save();

            // Set photo
            if( !empty($values['photo']) ) {
                $group->setPhoto($form->photo);
            }
            $row = $memberTable->createRow();
            $row->group_id = $group->group_id;
            $row->user_email = $viewer->email;
            $row->save();
            foreach ($resources as $resource) {
                $user = Engine_Api::_()->getItem('user', $resource);
                $row = $memberTable->createRow();
                $row->group_id = $group->group_id;
                if(!empty($user->email)) {
                    $row->user_email = $user->email;
                    $row->save();
                    Engine_Api::_()->getDbtable('calendars', 'calendar')->addCustomNotifications($user, $viewer, $group, 'group_member_add');
                } else if(!empty($resource)) {
                    $row->user_email = $resource;
                    $row->save();
                } 
            }
            // Commit
            $db->commit();
        } catch( Exception $e ) {
            return $this->exceptionWrapper($e, $form, $db);
        }

        return $this->_helper->redirector->gotoRoute(array('action' => 'manage'));
    }

    public function editAction()
    {
        $viewer = Engine_Api::_()->user()->getViewer();
        $this->view->group = $group = Engine_Api::_()->getItem('calendar_group', $this->_getParam('group_id'));
        if( !Engine_Api::_()->core()->hasSubject('calendar_group') ) {
            Engine_Api::_()->core()->setSubject($group);
        }

        if( !$this->_helper->requireSubject()->isValid() ) return;

        // In smoothbox
        $this->_helper->layout->setLayout('default-simple');
        
        // Prepare form
        $this->view->form = $form = new Calendar_Form_Group_Edit();

        // Populate form
        $form->populate($group->toArray());

        // check duplicacy of title
        if($this->_getParam('isAjax')){
            $calendarGroupTable = Engine_Api::_()->getDbtable('groups', 'calendar');
            $title = $this->_getParam('title');
            $groups = $calendarGroupTable->fetchRow($calendarGroupTable->select()->where("title LIKE ?", $title));

            $flag = true;
            if(!empty($groups && $groups->getIdentity() != $this->_getParam('group_id'))){
                $flag = false;
            }
            $check['flag'] = $flag;
            return $this->_helper->json($check);
        }

        // Check post/form
        if( !$this->getRequest()->isPost() ) {
            return;
        }
        if( !$form->isValid($this->getRequest()->getPost()) ) {
            return;
        }

        // Process
        $db = Engine_Db_Table::getDefaultAdapter();
        $db->beginTransaction();

        try {
            $values = $form->getValues();
            $calendarGroupTable = Engine_Api::_()->getDbtable('groups', 'calendar');
            $groups = $calendarGroupTable->fetchAll($calendarGroupTable->select()->where('title LIKE ?',$values['title']));
            foreach($groups as $value){
                if($value->group_id != $this->_getParam('group_id')){
                  return $form->addError('Title: This Title is already taken, please try another');
                }
            }

            $group->setFromArray($values);
            $group->modified_date = date('Y-m-d H:i:s');
            $group->save();

            if( !empty($values['photo']) ) {
                $group->setPhoto($form->photo);
            }

            $db->commit();

        }
        catch( Exception $e ) {
            $db->rollBack();
            throw $e;
        }
         $this->_forward('success', 'utility', 'core', array(
          'smoothboxClose' => 3000,
          'parentRefresh' => 3000,
          'messages' => array(Zend_Registry::get('Zend_Translate')->_('Details Updated Successfully.'))
      ));
    }

    public function deleteAction()
    {
        $viewer = Engine_Api::_()->user()->getViewer();
        $group = Engine_Api::_()->getItem('calendar_group', $this->getRequest()->getParam('group_id'));

        // In smoothbox
        $this->_helper->layout->setLayout('default-simple');

        $this->view->form = $form = new Calendar_Form_Group_Delete();

        if( !$group ) {
            $this->view->status = false;
            $this->view->error = Zend_Registry::get('Zend_Translate')->_("Group doesn't exist or not authorized to delete");
            return;
        }

        if( !$this->getRequest()->isPost() ) {
            $this->view->status = false;
            $this->view->error = Zend_Registry::get('Zend_Translate')->_('Invalid request method');
            return;
        }

        $db = $group->getTable()->getAdapter();
        $db->beginTransaction();

        try {
            // Get all members
            $members = Engine_Api::_()->getItemTable('calendar_groupmember')->getAllMembers($this->getRequest()->getParam('group_id')); 
            foreach ($members as $member) {
                $member->delete();
            }
            $group->delete();

            $db->commit();
        } catch( Exception $e ) {
            $db->rollBack();
            throw $e;
        }

        $this->view->status = true;
        $this->view->message = Zend_Registry::get('Zend_Translate')->_('Your group has been deleted Successfully.');
        return $this->_forward('success' ,'utility', 'core', array(
            'smoothboxClose' => 3000,
            'parentRefresh' => 3000,
            'messages' => Array($this->view->message)
        ));
    }

    public function addMembersAction() {
        $viewer = Engine_Api::_()->user()->getViewer();
        $this->view->group = $group = Engine_Api::_()->getItem('calendar_group', $this->getRequest()->getParam('group_id'));

        // In smoothbox
        $this->_helper->layout->setLayout('default-simple');

        $this->view->form = $form = new Calendar_Form_Groupmember_Add();

        if( !$group ) {
            $this->view->status = false;
            $this->view->error = Zend_Registry::get('Zend_Translate')->_("Group doesn't exist");
            return;
        }

        if( !$this->getRequest()->isPost() ) {
            return;
        }
        if( !$form->isValid($this->getRequest()->getPost()) ) {
            return;
        }

        $db = $group->getTable()->getAdapter();
        $db->beginTransaction();
        $memberTable = Engine_Api::_()->getDbtable('groupmembers', 'calendar');

        try {
            $viewer = Engine_Api::_()->user()->getViewer();
            $formValues = $form->getValues();

            $members = explode(",",$formValues['toValues']);
            $non_members = explode(',', $formValues['non_members']);
            $resources = array_unique (array_merge ($members, $non_members));

            foreach ($resources as $resource) {
                $user = Engine_Api::_()->getItem('user', $resource);
                $row = $memberTable->createRow();
                $row->group_id = $group->group_id;
                if(!empty($user->email)) {
                    $row->user_email = $user->email;
                    $row->save();
                    Engine_Api::_()->getDbtable('calendars', 'calendar')->addCustomNotifications($user, $viewer, $group, 'group_member_add');
                } else if(!empty($resource)) {
                    $row->user_email = $resource;
                    $row->save();
                } 
            }
            $db->commit();
        } catch( Exception $e ) {
            $db->rollBack();
            throw $e;
        }

        $this->view->status = true;
        $this->_forward('success', 'utility', 'core', array(
          'smoothboxClose' => 3000,
          'parentRefresh' => 3000,
          'messages' => array(Zend_Registry::get('Zend_Translate')->_('Member has been added Successfully.'))
      ));
    }

    public function removeMemberAction() {
        $group_id = $this->getRequest()->getParam('group_id');
        $user_email = $this->getRequest()->getParam('user_email');
        $viewer = Engine_Api::_()->user()->getViewer();
        $group = Engine_Api::_()->getItem('calendar_group', $group_id);

        $db = Engine_Db_Table::getDefaultAdapter();
        $db->beginTransaction();
        $memberTable = Engine_Api::_()->getDbtable('groupmembers', 'calendar');

        try {
            $memberTable->delete(array('group_id = ?'=> $group_id, 'user_email = ?' => $user_email));
            $userTable = Engine_Api::_()->getDbtable('users', 'user');
            $select = $userTable->select()
                              ->where('email = ? ', $user_email);
            $member = $userTable->fetchRow($select);
            if((!empty($member->email)) && ($user_email == $viewer->email)) {
                Engine_Api::_()->getDbtable('calendars', 'calendar')->addCustomNotifications($group->getOwner(), $viewer, $group, 'group_member_left');
            } elseif(!empty($member->email)) {
                Engine_Api::_()->getDbtable('calendars', 'calendar')->addCustomNotifications($member, $group->getOwner(), $group, 'group_member_remove');
            }
            $db->commit();
        } catch( Exception $e ) {
            $db->rollBack();
            throw $e;
        }

        $this->_forward('success', 'utility', 'core', array(
          'smoothboxClose' => 3000,
          'parentRefresh' => 3000,
          'messages' => array(Zend_Registry::get('Zend_Translate')->_('Member has been removed Successfully.'))
        ));
    }

    public function getusersAction() {
        $search_text = $this->_getParam('value', null);
        $limit = $this->_getParam('limit', 40);

        $data = array();
        $group_id = $this->getRequest()->getParam('group_id');
        $moduleContents = Engine_Api::_()->getItemTable('calendar_groupmember')->getUsers($search_text, $limit = 10, $group_id);

        foreach ($moduleContents as $moduleContent) {

            $content_photo = $this->view->itemPhoto($moduleContent, 'thumb.icon');

            $data[] = array(
                'id' => $moduleContent->user_id,
                'label' => $moduleContent->displayname,
                'photo' => $content_photo,
                'email' => $moduleContent->email
            );
        }
        return $this->_helper->json($data);
    }
}
