<?php
/**
 * SocialEngine
 *
 * @category   Application_Extensions
 * @package    Calendar
 * @copyright  Copyright 2015-2016 BigStep Technologies Pvt. Ltd.
 * @license    http://www.socialengineaddons.com/license/
 * @version    $Id: AdminBannerController.php 6590 2016-07-07 00:00:00Z SocialEngineAddOns $
 * @author     SocialEngineAddOns
 */

class Calendar_ScheduleController extends Core_Controller_Action_Standard
{
	public function viewAction() {
		$this->view->calendar_id = $this->_getParam('calendar_id');
		$this->view->calendar = Engine_Api::_()->getItem('calendar', $this->_getParam('calendar_id'));
		// Render
		$this->_helper->content
	            //->setNoRender()
		->setEnabled();

	}

	public function createAction() {

		$viewer = Engine_Api::_()->user()->getViewer();

		$paginator = Zend_Paginator::factory(Engine_Api::_()->getItemTable('calendar')->getAllCalendars(0, 1));

		$this->view->current_count = $paginator->getTotalItemCount();
		
		$calendar = Engine_Api::_()->getItem('calendar', $this->_getParam('calendar_id'));
		// In smoothbox
		$this->_helper->layout->setLayout('default-simple');
		// Prepare form
		$this->view->form = $form = new Calendar_Form_Schedule_Create();

	    // If not post or form not valid, return
		if( !$this->getRequest()->isPost() ) {
			return;
		}

		if( !$form->isValid($this->getRequest()->getPost()) ) {
			return;
		}

	    // Process
		$table = Engine_Api::_()->getDbtable('schedules', 'calendar');
		$location = Engine_Api::_()->getItemTable('calendar_schedulelocation');
		$db = $table->getAdapter();
		$db->beginTransaction();

		try {
	        // Create Calendar
			$viewer = Engine_Api::_()->user()->getViewer();
			$formValues = $form->getValues();
			if($formValues['start_datetime'] == $formValues['end_datetime']) {
				return $form->addError("Start and End Time must not be same.");
			}
			$dt = date('Y-m-d H:i:s', strtotime($formValues['start_datetime']));
			$date = new DateTime($dt, new DateTimeZone($viewer->timezone));
			$date->setTimezone(new DateTimeZone('UTC'));
			$formValues['start_datetime'] = $date->format('Y-m-d H:i:s');

			$dt = date('Y-m-d H:i:s', strtotime($formValues['end_datetime']));
			$date = new DateTime($dt, new DateTimeZone($viewer->timezone));
			$date->setTimezone(new DateTimeZone('UTC'));
			$formValues['end_datetime'] = $date->format('Y-m-d H:i:s');

			$values = array_merge($formValues, array(
				'owner_id' => $viewer->getIdentity(),
				'search' => 0
			));
			$Schedule = $table->createRow();
			$Schedule->setFromArray($values);
			$Schedule->save();

	        // save location
			$location = $location->createRow();
			$formValues = $form->getValues();
			$locationValues = $formValues['location_region'];
			$locationValues = json_decode($locationValues, true);
			$locationValues['schedule_id'] = $Schedule->getIdentity();
			$location->setFromArray($locationValues);
			$location->save();
	        // Commit
			$db->commit();
		} catch( Exception $e ) {
			return $this->exceptionWrapper($e, $form, $db);
		}
		$this->_forward('success', 'utility', 'core', array(
			'smoothboxClose' => 3000,
			'parentRefresh' => 3000,
			'messages' => array(Zend_Registry::get('Zend_Translate')->_('Your schedule has been saved.'))
		));
	}

	public function manageAction() {
		$calendar_id = $this->_getParam('calendar_id');
		$calendar = Engine_Api::_()->getItem('calendar', $calendar_id);

		$schedules = Engine_Api::_()->getDbtable('schedules', 'calendar')->getCalendarSchedules($calendar_id);

		echo json_encode($schedules);
		exit;
	}

	public function getSchedulesAction() {
		$viewer = Engine_Api::_()->user()->getViewer();

		$schedules = Engine_Api::_()->getDbtable('schedules', 'calendar')->getUserSchedules($viewer->getIdentity());

		echo json_encode($schedules);
		exit;
	}

	public function updateAction() {
		$viewer = Engine_Api::_()->user()->getViewer();
		$schedule_id = $this->_getParam('id');
		$schedule = Engine_Api::_()->getItem('calendar_schedule', $schedule_id);

		unset($_POST['id']);
		// Process
		$db = Engine_Db_Table::getDefaultAdapter();
		$db->beginTransaction();
		$dt = date('Y-m-d H:i:s', strtotime($_POST['start_datetime']));
		$date = new DateTime($dt, new DateTimeZone($viewer->timezone));
		$date->setTimezone(new DateTimeZone('UTC'));
		$_POST['start_datetime'] = $date->format('Y-m-d H:i:s');

		$dt = date('Y-m-d H:i:s', strtotime($_POST['end_datetime']));
		$date = new DateTime($dt, new DateTimeZone($viewer->timezone));
		$date->setTimezone(new DateTimeZone('UTC'));
		$_POST['end_datetime'] = $date->format('Y-m-d H:i:s');

		try {
			$schedule->setFromArray($_POST);
			$schedule->modified_date = date('Y-m-d H:i:s');
			$schedule->save();

			$db->commit();
		}
		catch( Exception $e ) {
			$db->rollBack();
			throw $e;
		}
		exit;
	}

	public function editAction() {
		$schedule_id = $this->_getParam('id');
		$schedule = Engine_Api::_()->getItem('calendar_schedule', $schedule_id);
		$viewer = Engine_Api::_()->user()->getViewer();

		if(!Engine_Api::_()->getDbtable('owners', 'calendar')->isCalendarOwner($schedule->calendar_id)) {
			$this->_forward('requireauth', 'error', 'core');
		}

		// In smoothbox
		$this->_helper->layout->setLayout('default-simple');
		
        // Prepare form
		$this->view->form = $form = new Calendar_Form_Schedule_Edit();

        // Populate form
		$dt = date('Y-m-d H:i:s', strtotime($schedule->start_datetime));
		$date = new DateTime($dt, new DateTimeZone('UTC'));
		$date->setTimezone(new DateTimeZone($viewer->timezone));
		$schedule->start_datetime = $date->format('Y-m-d H:i:s');

		$dt = date('Y-m-d H:i:s', strtotime($schedule->end_datetime));
		$date = new DateTime($dt, new DateTimeZone('UTC'));
		$date->setTimezone(new DateTimeZone($viewer->timezone));
		$schedule->end_datetime = $date->format('Y-m-d H:i:s');

		$form->populate($schedule->toArray());

        // Check post/form
		if( !$this->getRequest()->isPost() ) {
			return;
		}
		if( !$form->isValid($this->getRequest()->getPost()) ) {
			return;
		}

        // Process
		$locationTable = Engine_Api::_()->getDbtable('schedulelocations','calendar');
		$location = $locationTable->fetchRow('schedule_id = '.$this->_getParam('id'));
		$db = Engine_Db_Table::getDefaultAdapter();
		$db->beginTransaction();

		try {
			$values = $form->getValues();
			if($values['start_datetime'] == $values['end_datetime']) {
				return $form->addError("Start and End Time must not be same.");
			}

			$dt = date('Y-m-d H:i:s', strtotime($values['start_datetime']));
			$date = new DateTime($dt, new DateTimeZone($viewer->timezone));
			$date->setTimezone(new DateTimeZone('UTC'));
			$values['start_datetime'] = $date->format('Y-m-d H:i:s');

			$dt = date('Y-m-d H:i:s', strtotime($values['end_datetime']));
			$date = new DateTime($dt, new DateTimeZone($viewer->timezone));
			$date->setTimezone(new DateTimeZone('UTC'));
			$values['end_datetime'] = $date->format('Y-m-d H:i:s');

			$schedule->setFromArray($values);
			$schedule->modified_date = date('Y-m-d H:i:s');
			$schedule->save();


			if($values['location_region'] ){
				$locationValues = $values['location_region'];
				$locationValues = json_decode($locationValues, true);
				if(empty($location)) {
					$location = $locationTable->createRow();
				}

				$location->setFromArray($locationValues);
				$location->save();
			}

			$db->commit();

		}
		catch( Exception $e ) {
			$db->rollBack();
			throw $e;
		}
		$this->_forward('success', 'utility', 'core', array(
			'smoothboxClose' => 3000,
			'parentRefresh' => 3000,
			'messages' => array(Zend_Registry::get('Zend_Translate')->_('Your schedule has been updated.'))
		));
	}

	public function deleteAction()
	{
		$schedule_id = $this->_getParam('id');
		$schedule = Engine_Api::_()->getItem('calendar_schedule', $schedule_id);
		$viewer = Engine_Api::_()->user()->getViewer();

		if(!Engine_Api::_()->getDbtable('owners', 'calendar')->isCalendarOwner($schedule->calendar_id)) {
			return $this->_forward('requireauth', 'error', 'core');
		}

		$db = $schedule->getTable()->getAdapter();
		$db->beginTransaction();
		$status = true;
		$error = '';
		try {
			$schedule->delete();
			$status = true;
			$db->commit();
		} catch( Exception $e ) {
			$status = false;
			$error = "There was some error in deleting the schedule.";
			$db->rollBack();
            // throw $e;
		}

		$this->view->status = $status;
		$this->view->error = $error;
	}

	public function importSchedulesAction() {
		$viewer = Engine_Api::_()->user()->getViewer();

		$calendar = Engine_Api::_()->getItem('calendar', $this->_getParam('calendar_id'));
		// In smoothbox
		$this->_helper->layout->setLayout('default-simple');
		// Prepare form
		$this->view->form = $form = new Calendar_Form_Schedule_Import();

	    // If not post or form not valid, return
		if( !$this->getRequest()->isPost() ) {
			return;
		}

		if( !$form->isValid($this->getRequest()->getPost()) ) {
			return;
		}

		$icalString = file_get_contents($_FILES['filename']['tmp_name']);
		$icsEvents = array ();
		/* Explode the ICs Data to get datas as array according to string ‘BEGIN:’ */echo "<pre>";
		$icsData = explode ( "BEGIN:", $icalString );
		/* Iterating the icsData value to make all the start end dates as sub array */
		foreach ( $icsData as $key => $value ) {
			$icsDatesMeta [$key] = explode ( "\n", $value );
		}
		/* Itearting the Ics Meta Value */
		foreach ( $icsDatesMeta as $key => $value ) {
			foreach ( $value as $subKey => $subValue ) {
				/* to get ics events in proper order */
				$icsEvents = $this->getICSDates ( $key, $subKey, $subValue, $icsEvents );
			}
		}

	    // Process
		$table = Engine_Api::_()->getDbtable('schedules', 'calendar');
		$db = $table->getAdapter();
		$db->beginTransaction();

		try {
	        // Create Calendar
			$viewer = Engine_Api::_()->user()->getViewer();
			foreach($icsEvents as $event) {
				if(trim($event['BEGIN']) == 'VEVENT') {
					$start = date('Y-m-d H:i:s', strtotime($event['DTSTART']));
					$end = date('Y-m-d H:i:s', strtotime($event['DTEND']));

					$values = array(
						'calendar_id' => $calendar->getIdentity(),
						'title' => $event['SUMMARY'],
						'body' => $event['DESCRIPTION'],
						'location' => $event['LOCATION'] ? $event['LOCATION'] : '',
						'start_datetime' => $start,
						'end_datetime' => $end,
						'owner_id' => $viewer->getIdentity(),
						'search' => 0
					);
					$Schedule = $table->createRow();
					$Schedule->setFromArray($values);
					$Schedule->save();
				}
			}
	        // Commit
			$db->commit();
		} catch( Exception $e ) {
			return $this->exceptionWrapper($e, $form, $db);
		}
		$this->_forward('success', 'utility', 'core', array(
			'smoothboxClose' => 3000,
			'parentRefresh' => 3000,
			'messages' => array(Zend_Registry::get('Zend_Translate')->_('Schedules saved Successfully.'))
		));
	}

	function getICSDates($key, $subKey, $subValue, $icsDates) {
		if ($key != 0 && $subKey == 0) {
			$icsDates [$key] ["BEGIN"] = $subValue;
		} else {
			$subValueArr = explode ( ":", $subValue, 2 );
			if (isset ( $subValueArr [1] )) {
				if (strpos($subValueArr [0], 'DTSTART') !== false) {
					$icsDates [$key] ['DTSTART'] = $subValueArr [1];
				} else if (strpos($subValueArr [0], 'DTEND') !== false) {
					$icsDates [$key] ['DTEND'] = $subValueArr [1];
				} else
				$icsDates [$key] [$subValueArr [0]] = $subValueArr [1];
			}
		}
		return $icsDates;
	}

	public function moveAction() {
		$schedule_id = $this->_getParam('id');
		$schedule = Engine_Api::_()->getItem('calendar_schedule', $schedule_id);
		$viewer = Engine_Api::_()->user()->getViewer();

		if(!Engine_Api::_()->getDbtable('owners', 'calendar')->isCalendarOwner($schedule->calendar_id)) {
			$this->_forward('requireauth', 'error', 'core');
		}

		// In smoothbox
		$this->_helper->layout->setLayout('default-simple');
		$calendars = Engine_Api::_()->getItemTable('calendar')->getAllCalendars($schedule->calendar_id);
		if(empty($calendars->toArray())) {
			$this->view->noCalendar = true;
			return;
		}
		
        // Prepare form
		$this->view->form = $form = new Calendar_Form_Schedule_Move(array('calendar' => $schedule->calendar_id));

        // Check post/form
		if( !$this->getRequest()->isPost() ) {
			return;
		}
		if( !$form->isValid($this->getRequest()->getPost()) ) {
			return;
		}

		try {
	        // Move Schedule
			$formValues = $form->getValues();
			Engine_Api::_()->getItemTable('calendar_schedule')->update(array('calendar_id' => $formValues['calendar']), array('schedule_id = ?' => $schedule_id));

		} catch( Exception $e ) {
			return $this->exceptionWrapper($e, $form, $db);
		}
		$this->_forward('success', 'utility', 'core', array(
			'smoothboxClose' => 3000,
			'parentRefresh' => 3000,
			'messages' => array(Zend_Registry::get('Zend_Translate')->_('Schedule has been moved Successfully.'))
		));
	}
}