<?php
/**
 * SocialEngine
 *
 * @category   Application_Extensions
 * @package    Calendar
 * @copyright  Copyright 2015-2016 BigStep Technologies Pvt. Ltd.
 * @license    http://www.socialengineaddons.com/license/
 * @version    $Id: AdminBannerController.php 6590 2016-07-07 00:00:00Z SocialEngineAddOns $
 * @author     SocialEngineAddOns
 */

class Calendar_GroupController extends Siteapi_Controller_Action_Standard
{
    public function init() {
        if( !$this->_helper->requireUser()->isValid() ) 
            $this->respondWithError("unauthorized");
    }

    public function indexAction()
    {
        $viewer = Engine_Api::_()->user()->getViewer();
        $values['limit'] = (int) $this->getRequestParam('limit', 20);
        $values['page'] = (int) $this->getRequestParam('page', 1);

        // Get all calendars
        $response = array();
        if(Engine_Api::_()->getDbtable('groups', 'calendar')->getBrowseGroups() != NULL){
            $groups = Zend_Paginator::factory(Engine_Api::_()->getDbtable('groups', 'calendar')->getBrowseGroups());
            $groups->setItemCountPerPage($values['limit']);
            $groups->setCurrentPageNumber($values['page']);
            $response['totalItemCount'] = $groups->getTotalItemCount();
        }
        else
            $response['totalItemCount'] = 0;
        foreach($groups as $group){
            $groupArr = $group->toArray();
            $getContentImages = Engine_Api::_()->getApi('Core', 'siteapi')->getContentImage($group);
            $groupArr = array_merge($groupArr, $getContentImages);
            $groupArr['owner_title'] = $group->getOwner()->getTitle();
            $groupsArr[] = $groupArr;
        }
        if(!empty($groupsArr)){
            $response['response'] = $groupsArr;
        }
        else
            $response['response'] = "";

        $this->respondWithSuccess($response);
    }

    public function manageAction()
    {
        $viewer = Engine_Api::_()->user()->getViewer();
        $values['limit'] = (int) $this->getRequestParam('limit', 20);
        $values['page'] = (int) $this->getRequestParam('page', 1);

        // Get all calendars
        $response = array();
        if(Engine_Api::_()->getDbtable('groups', 'calendar')->getAllGroups() != null){
            $groups = Zend_Paginator::factory(Engine_Api::_()->getDbtable('groups', 'calendar')->getAllGroups());
            $groups->setItemCountPerPage($values['limit']);
            $groups->setCurrentPageNumber($values['page']);
            $response['totalItemCount'] = $groups->getTotalItemCount();
        }
        else
            $response['totalItemCount'] = 0;
        
        foreach($groups as $group){
            $groupArr = $group->toArray();
            $getContentImages = Engine_Api::_()->getApi('Core', 'siteapi')->getContentImage($group);
            $groupArr = array_merge($groupArr, $getContentImages);
            $groupArr['owner_title'] = $group->getOwner()->getTitle();

            $tempMenu = array();
            if ($group->isOwner($viewer)) {
                $tempMenu[] = array(
                    'label' => $this->translate('Edit'),
                    'name' => 'edit',
                    'url' => 'calendar-group/edit/' . $group->getIdentity(),
                );

                $tempMenu[] = array(
                    'name' => 'delete',
                    'label' => $this->translate('Delete'),
                    'url' => 'calendar-group/delete/' . $group->getIdentity()
                );
                  
            }
            $groupArr["menu"] = $tempMenu;

            $groupsArr[] = $groupArr;
        }
        if(!empty($groupsArr)){
            $response['response'] = $groupsArr;
        }
        else
            $response['response'] = "";

        $this->respondWithSuccess($response);
    }
    private function _sanitizeArray($dataArray = array(), $ignoreParams = array()) {
        $restrictedFields = array('email', 'password', 'salt', 'creation_ip', 'lastlogin_ip');
        foreach ($restrictedFields as $restrictedValue) {
            if (!in_array($restrictedValue, $ignoreParams) && in_array($restrictedValue, $dataArray)) {
                unset($dataArray[$restrictedValue]);
            }
        }
        return $dataArray;
    }
    public function viewAction()
    {
        $viewer = Engine_Api::_()->user()->getViewer();
        $group = Engine_Api::_()->getItem('calendar_group', $this->_getParam('group_id'));
        if( $group ) {
            Engine_Api::_()->core()->setSubject($group);
        }
        $response = array();
        $groupArr = $group->toArray();
        $groupArr['group_title'] = $group->getTitle();
        $getContentImages = Engine_Api::_()->getApi('Core', 'siteapi')->getContentImage($group);
        $groupArr = array_merge($groupArr, $getContentImages);
        $owner = $group->getOwner();
        $groupOwnerArr = $group->getOwner()->toArray();
        $groupArr['owner'] = $this->_sanitizeArray($groupOwnerArr);
        $canAddMembers = 0;
        if ($viewer->getIdentity() == $owner->getIdentity()){
            $canAddMembers = 1;
        }

        // Get all members
        $members = Engine_Api::_()->getItemTable('calendar_groupmember')->getAllMembers($this->_getParam('group_id'));
        if( count($members) > 0 ){
            $userTable = Engine_Api::_()->getDbtable('users', 'user');
            foreach($members as $member){
                $userArr = array();
                $select = $userTable->select()
                              ->where('email = ? ', $member->user_email);


                $user = $userTable->fetchRow($select);
                if(!empty($user->email))
                {   
                    $userArr['user_id'] = $user->getIdentity();
                    $getContentImages = Engine_Api::_()->getApi('Core', 'siteapi')->getContentImage($user);
                    $userArr['displayname'] = $user->getTitle();
                    $userArr['user_email'] = $user->email;
                    $userArr = array_merge($userArr, $getContentImages);
        
                }
                else{
                    $userArr['user_email'] = $member->user_email;
                    $getContentImages = Engine_Api::_()->getApi('Core', 'siteapi')->getContentImage($member);
                    $userArr = array_merge($userArr, $getContentImages);
                }
                if($viewer->getIdentity() == $owner->getIdentity() && ($viewer->email != $member->user_email))
                    $userArr['canRemoveMember'] = 1;
                elseif ($viewer->email == $member->user_email && ($viewer->getIdentity() != $owner->getIdentity()))
                    $userArr['canLeaveGroup'] = 1;
                $memberArr[] = $userArr;

            }
        }

        if(!empty($groupArr)){
            $response['group'] = $groupArr;
            $response['canAddMembers'] = $canAddMembers;
            $response['members'] = $memberArr;
        }
        else
            $response['group'] = "";

        $this->respondWithSuccess($response);
    
    }

    public function createAction()
    {
        $viewer = Engine_Api::_()->user()->getViewer();

        if ($this->getRequest()->isGet()) {
            $form['form'] = Engine_Api::_()->getApi('Siteapi_Core', 'calendar')->getGroupForm();
            $this->respondWithSuccess($form);
        }

        // If method not Post or form not valid , Return
        if ($this->getRequest()->isPost()) {
            // Process
            $table = Engine_Api::_()->getDbtable('groups', 'calendar');
            $memberTable = Engine_Api::_()->getDbtable('groupmembers', 'calendar');
            $db = $table->getAdapter();
            $db->beginTransaction();

            try {
                // Create Calendar
                $viewer = Engine_Api::_()->user()->getViewer();
                $values = array();
                $getForm = Engine_Api::_()->getApi('Siteapi_Core', 'calendar')->getGroupForm();
                foreach ($getForm as $element) {
                    if (isset($_REQUEST[$element['name']]))
                        $values[$element['name']] = $_REQUEST[$element['name']];
                }
                $data = $formValues = $values;

                // START FORM VALIDATION
                $validators = Engine_Api::_()->getApi('Siteapi_FormValidators', 'calendar')->getGroupFormValidators();
                $data['validators'] = $validators;
                $validationMessage = $this->isValid($data);

                if(!empty($formValues['title']))
                    $groups = $table->fetchRow($table->select()->where('title LIKE ?',$formValues['title']));

                if(!empty($groups)){
                    $validationMessage = (is_array($validationMessage)) ? $validationMessage : array();
                    $validationMessage['title'] = $this->translate('This title is already taken, please try another');
                }
                if (!empty($validationMessage) && @is_array($validationMessage)) {
                    $this->respondWithValidationError('validation_fail', $validationMessage);
                }
                $toValues = explode(",",$_REQUEST['toValues']);
                $members = array();
                foreach ($toValues as $data) {
                    if(strpos($data, '1111') !== false) {
                        $members[] = substr($data, 0, -4);
                    }
                }
                $non_members = explode(',', $formValues['non_members']);
                $resources = array_unique(array_merge($members, $non_members));

                $values = array_merge($formValues, array(
                    'owner_id' => $viewer->getIdentity(),
                ));

                $group = $table->createRow();
                $group->setFromArray($values);
                $group->save();

                // Set photo
                if( !empty($_FILES['photo']) ) {
                    $group->setPhoto($_FILES['photo'],1);
                }
                $row = $memberTable->createRow();
                $row->group_id = $group->group_id;
                $row->user_email = $viewer->email;
                $row->save();
                foreach ($resources as $resource) {
                    $user = Engine_Api::_()->getItem('user', $resource);
                    $row = $memberTable->createRow();
                    $row->group_id = $group->group_id;
                    if(!empty($user->email)) {
                        $row->user_email = $user->email;
                        $row->save();
                        Engine_Api::_()->getDbtable('calendars', 'calendar')->addCustomNotifications($user, $viewer, $group, 'group_member_add');
                    } else if(!empty($resource)) {
                        $row->user_email = $resource;
                        $row->save();
                    } 
                }
                // Commit
                $db->commit();
            } catch( Exception $e ) {
                $db->rollBack();
                $this->respondWithValidationError('internal_server_error', $e->getMessage());
            }
            $this->setRequestMethod();
            $this->_forward('view', 'group', 'calendar', array(
                'group_id' => $group->getIdentity(),
            ));
        }
    }

    public function editAction()
    {
        $viewer = Engine_Api::_()->user()->getViewer();
        $group = Engine_Api::_()->getItem('calendar_group', $this->_getParam('group_id'));

        if( !$group )
            $this->respondWithError("unauthorized");

        if( !Engine_Api::_()->core()->hasSubject('calendar_group') ) {
            Engine_Api::_()->core()->setSubject($group);
        }

        if( !$this->_helper->requireSubject()->isValid() )
            $this->respondWithError("unauthorized");
        $edit = 1;
        if ($this->getRequest()->isGet()) {
            $form['form'] = Engine_Api::_()->getApi('Siteapi_Core', 'calendar')->getGroupForm($edit);
            $form['formValues'] = $group->toArray();
            $getContentImages = Engine_Api::_()->getApi('Core', 'siteapi')->getContentImage($group);
            $form['formValues']['image_icon'] = $getContentImages['image_icon'];
            $this->respondWithSuccess($form);
        }

        // Check post/form
        if( $this->getRequest()->isPost() ) {

            // Process
            $db = Engine_Db_Table::getDefaultAdapter();
            $db->beginTransaction();

            try {
                $getForm = Engine_Api::_()->getApi('Siteapi_Core', 'calendar')->getGroupForm($edit);
                foreach ($getForm as $element) {
                    if (isset($_REQUEST[$element['name']]))
                        $values[$element['name']] = $_REQUEST[$element['name']];
                }

                $data = $values;
                // START FORM VALIDATION
                $validators = Engine_Api::_()->getApi('Siteapi_FormValidators', 'calendar')->getGroupFormValidators();
                $data['validators'] = $validators;
                $validationMessage = $this->isValid($data);
                
                $calendarGroupTable = Engine_Api::_()->getDbtable('groups', 'calendar');
                $groups = $calendarGroupTable->fetchAll($calendarGroupTable->select()->where('title LIKE ?',$values['title']));
                foreach($groups as $value){
                    if($value->group_id != $this->_getParam('group_id')){
                      $validationMessage['title'] = $this->translate('This title is already taken, please try another');    
                    }
                }

                $group->setFromArray($values);
                $group->modified_date = date('Y-m-d H:i:s');
                $group->save();

                if( !empty($_FILES['photo']) ) {
                    $group->setPhoto($_FILES['photo'],1);
                }

                $db->commit();
                $this->successResponseNoContent('no_content', true);

            }
            catch( Exception $e ) {
                $db->rollBack();
                $this->respondWithValidationError('internal_server_error', $e->getMessage());
            }
        }
    }

    public function deleteAction()
    {
        // Validate request methods
        $this->validateRequestMethod('DELETE');
        $viewer = Engine_Api::_()->user()->getViewer();
        $group = Engine_Api::_()->getItem('calendar_group', $this->getRequest()->getParam('group_id'));


        if( !$group ) {
            $this->respondWithError("unauthorized","Group doesn't exist or not authorized to delete");
        }

        $db = $group->getTable()->getAdapter();
        $db->beginTransaction();

        try {
            // Get all members
            $members = Engine_Api::_()->getItemTable('calendar_groupmember')->getAllMembers($this->getRequest()->getParam('group_id')); 
            foreach ($members as $member) {
                $member->delete();
            }
            $group->delete();

            $db->commit();
            $this->successResponseNoContent('no_content', true);
        } catch( Exception $e ) {
            $db->rollBack();
            $this->respondWithValidationError('internal_server_error', $e->getMessage());
        }

    }

    public function addMembersAction() {
        $viewer = Engine_Api::_()->user()->getViewer();
        $group = Engine_Api::_()->getItem('calendar_group', $this->getRequest()->getParam('group_id'));

        if ($this->getRequest()->isGet()) {
            $form['form'] = Engine_Api::_()->getApi('Siteapi_Core', 'calendar')->addGroupMemberForm();
            $this->respondWithSuccess($form);
        }


        if( !$group ) {
            $this->respondWithError("unauthorized","Group doesn't exist");
        }

        if($this->getRequest()->isPost()) {
        
            $db = $group->getTable()->getAdapter();
            $db->beginTransaction();
            $memberTable = Engine_Api::_()->getDbtable('groupmembers', 'calendar');

            try {
                $viewer = Engine_Api::_()->user()->getViewer();

                $members = explode(",",$_REQUEST['toValues']);
                $non_members = explode(',', $_REQUEST['non_members']);
                $resources = array_unique (array_merge ($members, $non_members));

                foreach ($resources as $resource) {
                    $user = Engine_Api::_()->getItem('user', $resource);
                    $row = $memberTable->createRow();
                    $row->group_id = $group->group_id;
                    if(!empty($user->email)) {
                        $row->user_email = $user->email;
                        $row->save();
                        Engine_Api::_()->getDbtable('calendars', 'calendar')->addCustomNotifications($user, $viewer, $group, 'group_member_add');
                    } else if(!empty($resource)) {
                        $row->user_email = $resource;
                        $row->save();
                    } 
                }
                $db->commit();
                $this->successResponseNoContent('no_content', true);
            } catch( Exception $e ) {
                $db->rollBack();
                $this->respondWithValidationError('internal_server_error', $e->getMessage());
            }
        }
    }

    public function removeMemberAction() {

        // Validate request methods
        $this->validateRequestMethod('DELETE');
        
        $group_id = $this->getRequest()->getParam('group_id');
        $user_email = $this->getRequest()->getParam('user_email');
        $viewer = Engine_Api::_()->user()->getViewer();
        $group = Engine_Api::_()->getItem('calendar_group', $group_id);

        $db = Engine_Db_Table::getDefaultAdapter();
        $db->beginTransaction();
        $memberTable = Engine_Api::_()->getDbtable('groupmembers', 'calendar');

        try {
            $memberTable->delete(array('group_id = ?'=> $group_id, 'user_email = ?' => $user_email));
            $userTable = Engine_Api::_()->getDbtable('users', 'user');
            $select = $userTable->select()
                              ->where('email = ? ', $user_email);
            $member = $userTable->fetchRow($select);
            if((!empty($member->email)) && ($user_email == $viewer->email)) {
                Engine_Api::_()->getDbtable('calendars', 'calendar')->addCustomNotifications($group->getOwner(), $viewer, $group, 'group_member_left');
            } elseif(!empty($member->email)) {
                Engine_Api::_()->getDbtable('calendars', 'calendar')->addCustomNotifications($member, $group->getOwner(), $group, 'group_member_remove');
            }
            $db->commit();
            $this->successResponseNoContent('no_content', true);
        } catch( Exception $e ) {
            $db->rollBack();
            $this->respondWithValidationError('internal_server_error', $e->getMessage());
        }

    }

    public function suggestMemberAction() {
        // Validate request methods
        $this->validateRequestMethod();
        $viewer = Engine_Api::_()->user()->getViewer();

        if ($viewer->getIdentity()) {
            $data = array();
            $search_text = $this->getRequestParam('to', null);
            $limit = $this->getRequestParam('limit', 10);

            $data = array();
            $group_id = $this->getRequestParam('group_id');

            if (!empty($group_id))
                $moduleContents = Engine_Api::_()->getItemTable('calendar_groupmember')->getUsers($search_text, $limit = 10, $group_id);
            else
                $moduleContents = Engine_Api::_()->getItemTable('calendar')->getUsers($search_text, $limit = 10);

            foreach ($moduleContents as $user) {
                $tempData['type'] = 'user';
                $tempData['id'] = $user->getIdentity();
                $tempData['guid'] = $user->getIdentity().'1111';
                $tempData['label'] = $user->getTitle();

                // Add images
                $getContentImages = Engine_Api::_()->getApi('Core', 'siteapi')->getContentImage($user);
                $tempData = array_merge($tempData, $getContentImages);

                $data[] = $tempData;
            }

            $this->respondWithSuccess($data);
        } 
    }
}
