<?php

/**
 * SocialEngine
 *
 * @category   Application_Extensions
 * @package    Document
 * @copyright  Copyright 2016-2017 BigStep Technologies Pvt. Ltd.
 * @license    http://www.socialengineaddons.com/license/
 * @version    $Id: GDSEMedia.php 6590 2016-07-12 9:40:21Z SocialEngineAddOns $
 * @author     SocialEngineAddOns
 */
include_once APPLICATION_PATH . '/application/modules/Document/Api/Google/Google_Client.php';
include_once APPLICATION_PATH . '/application/modules/Document/Api/Google/contrib/Google_DriveService.php';

class GDSEMedia {

    protected $scope = array('https://www.googleapis.com/auth/drive');
    private $_service;

    public function __construct($clientId = null, $serviceAccountName = null, $key = null, $getGoogleClientSecretKey = null, $checkAuth = null) {

        $client = new Google_Client();
        $client->setApplicationName("Google Drive SocialEngine Media");
        $base = Zend_Controller_Front::getInstance()->getBaseUrl();
        $url = ((!empty($_ENV["HTTPS"]) && 'on' == strtolower($_ENV["HTTPS"])) ? "https://" : "http://") . $_SERVER['HTTP_HOST'] . $base . '/admin/document/settings';
        $document_hide_old_fields = Engine_Api::_()->getApi('settings', 'core')->getSetting('document.hide.old.fields', 0);

        if (!$document_hide_old_fields && Engine_Api::_()->getApi('settings', 'core')->getSetting('document.client.id')) {
            $client->setClientId(Engine_Api::_()->getApi('settings', 'core')->getSetting('document.client.id'));
            $client->setAssertionCredentials(new Google_AssertionCredentials(
                    $serviceAccountName, $this->scope, $this->getKonten($key))
            );
            $this->_service = new Google_DriveService($client);
        } else {
            $client->setClientId($clientId);
            $client->setClientSecret($getGoogleClientSecretKey);
            $client->setRedirectUri($url);
            $client->setScopes($this->scope);

            if ($checkAuth) {
                $client->authenticate();
            } else {
                $refreshToken = Engine_Api::_()->getApi('settings', 'core')->getSetting('document.google.refresh.token');
                if (isset($_GET['code']) && !$refreshToken) {
                    $this->_service = new Google_DriveService($client);
                    $client->authenticate($_GET['code']);
                    $token = json_decode($client->getAccessToken());
                    Engine_Api::_()->getApi('settings', 'core')->setSetting('document.google.refresh.token', $token->refresh_token);
                    $tokens = $client->getAccessToken();
                    $client->setAccessToken($tokens);
                } else {
                    if ($refreshToken) {
                        $client->refreshToken($refreshToken);
                        $tokens = $client->getAccessToken();
                        $client->setAccessToken($tokens);
                    }
                    $this->_service = new Google_DriveService($client);
                }
            }
        }
    }

    public function getService() {
        try {
            return $this->_service;
        } catch (Exception $ex) {
            return false;
        }
        
    }

    public function __get($name) {
        try {
            return $this->_service->$name;
        } catch (Exception $ex) {
            return false;
        }
        
    }

    public function getKonten($url) {
        if (function_exists('curl_version')) {
            $data = curl_init();
            curl_setopt($data, CURLOPT_RETURNTRANSFER, 1);
            curl_setopt($data, CURLOPT_URL, $url);
            curl_setopt($data, CURLOPT_FOLLOWLOCATION, TRUE);
            curl_setopt($data, CURLOPT_SSL_VERIFYPEER, FALSE);
            curl_setopt($data, CURLOPT_SSL_VERIFYHOST, FALSE);
            curl_setopt($data, CURLOPT_USERAGENT, 'Mozilla/5.0 (Windows; U; Windows NT 6.1; rv:2.2) Gecko/20110201');
            $hasil = curl_exec($data);
            curl_close($data);
            return $hasil;
        } else {
            $hasil = file_get_contents(str_replace(' ', '%20', $url));
            return $hasil;
        }
    }

    public function getAboutError() {
        if (isset($this->_aboutError)) {
            return $this->_aboutError;
        }
        return false;
    }

    public function getAbout() {        
        try {
             return $this->_service->about->get();
        } catch (Exception $ex) {
            $this->_aboutError = $ex->getMessage();
            return false;
        }
    }

    public function deleteFile($fileId) {
        $result = $this->_service->files->delete($fileId);
        if (empty($result)) {
            return true;
        } else {
            return false;
        }
    }

    public function getNameFromId($fileId) {
        $file_proper = $this->_service->files->get($fileId);
        $file_name = $file_proper->title;
        return $file_name;
    }

    public function insertProperty($fileId, $key, $value, $visibility = 'PUBLIC') {
        if (!empty($value) || $value != '') {
            $newProperty = new Google_Property();
            $newProperty->setKey($key);
            $newProperty->setValue($value);
            $newProperty->setVisibility($visibility);
            return $this->_service->properties->insert($fileId, $newProperty);
        } else {
            return false;
        }
    }

    public function createFileFromPath($path, $fileName, $description, Google_ParentReference $fileParent = null, $mimeType, $restricted = false) {
        $file = new Google_DriveFile();
        $file->setTitle($fileName);
        $file->setDescription($description);
        $file->setMimeType($mimeType);
        if ($fileParent) {
            $file->setParents(array($fileParent));
        }

         $labelrestricted = $restricted == 1 ? 'false' : 'true';
        $labels = new Google_DriveFileLabels();
        $labels->setRestricted($labelrestricted);
        $file->setLabels($labels);

        $c = array('local' => array('cekbok' => 'checked', 'chunk' => '700', 'retries' => '3'), 'drive' => array('cekbok' => 'checked', 'chunk' => '2', 'retries' => '3'));

        $chunks = $c['drive']['chunk'];
        $max_retries = (int) $c['drive']['retries'];
        $chunkSize = (1024 * 1024) * (int) $chunks; // 2mb chunk
        $fileupload = new Google_MediaFileUpload($mimeType, null, true, $chunkSize);
        $fileupload->setFileSize(filesize($path));
        $mkFile = $this->_service->files->insert($file, array('mediaUpload' => $fileupload));
        $status = false;
        $handle = fopen($path, "rb");
        while (!$status && !feof($handle)) {
            $max = false;
            for ($i = 1; $i <= $max_retries; $i++) {
                $chunked = fread($handle, $chunkSize);
                if ($chunked) {
                    $createdFile = $fileupload->nextChunk($mkFile, $chunked);
                    break;
                } elseif ($i == $max_retries) {
                    $max = true;
                }
            }
            if ($max) {
                if ($createdFile) {
                    $this->_service->files->trash($createdFile['id']);
                }
                $createdFile = false;
                break;
            }
        }
        fclose($handle);
        if ($createdFile) {


            return $createdFile['id'];
        } else {
            return false;
        }
    }

    public function getFolder($email) {

        if (!$this->getFolderIdByName($email)) {
            return $this->createFolder($email);
        } else {
            return $this->getFolderIdByName($email);
        }
    }

    public function createFolder($name) {
        $file = new Google_DriveFile();
        $file->setTitle($name);
        $file->setMimeType('application/vnd.google-apps.folder');

        $createdFolder = $this->_service->files->insert($file, array('mimeType' => 'application/vnd.google-apps.folder'));
        return $createdFolder['id'];
    }

    public function setPermissions($fileId, $value, $role = 'writer', $type = 'user') {
        $perm = new Google_Permission();
        $perm->setValue($value);
        $perm->setType($type);
        $perm->setRole($role);

        return $this->_service->permissions->insert($fileId, $perm);
    }

    public function getFolderIdByName($name) {
        $parameters = array('q' => "mimeType = 'application/vnd.google-apps.folder'", 'maxResults' => 50);
        $files = $this->_service->files->listFiles($parameters);
        foreach ($files['items'] as $item) {
            if ($item['title'] == $name) {
                return $item['id'];
                break;
            }
        }
        return false;
    }

}

?>