<?php

/**
 * SocialEngine
 *
 * @category   Application_Extensions
 * @package    Document
 * @copyright  Copyright 2016-2017 BigStep Technologies Pvt. Ltd.
 * @license    http://www.socialengineaddons.com/license/
 * @version    $Id: GroupDocuments.php 6590 2016-07-12 9:40:21Z SocialEngineAddOns $
 * @author     SocialEngineAddOns
 */
class Document_Controller_Action_Helper_GroupDocuments extends Zend_Controller_Action_Helper_Abstract {

    function postDispatch() {
        //GET NAME OF MODULE, CONTROLLER AND ACTION
        $front = Zend_Controller_Front::getInstance();
        $module = $front->getRequest()->getModuleName();
        $controller = $front->getRequest()->getControllerName();
        $action = $front->getRequest()->getActionName();
        $view = $this->getActionController()->view;

        if (!(Engine_Api::_()->getDbtable('modules', 'document')->getIntegratedModules(array('enabled' => 1, 'item_type' => 'group', 'item_module' => 'group', 'checked' => 'enabled')))) {
            return;
        }


        //ADD DOCUMENT PRIVACY FIELDS AT GROUP CREATION AND EDITION
        if (($module == 'group' || $module == 'advgroup') && ($action == 'create' || $action == 'edit') && ($controller == 'index' || $controller == 'group')) {
            $new_element = $view->form;

            if (empty($new_element))
                return;

            $total_elements = 0;
            foreach ($new_element->getElements() as $value) {
                if ($value->helper != 'formHidden') {
                    $total_elements += 1;
                }
            }

            $user = Engine_Api::_()->user()->getViewer();

            $availableLabels = array(
                'registered' => 'Registered Members',
                'member' => 'All Group Members',
                'officer' => 'Officers and Owner Only',
            );

            $options = (array) Engine_Api::_()->authorization()->getAdapter('levels')->getAllowed('group', $user, 'auth_gdcreate');
            $options_create = array_intersect_key($availableLabels, array_flip($options));

            if (!empty($options_create)) {
                $new_element->addElement('Select', 'gdcreate', array(
                    'label' => 'Documents Creation Privacy',
                    'description' => 'Who may create documents in this group?',
                    'multiOptions' => $options_create,
                    'order' => $total_elements - 2,
                ));
                $new_element->gdcreate->getDecorator('Description')->setOption('placement', 'append');
            }

            if ($action == 'edit') {
                $group_id = $front->getRequest()->getParam('group_id');
                $group = Engine_Api::_()->getItem('group', $group_id);

                $auth = Engine_Api::_()->authorization()->context;
                $roles = array('officer', 'member', 'registered', 'everyone');

                foreach ($roles as $role) {
                    if (!empty($options_create)) {
                        if (1 === $auth->isAllowed($group, $role, 'gdcreate')) {
                            $new_element->gdcreate->setValue($role);
                        }
                    }
                }

                $authorization_table = Engine_Api::_()->getDbtable('allow', 'authorization');
                $authorization_tableName = $authorization_table->info('name');
                $gd_create_authorization = $authorization_table->select()
                        ->from($authorization_tableName, 'role')
                        ->where('resource_id = ?', $group_id)
                        ->where('action = ?', 'gdcreate');
                $create_authorizations = $gd_create_authorization->query()->fetchAll();
                $create_authorization_count = Count($create_authorizations);
                if ($create_authorization_count > 0) {
                    if ($create_authorization_count == 1 && $create_authorizations['0']['role'] == 'group_list' && !empty($options_create)) {
                        $set_value = 'officer';
                        $new_element->gdcreate->setValue($set_value);
                    }
                }
            }
        }
    }

}
