<?php

/**
 * SocialEngine
 *
 * @category   Application_Extensions
 * @package    Document
 * @copyright  Copyright 2016-2017 BigStep Technologies Pvt. Ltd.
 * @license    http://www.socialengineaddons.com/license/
 * @version    $Id: Create.php 6590 2016-07-12 9:40:21Z SocialEngineAddOns $
 * @author     SocialEngineAddOns
 */
class Document_Form_Create extends Engine_Form {

    protected $_defaultProfileId; 
    protected $_parentTypeItem;
    
    public function getDefaultProfileId() {
        return $this->_defaultProfileId;
    }

    public function setDefaultProfileId($default_profile_id) {
        $this->_defaultProfileId = $default_profile_id;
        return $this;
    } 

    public function setParentTypeItem($item) {
        $this->_parentTypeItem = $item;
    }

    public function getParentTypeItem() {
        return $this->_parentTypeItem;
    }

    public function init() {
        $this
                ->setTitle('Upload New Document')
                ->setDescription("Upload your new document by filling the information below, then click 'Submit'.")
                ->setAttrib('id', 'form-upload-document')
                ->setAttrib('name', 'document_create')
                ->setAttrib('enctype', 'multipart/form-data')
                ->setAction(Zend_Controller_Front::getInstance()->getRouter()->assemble(array()));

        $settings = Engine_Api::_()->getApi('settings', 'core');
        $viewer = Engine_Api::_()->user()->getViewer();
        $level_id = $viewer->level_id;
        if ( !empty( $this->getParentTypeItem() )) {
            $parentType = $this->getParentTypeItem()->getType();
            $shortTypeName = $this->getParentTypeItem()->getShortType(1);
        } else {
            $parentType = '';
            $shortTypeName = '';
        }

        $this->addElement('Text', 'document_title', array(
            'label' => 'Document Title',
            'required' => true,
            'filters' => array(
                new Engine_Filter_Censor(),
                'StripTags',
            ),
        ));

        $filter = new Engine_Filter_Html();
        $editorAllow = $settings->getSetting('document.show.editor', 1);
        if ($editorAllow) {
            $this->addElement('TinyMce', 'document_description', array(
                'label' => 'Document description',
                'required' => false,
                'allowEmpty' => true,
                'filters' => array(
                    new Engine_Filter_Censor(),
                    $filter,
                ),
                'editorOptions' => Engine_Api::_()->seaocore()->tinymceEditorOptions(),
            ));
        } else {
            $this->addElement('textarea', 'document_description', array(
                'label' => 'Document description',
                'attribs' => array('rows' => 24, 'cols' => 80, 'style' => 'width:300px; max-width:553px;height:120px;'),
                'filters' => array(
                    $filter,
                    new Engine_Filter_Censor(),
                ),
            ));
        }

        $categories = Engine_Api::_()->getDbTable('categories', 'document')->getCategories(0, 0);
        if (count($categories) != 0) {
            $categories_prepared[0] = "";
            foreach ($categories as $category) {
                $categories_prepared[$category->category_id] = $category->category_name;
            }

            $defaultProfileId = "0_0_" . $this->getDefaultProfileId();
            $onChangeEvent = "showFields(this.value, 1); subcategories(this.value, '', '');";
            $this->addElement('Select', 'category_id', array(
                'label' => 'Category',
                'allowEmpty' => false,
                'required' => true,
                'multiOptions' => $categories_prepared,
                'onchange' => $onChangeEvent
            ));

            $this->addElement('Select', 'subcategory_id', array(
                'RegisterInArrayValidator' => false,
                'allowEmpty' => true,
                'required' => false,
                'decorators' => array(array('ViewScript', array(
                            'viewScript' => 'application/modules/Document/views/scripts/_formSubcategory.tpl',
                            'class' => 'form element')))
            ));

            $this->addElement('Select', 'subsubcategory_id', array(
                'RegisterInArrayValidator' => false,
                'allowEmpty' => true,
                'required' => false,
                'decorators' => array(array('ViewScript', array(
                            'viewScript' => 'application/modules/Document/views/scripts/_formSubcategory.tpl',
                            'class' => 'form element')))
            ));
        }

        $customFields = new Document_Form_Custom_Standard(array(
            'item' => 'document',
            'decorators' => array(
                'FormElements'
        )));
        $customFields->removeElement('submit');
        if ($customFields->getElement($defaultProfileId)) {
            $customFields->getElement($defaultProfileId)
                    ->clearValidators()
                    ->setRequired(false)
                    ->setAllowEmpty(true);
        }
        $this->addSubForms(array(
            'fields' => $customFields
        ));

        $filesize = Engine_Api::_()->authorization()->getPermission($level_id, 'document', 'filesize');
        $extension = '';
        if (!$settings->getSetting('document.uploaded.extension', 0)) {
            $extension = $settings->getSetting('document.extension.type', 'pdf, txt, ps, rtf, epub, odt, odp, ods, odg, odf, sxw, sxc, sxi, sxd, doc, ppt, pps, xls, docx, pptx, ppsx, xlsx, tif, tiff, jpg,jpeg,png,gif');
            $description = Zend_Registry::get('Zend_Translate')->_('Browse and choose a file for your document. Maximum permissible size: %1$s KB and allowed file types: %2$s');
        } else {
            $description = Zend_Registry::get('Zend_Translate')->_('Browse and choose a file for your document.');
        }

        $description = sprintf($description, $filesize, $extension);
        $this->addElement('File', 'filename', array(
            'label' => 'Document File',
            'required' => true,
            'description' => $description
        ));
        $this->filename->getDecorator('Description')->setOption('placement', 'append');

        if ($settings->getSetting('document.thumbnail', 0)) {
            $this->addElement('File', 'documentthumbnail', array(
                'label' => "Document's Main Photo",
                'description' => 'If you do not upload Document’s main photo then default thumbnail image return by Google will be displayed here.',
                'required' => false
            ));
            $this->documentthumbnail->addValidator('Extension', false, 'jpg,jpeg,png,gif');
            $this->documentthumbnail->getDecorator('Description')->setOption('placement', 'append');
        }


        $this->addElement('Text', 'tags', array(
            'label' => 'Tags (Keywords)',
            'autocomplete' => 'off',
            'description' => 'Separate tags with commas.',
            'filters' => array(
                new Engine_Filter_Censor(),
            ),
        ));
        $this->tags->getDecorator("Description")->setOption("placement", "append");

        $this->addElement('Select', 'draft', array(
            'label' => 'Status',
            'multiOptions' => array("0" => "Published", "1" => "Saved As Draft"),
            'description' => 'If this entry is published, it cannot be switched back to draft mode.'
        ));
        $this->draft->getDecorator('Description')->setOption('placement', 'append');

        $profile_doc = Engine_Api::_()->authorization()->getPermission($level_id, 'document', 'profile_doc');
        $profile_doc_show = Engine_Api::_()->authorization()->getPermission($level_id, 'document', 'profile_doc_show');
        if ($profile_doc == 1 && $profile_doc_show == 1) {
            $this->addElement('Radio', 'profile_doc', array(
                'label' => 'Make Profile Document',
                'multiOptions' => array(
                    1 => 'Yes, make this your Profile Document. (Note: At any time only one document can be showcased as your Profile Document. Thus, if you have made any document as your profile document currently, then it will be changed to this one.)',
                    0 => 'No, do not make this your Profile Document.'
                ),
                'value' => 0,
            ));
        }

        $download_allow = Engine_Api::_()->authorization()->getPermission($level_id, 'document', 'download_allow');
        $download_show = Engine_Api::_()->authorization()->getPermission($level_id, 'document', 'download_show');
        if ($download_allow == 1 && $download_show == 1) {
            $this->addElement('Radio', 'download_allow', array(
                'label' => 'Allow Document Download',
                'multiOptions' => array(
                    1 => 'Yes, allow document download.',
                    0 => 'No, do not allow document download.'
                ),
                'value' => 1,
            ));
        }

        $email_allow = Engine_Api::_()->authorization()->getPermission($level_id, 'document', 'email_allow');
        $email_show = Engine_Api::_()->authorization()->getPermission($level_id, 'document', 'email_show');
        if ($email_allow == 1 && $email_show == 1) {
            $this->addElement('Radio', 'email_allow', array(
                'label' => 'Allow Email Attachment',
                'multiOptions' => array(
                    1 => 'Yes, allow document to be emailed as attachment.',
                    0 => 'No, do not allow document to be emailed as attachment.'
                ),
                'value' => 1,
            ));
        }

        //NETWORK BASE PAGE VIEW PRIVACY
        if (Engine_Api::_()->document()->documentBaseNetworkEnable()) {
            // Make Network List
            $table = Engine_Api::_()->getDbtable('networks', 'network');
            $select = $table->select()
                    ->from($table->info('name'), array('network_id', 'title'))
                    ->order('title');
            $result = $table->fetchAll($select);

            $networksOptions = array('0' => 'Everyone');
            foreach ($result as $value) {
                $networksOptions[$value->network_id] = $value->title;
            }

            if (count($networksOptions) > 0) {
                $this->addElement('Multiselect', 'networks_privacy', array(
                    'label' => 'Networks Selection',
                    'description' => Zend_Registry::get('Zend_Translate')->_("Select the networks, members of which should be able to see your document. (Press Ctrl and click to select multiple networks. You can also choose to make your document viewable to everyone.)"),
                    'multiOptions' => $networksOptions,
                    'value' => array(0)
                ));
            } else {
                
            }
        }

        $this->addElement('Checkbox', 'search', array(
            'label' => "Show this document in search results.",
            'value' => 1
        ));

        $availableLabels = array(
            'everyone' => 'Everyone',
            'registered' => 'All Registered Members',
            'owner_network' => 'Friends and Networks',
            'owner_member_member' => 'Friends of Friends',
            'owner_member' => 'Friends Only',
            'owner' => 'Just Me'
        );

        $explodeParentType = explode('_', $parentType);
        if (!empty($explodeParentType) && isset($explodeParentType[0]) && isset($explodeParentType[1])) {
            if (Engine_Api::_()->getDbtable('modules', 'core')->isModuleEnabled($explodeParentType[0] . 'member') && (in_array($parentType, array('sitepage_page', 'sitebusiness_business', 'sitegroup_group'))) && (Engine_Api::_()->getDbtable('modules', 'document')->getIntegratedModules(array('enabled' => 1, 'item_type' => $parentType, 'item_module' => $explodeParentType[0])))) {
                $options['parent_member'] = $shortTypeName . ' Members Only';
                $availableLabels = array(
                  'everyone' => 'Everyone',
                  'registered' => 'All Registered Members',
                  'owner_network' => 'Friends and Networks',
                  'owner_member_member' => 'Friends of Friends',
                  'owner_member' => 'Friends Only',
                  'parent_member' => $shortTypeName . ' Members Only',
                  'owner' => 'Just Me'
                  ); 
            } elseif (($parentType == 'siteevent_event') && (Engine_Api::_()->getDbtable('modules', 'document')->getIntegratedModules(array('enabled' => 1, 'item_type' => $parentType, 'item_module' => $explodeParentType[0])))) { 
                $availableLabels = array(
                  'everyone' => 'Everyone',
                  'registered' => 'All Registered Members',
                  'owner_network' => 'Friends and Networks',
                  'owner_member_member' => 'Friends of Friends',
                  'owner_member' => 'Friends Only',
                  'parent_member' => 'Event Guests Only', 
                  'owner' => 'Just Me'
                  );
            }
        } 
        
        $options = (array) Engine_Api::_()->authorization()->getAdapter('levels')->getAllowed('document', $viewer, 'auth_view');
        $options = array_intersect_key($availableLabels, array_flip($options));
        $orderPrivacyHiddenFields = 786590;
        if (count($options) > 1) {
            $this->addElement('Select', 'auth_view', array(
                'label' => 'View Privacy',
                'description' => 'Who may see this document?',
                'multiOptions' => $options,
                'value' => 'everyone',
            ));
            $this->auth_view->getDecorator('Description')->setOption('placement', 'append');
        } elseif (count($options) == 1) {
            $this->addElement('Hidden', 'auth_view', array(
                'value' => key($options),
                'order' => ++$orderPrivacyHiddenFields,
            ));
        } else {
            $this->addElement('Hidden', 'auth_view', array(
                'value' => 'everyone',
                'order' => ++$orderPrivacyHiddenFields,
            ));
        }

        $options = (array) Engine_Api::_()->authorization()->getAdapter('levels')->getAllowed('document', $viewer, 'auth_comment');
        $options = array_intersect_key($availableLabels, array_flip($options));

        if (count($options) > 1) {
            $this->addElement('Select', 'auth_comment', array(
                'label' => 'Comment Privacy',
                'description' => 'Who may post comments on this document?',
                'multiOptions' => $options,
                'value' => 'registered',
            ));
            $this->auth_comment->getDecorator('Description')->setOption('placement', 'append');
        } elseif (count($options) == 1) {
            $this->addElement('Hidden', 'auth_comment', array(
                'value' => key($options),
                'order' => ++$orderPrivacyHiddenFields,
            ));
        } else {
            $this->addElement('Hidden', 'auth_comment', array(
                'value' => 'everyone',
                'order' => ++$orderPrivacyHiddenFields,
            ));
        }

        $this->addElement('Button', 'submit', array(
            'label' => 'Submit',
            'type' => 'submit',
            'decorators' => array(array('ViewScript', array(
                        'viewScript' => '_formButtonCancel.tpl',
                        'class' => 'form element')))
        ));
    }

}
