<?php

/**
 * SocialEngine
 *
 * @category   Application_Extensions
 * @package    Document
 * @copyright  Copyright 2016-2017 BigStep Technologies Pvt. Ltd.
 * @license    http://www.socialengineaddons.com/license/
 * @version    $Id: Categories.php 6590 2016-07-12 9:40:21Z SocialEngineAddOns $
 * @author     SocialEngineAddOns
 */
class Document_Model_DbTable_Categories extends Engine_Db_Table {

    protected $_rowClass = 'Document_Model_Category';

    /**
     * Return subcategories
     *
     * @param int category_id
     * @return all sub categories
     */
    public function getSubCategories($category_id, $fetchColumns = array()) {

        //RETURN IF CATEGORY ID IS EMPTY
        if (empty($category_id)) {
            return;
        }

        //MAKE QUERY
        $select = $this->select();

        if (!empty($fetchColumns)) {
            $select->from($this->info('name'), $fetchColumns);
        }

        $select->where('cat_dependency = ?', $category_id)
                ->order('cat_order');

        //RETURN RESULTS
        return $this->fetchAll($select);
    }

    /**
     * Get all user categories
     * @param int $user_id : user id
     * @return all category list belongs to user id
     */
    public function getUserCategories($user_id) {

        //GET DOCUMENT TABLE
        $tableDocumentName = Engine_Api::_()->getDbtable('documents', 'document')->info('name');

        //GET CATEGORY TABLE NAME
        $tableCategoryName = $this->info('name');

        //MAKE QUERY
        $select = $this->select()
                ->setIntegrityCheck(false)
                ->from($tableCategoryName, array('category_name', 'category_id'))
                ->joinLeft($tableDocumentName, "$tableDocumentName.category_id = $tableCategoryName.category_id", array(''))
                ->group("$tableCategoryName.category_id")
                ->where($tableDocumentName . '.draft = ?', "0")
                ->where($tableDocumentName . '.approved = ?', "1")
                ->where($tableDocumentName . '.status = ?', "1")
                ->where($tableDocumentName . '.owner_id = ?', $user_id)
                ->order($tableCategoryName . '.category_name ASC');

        //RETURN RESULTS
        return $this->fetchAll($select);
    }

    /**
     * Return categories
     *
     * @param int $countDisplay
     * @return all categories
     */
    public function getCategories($countDisplay = 0, $document_owner_id = 0) {

        //GET CATEGORY TABLE NAME
        $categoryTableName = $this->info('name');

        //MAKE QUERY
        $select = $this->select()->where('cat_dependency = ?', 0);

        if (!empty($countDisplay)) {

            //GET DOCUMENT TABLE NAME
            $tableDocumentName = Engine_Api::_()->getDbtable('documents', 'document')->info('name');

            //MAKE QUERY
            $select = $select->setIntegrityCheck(false)
                    ->from($categoryTableName)
                    ->joinLeft($tableDocumentName, $tableDocumentName . '.category_id = ' . $categoryTableName . '.category_id', array('count(' . $tableDocumentName . '.category_id ) as count'))
                    ->group($categoryTableName . '.category_id');

            //CODING FOR DOCUMENT MAIN VIEW PAGE
            if (!empty($document_owner_id)) {
                $select = $select->where($tableDocumentName . '.owner_id = ?', $document_owner_id)
                        ->where($tableDocumentName . '.draft = ?', 0)
                        ->where($tableDocumentName . '.approved = ?', 1)
                        ->where($tableDocumentName . '.status = ?', 1);
            }
        }

        $select = $select->order('cat_order ASC');

        //RETURN DATA
        return $this->fetchAll($select);
    }

    /**
     * Get category object
     * @param int $category_id : category id
     * @return category object
     */
    public function getCategory($category_id) {

        //RETURN CATEGORY OBJECT
        return $this->find($category_id)->current();
    }

    /**
     * Gets all categories and subcategories
     *
     * @param string $category_id
     * @param string $fieldname
     * @param int $documentCondition
     * @param string $document
     * @param  all categories and subcategories
     */
    public function getAllCategories($category_id, $fieldname, $documentCondition, $document, $subcat = null, $limit = 0, $network_based_content = 0) {

        //GET CATEGORY TABLE NAME
        $tableCategoriesName = $this->info('name');

        //GET DOCUMENT TABLE
        $tableDocument = Engine_Api::_()->getDbtable('documents', 'document');
        $tableDocumentName = $tableDocument->info('name');

        //MAKE QUERY
        $select = $this->select()->setIntegrityCheck(false)->from($tableCategoriesName);

        if ($subcat == 1) {
            $select = $select->joinLeft($tableDocumentName, $tableDocumentName . '.' . $fieldname . '=' . $tableCategoriesName . '.category_id', array('count(DISTINCT ' . $tableDocumentName . '.' . $document . ' ) as count'));
        } else {
            $select = $select->joinLeft($tableDocumentName, $tableDocumentName . '.' . $fieldname . '=' . $tableCategoriesName . '.category_id', array('count(' . $tableDocumentName . '.' . $fieldname . ' ) as count'));
        }

        $select = $select->where($tableCategoriesName . '.cat_dependency = ' . $category_id)
                ->group($tableCategoriesName . '.category_id')
                ->order('cat_order');

        if (!empty($limit)) {
            $select = $select->limit($limit);
        }

        if ($documentCondition == 1) {
            $select->where($tableDocumentName . '.status = ?', 1)
                    ->where($tableDocumentName . '.approved = ?', 1)
                    ->where($tableDocumentName . '.draft = ?', 0)
                    ->where($tableDocumentName . ".search = ?", 1);
        }

        if ($network_based_content) {
            $select = $tableDocument->getNetworkBaseSql($select);
        }

        //RETURN DATA
        return $this->fetchAll($select);
    }

    /**
     * Return slug corrosponding to category name
     *
     * @param int $categoryname
     * @return categoryname
     */
    public function getCategorySlug($categoryname) {

        //GET SETTING
        $showslug = Engine_Api::_()->getApi('settings', 'core')->getSetting('document.categorywithslug', 1);

        if (!empty($showslug)) {
            return trim(preg_replace('/-+/', '-', preg_replace('/[^a-z0-9-]+/i', '-', strtolower($categoryname))), '-');
        } else {
            return $categoryname;
        }
    }

    /**
     * Return categories
     *
     * @param int $home_page_display
     * @return categories
     */
    public function getCategoriesByLevel($level = null) {

        $select = $this->select()->order('cat_order');
        switch ($level) {
            case 'category':
                $select->where('cat_dependency =?', 0);
                break;
            case 'subcategory':
                $select->where('cat_dependency !=?', 0);
                $select->where('subcat_dependency =?', 0);
                break;
            case 'subsubcategory':
                $select->where('cat_dependency !=?', 0);
                $select->where('subcat_dependency !=?', 0);
                break;
        }

        return $this->fetchAll($select);
    }

    /**
     * Return categories
     *
     * @param array $category_ids
     * @return all categories
     */
    public function getDocumentCategories($params = array()) {

        //MAKE QUERY
        $select = $this->select();

        //GET CATEGORY TABLE NAME
        $categoryTableName = $this->info('name');

        if (isset($params['orderBy']) && $params['orderBy'] == 'category_name') {
            $select->order('category_name');
        } else {
            $select->order('cat_order');
        }

        if (isset($params['cat_depandancy']) && strlen($params['cat_depandancy']) > 0) {
            $select->where('cat_dependency = ?', 0);
        }

        if (isset($params['sponsored']) && !empty($params['sponsored'])) {
            $select->where('sponsored = ?', 1);
        }

        if (isset($params['fetchColumns']) && !empty($params['fetchColumns'])) {
            $select->setIntegrityCheck(false)->from($categoryTableName, $params['fetchColumns']);
        } else {
            $select->setIntegrityCheck(false)->from($categoryTableName);
        }

        if (isset($params['havingDocuments']) && $params['havingDocuments']) {
            $tableDocument = Engine_Api::_()->getDbTable('documents', 'document');
            $tableDocumentName = $tableDocument->info('name');
            $select->join($tableDocumentName, "$tableDocumentName.category_id = $categoryTableName.category_id", null);
            $select->group('category_id');
        }
        if (isset($params['category_id']) && !empty($params['category_id'])) {
            $select->where("$categoryTableName.category_id in (?)", $params['category_id']);
        }
        if (isset($params['limit']) && !empty($params['limit'])) {
            $select->limit($params['limit']);
        }

        //RETURN DATA
        return $this->fetchAll($select);
    }

    public function getChildMapping($category_id, $profileTypeName = 'profile_type') {

        //GET CATEGORY TABLE NAME
        $categoryTableName = $this->info('name');

        $category = Engine_Api::_()->getItem('document_category', $category_id);

        $select = $this->select()
                ->from($categoryTableName, 'category_id')
                ->where("$profileTypeName != ?", 0)
                ->where("cat_dependency = $category->category_id OR subcat_dependency = $category->category_id");

        return $this->fetchAll($select);
    }

    /**
     * Get profile_type corresponding to category_id
     *
     * @param int category_id
     */
    public function getProfileType($categoryIds = array(), $categoryId = 0, $profileTypeName = 'profile_type') {

        if (!empty($categoryIds)) {
            $profile_type = 0;
            foreach ($categoryIds as $value) {
                $profile_type = $this->select()
                        ->from($this->info('name'), array("$profileTypeName"))
                        ->where("category_id = ?", $value)
                        ->query()
                        ->fetchColumn();

                if (!empty($profile_type)) {
                    return $profile_type;
                }
            }

            return $profile_type;
        } elseif (!empty($categoryId)) {

            //FETCH DATA
            $profile_type = $this->select()
                    ->from($this->info('name'), array("$profileTypeName"))
                    ->where("category_id = ?", $categoryId)
                    ->query()
                    ->fetchColumn();

            return $profile_type;
        }

        return 0;
    }

    /**
     * Return column name
     *
     * @param Varchar $column_name
     * @return column name
     */
    public function getColumnValue($column_name) {

        $column = $this->select()
                ->from($this->info('name'), "$column_name")
                ->where("$column_name <>?", 0)
                ->group("$column_name")
                ->query()
                ->fetchAll(Zend_Db::FETCH_COLUMN);

        return $column;
    }

    /**
     * Get Mapping array
     *
     */
    public function getMapping($profileTypeName = 'profile_type') {

        //MAKE QUERY
        $select = $this->select()->from($this->info('name'), array('category_id', "$profileTypeName"));

        //FETCH DATA
        $mapping = $this->fetchAll($select);

        //RETURN DATA
        if (!empty($mapping)) {
            return $mapping->toArray();
        }

        return null;
    }

    public function getChilds($category_id, $fetchColumns = array()) {

        //GET CATEGORY TABLE NAME
        $categoryTableName = $this->info('name');

        $category = Engine_Api::_()->getItem('document_category', $category_id);

        $select = $this->select()->where("cat_dependency = ?", $category_id);

        if (!empty($fetchColumns)) {
            $select->from($categoryTableName, $fetchColumns);
        } else {
            $select->from($categoryTableName);
        }

        //IF SUBCATEGORY THEN FETCH 3RD LEVEL CATEGORY
        if ($category->cat_dependency != 0 && $category->subcat_dependency == 0) {
            $select->where("subcat_dependency = ?", $category_id);
        }
        //IF CATEGORY THEN FETCH SUB-CATEGORY
        elseif ($category->cat_dependency == 0 && $category->subcat_dependency == 0) {
            $select->where("subcat_dependency = ?", 0);
        }
        //IF 3RD LEVEL CATEGORY
        else {
            return array();
        }

        return $this->fetchAll($select);
    }

    public function uploadDefaultImages() {
        @ini_set('memory_limit', '-1');
        $iconImagesToPath = "/temporary/document_categories_icons";
        $iconImagesfromPath = "/application/modules/Document/externals/images/category_images/document/icons";

        $mainImagesToPath = "/temporary/document_categories_main_images";
        $mainImagesfromPath = "/application/modules/Document/externals/images/category_images/document/main_images";

        $this->setDefaultImages($iconImagesToPath, $iconImagesfromPath, 'icon_id');
        $this->setDefaultImages($mainImagesToPath, $mainImagesfromPath, 'image_id');
    }

    public function setDefaultImages($toPath, $fromPath, $columnName) {
        @mkdir(APPLICATION_PATH . $toPath, 0777);
        $dir = APPLICATION_PATH . $fromPath;
        $public_dir = APPLICATION_PATH . $toPath;
        $fieArr = array();
        if (is_dir($dir) && is_dir($public_dir)) {
            $files = scandir($dir);
            foreach ($files as $file) {
                if($file == '.' || $file == '..')
                    continue;
                
                if (strstr($file, '.png') || strstr($file, '.jpg') || strstr($file, '.gif' || strstr($file, '.jpeg'))) {
                    $fieArr[] = $file;
                    
                    @copy(APPLICATION_PATH . "$fromPath/$file", APPLICATION_PATH . "$toPath/$file");
                }
            }
            @chmod(APPLICATION_PATH . $toPath, 0777);
        }
        //MAKE QUERY
        $select = $this->select()->from($this->info('name'), array('category_id', 'category_name', $columnName));
        
        $categories = $this->fetchAll($select);
        //UPLOAD DEFAULT ICONS
        foreach ($categories as $category) {
            $categoryName = Engine_Api::_()->seaocore()->getSlug($category->category_name, 225);
            
            $iconName = false;
            
            foreach ($fieArr as $f) {
                if (strstr($f, $categoryName)) {
                    $iconName = $f;
                    break;
                }
            }
            if ($iconName == false) {
                continue;
            }
            @chmod(APPLICATION_PATH . $toPath, 0777);
            $file = array();
            if ($columnName == 'icon_id' && !empty($category->icon_id)) {
                continue;
            } else if ($columnName == 'image_id' && !empty($category->image_id)) {
                continue;
            }

            $file['tmp_name'] = APPLICATION_PATH . "$toPath/$iconName";
            $file['name'] = $iconName;
            if (file_exists($file['tmp_name'])) {
                $name = basename($file['tmp_name']);
                $path = dirname($file['tmp_name']);
                $mainName = $path . '/' . $file['name'];
                @chmod($mainName, 0777);
                $photo_params = array(
                    'parent_id' => $category->category_id,
                    'parent_type' => "document_category",
                );

                //RESIZE IMAGE WORK
                $image = Engine_Image::factory();
                $image->open($file['tmp_name']);
                $image->open($file['tmp_name']);
                $image->resample(0, 0, $image->width, $image->height, $image->width, $image->height)
                        ->write($mainName)
                        ->destroy();

                $photoFile = Engine_Api::_()->storage()->create($mainName, $photo_params);
                //UPDATE FILE ID IN CATEGORY TABLE
                if (!empty($photoFile->file_id)) {
                    if ($columnName == 'icon_id') {
                        $category->icon_id = $photoFile->file_id;
                    } else if ($columnName == 'image_id') {
                        $category->image_id = $photoFile->file_id;
                    }
                    $category->save();
                }
            }
        }

        //REMOVE THE CREATED PUBLIC DIRECTORY
        if (is_dir(APPLICATION_PATH . $toPath)) {
            $files = scandir(APPLICATION_PATH . $toPath);
            foreach ($files as $file) {
                $is_exist = file_exists(APPLICATION_PATH . "$toPath/$file");
                if ($is_exist) {
                    @unlink(APPLICATION_PATH . "$toPath/$file");
                }
            }
            @rmdir(APPLICATION_PATH . $toPath);
        }
    }

}
