<?php

/**
 * SocialEngine
 *
 * @category   Application_Extensions
 * @package    Document
 * @copyright  Copyright 2016-2017 BigStep Technologies Pvt. Ltd.
 * @license    http://www.socialengineaddons.com/license/
 * @version    $Id: Document.php 6590 2016-07-12 9:40:21Z SocialEngineAddOns $
 * @author     SocialEngineAddOns
 */
class Document_Model_Document extends Core_Model_Item_Abstract {

    protected $_owner_type = 'user';
    protected $_parent_type = 'user';
    protected $_searchColumns = array('document_title', 'document_description', 'fulltext', 'draft', 'approved', 'status');
    protected $_parent_is_owner = true;

    public function isSearchable() {

        return ( (!isset($this->search) || $this->search) && !empty($this->_searchTriggers) && is_array($this->_searchTriggers) && $this->approved && empty($this->draft) && !empty($this->status));
    }

    public function getMediaType() {
        return 'document';
    }

    public function getParent($type = null) {

        if ($type === 'user') {
            return $this->getOwner(); 
        } 
        $this->_parent_type = $this->parent_type ? : $this->_parent_type;
        $this->_parent_is_owner = $this->_parent_type === $this->_owner_type;
        return parent::getParent($type); 
    }

    public function setPhoto($photo = null) {

        if ($photo) {
            try {
                if ($photo instanceof Zend_Form_Element_File) {
                    $file = $photo->getFileName();
                } else if (is_array($photo) && !empty($photo['tmp_name'])) {
                    $file = $photo['tmp_name'];
                } else if (is_string($photo) && file_exists($photo)) {
                    $file = $photo;
                } else {
                    throw new Document_Model_Exception('invalid argument passed to setPhoto');
                }
            } catch (Exception $e) {
                
            }

            $imageName = basename($file);
            $path = APPLICATION_PATH . DIRECTORY_SEPARATOR . 'temporary';

            $params = array(
                'parent_type' => 'document',
                'parent_id' => $this->document_id
            );

            // Save
            $storage = Engine_Api::_()->storage();

            // Resize image (main)
            $image = Engine_Image::factory();
            $image->open($file)
                    ->resize(720, 720)
                    ->write($path . '/m_' . $imageName)
                    ->destroy();

            // Resize image (normal)
            $image = Engine_Image::factory();
            $image->open($file)
                    ->resize(140, 160)
                    ->write($path . '/in_' . $imageName)
                    ->destroy();

            // Resize image (icon)
            $image = Engine_Image::factory();
            $image->open($file);

            $size = min($image->height, $image->width);
            $x = ($image->width - $size) / 2;
            $y = ($image->height - $size) / 2;

            $image->resample($x, $y, $size, $size, 48, 48)
                    ->write($path . '/is_' . $imageName)
                    ->destroy();

            // Store
            $iMain = $storage->create($path . '/m_' . $imageName, $params);
            $iIconNormal = $storage->create($path . '/in_' . $imageName, $params);
            $iSquare = $storage->create($path . '/is_' . $imageName, $params);

            $iMain->bridge($iIconNormal, 'thumb.normal');
            $iMain->bridge($iSquare, 'thumb.icon');

            // Remove temp files
            @unlink($path . '/m_' . $imageName);
            @unlink($path . '/in_' . $imageName);
            @unlink($path . '/is_' . $imageName);

            $photo_id = $iMain->getIdentity();

            $this->photo_id = $photo_id;
            $this->save();

            return $photo_id;
        }
    }

    /**
     * Create document
     *
     * @param array file_pass 
     * @return create document and return info
     * */
    public function setFile($file_pass) {
        if ($file_pass instanceof Zend_Form_Element_File) {
            $file = $file_pass->getFileName();
        } else if (is_array($file_pass) && !empty($file_pass['tmp_name'])) {
            $file = $file_pass['tmp_name'];
        } else if (is_string($file_pass) && file_exists($file_pass)) {
            $file = $file_pass;
        } else {
            throw new Document_Model_Exception('invalid argument passed to setFile');
        }
        $params = array(
            'parent_type' => 'document',
            'parent_id' => $this->getIdentity()
        );

        try {
            $document_return = Engine_Api::_()->storage()->create($file, $params);
        } catch (Exception $e) {
            $msg = $e->getMessage();
            return $msg;
        }

        if (!empty($document_return->file_id)) {

            //UPDATE FILE INFORMATION INTO DATABASE
            $this->modified_date = new Zend_Db_Expr('NOW()');
            $this->filename_id = $document_return->file_id;
            $this->storage_path = APPLICATION_PATH . '/' . $document_return->storage_path;
            $this->save();

            $storagemodule = Engine_Api::_()->getDbtable('modules', 'core')->getModule('storage');
            $storageversion = $storagemodule->version;
            if ($storageversion < '4.1.1') {
                $file_path = $document_return->storage_path;
            } else {
                $file_path = $document_return->map();
            }

            $document_info = array('document' => $this, 'file_path' => $file_path);

            return $document_info;
        }
    }

    /**
     * Return keywords
     *
     * @param char separator 
     * @return keywords
     * */
    public function getKeywords($separator = ' ') {
        $keywords = array();
        foreach ($this->tags()->getTagMaps() as $tagmap) {
            $tag = $tagmap->getTag();
            $keywords[] = $tag->getTitle();
        }

        if (null === $separator) {
            return $keywords;
        }

        return join($separator, $keywords);
    }

    /**
     * Gets an absolute URL to the page to view this item
     *
     * @return string
     */
    public function getHref($params = array()) {
        $slug = trim(preg_replace('/-+/', '-', preg_replace('/[^a-z0-9-]+/i', '-', strtolower($this->getTitle()))), '-');

        $params = array_merge(array(
            'route' => 'document_detail_view',
            'reset' => true,
            'user_id' => $this->owner_id,
            'document_id' => $this->document_id,
            'slug' => $slug,
                ), $params);
        $route = $params['route'];
        $reset = $params['reset'];
        unset($params['route']);
        unset($params['reset']);
        return Zend_Controller_Front::getInstance()->getRouter()
                        ->assemble($params, $route, $reset);
    }

    /**
     * Return a document title
     *
     * @return title
     * */
    public function getTitle() {
        return $this->document_title;
    }

    /**
     * Return a file name of document
     *
     * @return file name of document
     * */
    public function getDocumentFileName() {

        //GET STORAGE TABLE
        $tableStorage = Engine_Api::_()->getDbtable('files', 'storage');
        $tableStorageName = $tableStorage->info('name');

        //GET DOCUMENT TABLE NAME
        $tableDocumentName = Engine_Api::_()->getDbtable('documents', 'document')->info('name');

        //MAKE QUERY
        $file_name = $tableStorage->select()
                ->setIntegrityCheck(false)
                ->from($tableDocumentName, array(''))
                ->join($tableStorageName, "$tableStorageName.file_id = $this->filename_id", array('name'))
                ->where($tableStorageName . '.parent_type = ?', 'document')
                ->query()
                ->fetchColumn();

        //RETURN RESULTS
        return $file_name;
    }

    /**
     * Gets a proxy object for the comment handler
     *
     * @return Engine_ProxyObject
     * */
    public function comments() {
        return new Engine_ProxyObject($this, Engine_Api::_()->getDbtable('comments', 'core'));
    }

    /**
     * Gets a proxy object for the like handler
     *
     * @return Engine_ProxyObject
     * */
    public function likes() {
        return new Engine_ProxyObject($this, Engine_Api::_()->getDbtable('likes', 'core'));
    }

    /**
     * Gets a proxy object for the tags handler
     *
     * @return Engine_ProxyObject
     * */
    public function tags() {
        return new Engine_ProxyObject($this, Engine_Api::_()->getDbtable('tags', 'core'));
    }

    public function getDocumentExtThumbnailUrl($ext = null) {

        $ext = str_replace(".", "", strrchr($this->storage_path, "."));

        $view = Zend_Registry::isRegistered('Zend_View') ? Zend_Registry::get('Zend_View') : null;

        switch ($ext) {
            case 'mov':
            case 'mp4':
                $fileThumb = 'application/modules/Document/externals/images/icons/play.png';
                $title = $view->translate('Video');
                break;
            case 'jpg':
            case 'jpeg':
            case 'png':
            case 'gif':
                $fileThumb = 'application/modules/Document/externals/images/icons/camera.png';
                $title = $view->translate('Image');
                break;
            default :
                $fileThumb = 'application/modules/Document/externals/images/icons/document.png';
                $title = $view->translate('Document');
        }


        return "<img title=" . $title . " src= " . $view->layout()->staticBaseUrl . $fileThumb . " />";
    }

    public function __get($columnName) {
        if ($columnName == 'thumbnail') {
            return $this->getGoogleThumbNailUrl();
        }
        return parent::__get($columnName);
    }

    public function getGoogleThumbNailUrl() {
        return $this->google_file_id ? 'https://drive.google.com/thumbnail?authuser=0&sz=w220&id=' . $this->google_file_id : null;
    }

    public function getRichContent() {
        $item = $this;
        $view = Zend_Registry::isRegistered('Zend_View') ? Zend_Registry::get('Zend_View') : null;
        $params = array();

        $fsContent = '';
        if ($item->photo_id) {
            $thumb = $view->htmlLink($item->getHref(), '<img src="' . $item->getPhotoUrl() . '" />' . '<div class="document_icon">' . $item->getDocumentExtThumbnailUrl() . '</div>', array('class' => 'document_feed_thumb document_thumb_b_wrapper'));
        } elseif ($item->thumbnail) {
            //$thumb = $view->htmlLink($item->getHref(), '<img src="' . $item->thumbnail . '" />' . '<div class="document_icon"> ' . $item->getDocumentExtThumbnailUrl() . ' </div>', array('class' => 'document_feed_thumb'));
            
            $thumb = $view->htmlLink($item->getHref(), '<img src="' . $item->thumbnail . '" style="width:220px;height:220px;border:1px solid #ccc;background-color:#979797" />' . '<div class="document_icon"> ' . $item->getDocumentExtThumbnailUrl() . ' </div>', array('class' => 'document_feed_thumb'));
        } else {
            $defaultImage = $view->layout()->staticBaseUrl . 'application/modules/Document/externals/images/document_thumb.png';

            $thumb = $view->htmlLink($item->getHref(), '<img src="' . $defaultImage . '" />' . '<div class="document_icon">' . $item->getDocumentExtThumbnailUrl() . '</div>', array('class' => 'document_feed_thumb document_thumb_g_wrapper'));
        }

        // prepare title and description
        $title = "<div class='feed_item_link_title'><a class='sea_add_tooltip_link feed_document_title' rel= \"" . $item->getType() . ' ' . $item->getIdentity() . "\" href='" . $item->getHref($params) . "' >$item->document_title</a></div>";
        $tmpBody = strip_tags($item->document_description);
        $description = "<div class='document_desc'>" . (Engine_String::strlen($tmpBody) > 255 ? Engine_String::substr($tmpBody, 0, 255) . '...' : $tmpBody) . "</div>";

        $documentEmbedded = $thumb . '
            <div class="document_info">' . $title . $description . '</div>';

        return $documentEmbedded;
    }

    public function canView($user = null) {
        if (!($user instanceof User_Model_User))
            $user = Engine_Api::_()->user()->getViewer();
        $can_view = $this->isViewableByNetwork();

        if ($can_view) {
            $can_view = Engine_Api::_()->authorization()->isAllowed($this->getType(), $user, 'view');
        } else {
            // $can_view = Engine_Api::_()->authorization()->isAllowed($this->getType(), $user, 'edit');
        }
        return $can_view;
    }

    public function isViewableByNetwork() {
        $regName = 'view_privacy_' . $this->getGuid();
        if (!Zend_Registry::isRegistered($regName)) {
            $flage = true;
            $enableNetwork = Engine_Api::_()->getApi('settings', 'core')->getSetting('document.network', 0);
            $viewPricavyEnable = Engine_Api::_()->getApi('settings', 'core')->getSetting('document.networkprofile.privacy', 0);
            $viewer = Engine_Api::_()->user()->getViewer();
            if ($enableNetwork && $viewPricavyEnable && !$this->isOwner($viewer)) {
                $networkMembershipTable = Engine_Api::_()->getDbtable('membership', 'network');
                $viewerNetworkIds = $networkMembershipTable->getMembershipsOfIds($viewer);
                if (Engine_Api::_()->document()->documentBaseNetworkEnable()) {
                    if ($this->networks_privacy) {
                        if (!empty($viewerNetworkIds)) {
                            $videoNetworkId = explode(",", $this->networks_privacy);
                            $commanIds = array_intersect($videoNetworkId, $viewerNetworkIds);
                            if (empty($commanIds))
                                $flage = false;
                        } else {
                            $flage = false;
                        }
                    }
                } else {
                    if (!empty($viewerNetworkIds)) {
                        $ownerNetworkIds = $networkMembershipTable->getMembershipsOfIds($this->getOwner('user'));
                        if ($ownerNetworkIds) {
                            $commanIds = array_intersect($ownerNetworkIds, $viewerNetworkIds);
                            if (empty($commanIds))
                                $flage = false;
                        }
                    }
                }
            }
            Zend_Registry::set($regName, $flage);
        } else {
            $flage = Zend_Registry::get($regName);
        }
        return $flage;
    }

}
