<?php

/**
 * SocialEngine
 *
 * @category   Application_Extensions
 * @package    Document
 * @copyright  Copyright 2016-2017 BigStep Technologies Pvt. Ltd.
 * @license    http://www.socialengineaddons.com/license/
 * @version    $Id: Sitemobile.php 2011-05-05 9:40:21Z SocialEngineAddOns $
 * @author     SocialEngineAddOns
 */
class Document_Plugin_Sitemobile {

    protected $_pagesTable;
    protected $_contentTable;

    public function onIntegrated() {

        $this->_pagesTable = Engine_Api::_()->getApi('modules', 'sitemobile')->_pagesTable;
        $this->_contentTable = Engine_Api::_()->getApi('modules', 'sitemobile')->_contentTable;
        //Document
        $this->addDocumentProfileContent();
        $this->addDocumentHomePage();
        $this->addDocumentBrowsePage();
        $this->addDocumentManagePage();
        $this->addDocumentViewPage();

        //include APPLICATION_PATH . "/application/modules/Sitepagedocument/controllers/license/mobileLayoutCreation.php";
    }

    //DELETE USERS BELONGINGS BEFORE THAT USER DELETION
    public function onRenderLayoutMobileSMDefault($event) {
        $view = $event->getPayload();
        if (!($view instanceof Zend_View_Interface)) {
            return;
        }
    }

    //Document
    public function addDocumentProfileContent() {
        // install content areas

        $db = Engine_Db_Table::getDefaultAdapter();
        $page_id = Engine_Api::_()->getApi('modules', 'sitemobile')->getPageId('user_profile_index');

        // Check if it's already been placed
        $select = new Zend_Db_Select($db);
        $select
                ->from($this->_contentTable)
                ->where('page_id = ?', $page_id)
                ->where('type = ?', 'widget')
                ->where('name = ?', 'user_profile_index')
        ;
        $info = $select->query()->fetch();

        if (empty($info)) {

            // container_id (will always be there)
            $select = new Zend_Db_Select($db);
            $select
                    ->from($this->_contentTable)
                    ->where('page_id = ?', $page_id)
                    ->where('type = ?', 'container')
                    ->limit(1);
            $container_id = $select->query()->fetchObject()->content_id;

            // middle_id (will always be there)
            $select = new Zend_Db_Select($db);
            $select
                    ->from($this->_contentTable)
                    ->where('parent_content_id = ?', $container_id)
                    ->where('type = ?', 'container')
                    ->where('name = ?', 'middle')
                    ->limit(1);
            $middle_id = $select->query()->fetchObject()->content_id;

            // tab_id (tab container) may not always be there
            $select
                    ->reset('where')
                    ->where('type = ?', 'widget')
                    ->where('name = ?', 'sitemobile.container-tabs-columns')
                    ->where('page_id = ?', $page_id)
                    ->limit(1);
            $tab_id = $select->query()->fetchObject();
            if ($tab_id && @$tab_id->content_id) {
                $tab_id = $tab_id->content_id;
            } else {
                $tab_id = null;
            }

            // tab on profile
            $db->insert($this->_contentTable, array(
                'page_id' => $page_id,
                'type' => 'widget',
                'name' => 'document.profile-documents',
                'parent_content_id' => ($tab_id ? $tab_id : $middle_id),
                'order' => 1300,
                'params' => '{"title":"Documents","titleCount":true}',
            ));
        }
    }

    public function addDocumentHomePage() {
        $db = Engine_Db_Table::getDefaultAdapter();

        $page_id = Engine_Api::_()->getApi('modules', 'sitemobile')->getPageId('document_index_home');
        // insert if it doesn't exist yet
        if (!$page_id) {
            // Insert page
            $db->insert($this->_pagesTable, array(
                'name' => 'document_index_home',
                'displayname' => 'Documents - Documents Home Page',
                'title' => 'Documents Home Page',
                'description' => 'This is the document home page.',
                'custom' => 0,
            ));
            $page_id = $db->lastInsertId();

            // Insert main
            $db->insert($this->_contentTable, array(
                'type' => 'container',
                'name' => 'main',
                'page_id' => $page_id,
                'order' => 1,
            ));
            $main_id = $db->lastInsertId();

            // Insert main-middle
            $db->insert($this->_contentTable, array(
                'type' => 'container',
                'name' => 'middle',
                'page_id' => $page_id,
                'parent_content_id' => $main_id,
            ));
            $main_middle_id = $db->lastInsertId();

            $db->insert($this->_contentTable, array(
                'type' => 'widget',
                'name' => 'sitemobile.sitemobile-navigation',
                'page_id' => $page_id,
                'parent_content_id' => $main_middle_id,
                'order' => 1,
            ));
            // Insert Advance search
            $db->insert($this->_contentTable, array(
                'type' => 'widget',
                'name' => 'sitemobile.sitemobile-advancedsearch',
                'page_id' => $page_id,
                'parent_content_id' => $main_middle_id,
                'params' => '{"search":"2","title":"","nomobile":"0","name":"sitemobile.sitemobile-advancedsearch"}',
                'order' => 2,
            ));
            // Insert content
            $db->insert($this->_contentTable, array(
                'type' => 'widget',
                'name' => 'document.zero-documents',
                'page_id' => $page_id,
                'parent_content_id' => $main_middle_id,
                'order' => 3,
            ));

            // Insert content
            $db->insert($this->_contentTable, array(
                'type' => 'widget',
                'name' => 'document.middle-column-categories-documents',
                'page_id' => $page_id,
                'parent_content_id' => $main_middle_id,
                'order' => 4,
                'params' => '{"showAllCategories":"0","show2ndlevelCategory":"1","show3rdlevelCategory":"1"}',
            ));
        }
    }

    public function addDocumentBrowsePage() {
        $db = Engine_Db_Table::getDefaultAdapter();

        $page_id = Engine_Api::_()->getApi('modules', 'sitemobile')->getPageId('document_index_browse');
        // insert if it doesn't exist yet
        if (!$page_id) {
            // Insert page
            $db->insert($this->_pagesTable, array(
                'name' => 'document_index_browse',
                'displayname' => 'Documents - Documents Browse Page',
                'title' => 'Documents Browse Page',
                'description' => 'This is the document browse page.',
                'custom' => 0,
            ));
            $page_id = $db->lastInsertId();

            // Insert main
            $db->insert($this->_contentTable, array(
                'type' => 'container',
                'name' => 'main',
                'page_id' => $page_id,
                'order' => 1,
            ));
            $main_id = $db->lastInsertId();

            // Insert main-middle
            $db->insert($this->_contentTable, array(
                'type' => 'container',
                'name' => 'middle',
                'page_id' => $page_id,
                'parent_content_id' => $main_id,
            ));
            $main_middle_id = $db->lastInsertId();

            $db->insert($this->_contentTable, array(
                'type' => 'widget',
                'name' => 'sitemobile.sitemobile-navigation',
                'page_id' => $page_id,
                'parent_content_id' => $main_middle_id,
                'order' => 1,
            ));
            // Insert Advance search
            $db->insert($this->_contentTable, array(
                'type' => 'widget',
                'name' => 'sitemobile.sitemobile-advancedsearch',
                'page_id' => $page_id,
                'parent_content_id' => $main_middle_id,
                'params' => '{"search":"2","title":"","nomobile":"0","name":"sitemobile.sitemobile-advancedsearch"}',
                'order' => 2,
            ));
            // Insert content
            $db->insert($this->_contentTable, array(
                'type' => 'widget',
                'name' => 'document.browse-documents',
                'page_id' => $page_id,
                'parent_content_id' => $main_middle_id,
                'params' => '{"itemCount":"10"}',
                'order' => 3,
            ));
        }
    }

    public function addDocumentManagePage() {
        $db = Engine_Db_Table::getDefaultAdapter();

        $page_id = Engine_Api::_()->getApi('modules', 'sitemobile')->getPageId('document_index_manage');
        // insert if it doesn't exist yet
        if (!$page_id) {
            // Insert page
            $db->insert($this->_pagesTable, array(
                'name' => 'document_index_manage',
                'displayname' => 'Documents - Documents Manage Page',
                'title' => 'Manage Documents',
                'description' => 'This is manage document page.',
                'custom' => 0,
            ));
            $page_id = $db->lastInsertId();

            // Insert main
            $db->insert($this->_contentTable, array(
                'type' => 'container',
                'name' => 'main',
                'page_id' => $page_id,
                'order' => 1,
            ));
            $main_id = $db->lastInsertId();

            // Insert main-middle
            $db->insert($this->_contentTable, array(
                'type' => 'container',
                'name' => 'middle',
                'page_id' => $page_id,
                'parent_content_id' => $main_id,
            ));
            $main_middle_id = $db->lastInsertId();

            $db->insert($this->_contentTable, array(
                'type' => 'widget',
                'name' => 'sitemobile.sitemobile-navigation',
                'page_id' => $page_id,
                'parent_content_id' => $main_middle_id,
                'order' => 1,
            ));
            // Insert Advance search
            $db->insert($this->_contentTable, array(
                'type' => 'widget',
                'name' => 'sitemobile.sitemobile-advancedsearch',
                'page_id' => $page_id,
                'parent_content_id' => $main_middle_id,
                'params' => '{"search":"2","title":"","nomobile":"0","name":"sitemobile.sitemobile-advancedsearch"}',
                'order' => 2,
            ));

            // Insert content
            $db->insert($this->_contentTable, array(
                'type' => 'widget',
                'name' => 'document.manage-documents',
                'page_id' => $page_id,
                'parent_content_id' => $main_middle_id,
                'module' => 'core',
                'order' => 3,
            ));
        }
    }

    public function addDocumentViewPage() {
        $db = Engine_Db_Table::getDefaultAdapter();

        $page_id = Engine_Api::_()->getApi('modules', 'sitemobile')->getPageId('document_index_view');
        // insert if it doesn't exist yet
        if (!$page_id) {
            // Insert page
            $db->insert($this->_pagesTable, array(
                'name' => 'document_index_view',
                'displayname' => 'Documents - Document View Page',
                'title' => 'Document View Page',
                'description' => 'This is document view page.',
                'custom' => 0,
            ));
            $page_id = $db->lastInsertId();

            // Insert main
            $db->insert($this->_contentTable, array(
                'type' => 'container',
                'name' => 'main',
                'page_id' => $page_id,
            ));
            $main_id = $db->lastInsertId();

            // Insert middle
            $db->insert($this->_contentTable, array(
                'type' => 'container',
                'name' => 'middle',
                'page_id' => $page_id,
                'parent_content_id' => $main_id,
                'order' => 2,
            ));
            $middle_id = $db->lastInsertId();

            // Insert content
            $db->insert($this->_contentTable, array(
                'type' => 'widget',
                'name' => 'document.document-view-documents',
                'page_id' => $page_id,
                'parent_content_id' => $middle_id,
                'order' => 2,
            ));
            $db->insert($this->_contentTable, array(
                'type' => 'widget',
                'name' => 'sitemobile.comments',
                'page_id' => $page_id,
                'parent_content_id' => $middle_id,
                'order' => 3,
            ));
        }
    }

}
