<?php

/**
 * SocialEngine
 *
 * @category   Application_Extensions
 * @package    Document
 * @copyright  Copyright 2016-2017 BigStep Technologies Pvt. Ltd.
 * @license    http://www.socialengineaddons.com/license/
 * @version    $Id: IndexController.php 6590 2016-07-12 9:40:21Z SocialEngineAddOns $
 * @author     SocialEngineAddOns
 */
include_once APPLICATION_PATH . '/application/modules/Document/Api/GDSEMedia.php';

class Document_IndexController extends Seaocore_Controller_Action_Standard {

    protected $_document_google_email;
    protected $_document_client_id;
    protected $_document_service_account_name;
    protected $_document_private_key_url_path;
    protected $_GDSEMedia;
    protected $_getGoogleClientSecretKey;

    //COMMON ACTION WHICH CALL BEFORE EVERY ACTION OF THIS CONTROLLER
    public function init() {
        //DOCUMENT VIEW PRIVACY CHECK
        if (!$this->_helper->requireAuth()->setAuthParams('document', null, 'view')->isValid())
            return;
    }

    //ACTION FOR BROWSE LIST DOCUMENT
    public function browseAction() {

        //SHOW WIDGETS
        $coremodule = Engine_Api::_()->getDbtable('modules', 'core')->getModule('core');
        $coreversion = $coremodule->version;
        if ($coreversion < '4.1.0') {
            $this->_helper->content->render();
        } else {
            $this->_helper->content
                    ->setNoRender()
                    ->setEnabled();
        }
    }

    //ACTION FOR SHOWING THE HOME DOCUMENT
    public function homeAction() {

        $coremodule = Engine_Api::_()->getDbtable('modules', 'core')->getModule('core');
        $coreversion = $coremodule->version;
        if ($coreversion < '4.1.0') {
            $this->_helper->content->render();
        } else {
            $this->_helper->content
                    ->setNoRender()
                    ->setEnabled();
        }
    }

    //ACTION FOR MOBILE BROWSE LIST DOCUMENT
    public function mobiBrowseAction() {

        //SHOW WIDGETS
        $coremodule = Engine_Api::_()->getDbtable('modules', 'core')->getModule('core');
        $coreversion = $coremodule->version;
        if ($coreversion < '4.1.0') {
            $this->_helper->content->render();
        } else {
            $this->_helper->content
                    ->setNoRender()
                    ->setEnabled();
        }
    }

    //ACTION FOR MOBILE HOME LIST DOCUMENT
    public function mobiHomeAction() {

        //SHOW WIDGETS
        $coremodule = Engine_Api::_()->getDbtable('modules', 'core')->getModule('core');
        $coreversion = $coremodule->version;
        if ($coreversion < '4.1.0') {
            $this->_helper->content->render();
        } else {
            $this->_helper->content
                    ->setNoRender()
                    ->setEnabled();
        }
    }

    //ACTION FOR SHOW USERS DOCUMENTS
    public function manageAction() {

        global $gdsem_apiConfig;
        //CHECK USER VALIDATION
        if (!$this->_helper->requireUser()->isValid())
            return;

        $this->_helper->content
                ->setNoRender()
                ->setEnabled()
        ;
    }

    //ACTION FOR CREATE THE NEW DOCUMENT
    public function createAction() {

        global $gdsem_apiConfig;

        //CHECK USER VALIDATION
        if (!$this->_helper->requireUser()->isValid())
            return;

        //CHECK IF USER CAN CREATE DOCUMENTS
        if (!$this->_helper->requireAuth()->setAuthParams('document', null, 'create')->isValid())
            return;

        //GET VIEWER DETAIL
        $viewer = Engine_Api::_()->user()->getViewer();
        $viewer_id = $viewer->getIdentity();
        $level_id = $viewer->level_id;

        $documentInfoType = Engine_Api::_()->getApi('settings', 'core')->getSetting('document.info.type');
        $documentGlobalView = Engine_Api::_()->getApi('settings', 'core')->getSetting('document.global.view');
        $documentGlobalType = Engine_Api::_()->getApi('settings', 'core')->getSetting('document.global.type');
        $documentLsettings = Engine_Api::_()->getApi('settings', 'core')->getSetting('document.lsettings');

        //GET NAVIGATION
        $this->view->navigation = Engine_Api::_()->getApi('menus', 'core')->getNavigation('document_main', array(), 'document_main_create');
        $this->_GDSEMedia = $this->getGDSEMedia();
        //GET DOCUMENT TABLE
        $documentTable = Engine_Api::_()->getDbtable('documents', 'document');
        $this->view->gdSEMedia = $this->_GDSEMedia;
        //NUMBER OF DOCUMENTS SHOULD NOT EXCEED FROM ALLOWED LIMIT FOR THIS USER LEVEL
        $this->view->entries = $entries = Engine_Api::_()->authorization()->getPermission($level_id, 'document', 'entries');
        $total_entries = $documentTable->totalUserDocuments($viewer_id);
        if ($entries != 0 && $total_entries >= $entries) {
            $this->view->error_doc_limit = 1;
            return;
        }

        $quataAvailable = true;
        if ($this->_GDSEMedia) {
            $gdsem_apiConfig['use_objects'] = true;
            $quataAvailable = $this->_GDSEMedia->getAbout()->getQuotaBytesTotal() - $this->_GDSEMedia->getAbout()->getQuotaBytesUsed();
        }

        if (!$quataAvailable) {
            $this->view->error_doc_quata = 1;
            return;
        }

        for ($tempCount = 0; $tempCount < strlen($documentLsettings); $tempCount++) {
            $tempGlobalView += @ord($documentLsettings[$tempCount]);
        }
        $tempGlobalView = $tempGlobalView + $documentGlobalView;
        $gdsem_apiConfig['use_objects'] = false;
        //GET DEFAULT PROFILE ID
        $this->view->defaultProfileId = $defaultProfileId = Engine_Api::_()->getDbTable('metas', 'document')->defaultProfileId();

        $parent_type = $this->_getParam('parent_type');
        $parent_id = $this->_getParam('parent_id');

        $this->view->canCreate = $canCreate = Engine_Api::_()->document()->isCreatePrivacy($parent_type, $parent_id);
        if (empty($canCreate))
            return $this->_forwardCustom('requireauth', 'error', 'core');

        $this->view->tab_selected_id = $this->_getParam('tab');
        if (strpos($parent_type, "sitereview_listing") !== false) {
            $this->view->parentTypeItem = $parentTypeItem = Engine_Api::_()->getItem('sitereview_listing', $parent_id);
        } else {
            if ($parent_type && $parent_id)
                $this->view->parentTypeItem = $parentTypeItem = Engine_Api::_()->getItem($parent_type, $parent_id);
        }

        //SHOW DOCUMENT CREATE FORM
        $this->view->form = $form = new Document_Form_Create(
            array('defaultProfileId' => $defaultProfileId,
                'parentTypeItem' => $parentTypeItem     
            )); 
        $coremodule = Engine_Api::_()->getDbtable('modules', 'core')->getModule('core');
        $coreversion = $coremodule->version;
        if ($coreversion < '4.1.0') {
            $this->_helper->content->render();
        } else {
            $this->_helper->content
                    ->setEnabled();
        }

        if ($this->getRequest()->isPost() && $form->isValid($this->getRequest()->getPost())) {
            //BEGIN TRANSCATION
            $db = $documentTable->getAdapter();
            $db->beginTransaction();

            //GET FROM VALUES
            $values = $form->getValues();

            //CATEGORY IS REQUIRED FIELD
            if (empty($values['category_id'])) {
                $error = $this->view->translate('Please complete Category field - it is required.');
                $error = Zend_Registry::get('Zend_Translate')->_($error);

                $form->getDecorator('errors')->setOption('escape', false);
                $form->addError($error);
                return;
            }

            //DOCUMENT CREATION CODE
            try {

                $values = array_merge($form->getValues(), array(
                    'owner_type' => $viewer->getType(),
                    'owner_id' => $viewer_id,
                    'parent_type' => $parent_type,
                    'parent_id' => $parent_id,
                ));
                $this->view->is_error = 0;
                $this->view->excep_error = 0;

                //FILE SIZE SHOULD NOT EXCEED FROM ALLOWED LIMIT FOR THIS LEVEL
                $filesize = Engine_Api::_()->authorization()->getPermission($level_id, 'document', 'filesize');
                $filesize = $filesize * 1024;
                if ($filesize < 0) {
                    $filesize = (int) ini_get('upload_max_filesize') * 1024 * 1024;
                }
                if ($_FILES['filename']['size'] > $filesize) {
                    $error = $this->view->translate('File size can not be exceed from ') . ($filesize / 1024) . $this->view->translate(' KB for this user level');
                    $error = Zend_Registry::get('Zend_Translate')->_($error);
                    $form->getDecorator('errors')->setOption('escape', false);
                    $form->addError($error);
                    return;
                }
                //FILE EXTENSION SHOULD NOT DIFFER FROM ALLOWED TYPE
                $ext = str_replace(".", "", strrchr($_FILES['filename']['name'], "."));
                $settings = Engine_Api::_()->getApi('settings', 'core');
                if ($ext && !$settings->getSetting('document.uploaded.extension', 0)) {
                    $extension = $settings->getSetting('document.extension.type', 'pdf, txt, ps, rtf, epub, odt, odp, ods, odg, odf, sxw, sxc, sxi, sxd, doc, ppt, pps, xls, docx, pptx, ppsx, xlsx, tif, tiff, jpg, jpeg, png, gif');
                    $explodeArrayExtension = explode(", ", $extension);

                    if (!in_array($ext, $explodeArrayExtension)) {
                        $error = $this->view->translate("Invalid file extension. Allowed extensions are : $extension");
                        $error = Zend_Registry::get('Zend_Translate')->_($error);

                        $form->getDecorator('errors')->setOption('escape', false);
                        $form->addError($error);
                        return;
                    }
                }

                // SET DEFAULT VIEW TYPE OF DOCUMENTS
                if (empty($documentGlobalType) && ($documentInfoType != $tempGlobalView)) {
                    Engine_Api::_()->getApi('settings', 'core')->setSetting('document.viewtypeinfo.settings', 0);
                    Engine_Api::_()->getApi('settings', 'core')->setSetting('document.viewtypeinfo.type', 0);
                }

                $illegal_extensions = array('php', 'pl', 'cgi', 'html', 'htm', 'css', 'js');
                if (in_array($ext, $illegal_extensions) || !$ext) {
                    $error = $this->view->translate("Invalid file extension.");
                    $error = Zend_Registry::get('Zend_Translate')->_($error);

                    $form->getDecorator('errors')->setOption('escape', false);
                    $form->addError($error);
                    return;
                }

                if (empty($values['subcategory_id'])) {
                    $values['subcategory_id'] = 0;
                }
                if (empty($values['subsubcategory_id'])) {
                    $values['subsubcategory_id'] = 0;
                }

                if (Engine_Api::_()->document()->documentBaseNetworkEnable()) {
                    if (isset($values['networks_privacy']) && !empty($values['networks_privacy'])) {
                        if (in_array(0, $values['networks_privacy'])) {
                            unset($values['networks_privacy']);
                        }
                    }
                }

                //CREATE THE MAIN DOCUMENT
                $documentRow = $documentTable->createRow();
                $documentRow->setFromArray($values);
                $documentRow->owner_id = $viewer_id;

                //MAKE PROFILE DOCUMENT WORK
                $profile_doc = Engine_Api::_()->authorization()->getPermission($level_id, 'document', 'profile_doc');
                $profile_doc_show = Engine_Api::_()->authorization()->getPermission($level_id, 'document', 'profile_doc_show');
                if ($profile_doc == 1 && $profile_doc_show == 1 && !empty($documentRow->profile_doc)) {
                    //REMOVE OTHER DOCUMENT AS A PROFILE DOCUMENT
                    $documentTable->removeProfileDoc($documentRow->owner_id);
                }

                $documentRow->save();

                //DOWNLOAD ALLOW CHECK
                $download_allow = Engine_Api::_()->authorization()->getPermission($level_id, 'document', 'download_allow');
                $download_show = Engine_Api::_()->authorization()->getPermission($level_id, 'document', 'download_show');
                if (empty($download_allow)) {
                    $documentRow->download_allow = 0;
                } elseif (empty($download_show)) {
                    $documentRow->download_allow = 1;
                } else {
                    $documentRow->download_allow = $values['download_allow'];
                }
                $access = 'public';
                $documentRow->document_private = $access;

                if ($documentRow->document_private == 'public') {
                    $documentRow->secure_allow = 0;
                }

                if (!empty($values['filename'])) {
                    $local_info = $documentRow->setFile($form->filename);
                    $fileName = $_FILES['filename'];
                    $path = $_FILES['filename']['tmp_name'];
                    $name = $fileName['name'];

                    $document_description = $values['document_description'];
                    $folderId = $this->_GDSEMedia->getFolder($viewer->email . '-' . $viewer_id);
                    $this->_GDSEMedia->setPermissions($folderId, $this->_document_google_email);
                    $fileParent = new Google_ParentReference();
                    $fileParent->setId($folderId);


                    // try {
                    $base = Zend_Controller_Front::getInstance()->getBaseUrl();

                    $storagemodule = Engine_Api::_()->getDbtable('modules', 'core')->getModule('storage');
                    $storageversion = $storagemodule->version;
                    if ($storageversion < '4.1.1') {
                        $doc_base_url = "http://" . $_SERVER['HTTP_HOST'] . $base . "/";
                    } else {
                        $doc_base_url = "http://" . $_SERVER['HTTP_HOST'];
                    }

                    $doc_base_url = str_replace("index.php/", '', $doc_base_url);
                    $google_upload_url = $doc_base_url . $local_info['file_path'];

                    $db = Engine_Db_Table::getDefaultAdapter();
                    $type_array = $db->query("SHOW COLUMNS FROM engine4_storage_servicetypes LIKE 'enabled'")->fetch();

                    if ($storageversion >= '4.1.6' && !empty($type_array)) {
                        $storageServiceTypeTable = Engine_Api::_()->getDbtable('serviceTypes', 'storage');
                        $storageServiceTypeTableName = $storageServiceTypeTable->info('name');

                        $storageServiceTable = Engine_Api::_()->getDbtable('services', 'storage');
                        $storageServiceTableName = $storageServiceTable->info('name');

                        $select = $storageServiceTypeTable->select()
                                ->setIntegrityCheck(false)
                                ->from($storageServiceTypeTableName, array(''))
                                ->join($storageServiceTableName, "$storageServiceTypeTableName.servicetype_id = $storageServiceTableName.servicetype_id", array('enabled', 'default'))
                                ->where("$storageServiceTypeTableName.plugin = ?", "Storage_Service_Local")
                                ->where("$storageServiceTypeTableName.enabled = ?", 1)
                                ->limit(1);
                        $storageCheck = $storageServiceTypeTable->fetchRow($select);
                        if (!empty($storageCheck)) {
                            if ($storageCheck->enabled == 1 && $storageCheck->default == 1) {
                                $google_upload_url = $doc_base_url . $local_info['file_path'];
                            } else {
                                $google_upload_url = $local_info['file_path'];
                            }
                        }
                    }


                    //GET STORAGE FILE OBJECT	
                    $storage_file = Engine_Api::_()->getItem('storage_file', $documentRow->filename_id);
                    $google_upload_url = $storage_file->temporary();
                    $mimeType = Engine_Api::_()->document()->get_mime_content_type($google_upload_url);
                    if ($documentInfoType == $tempGlobalView)
                        $fileId = $this->_GDSEMedia->createFileFromPath($google_upload_url, $name, $document_description, $fileParent, $mimeType, $documentRow->download_allow);

                    $this->_GDSEMedia->setPermissions($fileId, 'me', 'reader', 'anyone');
                    $documentRow->google_folder_id = $folderId;
                    $documentRow->google_file_id = $fileId;
                    $documentRow->status = 1;
                    $documentRow->save();
                    $gdsem_apiConfig['use_objects'] = true;
                    $file = $this->_GDSEMedia->files->get($fileId);
                    //  $documentRow->thumbnail = $file->getThumbnailLink();
                }
                $documentRow->save();
                if (Engine_Api::_()->getApi('settings', 'core')->getSetting('document.thumbnail', 0) && $_FILES['documentthumbnail']['name']) {
                    $documentRow->setPhoto($form->documentthumbnail);
                }

                //CHECKS FOR DOCUMENT APPROVEL AT CREATION TIME
                $document_approved = Engine_Api::_()->authorization()->getPermission($level_id, 'document', 'approved');
                if ($document_approved == 1) {
                    $documentRow->approved = 1;
                } else {
                    $documentRow->approved = 0;
                }

                //CHECKS FOR DOCUMENT FEATURED AT CREATION TIME
                $document_featured = Engine_Api::_()->authorization()->getPermission($level_id, 'document', 'featured');
                if ($document_featured == 1) {
                    $documentRow->featured = 1;
                } else {
                    $documentRow->featured = 0;
                }

                //CHECKS FOR DOCUMENT SPONSORED AT CREATION TIME
                $document_sponsored = Engine_Api::_()->authorization()->getPermission($level_id, 'document', 'sponsored');
                if ($document_sponsored == 1) {
                    $documentRow->sponsored = 1;
                } else {
                    $documentRow->sponsored = 0;
                }

                //EMAIL ALLOW CHECK
                $email_allow = Engine_Api::_()->authorization()->getPermission($level_id, 'document', 'email_allow');
                $email_show = Engine_Api::_()->authorization()->getPermission($level_id, 'document', 'email_show');
                if (empty($email_allow)) {
                    $documentRow->email_allow = 0;
                } elseif (empty($email_show)) {
                    $documentRow->email_allow = 1;
                } else {
                    $documentRow->email_allow = $values['email_allow'];
                }

                $documentRow->filemime = $_FILES['filename']['type'];
                $documentRow->filesize = $_FILES['filename']['size'];
                $documentRow->migrated = 1;
                $documentRow->save();

                //DOCUMENT VIEW PRIVACY WORK
                $auth = Engine_Api::_()->authorization()->context;
                $roles = array('owner', 'parent_member', 'owner_member', 'owner_member_member', 'owner_network', 'registered', 'everyone');

                if ($values['auth_view'])
                    $auth_view = $values['auth_view'];
                else
                    $auth_view = "everyone";
                $viewMax = array_search($auth_view, $roles);

                foreach ($roles as $i => $role) {
                    $auth->setAllowed($documentRow, $role, 'view', ($i <= $viewMax));
                }

                //DOCUMENT COMMENT PRIVACY WORK
                $roles = array('owner', 'parent_member', 'owner_member', 'owner_member_member', 'owner_network', 'registered');
                if ($values['auth_comment'])
                    $auth_comment = $values['auth_comment'];
                else
                    $auth_comment = "everyone";
                $commentMax = array_search($auth_comment, $roles);

                foreach ($roles as $i => $role) {
                    $auth->setAllowed($documentRow, $role, 'comment', ($i <= $commentMax));
                }

                //ADDING TAGS
                if (!empty($values['tags'])) {
                    $tags = preg_split('/[,]+/', $values['tags']);
                    $tags = array_filter(array_map("trim", $tags));
                    $documentRow->tags()->addTagMaps($viewer, $tags);
                }

                $documentRow->save();
                //CUSTOM FIELD WORK
                $customfieldform = $form->getSubForm('fields');
                $customfieldform->setItem($documentRow);
                $customfieldform->saveValues();

                $categoryIds = array();
                $categoryIds[] = $documentRow->category_id;
                $categoryIds[] = $documentRow->subcategory_id;
                $categoryIds[] = $documentRow->subsubcategory_id;
                $documentRow->profile_type = Engine_Api::_()->getDbTable('categories', 'document')->getProfileType($categoryIds, 0, 'profile_type');
                $documentRow->save();

                //START PAGE INTEGRATION WORK
                $page_id = $this->_getParam('page_id');
                if (!empty($page_id)) {
                    $viewer_id = Engine_Api::_()->user()->getViewer()->getIdentity();
                    $moduleEnabled = Engine_Api::_()->getDbtable('modules', 'core')->isModuleEnabled('sitepageintegration');
                    if (!empty($moduleEnabled)) {
                        $contentsTable = Engine_Api::_()->getDbtable('contents', 'sitepageintegration');
                        $row = $contentsTable->createRow();
                        $row->owner_id = $viewer_id;
                        $row->resource_owner_id = $documentRow->owner_id;
                        $row->page_id = $page_id;
                        $row->resource_type = 'document';
                        $row->resource_id = $documentRow->document_id;
                        $row->save();
                    }
                }
                //END PAGE INTEGRATION WORK
                //
                //ADD ACTIVITY ONLY IF DOCUMENT IS PUBLISHED
                if ($documentRow->draft == 0 && $documentRow->approved == 1 && $documentRow->status == 1 && $documentRow->activity_feed == 0) {

                    //GET DOCUMENT OWNER OBJECT
                    $creator = Engine_Api::_()->getItem('user', $documentRow->owner_id);
                    //GET ACTIVITY TABLE
                    $activityTable = Engine_Api::_()->getDbtable('actions', 'activity');
                    if ($parent_type == 'sitepage_page') {
                        $sitepage = Engine_Api::_()->getItem('sitepage_page', $parent_id);
                        $action = Engine_Api::_()->getDbtable('actions', 'activity')->addActivity($creator, $sitepage, 'document_sitepage_document_new');
                    } else if ($parent_type == 'sitebusiness_business') {
                        $sitebusiness = Engine_Api::_()->getItem('sitebusiness_business', $parent_id);
                        $action = Engine_Api::_()->getDbtable('actions', 'activity')->addActivity($creator, $sitebusiness, 'document_sitebusiness_document_new');
                    } else if ($parent_type == 'sitegroup_group') {
                        $sitegroup = Engine_Api::_()->getItem('sitegroup_group', $parent_id);
                        $action = Engine_Api::_()->getDbtable('actions', 'activity')->addActivity($creator, $sitegroup, 'document_sitegroup_document_new');
                    } else if ($parent_type == 'sitestore_store') {
                        $sitestore = Engine_Api::_()->getItem('sitestore_store', $parent_id);
                        $action = Engine_Api::_()->getDbtable('actions', 'activity')->addActivity($creator, $sitestore, 'document_sitestore_document_new');
                    } else if ($parent_type == 'siteevent_event') {
                        $siteevent = Engine_Api::_()->getItem('siteevent_event', $parent_id);
                        $action = Engine_Api::_()->getDbtable('actions', 'activity')->addActivity($creator, $siteevent, 'document_siteevent_document_new');
                    } else if ($parent_type == 'group') {
                        $group = Engine_Api::_()->getItem('group', $parent_id);
                        $action = Engine_Api::_()->getDbtable('actions', 'activity')->addActivity($creator, $group, 'document_group_document_new');
                    } else if ($parent_type == 'event') {
                        $event = Engine_Api::_()->getItem('event', $parent_id);
                        $action = Engine_Api::_()->getDbtable('actions', 'activity')->addActivity($creator, $event, 'document_event_document_new');
                    } else {
                        $action = $activityTable->addActivity($creator, $documentRow, 'document_new');
                    }

                    //MAKE SURE ACTION EXISTS BEFORE ATTACHING THE DOUCMENT TO THE ACTIVITY
                    if ($action != null) {
                        $activityTable->attachActivity($action, $documentRow);
                        $documentRow->activity_feed = 1;
                        $documentRow->save();
                    }
                }
                //COMMIT
                $db->commit();
            } catch (Exception $e) {
                $db->rollBack();
                throw $e;
            }


            if ($this->view->tab_selected_id && $this->view->parentTypeItem) {

                return $this->_redirectCustom($this->view->parentTypeItem->getHref(array('tab' => $this->view->tab_selected_id)), array('prependBase' => false));
            } else {
                //RETRUN TO MANAGE DOCUMENT
                $routeStartP = Engine_Api::_()->getApi('settings', 'core')->getSetting('document.manifestUrlP', "documents");
                return $this->_redirect("$routeStartP" . "/manage");
            }
        }
    }

    //ACTION FOR EDIT THE DOCUMENT
    public function editAction() {

        global $gdsem_apiConfig;

        //CHECK USER VALIDATION
        if (!$this->_helper->requireUser()->isValid())
            return;

        //GET VIEWER DETAIL
        $viewer = Engine_Api::_()->user()->getViewer();
        $this->view->viewer_id = $viewer_id = $viewer->getIdentity();
        $level_id = $viewer->level_id;
        $this->_GDSEMedia = $this->getGDSEMedia();
        //GET NAVIGATION
        $this->view->navigation = Engine_Api::_()->getApi('menus', 'core')->getNavigation('document_main');

        //GET DOCUMENT OBJECT
        $this->view->document = $document = Engine_Api::_()->getItem('document', $this->_getParam('document_id'));
        $previous_category_id = $document->category_id;

        $parent_type = $document->parent_type;
        $parent_id = $document->parent_id;
        if ($parent_type && $parent_id) {

            $canEdit = $isParentEditPrivacy = Engine_Api::_()->document()->isEditPrivacy($parent_type, $parent_id, $document);

            if (empty($isParentEditPrivacy))
                return $this->_forward('requireauth', 'error', 'core');
        } else {

            if (!$this->_helper->requireAuth()->setAuthParams($document, $viewer, 'edit')->isValid())
                return;

            if ($viewer->getIdentity() != $document->owner_id && !$this->_helper->requireAuth()->setAuthParams($document, null, 'edit')->isValid()) {
                return $this->_forward('requireauth', 'error', 'core');
            }
        }
        $this->view->tab_selected_id = $this->_getParam('tab');
        if (strpos($parent_type, "sitereview_listing") !== false) {
            $this->view->parentTypeItem = $parentTypeItem = Engine_Api::_()->getItem('sitereview_listing', $parent_id);
        } else {
            if ($parent_type && $parent_id)
                $this->view->parentTypeItem = $parentTypeItem = Engine_Api::_()->getItem($parent_type, $parent_id);
        }

        $documentInfoType = Engine_Api::_()->getApi('settings', 'core')->getSetting('document.info.type');
        $documentGlobalView = Engine_Api::_()->getApi('settings', 'core')->getSetting('document.global.view');
        $documentGlobalType = Engine_Api::_()->getApi('settings', 'core')->getSetting('document.global.type');
        $documentLsettings = Engine_Api::_()->getApi('settings', 'core')->getSetting('document.lsettings');
        $subcategory = Engine_Api::_()->getDbTable('categories', 'document')->getCategory($document->subcategory_id);
        if (!empty($subcategory->category_name)) {
            $this->view->subcategory_name = $subcategory->category_name;
        }

        //GET DEFAULT PROFILE TYPE ID
        $this->view->defaultProfileId = $defaultProfileId = Engine_Api::_()->getDbTable('metas', 'document')->defaultProfileId();

        //GET PROFILE MAPPING ID
        $categoryIds = array();
        $categoryIds[] = $document->category_id;
        $categoryIds[] = $document->subcategory_id;
        $categoryIds[] = $document->subsubcategory_id;
        $this->view->profileType = $previous_profile_type = Engine_Api::_()->getDbtable('categories', 'document')->getProfileType($categoryIds, 0, 'profile_type');
        if (isset($_POST['category_id']) && !empty($_POST['category_id'])) {
            $categoryIds = array();
            $categoryIds[] = $_POST['category_id'];
            if (isset($_POST['subcategory_id']) && !empty($_POST['subcategory_id'])) {
                $categoryIds[] = $_POST['subcategory_id'];
            }
            if (isset($_POST['subsubcategory_id']) && !empty($_POST['subsubcategory_id'])) {
                $categoryIds[] = $_POST['subsubcategory_id'];
            }
            $this->view->profileType = $previous_profile_type = Engine_Api::_()->getDbtable('categories', 'document')->getProfileType($categoryIds, 0, 'profile_type');
        }

        for ($tempCount = 0; $tempCount < strlen($documentLsettings); $tempCount++) {
            $tempGlobalView += @ord($documentLsettings[$tempCount]);
        }
        $tempGlobalView = $tempGlobalView + $documentGlobalView;
        $coremodule = Engine_Api::_()->getDbtable('modules', 'core')->getModule('core');
        $coreversion = $coremodule->version;
        if ($coreversion < '4.1.0') {
            $this->_helper->content->render();
        } else {
            $this->_helper->content
                    ->setEnabled();
        }

        //SHOW DOCUMENT EDIT FORM
        $this->view->form = $form = new Document_Form_Edit(
            array('item' => $document,
                'defaultProfileId' => $defaultProfileId,
                'parentTypeItem' => $parentTypeItem,
             ));

        //REMOVE DRAFT ELEMENT IF ALREADY PUBLISHED
        if ($document->draft == "0") {
            $form->removeElement('draft');
        }

        //SAVE DOCUMENT DETAIL
        $saved = $this->_getParam('saved');
        if (!$this->getRequest()->isPost() || $saved) {
            if ($saved) {
                $url = $this->_helper->url->url(array('user_id' => $document->owner_id, 'document_id' => $document->getIdentity()), 'document_detail_view');
                $form->addNotice(Zend_Registry::get('Zend_Translate')->_('Your changes were saved. Click <a href=\'%1$s\'>here</a> to view your document.', $url));
            }

            //PREPARE TAGS
            $documentTags = $document->tags()->getTagMaps();
            $tagString = '';
            foreach ($documentTags as $tagmap) {
                if ($tagString !== '') {
                    $tagString .= ', ';
                }
                $tagString .= $tagmap->getTag()->getTitle();
            }
            $this->view->tagNamePrepared = $tagString;
            $form->tags->setValue($tagString);

            //SHOW PRE-FIELD FORM
            $form->populate($document->toArray());

            //SHOW PRE-FIELD PRIVACY
            $auth = Engine_Api::_()->authorization()->context;
            $roles = array('owner', 'parent_member', 'owner_member', 'owner_member_member', 'owner_network', 'registered', 'everyone');
            foreach ($roles as $role) {
                if ($form->auth_view) {
                    if (1 === $auth->isAllowed($document, $role, 'view')) {
                        $form->auth_view->setValue($role);
                    }
                }
                if ($form->auth_comment) {
                    if (1 === $auth->isAllowed($document, $role, 'comment')) {
                        $form->auth_comment->setValue($role);
                    }
                }
            }

            if (Engine_Api::_()->document()->documentBaseNetworkEnable()) {
                if (empty($document->networks_privacy)) {
                    $form->networks_privacy->setValue(array(0));
                }
            }

            return;
        }

        //CHECK FORM VALIDATION
        if (!$form->isValid($this->getRequest()->getPost())) {
            return;
        }

        //GET FORM VALUES
        $values = $form->getValues();
        $values['parent_type'] = $parent_type;
        $values['parent_id'] = $parent_id;
        //CATEGORY IS REQUIRED FIELD
        if (empty($values['category_id'])) {
            $error = $this->view->translate('Please complete Category field - it is required.');
            $error = Zend_Registry::get('Zend_Translate')->_($error);

            $form->getDecorator('errors')->setOption('escape', false);
            $form->addError($error);
            return;
        }

        //BEGIN TRANSCATION
        $db = Engine_Db_Table::getDefaultAdapter();
        $db->beginTransaction();

        try {

            if (Engine_Api::_()->document()->documentBaseNetworkEnable() && isset($values['networks_privacy']) && !empty($values['networks_privacy']) && in_array(0, $values['networks_privacy'])) {
                $values['networks_privacy'] = new Zend_Db_Expr('NULL');
                $form->networks_privacy->setValue(array(0));
            }

            $document->setFromArray($values);
            $document->modified_date = new Zend_Db_Expr('NOW()');
            $doc_title = $values['document_title'];
            $description = $values['document_description'];

            //MAKE PROFILE DOCUMENT WORK
            $profile_doc = Engine_Api::_()->authorization()->getPermission($level_id, 'document', 'profile_doc');
            $profile_doc_show = Engine_Api::_()->authorization()->getPermission($level_id, 'document', 'profile_doc_show');
            if ($profile_doc == 1 && $profile_doc_show == 1 && !empty($document->profile_doc)) {
                //REMOVE OTHER DOCUMENT AS A PROFILE DOCUMENT
                Engine_Api::_()->getDbtable('documents', 'document')->removeProfileDoc($document->owner_id);
            }

            if (isset($values['category_id']) && !empty($values['category_id'])) {

                if ($document->profile_type != $previous_profile_type) {

                    $fieldvalueTable = Engine_Api::_()->fields()->getTable('document', 'values');
                    $fieldvalueTable->delete(array('item_id = ?' => $document->document_id));

                    Engine_Api::_()->fields()->getTable('document', 'search')->delete(array(
                        'item_id = ?' => $document->document_id,
                    ));

                    if (!empty($document->profile_type) && !empty($previous_profile_type)) {
                        //PUT NEW PROFILE TYPE
                        $fieldvalueTable->insert(array(
                            'item_id' => $document->document_id,
                            'field_id' => $defaultProfileId,
                            'index' => 0,
                            'value' => $document->profile_type,
                        ));
                    }
                }
                $document->save();
            }

            $documentRow = $document;
            if (!empty($_FILES['filename']['name'])) {

                //FILE SIZE SHOULD NOT EXCEED FROM ALLOWED LIMIT FOR THIS LEVEL
                $filesize = Engine_Api::_()->authorization()->getPermission($level_id, 'document', 'filesize');
                $filesize = $filesize * 1024;
                if ($filesize < 0) {
                    $filesize = (int) ini_get('upload_max_filesize') * 1024 * 1024;
                }
                if ($_FILES['filename']['size'] > $filesize) {
                    $error = $this->view->translate('File size can not be exceed from ') . $filesize . $this->view->translate(' KB for this user level');
                    $error = Zend_Registry::get('Zend_Translate')->_($error);

                    $form->getDecorator('errors')->setOption('escape', false);
                    $form->addError($error);
                    return;
                }

                //FILE EXTENSION SHOULD NOT DIFFER FROM ALLOWED TYPE
                $ext = str_replace(".", "", strrchr($_FILES['filename']['name'], "."));
                $settings = Engine_Api::_()->getApi('settings', 'core');
                if ($ext && !$settings->getSetting('document.uploaded.extension', 0)) {
                    $extension = $settings->getSetting('document.extension.type', 'pdf, txt, ps, rtf, epub, odt, odp, ods, odg, odf, sxw, sxc, sxi, sxd, doc, ppt, pps, xls, docx, pptx, ppsx, xlsx, tif, tiff, jpg, jpeg, png, gif');
                    $explodeArrayExtension = explode(", ", $extension);
                    if (!in_array($ext, $explodeArrayExtension)) {
                        $error = $this->view->translate("Invalid file extension. Allowed extensions are : $extension");
                        $error = Zend_Registry::get('Zend_Translate')->_($error);
                        $form->getDecorator('errors')->setOption('escape', false);
                        $form->addError($error);
                        return;
                    }
                }

                $illegal_extensions = array('php', 'pl', 'cgi', 'html', 'htm', 'css', 'js');
                if (in_array($ext, $illegal_extensions) || !$ext) {
                    $error = $this->view->translate("Invalid file extension.");
                    $error = Zend_Registry::get('Zend_Translate')->_($error);

                    $form->getDecorator('errors')->setOption('escape', false);
                    $form->addError($error);
                    return;
                }


                $local_info = $documentRow->setFile($form->filename);

                if (!empty($values['filename'])) {
                    $fileName = $_FILES['filename'];
                    $path = $local_info['document']->storage_path;
                    $name = $fileName['name'];
                    // $mimeType = $fileName['type'];
                    $document_description = $values['document_description'];

                    $folderId = $this->_GDSEMedia->getFolder($viewer->email);
                    $this->_GDSEMedia->setPermissions($folderId, $this->_document_google_email);

                    $fileParent = new Google_ParentReference();
                    $fileParent->setId($folderId);

                    // try {
                    $base = Zend_Controller_Front::getInstance()->getBaseUrl();

                    $storagemodule = Engine_Api::_()->getDbtable('modules', 'core')->getModule('storage');
                    $storageversion = $storagemodule->version;
                    if ($storageversion < '4.1.1') {
                        $doc_base_url = "http://" . $_SERVER['HTTP_HOST'] . $base . "/";
                    } else {
                        $doc_base_url = "http://" . $_SERVER['HTTP_HOST'];
                    }

                    $doc_base_url = str_replace("index.php/", '', $doc_base_url);
                    $google_upload_url = $doc_base_url . $local_info['file_path'];

                    $db = Engine_Db_Table::getDefaultAdapter();
                    $type_array = $db->query("SHOW COLUMNS FROM engine4_storage_servicetypes LIKE 'enabled'")->fetch();

                    if ($storageversion >= '4.1.6' && !empty($type_array)) {
                        $storageServiceTypeTable = Engine_Api::_()->getDbtable('serviceTypes', 'storage');
                        $storageServiceTypeTableName = $storageServiceTypeTable->info('name');

                        $storageServiceTable = Engine_Api::_()->getDbtable('services', 'storage');
                        $storageServiceTableName = $storageServiceTable->info('name');

                        $select = $storageServiceTypeTable->select()
                                ->setIntegrityCheck(false)
                                ->from($storageServiceTypeTableName, array(''))
                                ->join($storageServiceTableName, "$storageServiceTypeTableName.servicetype_id = $storageServiceTableName.servicetype_id", array('enabled', 'default'))
                                ->where("$storageServiceTypeTableName.plugin = ?", "Storage_Service_Local")
                                ->where("$storageServiceTypeTableName.enabled = ?", 1)
                                ->limit(1);
                        $storageCheck = $storageServiceTypeTable->fetchRow($select);
                        if (!empty($storageCheck)) {
                            if ($storageCheck->enabled == 1 && $storageCheck->default == 1) {
                                $google_upload_url = $doc_base_url . $local_info['file_path'];
                            } else {
                                $google_upload_url = $local_info['file_path'];
                            }
                        }
                    }

                    //GET STORAGE FILE OBJECT	
                    $storage_file = Engine_Api::_()->getItem('storage_file', $documentRow->filename_id);
                    $google_upload_url = $storage_file->temporary();
                    $mimeType = Engine_Api::_()->document()->get_mime_content_type($google_upload_url);
                    if ($documentInfoType == $tempGlobalView)
                        $fileId = $this->_GDSEMedia->createFileFromPath($google_upload_url, $name, $document_description, $fileParent, $mimeType, $documentRow->download_allow);

                    $this->_GDSEMedia->setPermissions($fileId, 'me', 'reader', 'anyone');
                    $documentRow->google_folder_id = $folderId;
                    $documentRow->google_file_id = $fileId;
                    $documentRow->status = 1;
                    $documentRow->save();

                    $gdsem_apiConfig['use_objects'] = true;
                    $file = $this->_GDSEMedia->files->get($fileId);
                    // $documentRow->thumbnail = $file->getThumbnailLink();
                }

                $documentRow->status = 1;
                $documentRow->filemime = $_FILES['filename']['type'];
                $documentRow->filesize = $_FILES['filename']['size'];
                $documentRow->save();
                //FILE UPLOADING WORK END HERE
                //DELETE PREVIOUSELY CREATED THUMBNAIL
                if (!empty($documentRow->photo_id)) {
                    $thumbnail_photo = Engine_Api::_()->getItem('storage_file', $documentRow->photo_id);
                    $thumbnail_photo->delete();
                    $documentRow->photo_id = 0;
                }
            }

            // SET DEFAULT VIEW TYPE OF DOCUMENTS
            if (empty($documentGlobalType) && ($documentInfoType != $tempGlobalView)) {
                Engine_Api::_()->getApi('settings', 'core')->setSetting('document.viewtypeinfo.settings', 0);
                Engine_Api::_()->getApi('settings', 'core')->setSetting('document.viewtypeinfo.type', 0);
            }

            if (Engine_Api::_()->getApi('settings', 'core')->getSetting('document.thumbnail', 0) && $_FILES['documentthumbnail']['name']) {
                $documentRow->setPhoto($form->documentthumbnail);
            }
            $document->save();

            //DOCUMENT VIEW PRIVACY WORK
            $auth = Engine_Api::_()->authorization()->context;
            $roles = array('owner', 'parent_member', 'owner_member', 'owner_member_member', 'owner_network', 'registered', 'everyone');

            if ($values['auth_view'])
                $auth_view = $values['auth_view'];
            else
                $auth_view = "everyone";
            $viewMax = array_search($auth_view, $roles);

            foreach ($roles as $i => $role) {
                $auth->setAllowed($document, $role, 'view', ($i <= $viewMax));
            }

            //DOCUMENT COMMENT PRIVACY WORK
            $roles = array('owner', 'parent_member', 'owner_member', 'owner_member_member', 'owner_network', 'registered');
            if ($values['auth_comment'])
                $auth_comment = $values['auth_comment'];
            else
                $auth_comment = "everyone";
            $commentMax = array_search($auth_comment, $roles);

            foreach ($roles as $i => $role) {
                $auth->setAllowed($document, $role, 'comment', ($i <= $commentMax));
            }

            //HANDLE TAGS
            if (isset($values['tags'])) {
                $tags = preg_split('/[,]+/', $values['tags']);
                $tags = array_filter(array_map("trim", $tags));
                $document->tags()->setTagMaps($viewer, $tags);
            }

//            //CUSTOM FIELD WORK
//            $customfieldform = $form->getSubForm('fields');
//            $customfieldform->setItem($document);
//            $customfieldform->saveValues();

            if (isset($values['category_id']) && !empty($values['category_id'])) {
                $categoryIds = array();
                $categoryIds[] = $document->category_id;
                $categoryIds[] = $document->subcategory_id;
                $categoryIds[] = $document->subsubcategory_id;
                $document->profile_type = Engine_Api::_()->getDbtable('categories', 'document')->getProfileType($categoryIds, 0, 'profile_type');
                if ($document->profile_type != $previous_profile_type) {

                    $fieldvalueTable = Engine_Api::_()->fields()->getTable('document', 'values');
                    $fieldvalueTable->delete(array('item_id = ?' => $document->document_id));

                    Engine_Api::_()->fields()->getTable('document', 'search')->delete(array(
                        'item_id = ?' => $document->document_id,
                    ));

                    if (!empty($document->profile_type) && !empty($previous_profile_type)) {
                        //PUT NEW PROFILE TYPE
                        $fieldvalueTable->insert(array(
                            'item_id' => $document->document_id,
                            'field_id' => $defaultProfileId,
                            'index' => 0,
                            'value' => $document->profile_type,
                        ));
                    }
                }
                $document->save();
            }

            $draft_value = 0;
            if (isset($values['draft'])) {
                $draft_value = $values['draft'];
            }

            //INSERT NEW ACTIVITY IF DOCUMENT IS JUST GETTING PUBLISHED
            $action = Engine_Api::_()->getDbtable('actions', 'activity')->getActionsByObject($document);
            if (count($action->toArray()) <= 0 && $draft_value == 0 && $document->approved == 1 && $document->status == 1 && $document->activity_feed == 0) {

                //GET DOCUMENT OWNER OBJECT
                $creator = Engine_Api::_()->getItem('user', $document->owner_id);

                //GET ACTIVITY TABLE
                $activityTable = Engine_Api::_()->getDbtable('actions', 'activity');


                if ($parent_type == 'sitepage_page') {
                    $sitepage = Engine_Api::_()->getItem('sitepage_page', $parent_id);
                    $action = Engine_Api::_()->getDbtable('actions', 'activity')->addActivity($creator, $sitepage, 'document_sitepage_document_new');
                } else if ($parent_type == 'sitebusiness_business') {
                    $sitebusiness = Engine_Api::_()->getItem('sitebusiness_business', $parent_id);
                    $action = Engine_Api::_()->getDbtable('actions', 'activity')->addActivity($creator, $sitebusiness, 'document_sitebusiness_document_new');
                } else if ($parent_type == 'sitegroup_group') {
                    $sitegroup = Engine_Api::_()->getItem('sitegroup_group', $parent_id);
                    $action = Engine_Api::_()->getDbtable('actions', 'activity')->addActivity($creator, $sitegroup, 'document_sitegroup_document_new');
                } else if ($parent_type == 'sitestore_store') {
                    $sitestore = Engine_Api::_()->getItem('sitestore_store', $parent_id);
                    $action = Engine_Api::_()->getDbtable('actions', 'activity')->addActivity($creator, $sitestore, 'document_sitestore_document_new');
                } else if ($parent_type == 'siteevent_event') {
                    $siteevent = Engine_Api::_()->getItem('siteevent_event', $parent_id);
                    $action = Engine_Api::_()->getDbtable('actions', 'activity')->addActivity($creator, $siteevent, 'document_siteevent_document_new');
                } else if ($parent_type == 'group') {
                    $group = Engine_Api::_()->getItem('group', $parent_id);
                    $action = Engine_Api::_()->getDbtable('actions', 'activity')->addActivity($creator, $group, 'document_group_document_new');
                } else if ($parent_type == 'event') {
                    $event = Engine_Api::_()->getItem('event', $parent_id);
                    $action = Engine_Api::_()->getDbtable('actions', 'activity')->addActivity($creator, $event, 'document_event_document_new');
                } else {

                    $action = $activityTable->addActivity($creator, $document, 'document_new');
                }
                //MAKE SURE ACTION EXISTS BEFOR ATTACHING THE DOCUMENT TO THE ACTIVITY
                if ($action != null) {
                    $activityTable->attachActivity($action, $document);
                    $document->activity_feed = 1;
                    $document->save();
                }
            }
            $actionTable = Engine_Api::_()->getDbtable('actions', 'activity');

            foreach ($actionTable->getActionsByObject($document) as $action) {
                $actionTable->resetActivityBindings($action);
            }

            //COMMIT
            $db->commit();

            if ($this->view->tab_selected_id && $this->view->parentTypeItem) {

                return $this->_redirectCustom($this->view->parentTypeItem->getHref(array('tab' => $this->view->tab_selected_id)), array('prependBase' => false));
            } else {
                //RETRUN TO MANAGE DOCUMENT
                $routeStartP = Engine_Api::_()->getApi('settings', 'core')->getSetting('document.manifestUrlP', "documents");
                return $this->_redirect("$routeStartP" . "/manage");
            }
        } catch (Exception $e) {
            $db->rollBack();
            throw $e;
        }
    }

    //ACTION FOR SHOWING THE HOME DOCUMENT
    public function mobiViewAction() {

        //GET DOCUMNET MODEL
        $document = Engine_Api::_()->getItem('document', $this->_getParam('document_id'));
        if (empty($document)) {
            return $this->_forward('notfound', 'error', 'core');
        } else {
            Engine_Api::_()->core()->setSubject($document);
        }

        //GET VIEWER ID
        $viewer = Engine_Api::_()->user()->getViewer();
        $viewer_id = $viewer->getIdentity();

        //GET USER LEVEL ID
        if (!empty($viewer_id)) {
            $level_id = $viewer->level_id;
        } else {
            $level_id = Engine_Api::_()->getDbtable('levels', 'authorization')->fetchRow(array('type = ?' => "public"))->level_id;
        }

        //WHO CAN VIEW THE DOCUMENTS
        if (!$this->_helper->requireAuth()->setAuthParams($document, null, 'view')->isValid()) {
            return;
        }

        if ($document->parent_type && $document->parent_id) {
            $isParentViewPrivacy = Engine_Api::_()->document()->isParentViewPrivacy($document);
            if (empty($isParentViewPrivacy))
                return $this->_forwardCustom('requireauth', 'error', 'core');
        } else {
            //WHO CAN VIEW THE DOCUMENTS
            $can_view = Engine_Api::_()->authorization()->getPermission($level_id, 'document', 'view');
            if ($can_view != 2 && $viewer_id != $document->owner_id && ($document->draft == 1 || $document->status != 1 || $document->approved != 1)) {
                return $this->_forward('requireauth', 'error', 'core');
            }
        }

        $coremodule = Engine_Api::_()->getDbtable('modules', 'core')->getModule('core');
        $coreversion = $coremodule->version;
        if ($coreversion < '4.1.0') {
            $this->_helper->content->render();
        } else {
            $this->_helper->content
                    ->setNoRender()
                    ->setEnabled();
        }
    }

    //ACTION FOR SHOWING THE HOME DOCUMENT
    public function viewAction() {

        global $gdsem_apiConfig;

        //GET DOCUMNET MODEL
        $document = Engine_Api::_()->getItem('document', $this->_getParam('document_id'));
        if (empty($document)) {
            return $this->_forward('notfound', 'error', 'core');
        } else {
            Engine_Api::_()->core()->setSubject($document);
        }

        //PAGE INTERGRATION PLUGIN PRIVACY WORK
        if (Engine_Api::_()->getDbtable('modules', 'core')->isModuleEnabled('sitepageintegration') || Engine_Api::_()->getDbtable('modules', 'core')->isModuleEnabled('sitebusinessintegration') || Engine_Api::_()->getDbtable('modules', 'core')->isModuleEnabled('sitegroupintegration')) {
            $itemPrivacyCheck = Engine_Api::_()->seaocore()->itemPrivacyCheck($document);
            if ($itemPrivacyCheck) {
                return $this->_forwardCustom('requireauth', 'error', 'core');
            }
        }

        //GET VIEWER ID
        $viewer = Engine_Api::_()->user()->getViewer();
        $viewer_id = $viewer->getIdentity();

        //GET USER LEVEL ID
        if (!empty($viewer_id)) {
            $level_id = $viewer->level_id;
        } else {
            $level_id = Engine_Api::_()->getDbtable('levels', 'authorization')->fetchRow(array('type = ?' => "public"))->level_id;
        }

        //WHO CAN VIEW THE DOCUMENTS
        if (!$this->_helper->requireAuth()->setAuthParams($document, null, 'view')->isValid()) {
            return $this->_forward('requireauth', 'error', 'core');
        }

        if ($document->parent_type && $document->parent_id) {
            //WHO CAN VIEW THE DOCUMENTS
            if (strpos($document->parent_type, "sitereview_listing") !== false) {
                $sitereview = Engine_Api::_()->getItem('sitereview_listing', $document->parent_id);

                //WHO CAN VIEW THE DOCUMENTS
                if (!$this->_helper->requireAuth()->setAuthParams($sitereview, null, "view_listtype_$sitereview->listingtype_id")->isValid()) {
                    return $this->_forwardCustom('requireauth', 'error', 'core');
                }
            } else {
                $isParentViewPrivacy = Engine_Api::_()->document()->isParentViewPrivacy($document);

                if (empty($isParentViewPrivacy))
                    return $this->_forwardCustom('requireauth', 'error', 'core');
            }
        } else {

            //WHO CAN VIEW THE DOCUMENTS
            $this->view->viewPrivacy = $document->canView($viewer);

            if (!$this->view->viewPrivacy) {
                return $this->_forward('requireauth', 'error', 'core');
            }

            if ($this->view->viewPrivacy == 1 && $viewer_id != $document->owner_id && ($document->draft == 1 || $document->status != 1 || $document->approved != 1)) {
                return $this->_forward('requireauth', 'error', 'core');
            }
        }

        //ADD META DESCRIPTION
        $view = Zend_Registry::isRegistered('Zend_View') ? Zend_Registry::get('Zend_View') : null;
        $siteinfo = $view->layout()->siteinfo;
        $siteinfo['description'] = $document->document_description;
        $view->layout()->siteinfo = $siteinfo;

        $coremodule = Engine_Api::_()->getDbtable('modules', 'core')->getModule('core');
        $coreversion = $coremodule->version;
        if ($coreversion < '4.1.0') {
            $this->_helper->content->render();
        } else {
            $this->_helper->content
                    ->setNoRender()
                    ->setEnabled();
        }

        //NAVIGATION WORK FOR FOOTER.(DO NOT DISPLAY NAVIGATION IN FOOTER ON VIEW PAGE.)
        if (!Engine_API::_()->seaocore()->checkSitemobileMode('fullsite-mode')) {
            if (!Zend_Registry::isRegistered('sitemobileNavigationName')) {
                Zend_Registry::set('sitemobileNavigationName', 'setNoRender');
            }
        }
    }

    //ACTION FOR SHOW USER DOCUMENT LIST
    public function listAction() {

        //OWNER INFORMATION
        $this->view->owner = $owner = Engine_Api::_()->getItem('user', $this->_getParam('user_id'));
        $this->view->contentItem = Engine_Api::_()->getItem('document', $this->_getParam('document_id'));
        $this->view->circularImage = Engine_Api::_()->getApi('settings', 'core')->getSetting('document.circular.image', 1);
        $this->view->formValues = $values = $_GET;

        if (!empty($_GET['search'])) {
            $this->view->search = $_GET['search'];
        }

        if (!empty($_GET['category'])) {
            $this->view->category = $_GET['category'];
        }

        if (!empty($_GET['tag'])) {
            $this->view->tags = $this->view->tag = $_GET['tag'];
        }

        if (!empty($_GET['page'])) {
            $this->view->page = $_GET['page'];
        }

        $values['user_id'] = $owner_id = $owner->getIdentity();
        $values['draft'] = "0";
        $values['status'] = "1";
        $values['approved'] = "1";
        $values['searchable'] = "1";
        $values['network_based_content'] = 1;
        $this->view->assign($values);

        //CHECK THAT RATING IS VIEABLE OR NOT
        $this->view->show_rate = Engine_Api::_()->getApi('settings', 'core')->getSetting('document.rating', 1);

        if ($this->view->contentItem && ($this->view->contentItem->parent_type && $this->view->contentItem->parent_id) ) {
            if ($this->view->contentItem->parent_type != 'sitereview_listing') {
                $values['parent_type'] = $this->view->contentItem->parent_type;
                $values['parent_id'] = $this->view->contentItem->parent_id;
            } else {
                $values['parent_type'] = 'sitereview_listing_' . $this->view->contentItem->listingtype_id;
                $values['parent_id'] = $this->view->contentItem->getIdentity();
            }
        }

        //GET PAGINATOR
        $this->view->paginator = Engine_Api::_()->getDbtable('documents', 'document')->getDocumentsPaginator($values);
        $items_per_page = 10;
        $this->view->paginator->setItemCountPerPage($items_per_page);
        $this->view->paginator->setCurrentPageNumber($this->_getParam('page', 1));

        //FETCH USER TAGS
        $this->view->userTags = Engine_Api::_()->getDbtable('tags', 'core')->getTagsByTagger('document', $owner);

        //FETCH USER CATEGORIES
        $this->view->userCategories = Engine_Api::_()->getDbtable('categories', 'document')->getUserCategories($owner_id);
    }

    //ACTION FOR MAKE/REMOVE THE DOCUMENT AS A PROFILE
    public function profileDocAction() {

        //CHECK USER VALIDATION
        if (!$this->_helper->requireUser()->isValid())
            return;

        //GET VIEWER INFORMATION
        $viewer = Engine_Api::_()->user()->getViewer();
        $viewer_id = $viewer->getIdentity();
        $level_id = $viewer->level_id;

        //CHECK THAT MEMBER CAN MAKE PROFILE DOCUMENT OR NOT
        $can_profile_doc = Engine_Api::_()->authorization()->getPermission($level_id, 'document', 'profile_doc');
        if (empty($can_profile_doc)) {
            return;
        }

        //GET DOCUMENT ID AND DOCUMENT ITEM
        $document_id = $this->view->document_id = $this->_getParam('document_id');
        $document = Engine_Api::_()->getItem('document', $document_id);
        $this->view->profile_doc = $document->profile_doc;

        //SMOOTHBOX
        if (null === $this->_helper->ajaxContext->getCurrentContext()) {
            $this->_helper->layout->setLayout('default-simple');
        } else {//NO LAYOUT
            $this->_helper->layout->disableLayout(true);
        }

        if (!$this->getRequest()->isPost())
            return;

        //CHECK CAN MAKE FEATURED OR NOT(ONLY GROUP DOUCMENT CAN MAKE FEATURED/UN-FEATURED)
        if (!empty($can_profile_doc)) {
            $this->view->permission = true;
            $this->view->success = false;
            $tableDocument = Engine_Api::_()->getDbtable('documents', 'document');
            $db = $tableDocument->getAdapter();
            $db->beginTransaction();
            try {
                if ($document->profile_doc == 0) {

                    //REMOVE OTHER DOCUMENT AS A PROFILE DOCUMENT
                    $tableDocument->removeProfileDoc($document->owner_id);

                    $document->profile_doc = 1;
                } else {
                    $document->profile_doc = 0;
                }

                $document->save();
                $db->commit();
                $this->view->success = true;
            } catch (Exception $e) {
                $db->rollback();
                throw $e;
            }
        } else {
            $this->view->permission = false;
        }

        $this->_forward('success', 'utility', 'core', array(
            'smoothboxClose' => 10,
            'parentRefresh' => 10,
            'messages' => array('')
        ));
    }

    //ACTION FOR EMAIL THE DOCUMENT
    public function emailAction() {

        //CHECK USER VALIDATION
        if (!$this->_helper->requireUser()->isValid())
            return;

        //GET VIEWER DETAIL
        $viewer = Engine_Api::_()->user()->getViewer();
        $viewer_id = $viewer->getIdentity();
        $level_id = $viewer->level_id;

        //TO BE VERIFY THAT DOCUMNETS HAD ENABLED FOR THIS USER
        $view = Engine_Api::_()->authorization()->getPermission($level_id, 'document', 'view');
        if ($view == 0) {
            return $this->_forward('requireauth', 'error', 'core');
        }

        $document_id = $this->_getParam('id');
        if (empty($document_id)) {

            $routeStartP = Engine_Api::_()->getApi('settings', 'core')->getSetting('document.manifestUrlP', "documents");
            return $this->_redirect("$routeStartP" . "/manage");
        } else {
            $document = Engine_Api::_()->getItem('document', $document_id);
        }

        //CAN'T EMAIL PRIVATE DOCUMENT
        if ($viewer_id != $document->owner_id && ($document->draft == 1 || $document->approved != 1 || $document->status != 1)) {
            $page = "error";
            $this->view->error_header = 639;
            $this->view->error_message = $this->view->translate('You do not have permission to view this document.');
            $this->error_submit = 641;
        }

        //CHECK THAT EMAIL IS ALLOW OR NOT
        $email_allow = Engine_Api::_()->authorization()->getPermission($level_id, 'document', 'email_allow');
        if (($document->email_allow != 1) || ($document->status != 1) || ($email_allow != 1 )) {
            $page = "error";
            $this->view->error_header = 639;
            $this->view->error_message = $this->view->translate('You do not have permission to view this document.');
            $this->error_submit = 641;
        }

        $time_out = 50000;
        $is_error = 0;
        $error_array = array();
        $excep_error = 0;
        $excep_message = '';

        //FILENAME FROM STORAGE TABLE
        $file_name = $document->getDocumentFileName();

        if (!empty($file_name)) {
            $this->view->attach = $file_name;
        } else {
            $this->view->attach = $document->storage_path;
        }

        if (isset($_POST['submit']) && $_POST['submit'] == 'Send') {
            $to = $_POST['to'];
            $subject = $_POST['subject'];
            $user_message = $_POST['message'];

            if (empty($to) || !filter_var($to, FILTER_VALIDATE_EMAIL)) {
                $is_error = 1;
                $error = $this->view->translate('Please enter a valid email.');
                $error_array[] = $error;
            }

            if (empty($subject)) {
                $is_error = 1;
                $error = $this->view->translate('Please enter the subject.');
                $error_array[] = $error;
            }
            if ($is_error != 1) {

                $from = $viewer->displayname . '<' . $viewer->email . '>';

                $fileatt_type = $document->filemime;
                $fileatt_name = $file_name;
                $headers = "From: $from";

                $data = file_get_contents($document->storage_path);

                $semi_rand = md5(time());
                $mime_boundary = "==Multipart_Boundary_x{$semi_rand}x";

                $headers .= "\nMIME-Version: 1.0\n" .
                        "Content-Type: multipart/mixed;\n" .
                        " boundary=\"{$mime_boundary}\"";

                $email_message = "This is a multi-part message in MIME format.\n\n" .
                        "--{$mime_boundary}\n" .
                        "Content-Type:text/html; charset=\"iso-8859-1\"\n" .
                        "Content-Transfer-Encoding: 7bit\n\n" . $user_message . "\n\n";

                $data = chunk_split(base64_encode($data));
                $email_message .= "--{$mime_boundary}\n" .
                        "Content-Type: {$fileatt_type};\n" .
                        " name=\"{$fileatt_name}\"\n" .
                        "Content-Transfer-Encoding: base64\n\n" .
                        $data . "\n\n" .
                        "--{$mime_boundary}--\n";

                $mail_sent = mail($to, $subject, $email_message, $headers);
                if ($mail_sent) {
                    $this->view->msg = $this->view->translate('Email has been sent successfully.');
                    $time_out = 7000;
                    $this->view->no_form = 1;
                } else {
                    $is_error = 1;
                    $error_array[] = $this->view->translate('There was an error in sending your email. Please try again later.');
                    $time_out = 50000;
                    $this->view->no_form = 1;
                }
            }
            $this->view->to = $to;
            $this->view->subject = $subject;
            $this->view->user_message = $user_message;
        }
        $this->view->is_error = $is_error;
        $this->view->time_out = $time_out;
        $this->view->error_array = array_unique($error_array);
        $this->view->excep_error = $excep_error;
        $this->view->excep_message = $excep_message;
    }

    //ACTION FOR RATING DOCUMENTS
    public function ratingAction() {

        //GET VIEWER ID
        $viewer_id = Engine_Api::_()->user()->getViewer()->getIdentity();

        //GET RATING
        $rating = $this->_getParam('rating');

        //GET DOCUMENT ID
        $document_id = $this->_getParam('document_id');

        //GET RATING TABLE
        $tableRating = Engine_Api::_()->getDbtable('ratings', 'document');

        //BEGIN TRANSCATION
        $db = $tableRating->getAdapter();
        $db->beginTransaction();

        try {
            $tableRating->doDocumentRating($document_id, $viewer_id, $rating);

            $total = $tableRating->countRating($document_id);

            $document = Engine_Api::_()->getItem('document', $document_id);

            //UPDATE CURRENT AVERAGE RATING IN DOCUMENT TABLE
            $document->rating = $rating = $tableRating->avgRating($document_id);

            $document->save();

            //COMMIT
            $db->commit();
        } catch (Exception $e) {
            $db->rollBack();
            throw $e;
        }

        $data = array();
        $data[] = array(
            'total' => $total,
            'rating' => $rating,
        );
        return $this->_helper->json($data);
        $data = Zend_Json::encode($data);
        $this->getResponse()->setBody($data);
    }

    //ACTION FOR DOCUMENT PUBLISH
    public function publishAction() {

        //CHECK USER VALIDATION
        if (!$this->_helper->requireUser()->isValid())
            return;

        //LAYOUT
        if (null === $this->_helper->ajaxContext->getCurrentContext()) {
            $this->_helper->layout->setLayout('default-simple');
        } else {
            $this->_helper->layout->disableLayout(true);
        }

        //GET DOCUMENT ID AND OBJECT
        $document_id = $this->view->document_id = $this->getRequest()->getParam('document_id');
        $document = Engine_Api::_()->getItem('document', $document_id);

        if (!$this->getRequest()->isPost())
            return;

        //GET VIEWER DETAIL
        $viewer = Engine_Api::_()->user()->getViewer();

        //WHO CAN EDIT THE DOCUMENT
        $can_edit = Engine_Api::_()->authorization()->getPermission($viewer->level_id, 'document', 'edit');

        if (!empty($can_edit)) {

            $document->modified_date = new Zend_Db_Expr('NOW()');
            $document->draft = 0;
            $document->save();

            $this->view->success = true;

            //ADD ACTIVITY ONLY IF DOCUMENT IS PUBLISHED
            if ($document->draft == 0 && $document->approved == 1 && $document->status == 1 && $document->activity_feed == 0) {

                //GET DOCUMENT OWNER OBJECT
                $creator = Engine_Api::_()->getItem('user', $document->owner_id);

                //GET ACTIVITY TABLE
                $activityTable = Engine_Api::_()->getDbtable('actions', 'activity');

                $action = $activityTable->addActivity($creator, $document, 'document_new');

                //MAKE SURE ACTION EXISTS BEFORE ATTACHING THE DOUCMENT TO THE ACTIVITY
                if ($action != null) {
                    $activityTable->attachActivity($action, $document);
                    $document->activity_feed = 1;
                    $document->save();
                }
            }
        }

        $this->_forward('success', 'utility', 'core', array(
            'smoothboxClose' => 10,
            'parentRefresh' => 10,
            'messages' => array('')
        ));
    }

    //ACTION FOR DELETE DOCUMENT
    public function deleteAction() {

        //CHECK USER VALIDATION
        if (!$this->_helper->requireUser()->isValid())
            return;

        //GET NAVIGATION
        $this->view->navigation = Engine_Api::_()->getApi('menus', 'core')->getNavigation('document_main');

        $viewer = Engine_Api::_()->user()->getViewer();

        //GET VIEWER ID
        $viewer_id = Engine_Api::_()->user()->getViewer()->getIdentity();

        //GET USER LEVEL
        $level_id = Engine_Api::_()->user()->getViewer()->level_id;
        $can_delete = Engine_Api::_()->authorization()->getPermission($level_id, 'document', 'delete');

        //GET DOCUMENT ID
        $document_id = $this->_getParam('document_id');

        //GET DOCUMENT OBJECT
        $this->view->document = $document = Engine_Api::_()->getItem('document', $document_id);

        $parent_type = $document->parent_type;
        $parent_id = $document->parent_id;
        if ($parent_type && $parent_id) {

            $isParentDeletePrivacy = Engine_Api::_()->document()->canDeletePrivacy($$parent_type, $parent_id, $document);

            if (empty($isParentDeletePrivacy))
                return $this->_forwardCustom('requireauth', 'error', 'core');
        } else {
            if ($viewer->getIdentity() != $document->owner_id && !$this->_helper->requireAuth()->setAuthParams($document, null, 'delete')->isValid()) {
                return $this->_forward('requireauth', 'error', 'core');
            }
        }

        if ($this->getRequest()->isPost() && $this->getRequest()->getPost('confirm') == true) {

            //DELETE DOCUMENT BELONGINGS
            Engine_Api::_()->document()->deleteContent($document_id);

            $routeStartP = Engine_Api::_()->getApi('settings', 'core')->getSetting('document.manifestUrlP', "documents");
            return $this->_redirect("$routeStartP" . "/manage");
        }
    }

    //ACITON FOR LISTING DOCUMENTS AT HOME DOCUMENT
    public function ajaxHomeDocumentsAction() {

        //GET QUERY DATA
        $tab_show_values = $this->_getParam('tabShow', null);
        $this->view->listView = $this->_getParam('listView', 0);
        $this->view->gridView = $this->_getParam('gridView', 0);
        $this->view->defaultView = $this->_getParam('defaultView', 0);
        $this->view->active_tab_list = $listLimit = $this->_getParam('listLimit', 0);
        $this->view->active_tab_image = $gridLimit = $this->_getParam('gridLimit', 0);
        $this->view->widgetSettings = $this->_getParam('widgetSettings');
        $params = array();
        $params['limit'] = $listLimit > $gridLimit ? $listLimit : $gridLimit;

        if ($tab_show_values == 'Most Viewed') {
            $params['orderby'] = 'views DESC';
            $params['zero_count'] = 'views';
        }

        if ($tab_show_values == 'Featured') {
            $params['orderby'] = 'featured DESC';
            $params['featured'] = 1;
        }

        if ($tab_show_values == 'Sponosred') {
            $params['orderby'] = 'sponsored DESC';
            $params['sponsored'] = 1;
        }

        if ($tab_show_values == 'Random') {
            $params['orderby'] = 'RAND() DESC';
        }

        //GET AJAX HOME WIDGET DATA
        $this->view->documents = Engine_Api::_()->getDbtable('documents', 'document')->widgetDocumentsData($params);
    }

    //ACTION FOR SHOWING SPONSORED DOCUMENT AT DOCUMENT HOME 
    public function homeSponsoredAction() {

        //RETRIVE THE VALUE OF BUTTON DIRECTION
        $params = array();
        $params['sponsored'] = 1;
        $this->view->category_id = $params['category_id'] = $_GET['category_id'];
        $this->view->widgetSettings = $this->_getParam('widgetSettings');
        $this->view->direction = $direction = $_GET['direction'];
        $this->view->totalDocuments = $params['totalDocuments'] = $_GET['limit'];
        $this->view->titletruncation = $_GET['titletruncation'];

        //GET SPONSORED DOCUMENTS
        $this->view->documents = Engine_Api::_()->getDbtable('documents', 'document')->widgetDocumentsData($params);
    }

    //ACTION TO GET SUB-CATEGORY
    public function subCategoryAction() {

        //GET CATEGORY ID
        $category_id_temp = $this->_getParam('category_id_temp');

        //INTIALIZE ARRAY
        $this->view->subcats = $data = array();

        //RETURN IF CATEGORY ID IS EMPTY
        if (empty($category_id_temp))
            return;

        //GET CATEGORY TABLE
        $tableCategory = Engine_Api::_()->getDbTable('categories', 'document');

        //GET CATEGORY
        $category = $tableCategory->getCategory($category_id_temp);
        if (!empty($category->category_name)) {
            $categoryName = $tableCategory->getCategorySlug($category->category_name);
        }

        //GET SUB-CATEGORY
        $subCategories = $tableCategory->getSubCategories($category_id_temp);

        foreach ($subCategories as $subCategory) {
            $content_array = array();
            $content_array['category_name'] = Zend_Registry::get('Zend_Translate')->_($subCategory->category_name);
            $content_array['category_id'] = $subCategory->category_id;
            $content_array['categoryname_temp'] = $categoryName;
            $data[] = $content_array;
        }

        $this->view->subcats = $data;
    }

    //ACTION FOR FETCHING SUB-CATEGORY
    public function subsubCategoryAction() {

        //GET SUB-CATEGORY ID
        $subcategory_id_temp = $this->_getParam('subcategory_id_temp');

        //INTIALIZE ARRAY
        $this->view->subsubcats = $data = array();

        //RETURN IF SUB-CATEGORY ID IS EMPTY
        if (empty($subcategory_id_temp))
            return;

        //GET CATEGORY TABLE
        $tableCategory = Engine_Api::_()->getDbTable('categories', 'document');

        //GET SUB-CATEGORY
        $subCategory = $tableCategory->getCategory($subcategory_id_temp);
        if (!empty($subCategory->category_name)) {
            $subCategoryName = $tableCategory->getCategorySlug($subCategory->category_name);
        }

        //GET 3RD LEVEL CATEGORIES
        $subCategories = $tableCategory->getSubCategories($subcategory_id_temp);
        foreach ($subCategories as $subCategory) {
            $content_array = array();
            $content_array['category_name'] = Zend_Registry::get('Zend_Translate')->_($subCategory->category_name);
            $content_array['category_id'] = $subCategory->category_id;
            $content_array['categoryname_temp'] = $subCategoryName;
            $data[] = $content_array;
        }
        $this->view->subsubcats = $data;
    }

    //ACTION FOR CONSTRUCT TAG CLOUD
    public function tagscloudAction() {

        //CONSTRUCTING TAG CLOUD
        $tag_array = array();
        $tag_cloud_array = Engine_Api::_()->document()->getTags(0, 0);

        foreach ($tag_cloud_array as $vales) {
            $tag_array[$vales['text']] = $vales['Frequency'];
            $tag_id_array[$vales['text']] = $vales['tag_id'];
        }

        if (!empty($tag_array)) {
            $max_font_size = 18;
            $min_font_size = 12;
            $max_frequency = max(array_values($tag_array));
            $min_frequency = min(array_values($tag_array));
            $spread = $max_frequency - $min_frequency;
            if ($spread == 0) {
                $spread = 1;
            }
            $step = ($max_font_size - $min_font_size) / ($spread);

            $tag_data = array('min_font_size' => $min_font_size, 'max_font_size' => $max_font_size, 'max_frequency' => $max_frequency, 'min_frequency' => $min_frequency, 'step' => $step);
            $this->view->tag_data = $tag_data;
            $this->view->tag_id_array = $tag_id_array;
        }
        $this->view->tag_array = $tag_array;
    }

    public function categoriesAction() {

        //SHOW WIDGETS
        $coremodule = Engine_Api::_()->getDbtable('modules', 'core')->getModule('core');
        $coreversion = $coremodule->version;
        if ($coreversion < '4.1.0') {
            $this->_helper->content->render();
        } else {
            $this->_helper->content
                    ->setNoRender()
                    ->setEnabled();
        }
    }

    //ACTION FOR GETTING THE PAGES WHICH PAGES CAN BE SEARCH
    public function getSearchDocumentsAction() {

        $userdocuments = Engine_Api::_()->getDbtable('documents', 'document')->getDayItems($this->_getParam('text'), $this->_getParam('limit', 10), $this->_getParam('category_id'));

        $data = array();
        $mode = $this->_getParam('struct');
        $count = count($userdocuments);
        if ($mode == 'text') {
            $i = 0;
            foreach ($userdocuments as $userdocument) {
                $document = Engine_Api::_()->getItem('document', $userdocument->document_id);
                $i++;
                $content_photo = $this->view->itemPhoto($userdocument, 'thumb.icon');
                $data[] = array(
                    'id' => $userdocument->document_id,
                    'label' => $userdocument->document_title,
                    'photo' => $content_photo,
                    'document_url' => $document->getHref(),
                    'total_count' => $count,
                    'count' => $i
                );
            }
        } else {
            $i = 0;
            foreach ($userdocuments as $userdocument) {
                $document = Engine_Api::_()->getItem('document', $userdocument->document_id);

                $content_photo = $this->view->itemPhoto($userdocument, 'thumb.icon');
                $i++;
                $data[] = array(
                    'id' => $userdocument->document_id,
                    'label' => $userdocument->document_title,
                    'photo' => $content_photo,
                    'document_url' => $document->getHref(),
                    'total_count' => $count,
                    'count' => $i
                );
            }
        }
        if (!empty($data) && $i >= 1) {
            if ($data[--$i]['count'] == $count) {
                $data[$count]['id'] = 'stopevent';
                $data[$count]['label'] = $this->_getParam('text');
                $data[$count]['document_url'] = 'seeMoreLink';
                $data[$count]['total_count'] = $count;
            }
        }

        return $this->_helper->json($data);
    }

    public function getGDSEMedia() {
        $coreApi = Engine_Api::_()->document();
        $document_client_id = $this->_document_client_id = $coreApi->getGoogleClientId();
        $getGoogleClientSecretKey = $this->_getGoogleClientSecretKey = $coreApi->getGoogleClientSecretKey();
        $document_google_email = $this->_document_google_email = $coreApi->getGoogleEmail();
        $document_hide_old_fields = Engine_Api::_()->getApi('settings', 'core')->getSetting('document.hide.old.fields', 0);
        if ($document_hide_old_fields) {
            $this->GDSEMedia = new GDSEMedia($document_client_id, null, null, $getGoogleClientSecretKey);
        } else {
            $document_service_account_name = $this->_document_service_account_name = $coreApi->getGoogleServiceAccountName();
            $document_private_key_url_path = $this->_document_private_key_url_path = $coreApi->getPrivateKeyUrl();
            if ($document_google_email && $document_client_id && $document_service_account_name && $document_private_key_url_path) {
                $this->GDSEMedia = new GDSEMedia($document_client_id, $document_service_account_name, $document_private_key_url_path);
            }
        }

        return $this->GDSEMedia;
    }

}
