<?php

/**
 * SocialEngine
 *
 * @category   Application_Extensions
 * @package    Eventdocument
 * @copyright  Copyright 20011-2012 BigStep Technologies Pvt. Ltd.
 * @license    http://www.socialengineaddons.com/license/
 * @version    $Id: Core.php 2012-01-25 9:40:21Z SocialEngineAddOns $
 * @author     SocialEngineAddOns
 */
class Eventdocument_Api_Core extends Core_Api_Abstract {

  /**
   * Return document tabid
   *
   * @return tabid
   */
  public function getTabId() {
    $tab_id = '';
    $tablecontent = Engine_Api::_()->getDbtable('content', 'core');
    $select = $tablecontent->select()
                    ->where('name = ?', 'eventdocument.profile-eventdocuments')
                    ->limit(1);
    $row = $tablecontent->fetchRow($select);
    if ($row !== null) {
      $tab_id = $row->content_id;
    }

    return $tab_id;
  }

  /**
   * Send email to document and page owner if document has been deleted from scirbd
   * @param array $document : document item
   * @param string $event_title : event title
   */
  public function emailDocumentDelete($document, $event_title, $event_user_id) {

    if (empty($document)) {
      return;
    }

    if (empty($event_title)) {
      $event_title = "Event Title";
    }

		$slug = trim(preg_replace('/-+/', '-', preg_replace('/[^a-z0-9-]+/i', '-', strtolower($document->title))), '-');
    $document_title_with_link = '<a href = http://' . $_SERVER['HTTP_HOST'] . Zend_Controller_Front::getInstance()->getRouter()->assemble(array('user_id' => $document->owner_id, 'document_id' => $document->document_id, 'slug' => $slug), 'eventdocument_detail_view') . ">$document->title</a>";

    $edit_document_link = 'http://' . $_SERVER['HTTP_HOST'] . Zend_Controller_Front::getInstance()->getRouter()->assemble(array('document_id' => $document->document_id, 'event_id' => $document->event_id), 'eventdocument_edit');

    $delete_document_link = 'http://' . $_SERVER['HTTP_HOST'] . Zend_Controller_Front::getInstance()->getRouter()->assemble(array('document_id' => $document->document_id, 'event_id' => $document->event_id), 'eventdocument_delete');

    $event_title_with_link = '<a href = http://' . $_SERVER['HTTP_HOST'] . Zend_Controller_Front::getInstance()->getRouter()->assemble(array('id' => $document->event_id), 'event_profile') . ">$event_title</a>";

    $userTable = Engine_Api::_()->getItemTable('user');
    $document_owner_email_id = $userTable->select()
                    ->from($userTable, 'email')
                    ->where('`user_id` = ?', $event_user_id)
                    ->limit(1)
                    ->query()
                    ->fetchColumn(0);

    if (!empty($document_owner_email_id)) {
      Engine_Api::_()->getApi('mail', 'core')->sendSystem($document_owner_email_id, 'notify_docowner_eventdocument_delete', array(
          'document_title_with_link' => $document_title_with_link,
          'event_title_with_link' => $event_title_with_link,
          'delete_document_link' => $delete_document_link,
          'edit_document_link' => $edit_document_link,
          'queue' => true
      ));
    }

    $event_owner_id = Engine_Api::_()->eventdocument()->eventUserId($document->event_id);
    $userTable = Engine_Api::_()->getItemTable('user');
    $event_owner_email_id = $userTable->select()
                    ->from($userTable, 'email')
                    ->where('`user_id` = ?', $event_owner_id)
                    ->limit(1)
                    ->query()
                    ->fetchColumn(0);

    if (!empty($event_owner_email_id)) {
      Engine_Api::_()->getApi('mail', 'core')->sendSystem($event_owner_email_id, 'notify_eventowner_eventdocument_delete', array(
          'document_title_with_link' => $document_title_with_link,
          'event_title_with_link' => $event_title_with_link,
          'delete_document_link' => $delete_document_link,
          'queue' => true
      ));
    }
  }

  /**
   * Delete the eventdocument and ratings
   * 
   * @param int $document_id
   */
  public function deleteContent($document_id) {

    //GET THE DOCUMENT OBJECT
    $eventdocument = Engine_Api::_()->getItem('eventdocument_document', $document_id);

    if (empty($eventdocument)) {
      return;
    }

    include_once APPLICATION_PATH . '/application/modules/Eventdocument/Api/Scribdevent.php';

    $this->scribd_api_key = Engine_Api::_()->getApi('settings', 'core')->eventdocument_api_key;
    $this->scribd_secret = Engine_Api::_()->getApi('settings', 'core')->eventdocument_secret_key;
    $this->scribdevent = new Scribdevent($this->scribd_api_key, $this->scribd_secret);

    //DELETE DOCUMENT FROM SCRIBD
    if (!empty($eventdocument->doc_id)) {
      $this->scribdevent->my_user_id = $eventdocument->owner_id;
      $this->scribdevent->delete($eventdocument->doc_id);
    }

    //DELETE ENTRY FROM engine4_document_fields_search TABLE CORRESPONDIG TO item_id
    $searchTable = Engine_Api::_()->getItem('eventdocument_search', $document_id);
    if (!empty($searchTable)) {
      $searchTable->delete();
    }

    Engine_Api::_()->getDbtable('ratings', 'eventdocument')->delete(array('document_id = ?' => $document_id));

    //DELETE DOCUMENT FROM LOCAL SERVER
    $storagemodule = Engine_Api::_()->getDbtable('modules', 'core')->getModule('storage');
    $storageversion = $storagemodule->version;
    if ($storageversion < '4.1.1' && file_exists($eventdocument->storage_path) && !empty($eventdocument->storage_path)) {
      unlink($eventdocument->storage_path);
    }

    //DELETE DOCUMENT AND OTHER BELONGINGS
    $eventdocument->delete();
  }

  /**
   * Delete document from server
   * @param int $document_id : document id
   */
  public function deleteServerDocument($document_id) {

    $document = Engine_Api::_()->getItem('eventdocument_document', $document_id);

    $storagemodule = Engine_Api::_()->getDbtable('modules', 'core')->getModule('storage');
    $storageversion = $storagemodule->version;
    if ($storageversion < '4.1.1' && file_exists($document->storage_path) && !empty($document->storage_path)) {
      unlink($document->storage_path);
    }

    if (!empty($document->filename_id)) {
      $storage = Engine_Api::_()->getItem('storage_file', $document->filename_id);
      $fileName = $storage->name;
      $storage->delete();

      $document->storage_path = $fileName;
      $document->filename_id = 0;
      $document->save();
    }
  }

  /**
   * Get Truncation String
   *
   * @param string $text
   * @param int $limit
   * @return truncate string
   */
  public function truncateText($text, $limit) {
    $tmpBody = strip_tags($text);
    return ( Engine_String::strlen($tmpBody) > $limit ? Engine_String::substr($tmpBody, 0, $limit) . '..' : $tmpBody );
  }

  /**
   * Get event owner id
   *
   * @param int $event_id 
   * @return event owner id
   */
  public function eventUserID($event_id) {
    $eventTable = Engine_Api::_()->getItemTable('event');
    $event_user_id = $eventTable->select()
                    ->from($eventTable->info('name'), 'user_id')
                    ->where('event_id = ?', $event_id)
                    ->limit(1)
                    ->query()
                    ->fetchColumn(0);
    return $event_user_id;
  }

}