<?php

/**
 * SocialEngine
 *
 * @category   Application_Extensions
 * @package    Eventdocument
 * @copyright  Copyright 20011-2012 BigStep Technologies Pvt. Ltd.
 * @license    http://www.socialengineaddons.com/license/
 * @version    $Id: Global.php 2012-01-25 9:40:21Z SocialEngineAddOns $
 * @author     SocialEngineAddOns
 */
class Eventdocument_Form_Admin_Global extends Engine_Form {

  public function init() {
    $this
            ->setTitle('Global Settings')
            ->setDescription('These settings affect all members in your community.');

    $this->addElement('Text', 'eventdocument_lsettings', array(
        'label' => 'Enter License key',
	'required' => true,
        'description' => "Please enter your license key that was provided to you when you purchased this plugin. If you do not know your license key, please contact the Support Team of SocialApps.tech from the Support section of your Account Area.(Key Format: XXXXXX-XXXXXX-XXXXXX )",
        'value' => Engine_Api::_()->getApi('settings', 'core')->getSetting('eventdocument_lsettings'),
    ));

    //GET SCRIBD KEYS IF OTHER DOCUMENT PLUGIN IS ALREADY INSTALLED AND HAVING THESE KEYS.
    $coreApi = Engine_Api::_()->getApi('settings', 'core');
    $scribd_api_key = $coreApi->getSetting('eventdocument.api.key');
    $scribd_secret_key = $coreApi->getSetting('eventdocument.secret.key');
    if (empty($scribd_api_key) && empty($scribd_secret_key)) {
      Engine_Api::_()->seaocore()->getScribdApiKeys('eventdocument');
    }
    
    $this->addElement('Text', 'eventdocument_api_key', array(
        'label' => 'Scribd API Key',
        'required' => true,
        'description' => 'The Scribd API Key for your website. [Please visit the FAQ section to see how to obtain these credentials.]',
        'value' => Engine_Api::_()->getApi('settings', 'core')->getSetting('eventdocument.api.key', ''),
    ));

    $this->addElement('Text', 'eventdocument_secret_key', array(
        'label' => 'Scribd Secret Key',
        'required' => true,
        'description' => 'The Scribd Secret Key for your website. [Please visit the FAQ section to see how to obtain these credentials.]',
        'value' => Engine_Api::_()->getApi('settings', 'core')->getSetting('eventdocument.secret.key', ''),
    ));

    if( APPLICATION_ENV == 'production' ) {
      $this->addElement('Checkbox', 'environment_mode', array(
          'label' => 'Your community is currently in "Production Mode". We recommend that you momentarily switch your site to "Development Mode" so that the CSS of this plugin renders fine as soon as the plugin is installed. After completely installing this plugin and visiting few pages of your site, you may again change the System Mode back to "Production Mode" from the Admin Panel Home. (In Production Mode, caching prevents CSS of new plugins to be rendered immediately after installation.)',
          'description' => 'System Mode',
          'value' => 1,
      ));
    } else {
      $this->addElement('Hidden', 'environment_mode', array('order' => 990, 'value' => 0));
    }

    $this->addElement('Button', 'submit_lsetting', array(
        'label' => 'Activate Your Plugin Now',
        'type' => 'submit',
        'ignore' => true
    ));

    $this->addElement('Radio', 'eventdocument_default_visibility', array(
        'label' => 'Visibility for Event Documents',
        'description' => 'Event documents visible only on this website will be private and available only on your website, whereas the ones which will be public on Scribd.com will be available to everyone on Scribd.(Note : This setting will only apply to new event documents created and not to the existing event documents on the site.)',
        'multiOptions' => array(
            'public' => 'Public on Scribd.com',
            'private' => 'Only on this website'
        ),
        'value' => Engine_Api::_()->getApi('settings', 'core')->getSetting('eventdocument.default.visibility', 'private'),
    ));

    $this->addElement('Radio', 'eventdocument_visibility_option', array(
        'description' => 'Show visibility option to users. Allow users to choose whether their event documents will be public or private,i.e., available only on your website, or also on Scribd.com.',
        'multiOptions' => array(
            1 => ' 	Yes',
            0 => ' 	No'
        ),
        'value' => Engine_Api::_()->getApi('settings', 'core')->getSetting('eventdocument.visibility.option', 1),
    ));

    $this->addElement('Radio', 'eventdocument_carousel', array(
        'label' => 'Featured Documents Carousel',
        'description' => 'Do you want to show the carousel for featured documents in events in the Documents tab of events ?',
        'multiOptions' => array(
            1 => ' 	Yes',
            0 => ' 	No'
        ),
        'value' => Engine_Api::_()->getApi('settings', 'core')->getSetting('eventdocument.carousel', 1),
    ));

    $this->addElement('Text', 'eventdocument_number_carousel', array(
        'label' => 'Documents in Featured Carousel',
        'description' => 'How many documents should be shown in the carousel for featured documents (value cannot be empty or zero) ?',
        'required' => true,
        'value' => Engine_Api::_()->getApi('settings', 'core')->getSetting('eventdocument.number.carousel', 15),
        'validators' => array(
            array('Int', true),
            array('GreaterThan', true, array(0)),
        ),
    ));

    $this->addElement('Radio', 'eventdocument_featured', array(
        'label' => 'Making Event Documents Featured',
        'description' => 'Allow event owners to make documents in their events as featured.',
        'multiOptions' => array(
            1 => ' 	Yes',
            0 => ' 	No'
        ),
        'value' => Engine_Api::_()->getApi('settings', 'core')->getSetting('eventdocument.featured', 1),
    ));

    $this->addElement('Radio', 'eventdocument_show_editor', array(
        'label' => 'WYSIWYG Editor',
        'description' => 'Allow WYSIWYG editor for description of event documents.',
        'multiOptions' => array(
            1 => ' 	Yes',
            0 => ' 	No'
        ),
        'value' => Engine_Api::_()->getApi('settings', 'core')->getSetting('eventdocument.show.editor', 1),
    ));

    $filesize = (int) ini_get('upload_max_filesize') * 1024;
    $show_description = Zend_Registry::get('Zend_Translate')->_('Enter the maximum event document file size in KB. Valid values are from 1 to %s KB.');
    $show_description = sprintf($show_description, $filesize);
    $this->addElement('Text', 'eventdocument_filesize', array(
        'label' => 'Maximum file size',
        'description' => $show_description,
        'value' => Engine_Api::_()->getApi('settings', 'core')->getSetting('eventdocument.filesize', 2048),
    ));

    $this->addElement('Radio', 'eventdocument_scribd_viewer', array(
        'label' => 'Default Document Viewer Type',
        'description' => 'Select the default viewer type for documents on your site. (Note: Secure documents can be viewed in Flash reader only because secure documents use access-management technology which is available in Flash only. Therefore, secure documents will always be viewed in Flash reader, even if you choose HTML5 reader as default.)',
        'multiOptions' => array(
						1 => 'Flash Reader',
            0 => 'HTML5 Reader'
        ),
        'value' => Engine_Api::_()->getApi('settings', 'core')->getSetting('eventdocument.scribd.viewer', 1),
    ));

    $this->addElement('Radio', 'eventdocument_fullscreen_button', array(
        'label' => 'Fullscreen option in Flash Reader',
        'description' => "Do you want the 'Fullscreen' option to be available in the Flash Reader?",
        'multiOptions' => array(
						0 => 'Yes',
            1 => 'No'
        ),
        'value' => Engine_Api::_()->getApi('settings', 'core')->getSetting('eventdocument.fullscreen.button', 0),
    ));

    $this->addElement('Radio', 'eventdocument_flash_mode', array(
        'label' => 'Default View Mode in Flash Reader',
        'description' => 'Choose the default view mode of Flash Reader for viewing documents. Users will be able to change the mode in the viewer.',
        'multiOptions' => array(
						'list' => 'List',
            'book' => 'Book',
            'slide' => 'Slide',
						'tile' => 'Tile'
        ),
        'value' => Engine_Api::_()->getApi('settings', 'core')->getSetting('eventdocument.flash.mode', 'list'),
    ));

    $this->addElement('Radio', 'eventdocument_disable_button', array(
        'label' => 'Disabled links in Reader',
        'description' => 'Do you want the disabled links in the Document Viewer like Download, etc to be hidden?',
        'multiOptions' => array(
						1 => 'Yes',
            0 => 'No'
        ),
        'value' => Engine_Api::_()->getApi('settings', 'core')->getSetting('eventdocument.disable.button', 0),
    ));

    $this->addElement('Radio', 'eventdocument_rating', array(
        'label' => 'Event Document Rating',
        'description' => 'Allow logged-in users to give rating to event documents.',
        'multiOptions' => array(
            1 => ' 	Yes',
            0 => ' 	No'
        ),
        'value' => Engine_Api::_()->getApi('settings', 'core')->getSetting('eventdocument.rating', 1),
    ));

    $this->addElement('Radio', 'eventdocument_report', array(
        'label' => 'Report as inappropriate',
        'description' => 'Allow logged-in users to report event documents as inappropriate.',
        'multiOptions' => array(
            1 => ' 	Yes',
            0 => ' 	No'
        ),
        'value' => Engine_Api::_()->getApi('settings', 'core')->getSetting('eventdocument.report', 1),
    ));

    $this->addElement('Radio', 'eventdocument_share', array(
        'label' => 'Social Sharing Buttons',
        'description' => 'Do you want to show social sharing buttons on the main event document page ?',
        'multiOptions' => array(
            1 => ' 	Yes, show the social sharing buttons on the main event document page.',
            0 => ' 	No, do not show the social sharing buttons on the main event document page.'
        ),
        'value' => Engine_Api::_()->getApi('settings', 'core')->getSetting('eventdocument.share', 1),
    ));

		$social_share_default_code = '<div class="addthis_toolbox addthis_default_style ">
		<a class="addthis_button_preferred_1"></a>
		<a class="addthis_button_preferred_2"></a>
		<a class="addthis_button_preferred_3"></a>
		<a class="addthis_button_preferred_4"></a>
		<a class="addthis_button_preferred_5"></a>
		<a class="addthis_button_compact"></a>
		<a class="addthis_counter addthis_bubble_style"></a>
		</div>
		<script type="text/javascript">
		var addthis_config = {
							services_compact: "facebook, twitter, linkedin, google, digg, more",
							services_exclude: "print, email"
		}
		</script>
		<script type="text/javascript" src="https://s7.addthis.com/js/250/addthis_widget.js"></script>';

    $this->addElement('Textarea', 'eventdocument_code_share', array(
        'description' => "Personalize the code for social sharing buttons by adding your own code generated from: <a href='http://www.addthis.com/' target='_blank'>http://www.addthis.com/</a>. If you do not want to show these buttons, then you can simply empty this field.",
        'value' => Engine_Api::_()->getApi('settings', 'core')->getSetting('eventdocument.code.share', $social_share_default_code),
    ));
		$this->eventdocument_code_share->addDecorator('Description', array('placement' => 'PREPEND','class' => 'description', 'escape' => false));

    $this->addElement('Text', 'eventdocument_viewer_height', array(
        'label' => 'Document Viewer Height',
        'description' => 'What should be the height in pixels of the document viewer on document view page ?',
        'value' => Engine_Api::_()->getApi('settings', 'core')->getSetting('eventdocument.viewer.height', 600),
    ));

    $this->addElement('Text', 'eventdocument_viewer_width', array(
        'label' => 'Document Viewer Width',
        'description' => 'What should be the width in pixels of the document viewer on document view page ?',
        'value' => Engine_Api::_()->getApi('settings', 'core')->getSetting('eventdocument.viewer.width', 730),
    ));

    $this->addElement('Checkbox', 'eventdocument_licensing_option', array(
        'label' => 'Selecting this will allow users to choose the license to be associated with their event documents.',
        'description' => 'Show license option to users',
        'value' => Engine_Api::_()->getApi('settings', 'core')->getSetting('eventdocument.licensing.option', 1),
    ));

    $this->addElement('Select', 'eventdocument_licensing_scribd', array(
        'label' => 'License associated with event documents',
        'description' => 'Choose the license to be associated with the event documents on your site. The license will be shown on your site, as well as on Scribd.com.',
        'multiOptions' => array(
            'ns' => 'Unspecified - no licensing information associated',
            'by' => 'By attribution (by)',
            'by-nc' => 'By attribution, non-commercial (by-nc)',
            'by-nc-nd' => 'By attribution, non-commercial, non-derivative (by-nc-nd)',
            'by-nc-sa' => 'By attribution, non-commercial, share alike (by-nc-sa)',
            'by-nd' => 'By attribution, non-derivative (by-nd)',
            'by-sa' => 'By attribution, share alike (by-sa)',
            'pd' => 'Public domain',
            'c' => 'Copyright - all rights reserved',
        ),
        'value' => Engine_Api::_()->getApi('settings', 'core')->getSetting('eventdocument.licensing.scribd', 'ns'),
    ));
    $this->eventdocument_licensing_scribd->getDecorator('Description')->setOption('placement', 'append');

    $this->addElement('Checkbox', 'eventdocument_include_full_text', array(
        'label' => "If this option is checked, the full text for a event document will be visible if downloading is enabled for that event document and if the iPaper viewer is not visible because of javascript being disabled on user's browser. Also, full text on the page allows search engines to index content, and increases SEO.",
        'description' => 'Include full text on pages',
        'value' => Engine_Api::_()->getApi('settings', 'core')->getSetting('eventdocument.include.full.text', 1),
    ));

    $this->addElement('Radio', 'eventdocument_visitor_fulltext', array(
        'label' => '',
        'description' => ' Do you want full texts for event documents to be included on event document pages for non-logged-in users also? (Choosing "Yes" over here will enable full text on your event document pages to be indexed by search engines.)',
        'multiOptions' => array(
            1 => 'Yes',
            0 => 'No'
        ),
        'value' => Engine_Api::_()->getApi('settings', 'core')->getSetting('eventdocument.visitor.fulltext', 1),
    ));

    $this->addElement('Checkbox', 'eventdocument_save_local_server', array(
        'label' => "Save event documents on your site's server",
        'description' => 'Save event documents on server',
        'value' => Engine_Api::_()->getApi('settings', 'core')->getSetting('eventdocument.save.local.server', 1),
    ));

    $this->addElement('Radio', 'eventdocument_download_allow', array(
        'label' => 'Event Document downloading',
        'description' => 'Enable downloading of event documents.',
        'multiOptions' => array(
            1 => ' 	Yes',
            0 => ' 	No'
        ),
        'value' => Engine_Api::_()->getApi('settings', 'core')->getSetting('eventdocument.download.allow', 1),
    ));

    $this->addElement('Radio', 'eventdocument_download_show', array(
        'description' => 'Show option to users during event document creation to allow downloading of their event documents.',
        'multiOptions' => array(
            1 => ' 	Yes',
            0 => ' 	No'
        ),
        'value' => Engine_Api::_()->getApi('settings', 'core')->getSetting('eventdocument.download.show', 1),
    ));

    $this->addElement('Select', 'eventdocument_download_format', array(
        'label' => 'Download Format',
        'description' => 'Select the format in which the downloadable event documents will be downloaded in.',
        'multiOptions' => array(
            'pdf' => 'PDF',
            'original' => 'Original Event Document Format',
            'txt' => 'Plain Text'
        ),
        'value' => Engine_Api::_()->getApi('settings', 'core')->getSetting('eventdocument.download.format', 'pdf'),
    ));

    $this->addElement('Radio', 'eventdocument_secure_allow', array(
        'label' => 'Secure iPaper Settings',
        'description' => 'Secure event document iPaper cannot be embedded on other sites. Note that this is a permanent setting for a event document during its first upload. Thus any change in this setting will only work for new event document uploads.(Note : This setting will only apply to new event documents created and not to the existing event documents on the site. )',
        'multiOptions' => array(
            1 => 'Make iPaper event documents secure. Do not allow embedding on other sites. (Note: Secure documents can be viewed in Flash reader only because secure documents use access-management technology which is available in Flash only. Therefore, secure documents will always be viewed in Flash reader, even if you choose HTML5 reader as default.)',
            0 => 'Do not make iPaper event documents secure. Allow embedding on other sites.'
        ),
        'value' => Engine_Api::_()->getApi('settings', 'core')->getSetting('eventdocument.secure.allow', 0),
    ));

    $this->addElement('Radio', 'eventdocument_secure_show', array(
        'description' => 'Show security option to users. Allow users to choose if their event documents should be secure or not.',
        'multiOptions' => array(
            1 => ' 	Yes',
            0 => ' 	No'
        ),
        'value' => Engine_Api::_()->getApi('settings', 'core')->getSetting('eventdocument.secure.show', 1),
    ));

    $this->addElement('Radio', 'eventdocument_email_allow', array(
        'label' => 'Email attachment Settings',
        'description' => 'Enable emailing as attachments for event documents on your site.',
        'multiOptions' => array(
            1 => ' 	Yes',
            0 => ' 	No'
        ),
        'value' => Engine_Api::_()->getApi('settings', 'core')->getSetting('eventdocument.email.allow', 1),
    ));

    $this->addElement('Radio', 'eventdocument_email_show', array(
        'description' => 'Allow members to choose during event document creation if their event documents could be emailed as attachments or not.',
        'multiOptions' => array(
            1 => ' 	Yes',
            0 => ' 	No'
        ),
        'value' => Engine_Api::_()->getApi('settings', 'core')->getSetting('eventdocument.email.show', 1),
    ));

    $this->addElement('Radio', 'eventdocument_title_truncation', array(
        'label' => 'Show Full Title Without Truncation',
        'description' => 'Do you want to show the full event document title without truncation on various pages like widgets, event profile etc..',
        'multiOptions' => array(
            1 => 'Yes',
            0 => 'No'
        ),
        'value' => Engine_Api::_()->getApi('settings', 'core')->getSetting('eventdocument.title.truncation', 0),
    ));

    $this->addElement('Button', 'submit', array(
        'label' => 'Save Changes',
        'type' => 'submit',
        'ignore' => true
    ));
  }

}
