<?php

/**
 * SocialEngine
 *
 * @category   Application_Extensions
 * @package    Eventdocument
 * @copyright  Copyright 20011-2012 BigStep Technologies Pvt. Ltd.
 * @license    http://www.socialengineaddons.com/license/
 * @version    $Id: Eventdocument.php 2012-01-25 9:40:21Z SocialEngineAddOns $
 * @author     SocialEngineAddOns
 */
class Eventdocument_Model_Document extends Core_Model_Item_Abstract {

  protected $_owner_type = 'user';
  protected $_parent_type = 'user';
  //WORK FOR GLOBAL SEARCH
  protected $_searchColumns = array('title', 'description', 'fulltext');
  protected $_parent_is_owner = true;

	public function getMediaType() {
		return 'document';
	}


  //ENTRY OF FILE IN STORAGE TABLE
  public function setFile($file_pass) {
    if ($file_pass instanceof Zend_Form_Element_File) {
      $file = $file_pass->getFileName();
    } else if (is_array($file_pass) && !empty($file_pass['tmp_name'])) {
      $file = $file_pass['tmp_name'];
    } else if (is_string($file_pass) && file_exists($file_pass)) {
      $file = $file_pass;
    } else {
      throw new Eventdocument_Model_Exception('invalid argument passed to setFile');
    }
    $params = array(
        'parent_type' => 'eventdocument',
        'parent_id' => $this->getIdentity()
    );

    try {
      $eventdocument_return = Engine_Api::_()->storage()->create($file, $params);
    } catch (Exception $e) {
      $msg = $e->getMessage();
      return $msg;
    }

    if (!empty($eventdocument_return->file_id)) {

      //UPDATE FILE INFORMATION INTO DATABASE
      $this->modified_date = new Zend_Db_Expr('NOW()');
      $this->filename_id = $eventdocument_return->file_id;
      $this->storage_path = APPLICATION_PATH . '/' . $eventdocument_return->storage_path;
      $this->save();

      $storagemodule = Engine_Api::_()->getDbtable('modules', 'core')->getModule('storage');
      $storageversion = $storagemodule->version;
      if ($storageversion < '4.1.1') {
        $file_path = $eventdocument_return->storage_path;
      } else {
        $file_path = $eventdocument_return->map();
      }

      $eventdocument_info = array('eventdocument' => $this,
          'file_path' => $file_path);
      return $eventdocument_info;
    }
  }

  /**
   * Return a file name of document
   *
   * @return file name of document
   * */
  public function getDocumentFileName() {

    //FILENAME FROM STORAGE TABLE
    $tableStorage = Engine_Api::_()->getDbtable('files', 'storage');
    $tableStorageName = $tableStorage->info('name');
    $tableDocumentName = Engine_Api::_()->getDbtable('documents', 'eventdocument')->info('name');

    $file_name = $tableStorage->select()
                    ->setIntegrityCheck(false)
                    ->from($tableDocumentName, array(''))
                    ->join($tableStorageName, "$tableStorageName.file_id = $this->filename_id", array('name'))
                    ->where($tableStorageName . '.parent_type = ?', 'eventdocument')
                    ->query()
                    ->fetchColumn();
    return $file_name;
  }

  /**
   * Gets an absolute URL to the page to view this item
   *
   * @return string
   */
  public function getHref($params = array()) {
    $slug = trim(preg_replace('/-+/', '-', preg_replace('/[^a-z0-9-]+/i', '-', strtolower($this->getTitle()))), '-');

    $tab_id = Engine_Api::_()->eventdocument()->getTabId();

    $params = array_merge(array(
                'route' => 'eventdocument_detail_view',
                'reset' => true,
                'user_id' => $this->owner_id,
                'document_id' => $this->document_id,
                'slug' => $slug,
                'tab_id' => $tab_id,
                    ), $params);

    $route = $params['route'];
    $reset = $params['reset'];
    unset($params['route']);
    unset($params['reset']);
    return Zend_Controller_Front::getInstance()->getRouter()
            ->assemble($params, $route, $reset);
  }

  /**
   * Return a document title
   *
   * @return title
   * */
  public function getTitle() {
    return $this->title;
  }

  /**
   * Return a document trunacte description
   *
   * @return truncate description
   * */
  public function getDescription() {
    $tmpBody = strip_tags($this->description);
    return ( Engine_String::strlen($tmpBody) > 200 ? Engine_String::substr($tmpBody, 0, 200) . '...' : $tmpBody );
  }

  /**
   * Gets a proxy object for the comment handler
   *
   * @return Engine_ProxyObject
   * */
  public function comments() {
    return new Engine_ProxyObject($this, Engine_Api::_()->getDbtable('comments', 'core'));
  }

  /**
   * Gets a proxy object for the like handler
   *
   * @return Engine_ProxyObject
   * */
  public function likes() {
    return new Engine_ProxyObject($this, Engine_Api::_()->getDbtable('likes', 'core'));
  }

}