<?php

/**
 * SocialEngine
 *
 * @category   Application_Extensions
 * @package    Eventdocument
 * @copyright  Copyright 20011-2012 BigStep Technologies Pvt. Ltd.
 * @license    http://www.socialengineaddons.com/license/
 * @version    $Id: IndexController.php 2012-01-25 9:40:21Z SocialEngineAddOns $
 * @author     SocialEngineAddOns
 */
include_once APPLICATION_PATH . '/application/modules/Eventdocument/Api/Scribdevent.php';

class Eventdocument_IndexController extends Core_Controller_Action_Standard {

  //COMMAN FUNCTION WHICH CALLS AUTOMATICALLY BEFORE ALL ACTIONS
  public function init() {
    //SET SCRIBD API AND SCECRET KEY
    $this->scribd_api_key = Engine_Api::_()->getApi('settings', 'core')->eventdocument_api_key;
    $this->scribd_secret = Engine_Api::_()->getApi('settings', 'core')->eventdocument_secret_key;
    $this->scribdevent = new Scribdevent($this->scribd_api_key, $this->scribd_secret);
  }

  //ACTION FOR CREATE THE NEW DOCUMENT
  public function createAction() {
    //USER VALIDATION
    if (!$this->_helper->requireUser()->isValid())
      return;

    //GET VIEWER INFORMATION
    $viewer = Engine_Api::_()->user()->getViewer();
    $viewer_id = $viewer->getIdentity();

    //GET EVENT ID AND OBJECT
    $event_id = $this->_getParam('event_id');
    $event = Engine_Api::_()->getItem('event', $event_id);

    //WHO CAN VIEW THIS DOCUMENT
    if (!$event->authorization()->isAllowed($viewer, 'view')) {
      return $this->_forward('requireauth', 'error', 'core');
    }

    //CHECK WHO CAN CREATE DOCUMENTS
    $can_create = Engine_Api::_()->authorization()->isAllowed($event, $viewer, 'edcreate');
    if (empty($can_create)) {
      return $this->_forward('requireauth', 'error', 'core');
    }

    //MAKE LINK OF "Back to Event Documents"
    $this->view->tab_selected_id = Engine_Api::_()->eventdocument()->getTabId();
    $this->view->event_id = $event_id = $this->_getParam('event_id');

    global $eventdocument_requireauth;

    //SHOW DOCUMENT CREATE FORM
    $this->view->form = $form = new Eventdocument_Form_Create();

    //CHECK THAT CREATOR ALREADY HAVE DOCUMENTS AT SCRIBD SITE
    try {
      $result = $this->scribdevent->getList();
    } catch (Exception $e) {
      $code = $e->getCode();
      if ($code == 401) {
        $message = $e->getMessage();

        $error = $message . $this->view->translate(': API key is not correct');
        $error = Zend_Registry::get('Zend_Translate')->_($error);

        $form->getDecorator('errors')->setOption('escape', false);
        $form->addError($error);
        return;
      }
    }

    if ($this->getRequest()->isPost() && $form->isValid($this->getRequest()->getPost())) {

      //CONNET WITH DOCUMENT TABLE
      $eventdocumentTable = Engine_Api::_()->getItemTable('eventdocument_document');
      $db = $eventdocumentTable->getAdapter();
      $db->beginTransaction();

      //GET POSTED VALUES FROM CREATE FORM
      $values = $form->getValues();

      //SET SCRIBD MY_USER_ID
      $this->scribdevent->my_user_id = $viewer_id;

      //DOCUMENT CREATION CODE
      try {
        $values = array_merge($form->getValues(), array(
                    'owner_type' => $viewer->getType(),
                    'owner_id' => $viewer->getIdentity(),
                ));
        $this->view->is_error = $this->view->excep_error = 0;

        //MAKE SURE THAT FILE SIZE SHOULD NOT EXCEED FROM ALLOWED LIMIT DEPEND ON USER LEVEL
        $filesize = Engine_Api::_()->getApi('settings', 'core')->getSetting('eventdocument.filesize', 2048);
        $filesize = $filesize * 1024;
        if ($filesize < 0) {
          $filesize = (int) ini_get('upload_max_filesize') * 1024 * 1024;
        }
        if ($_FILES['filename']['size'] > $filesize) {
          $error = $this->view->translate('File size can not be exceed from ') . ($filesize / 1024) . $this->view->translate(' KB');
          $error = Zend_Registry::get('Zend_Translate')->_($error);

          $form->getDecorator('errors')->setOption('escape', false);
          $form->addError($error);
          return;
        }

        if (empty($eventdocument_requireauth)) {
          return;
        }

        //MAKE SURE THAT FILE EXTENSION SHOULD NOT DIFFER FROM ALLOWED TYPE
        $ext = str_replace(".", "", strrchr($_FILES['filename']['name'], "."));
        if (!in_array($ext, array('pdf', 'txt', 'ps', 'rtf', 'epub', 'odt', 'odp', 'ods', 'odg', 'odf', 'sxw', 'sxc', 'sxi', 'sxd', 'doc', 'ppt', 'pps', 'xls', 'docx', 'pptx', 'ppsx', 'xlsx', 'tif', 'tiff'))) {
          $error = $this->view->translate("Invalid file extension. Allowed extensions are :'pdf', 'txt', 'ps', 'rtf', 'epub', 'odt', 'odp', 'ods', 'odg', 'odf', 'sxw', 'sxc', 'sxi', 'sxd', 'doc', 'ppt', 'pps', 'xls', 'docx', 'pptx', 'ppsx', 'xlsx', 'tif', 'tiff'");
          $error = Zend_Registry::get('Zend_Translate')->_($error);

          $form->getDecorator('errors')->setOption('escape', false);
          $form->addError($error);
          return;
        }

        //CHECKS FOR SCRIBD LICENSE AND LICENSE OPTION
        $licensing_option = Engine_Api::_()->getApi('settings', 'core')->getSetting('eventdocument.licensing.option', 1);
        $licensing_scribd = Engine_Api::_()->getApi('settings', 'core')->getSetting('eventdocument.licensing.scribd', 'ns');

        if ($licensing_option == 0) {
          $license_eventdocument = $licensing_scribd;
					$values['license'] = $licensing_scribd;
        } else {
          $license_eventdocument = $values['license'];
        }

        if ($license_eventdocument == 'ns') {
          $scribd_license = null;
        } else {
          $scribd_license = $license_eventdocument;
        }

        $eventdocument_download = $values['download_allow'];

        //CREATE THE MAIN DOCUMENT
        $eventdocumentRow = $eventdocumentTable->createRow();
        $eventdocumentRow->setFromArray($values);
        $eventdocumentRow->owner_id = $viewer_id;
        $eventdocumentRow->event_id = $event_id;
        $event = Engine_Api::_()->getItem('event', $event_id);
        $eventdocumentRow->save();

        //SECURE IPAPER CHECK
        $secure_allow = Engine_Api::_()->getApi('settings', 'core')->getSetting('eventdocument.secure.allow', 0);
        $secure_show = Engine_Api::_()->getApi('settings', 'core')->getSetting('eventdocument.secure.show', 1);
        if (empty($secure_allow)) {
          $eventdocumentRow->secure_allow = 0;
        } elseif (empty($secure_show)) {
          $eventdocumentRow->secure_allow = 1;
        } else {
          $eventdocumentRow->secure_allow = $values['secure_allow'];
        }

        //DOWNLOAD ALLOW CHECK
        $download_allow = Engine_Api::_()->getApi('settings', 'core')->getSetting('eventdocument.download.allow', 1);
        $download_show = Engine_Api::_()->getApi('settings', 'core')->getSetting('eventdocument.download.show', 1);
        if (empty($download_allow)) {
          $eventdocumentRow->download_allow = 0;
        } elseif (empty($download_show)) {
          $eventdocumentRow->download_allow = 1;
        } else {
          $eventdocumentRow->download_allow = $values['download_allow'];
        }

        $eventdocument_download = $eventdocumentRow->download_allow;

        //CHECKS FOR DEFAULT VISIBILITY
        $eventdocument_default_visibility = Engine_Api::_()->getApi('settings', 'core')->getSetting('eventdocument.default.visibility', 'private');
        $eventdocument_visibility_option = Engine_Api::_()->getApi('settings', 'core')->getSetting('eventdocument.visibility.option', 1);
        if ($eventdocument_default_visibility == 'private') {
          $access = 'private';
        } elseif ($eventdocument_visibility_option == 1) {
          $access = $values['default_visibility'];
        } else {
          $access = 'public';
        }
        $eventdocumentRow->private = $access;

        //IF FILENAME IS NOT EMPTY THAN BEGIN THE SCRIBD WORK
        if (!empty($values['filename'])) {
          $local_info = $eventdocumentRow->setFile($form->filename);
          $secure_allow = $eventdocumentRow->secure_allow;
          $download = "view-only";
					$rev_id = NULL;
          $data = $this->scribdUpload($local_info, $rev_id, $access, $secure_allow, $download, $eventdocumentRow->filename_id);
        }
        $doc_title = $values['title'];
        $description = $values['description'];
        try {
          $changesetting = $this->scribdevent->changeSettings($data['doc_id'], $doc_title, $description, $access, $scribd_license, $eventdocument_download);

          $setting = $this->scribdevent->getSettings($data['doc_id']);
        } catch (Exception $e) {
          $message = $e->getMessage();
          $this->view->excep_error = 1;
          $this->view->excep_message = $message;
        }

        //EMAIL ALLOW CHECK
        $email_allow = Engine_Api::_()->getApi('settings', 'core')->getSetting('eventdocument.email.allow', 1);
        $email_show = Engine_Api::_()->getApi('settings', 'core')->getSetting('eventdocument.email.show', 1);
        if (empty($email_allow)) {
          $eventdocumentRow->email_allow = 0;
        } elseif (empty($email_show)) {
          $eventdocumentRow->email_allow = 1;
        } else {
          $eventdocumentRow->email_allow = $values['email_allow'];
        }

        $eventdocumentRow->approved = 1;
        $eventdocumentRow->featured = 0;
        $eventdocumentRow->doc_id = $data['doc_id'];
        $eventdocumentRow->access_key = $data['access_key'];
        $eventdocumentRow->secret_password = $data['secret_password'];
        $eventdocumentRow->filemime = $_FILES['filename']['type'];
        $eventdocumentRow->filesize = $_FILES['filename']['size'];
        $eventdocumentRow->save();

        //COMMENT PRIVACY
        $auth = Engine_Api::_()->authorization()->context;
        $roles = array('owner', 'owner_member', 'owner_member_member', 'owner_network', 'everyone');
        $auth_comment = "everyone";
        $commentMax = array_search($auth_comment, $roles);
        foreach ($roles as $i => $role) {
          $auth->setAllowed($eventdocumentRow, $role, 'comment', ($i <= $commentMax));
        }

        //SAVE CUSTOM FIELDS VALUES
        $customfieldform = $form->getSubForm('fields');
        $customfieldform->setItem($eventdocumentRow);
        $customfieldform->saveValues();

        //COMMIT
        $db->commit();
      } catch (Exception $e) {
        $db->rollBack();
        throw $e;
      }

      //GO TO EVENT PROFILE PAGE WITH EVENT DOCUMENT SELECTED TAB
      $event_id = $this->_getParam('event_id');

			if(Engine_Api::_()->getDbtable('modules', 'core')->isModuleEnabled('ynevent')) {
				return $this->_helper->redirector->gotoRoute(array('id' => $event_id), 'event_profile', true);
			}
			else {
				return $this->_helper->redirector->gotoRoute(array('id' => $event_id, 'tab' => Engine_Api::_()->eventdocument()->getTabId()), 'event_profile', true);
			}
    }
  }

   //ACTION FOR RETURN THE SCRIBD THUMBNAIL IMAGE
   public function sslAction() {
 
 		$url = urldecode($_GET['url']);
 		header("Cache-Control: no-cache");
 		header("Content-type:image/jpeg");
 		$image2 = imagecreatefromjpeg($url);
 		$width = imagesx($image2);
 		$height = imagesy($image2);
 		$imgh = 84;
 		$imgw = $width / $height * $imgh;
 		$thumb=imagecreatetruecolor($imgw,$imgh);
 		imagecopyresampled($thumb,$image2,0,0,0,0,$imgw,$imgh,$width,$height);
 		imagejpeg($thumb);
 		die;
 	}

  //ACTION FOR EDIT THE DOCUMENT
  public function editAction() {
    //CHECK USER VALIDATION
    if (!$this->_helper->requireUser()->isValid())
      return;

    //GET LOGGED IN USER INFORMATION
    $viewer = Engine_Api::_()->user()->getViewer();
    $viewer_id = $viewer->getIdentity();

    //GET DOCUMENT INFO
    $eventdocument = Engine_Api::_()->getItem('eventdocument_document', $this->_getParam('document_id'));

    //GET USER LEVEL
    $level_id = Engine_Api::_()->user()->getViewer()->level_id;

    //GET EVENT OWNER ID
    $event_user_id = Engine_Api::_()->eventdocument()->eventUserId($eventdocument->event_id);

    //SUPERADMIN, DOCUMENT OWNER AND EVENT OWNER CAN EDIT DOCUMENT
    if ($level_id != 1 && $viewer_id != $eventdocument->owner_id && $viewer_id != $event_user_id) {
      return $this->_forward('requireauth', 'error', 'core');
    }

    //GENERATE EDIT FORM
    $this->view->form = $form = new Eventdocument_Form_Edit(array('item' => $eventdocument));

    //SEND TAB AND EVENT ID TO TPL FILE
    $this->view->tab_selected_id = Engine_Api::_()->eventdocument()->getTabId();
    $this->view->event_id = $event_id = $this->_getParam('event_id');

    //GET EVENT OBJECT
    $event = Engine_Api::_()->getItem('event', $event_id);

    //IF DOCUMENT IN PUBLISHED STAT THAN REMOVE ELEMENT
    if ($eventdocument->draft == "0") {
      $form->removeElement('draft');
    }

    //SET SCRIBD MY_USER_ID
    $this->scribdevent->my_user_id = $eventdocument->owner_id;

    //SAVE DOCUMENT DETAIL
    $saved = $this->_getParam('saved');
    if (!$this->getRequest()->isPost() || $saved) {
      if ($saved) {
        $url = $this->_helper->url->url(array('user_id' => $eventdocument->owner_id, 'document_id' => $eventdocument->getIdentity()), 'eventdocument_detail_view');
        $form->addNotice(Zend_Registry::get('Zend_Translate')->_('Your changes were saved. Click <a href=\'%1$s\'>here</a> to view your document.', $url));
      }

      //SHOW PREFIELD
      $form->populate($eventdocument->toArray());

      return;
    }
    if (!$form->isValid($this->getRequest()->getPost())) {
      return;
    }

    $values = $form->getValues();

    $db = Engine_Db_Table::getDefaultAdapter();
    $db->beginTransaction();

    try {
      $eventdocument->setFromArray($values);
      $eventdocument->modified_date = new Zend_Db_Expr('NOW()');
      $doc_title = $values['title'];
      $description = $values['description'];

      $eventdocument_download = $values['download_allow'];

      $license_eventdocument = $values['license'];

      if ($license_eventdocument == 'ns') {
        $scribd_license = null;
      } else {
        $scribd_license = $license_eventdocument;
      }

      //CHECKS FOR DEFAULT VISIBILITY
      $eventdocument_default_visibility = Engine_Api::_()->getApi('settings', 'core')->getSetting('eventdocument.default.visibility', 'private');
      $eventdocument_visibility_option = Engine_Api::_()->getApi('settings', 'core')->getSetting('eventdocument.visibility.option', 1);
      if ($eventdocument_default_visibility == 'private') {
        $access = 'private';
      } elseif ($eventdocument_visibility_option == 1) {
        $access = $values['default_visibility'];
      } else {
        $access = 'public';
      }
      $eventdocument->private = $access;

      //MAKE SURE THAT FILE SIZE SHOULD NOT EXCEED FROM ALLOWED LIMIT DEPEND ON USER LEVEL
      if (!empty($_FILES['filename']['name'])) {
        $filesize = Engine_Api::_()->getApi('settings', 'core')->getSetting('eventdocument.filesize', 2048);
        $filesize = $filesize * 1024;
        if ($filesize < 0) {
          $filesize = (int) ini_get('upload_max_filesize') * 1024 * 1024;
        }
        if ($_FILES['filename']['size'] > $filesize) {
          $error = $this->view->translate('Filesize can not be exceed from ') . $filesize . $this->view->translate(' KB for this user level');
          $error = Zend_Registry::get('Zend_Translate')->_($error);

          $form->getDecorator('errors')->setOption('escape', false);
          $form->addError($error);
          return;
        }

        //MAKE SURE THAT FILE EXTENSION SHOULD NOT DIFFER FROM ALLOWED TYPE
        $ext = str_replace(".", "", strrchr($_FILES['filename']['name'], "."));
        if (!in_array($ext, array('pdf', 'txt', 'ps', 'rtf', 'epub', 'odt', 'odp', 'ods', 'odg', 'odf', 'sxw', 'sxc', 'sxi', 'sxd', 'doc', 'ppt', 'pps', 'xls', 'docx', 'pptx', 'ppsx', 'xlsx', 'tif', 'tiff'))) {
          $error = $this->view->translate('Invalid file extension!');
          $error = Zend_Registry::get('Zend_Translate')->_($error);

          $form->getDecorator('errors')->setOption('escape', false);
          $form->addError($error);
          return;
        }

        //IF FILENAME IS NOT EMPTY THAN BEGIN THE SCRIBD WORK
        if (!empty($values['filename'])) {

          $filename_id_prev = $eventdocument->filename_id;
					$rev_id = $eventdocument->doc_id;
          $local_info = $eventdocument->setFile($form->filename);
          $secure_allow = $eventdocument->secure_allow;
					$download = "view-only";
          $data = $this->scribdUpload($local_info, $rev_id, $access, $secure_allow, $download, $eventdocument->filename_id);

          //FIRST DELETE FILE ENTRY FROM engine4_storage_files
          Engine_Api::_()->getDbtable('files', 'storage')->delete(array(
              'file_id = ?' => $filename_id_prev,
          ));
        }

        try {
          $stat = $this->scribdevent->getConversionStatus($data['doc_id']);
        } catch (Exception $e) {
          $message = $e->getMessage();
          $this->view->excep_error = 1;
          $this->view->excep_message = $message;
        }

        try {
          $changesetting = $this->scribdevent->changeSettings($data['doc_id'], $doc_title, $description, $access, $scribd_license, $eventdocument_download);
          $setting = $this->scribdevent->getSettings($data['doc_id']);
        } catch (Exception $e) {
          $message = $e->getMessage();
          $this->view->excep_error = 1;
          $this->view->excep_message = $message;
        }

        $eventdocument->status = 0;
        $eventdocument->doc_id = $data['doc_id'];
        $eventdocument->access_key = $data['access_key'];
        $eventdocument->secret_password = $data['secret_password'];
        $eventdocument->filemime = $_FILES['filename']['type'];
        $eventdocument->filesize = $_FILES['filename']['size'];
        $eventdocument->thumbnail = NULL;
        //FILE UPLOADING WORK END HERE
      }
      $eventdocument->save();

      $customfieldform = $form->getSubForm('fields');
      $customfieldform->setItem($eventdocument);
      $customfieldform->saveValues();

      $draft_value = 0;
      if (isset($values['draft'])) {
        $draft_value = $values['draft'];
      }

      //INSERT NEW ACTIVITY IF DOCUMENT IS JUST GETTING PUBLISHED
      $action = Engine_Api::_()->getDbtable('actions', 'activity')->getActionsByObject($eventdocument);
      if (count($action->toArray()) <= 0 && $draft_value == 0 && $eventdocument->approved == 1 && $eventdocument->status == 1 && $eventdocument->activity_feed == 0) {
        $action = Engine_Api::_()->getDbtable('actions', 'activity')->addActivity($viewer, $event, 'eventdocument_new');

        //MAKE SURE ACTION EXISTS BEFOR ATTACHING THE DOCUMENT TO THE ACTIVITY
        if ($action != null) {
          Engine_Api::_()->getDbtable('actions', 'activity')->attachActivity($action, $eventdocument);
          $eventdocument->activity_feed = 1;
          $eventdocument->save();
        }
      }

      $actionTable = Engine_Api::_()->getDbtable('actions', 'activity');
      foreach ($actionTable->getActionsByObject($eventdocument) as $action) {
        $actionTable->resetActivityBindings($action);
      }
      $db->commit();

			if(Engine_Api::_()->getDbtable('modules', 'core')->isModuleEnabled('ynevent')) {
				return $this->_helper->redirector->gotoRoute(array('id' => $event_id), 'event_profile', true);
			}
			else{
				return $this->_helper->redirector->gotoRoute(array('id' => $event_id, 'tab' => Engine_Api::_()->eventdocument()->getTabId()), 'event_profile', true);
			}

    } catch (Exception $e) {
      $db->rollBack();
      throw $e;
    }
  }

  //ACTION FOR VIEW THE DOCUMENT
  public function viewAction() {
    //GET LOGGED IN USER INFORMATION
    $viewer = Engine_Api::_()->user()->getViewer();
    $this->view->viewer_id = $viewer_id = $viewer->getIdentity();

    //GET USER LEVEL
    if (!empty($viewer_id)) {
      $level_id = Engine_Api::_()->user()->getViewer()->level_id;
    } else {
      $level_id = Engine_Api::_()->getDbtable('levels', 'authorization')->fetchRow(array('type = ?' => "public"))->level_id;
    }

    //GET DOCUMNET MODEL
    $this->view->eventdocument = $eventdocument = Engine_Api::_()->getItem('eventdocument_document', $this->_getParam('document_id'));
    if (empty($eventdocument)) {
      return $this->_forward('notfound', 'error', 'core');
    }

    //GET EVENT ID AND SEND TO TPL
    $this->view->event_id = $event_id = $eventdocument->event_id;

    //GET EVENT OBJECT
    $event = Engine_Api::_()->getItem('event', $event_id);

    //GET EVENT OWNER ID
    $this->view->event_user_id = $event->user_id;

    //WHO CAN VIEW THIS DOCUMENT
    if (!$event->authorization()->isAllowed($viewer, 'view')) {
      return $this->_forward('requireauth', 'error', 'core');
    }

    //SUPERADMIN, DOCUMENT OWNER AND EVENT OWNER CAN VIEW DOCUMENT
    if ($level_id != 1 && $viewer_id != $eventdocument->owner_id && $viewer_id != $event->user_id) {
      if ($eventdocument->draft == 1 || $eventdocument->status != 1 || $eventdocument->approved != 1 || $eventdocument->search != 1) {
        return $this->_forward('requireauth', 'error', 'core');
      }
    }
    
    //WHO CAN COMMENT THIS DOCUMENT
    $this->view->can_comment = 1;
    if ($level_id != 1) {
      $this->view->can_comment = $event->authorization()->isAllowed(null, 'comment');
    }

    //SEND EVENT TITLE TO TPL
    $this->view->event_title = $event_title = $event->title;    

    //CHECK THAT VIEWER CAN RATE THE DOCUMENT OR NOT
    $this->view->can_rate = Engine_Api::_()->getApi('settings', 'core')->getSetting('eventdocument.rating', 1);

    //CHECK THAT VIEWER CAN SHARE THE DOCUMENT OR NOT
    $this->view->can_share = Engine_Api::_()->getApi('settings', 'core')->getSetting('eventdocument.share', 1);

    //GET OWNER INFORMATION
    $this->view->owner = $owner = $eventdocument->getOwner();

		$this->view->ynevent_enabled = Engine_Api::_()->getDbtable('modules', 'core')->isModuleEnabled('ynevent');

		//SSL WORK
		$this->view->https = 0;
		if (!empty($_SERVER["HTTPS"]) && 'on' == strtolower($_SERVER["HTTPS"])) {
			$this->view->https = 1;
    }
		$this->view->manifest_path = "eventdocuments";

    //GET CURRENT URL
    $front = Zend_Controller_Front::getInstance();
		if(!empty($this->view->https)) {
			$curr_url = 'https://' . $_SERVER['HTTP_HOST'] . $front->getRequest()->getRequestUri();
		}
		else {
			$curr_url = 'http://' . $_SERVER['HTTP_HOST'] . $front->getRequest()->getRequestUri();
		}
    $this->view->curr_url = urlencode((string) $curr_url);

    //INCREMENT DOCUMENT VIEWS IF VIEWER IS NOT OWNER
    if (!$owner->isSelf($viewer)) {
      $eventdocument->view_count++;
    }

    //SET SCRIBD USER ID
    $this->scribdevent->my_user_id = $eventdocument->owner_id;

    $stat = null;
    if (!empty($eventdocument->doc_id)) {
      try {
        $stat = trim($this->scribdevent->getConversionStatus($eventdocument->doc_id));
      } catch (Exception $e) {
        $message = $e->getMessage();
        $this->view->excep_error = 1;
        $this->view->excep_message = $message;
      }
    }

		//GET EMAIL, DOWNLOAD AND DOWNLOAD FORMAT SETTINGS
    $this->view->email_allow = Engine_Api::_()->getApi('settings', 'core')->getSetting('eventdocument.email.allow', 1);
    $this->view->download_allow = $download_allow = Engine_Api::_()->getApi('settings', 'core')->getSetting('eventdocument.download.allow', 1);
		$download_format = Engine_Api::_()->getApi('settings', 'core')->getSetting('eventdocument.download.format', 'pdf');

    if (!empty($viewer_id)) {
      if ($download_allow && $stat == 'DONE' && $eventdocument->download_allow) {
        try {
          $link = $this->scribdevent->getDownloadUrl($eventdocument->doc_id, $download_format);
        } catch (Exception $e) {
          $message = $e->getMessage();
          $this->view->excep_error = 1;
          $this->view->excep_message = $message;
        }
        $this->view->link = trim($link['download_link']);
        $eventdocument_include_full_text = Engine_Api::_()->getApi('settings', 'core')->getSetting('eventdocument.include.full.text', 1);
        if ($eventdocument_include_full_text == 1) {
          $doc_full_text = $eventdocument->fulltext;
          $this->view->doc_full_text = $doc_full_text;
        }
      }
    } else { //We show full text in case of nonlogged in user if document is available for downloading and Admin had allowd for full text in global settings
      if ($stat == 'DONE') {
        $eventdocument_include_full_text = Engine_Api::_()->getApi('settings', 'core')->getSetting('eventdocument.include.full.text', 1);
        $eventdocument_visitor_fulltext = Engine_Api::_()->getApi('settings', 'core')->getSetting('eventdocument.visitor.fulltext', 1);
        if ($eventdocument_include_full_text == 1 && $eventdocument_visitor_fulltext == 1 && $eventdocument->download_allow) {
          $doc_full_text = $eventdocument->fulltext;
          $this->view->doc_full_text = $doc_full_text;
        }
      }
    }

    //IF STAT IS DONE THAN UPDATE DOCUMENT STATUS AND OTHER INFORMATION
    if ($stat == 'DONE') {
      try {
        //GETTING DOCUMENT'S FULL TEXT
        $texturl = $this->scribdevent->getDownloadUrl($eventdocument->doc_id, 'txt');
        if ($eventdocument->status != 1) {
          $texturl = trim($texturl['download_link']);
          $file_contents = file_get_contents($texturl);
          if (empty($file_contents)) {
            $site_url = $texturl;
            $ch = curl_init();
            $timeout = 0; //set to zero for no timeout
            curl_setopt($ch, CURLOPT_URL, $site_url);
            curl_setopt($ch, CURLOPT_CONNECTTIMEOUT, $timeout);

            ob_start();
            curl_exec($ch);
            curl_close($ch);
            $file_contents = ob_get_contents();
            ob_end_clean();
          }
          $full_text = $file_contents;
          $eventdocument->fulltext = $full_text;
          $eventdocument->save();

        }
      } catch (Exception $e) {
        if ($eventdocument->status != 3 && $e->getCode() == 619) {
          $eventdocument->status = 3;
          $eventdocument->save();

          //SEND EMAIL TO DOCUMENT OWNER IF EVENT DOCUMENT HAS BEEN DELETED FROM SCRIBD
          Engine_Api::_()->eventdocument()->emailDocumentDelete($eventdocument, $event_title, $event->user_id);
        }
      }
      
      if($eventdocument->status != 3 && $eventdocument->status != 2) {
          $setting = $this->scribdevent->getSettings($eventdocument->doc_id);
          $thumbnail_url = trim($setting['thumbnail_url']);
          $eventdocument->thumbnail = $thumbnail_url;
          $eventdocument->status = 1;
          $eventdocument->save();

          //ADD ACTIVITY ONLY IF DOCUMENT IS PUBLISHED
          if ($eventdocument->draft == 0 && $eventdocument->approved == 1 && $eventdocument->status == 1 && $eventdocument->activity_feed == 0) {
            $api = Engine_Api::_()->getDbtable('actions', 'activity');
            $creator = Engine_Api::_()->getItem('user', $eventdocument->owner_id);
            $action = $api->addActivity($creator, $event, 'eventdocument_new');

            //MAKE SURE ACTION EXISTS BEFORE ATTACHING THE DOUCMENT TO THE ACTIVITY
            if ($action != null) {
              $api->attachActivity($action, $eventdocument);
              $eventdocument->activity_feed = 1;
              $eventdocument->save();
            }
          }
      }      

    } elseif ($stat == 'ERROR') {
      if ($eventdocument->status != 2) {
        $eventdocument->status = 2;
        $eventdocument->save();
      }
    } else {
      $eventdocument->save();
    }

    //DELETE DOCUMENT FROM SERVER IF ALLOWED BY ADMIN AND HAS STATUS ONE OR TWO
    $eventdocument_save_local_server = Engine_Api::_()->getApi('settings', 'core')->getSetting('eventdocument.save.local.server', 1);
    if ($eventdocument_save_local_server == 0 && ($eventdocument->status == 1 || $eventdocument->status == 2)) {
      Engine_Api::_()->eventdocument()->deleteServerDocument($eventdocument->document_id);
    }

    //SETTING PARAMETERS FOR SECURE DOCUMENT
    if ($viewer->getIdentity() == 0) {
      $uid = mt_rand(1000, 100000);
    } else {
      $uid = $viewer->getIdentity();
    }
    $scribd_secret = Engine_Api::_()->getApi('settings', 'core')->eventdocument_secret_key;
    $sessionId = session_id();
    $signature = md5($scribd_secret . 'document_id' . $eventdocument->doc_id . 'session_id' . $sessionId . 'user_identifier' . $uid);
    $this->view->uid = $uid;
    $this->view->sessionId = $sessionId;
    $this->view->signature = $signature;
    $this->view->download_allow = $download_allow;

    //FETCH 3 RECENT DOCUMENT OF SAME EVENT
    $this->view->eventdocumentUser = Engine_Api::_()->getDbtable('documents', 'eventdocument')->sameEventDocuments($event_id, $eventdocument->document_id);
    $this->view->eventdocumentUserTotal = Count($this->view->eventdocumentUser);

    //REPORT CODE
    $this->view->eventdocument_report = $eventdocument_report = Engine_Api::_()->getApi('settings', 'core')->getSetting('eventdocument.report', 1);
    if (!empty($viewer_id) && $eventdocument_report == 1) {
      $report = $this->view->report = $eventdocument;
      if (!empty($report)) {
        Engine_Api::_()->core()->setSubject($report);
      }
      if (!$this->_helper->requireSubject()->isValid())
        return;
    }

    //RATING WORK
    $this->view->rating_count = Engine_Api::_()->getDbTable('ratings', 'eventdocument')->countRating($eventdocument->getIdentity());
    $this->view->eventdocument_rated = Engine_Api::_()->getDbTable('ratings', 'eventdocument')->previousRated($eventdocument->getIdentity(), $viewer_id);

    //CUSTOM FIELD WORK
    $this->view->addHelperPath(APPLICATION_PATH . '/application/modules/Fields/View/Helper', 'Fields_View_Helper');
    $this->view->fieldStructure = $fieldStructure = Engine_Api::_()->fields()->getFieldsStructurePartial($eventdocument);
  }

  //ACTION FOR EMAIL THE DOCUMENT
  public function emailAction() {

    //GET VIEWER INFORMATION
    $viewer = Engine_Api::_()->user()->getViewer();
    $viewer_id = $viewer->getIdentity();

    //TO BE VERIFY THAT DOCUMNETS HAD ENABLED FOR THIS USER
    $document_id = $this->_getParam('id');
    if (empty($document_id)) {
      return $this->_redirect("eventdocuments/manage");
    } else {
      $eventdocument = Engine_Api::_()->getItem('eventdocument_document', $document_id);
    }

    //GET EVENT ID AND OBJECT
    $event_id = $eventdocument->event_id;
    $event = Engine_Api::_()->getItem('event', $event_id);

    //CHECK VIEWER CAN VIEW THIS DOCUMENT OR NOT
    if (!$event->authorization()->isAllowed($viewer, 'view')) {
      return $this->_forward('requireauth', 'error', 'core');
    }

    //DOCUMENT OWNER ID SHOULD NOT BE NULL
    if ($eventdocument->owner_id == 0) {
      return $this->_forward('requireauth', 'error', 'core');
    }

    //DO NOT SHOW DOCUMENT IF IT IS NOT PUBLISHED TO OTHER USER
    if ($viewer_id != $eventdocument->owner_id && $eventdocument->draft == 1) {
      $page = "error";
      $this->view->error_header = 639;
      $this->view->error_message = $this->view->translate('You do not have permission to view this document.');
      $this->error_submit = 641;
    }

    //DO NOT SHOW DOCUMENT IF IT IS NOT ACTIVE
    if ($viewer_id != $eventdocument->owner_id && $eventdocument->approved != 1) {
      $page = "error";
      $this->view->error_header = 639;
      $this->view->error_message = $this->view->translate('You do not have permission to view this document.');
      $this->error_submit = 641;
    }

    //CHECK THAT EMAIL IS ALLOW OR NOT
    $email_allow = Engine_Api::_()->getApi('settings', 'core')->getSetting('eventdocument.email.allow', 1);
    if (($eventdocument->email_allow != 1) || ($eventdocument->status != 1) || ($email_allow != 1 )) {
      $page = "error";
      $this->view->error_header = 639;
      $this->view->error_message = $this->view->translate('You do not have permission to view this document.');
      $this->error_submit = 641;
    }

    $time_out = 50000;
    $is_error = 0;
    $error_array = array();
    $excep_error = 0;
    $excep_message = '';

    //FILENAME FROM STORAGE TABLE
    $file_name = $eventdocument->getDocumentFileName();

    if (!empty($file_name)) {
      $this->view->attach = $file_name;
    } else {
      $this->view->attach = $eventdocument->storage_path;
    }

    $this->view->smoothbox_error = 0;
    if (isset($_POST['submit']) && $_POST['submit'] == 'Send') {
      $to = $_POST['to'];
      $subject = $_POST['subject'];
      $user_message = $_POST['message'];

      if (empty($to) || !filter_var($to, FILTER_VALIDATE_EMAIL)) {
        $is_error = 1;
        $this->view->smoothbox_error = 1;
        $error = $this->view->translate('Please enter a valid email.');
        $error_array[] = $error;
      }

      if (empty($subject)) {
        $is_error = 1;
        $this->view->smoothbox_error = 1;
        $error = $this->view->translate('Please enter the subject.');
        $error_array[] = $error;
      }
      if ($is_error != 1) {

        $from = $viewer->displayname . '<' . $viewer->email . '>';

        $fileatt_type = $eventdocument->filemime;
        $fileatt_name = $file_name;
        $headers = "From: $from";

        //SET SCRIBD USER ID
        $this->scribdevent->my_user_id = $eventdocument->owner_id;

        try {
          $link = $this->scribdevent->getDownloadUrl($eventdocument->doc_id, 'original');
        } catch (Exception $e) {
          $message = $e->getMessage();
          $this->view->excep_error = 1;
          $this->view->excep_message = $message;
        }

        $link = trim($link['download_link']);
        $data = file_get_contents($link);

        if (empty($data)) {
          $ch = curl_init();
          $timeout = 0;
          curl_setopt($ch, CURLOPT_URL, $link);
          curl_setopt($ch, CURLOPT_CONNECTTIMEOUT, $timeout);
          ob_start();
          curl_exec($ch);
          curl_close($ch);
          $data = ob_get_contents();
          ob_end_clean();
        }

        $semi_rand = md5(time());
        $mime_boundary = "==Multipart_Boundary_x{$semi_rand}x";

        $headers .= "\nMIME-Version: 1.0\n" .
                "Content-Type: multipart/mixed;\n" .
                " boundary=\"{$mime_boundary}\"";

        $email_message = "This is a multi-part message in MIME format.\n\n" .
                "--{$mime_boundary}\n" .
                "Content-Type:text/html; charset=\"iso-8859-1\"\n" .
                "Content-Transfer-Encoding: 7bit\n\n" . $user_message . "\n\n";

        $data = chunk_split(base64_encode($data));

        $email_message .= "--{$mime_boundary}\n" .
                "Content-Type: {$fileatt_type};\n" .
                " name=\"{$fileatt_name}\"\n" .
                "Content-Transfer-Encoding: base64\n\n" .
                $data . "\n\n" .
                "--{$mime_boundary}--\n";

        $mail_sent = mail($to, $subject, $email_message, $headers);
        if ($mail_sent) {
          $this->view->msg = $this->view->translate('Email has been sent successfully.');
          $time_out = 7000;
          $this->view->no_form = 1;
        } else {
          $is_error = 1;
          $error_array[] = $this->view->translate('There was an error in sending your email. Please try again later.');
          $time_out = 50000;
          $this->view->no_form = 1;
        }
      }
      $this->view->to = $to;
      $this->view->subject = $subject;
      $this->view->user_message = $user_message;
    }
    $this->view->is_error = $is_error;
    $this->view->time_out = $time_out;
    $this->view->error_array = array_unique($error_array);
    $this->view->excep_error = $excep_error;
    $this->view->excep_message = $excep_message;
  }

  //ACTION FOR RATING DOCUMENTS
  public function ratingAction() {
    //CHECK USER VALIDATION
    if (!$this->_helper->requireUser()->isValid())
      return;

    //GET VIEWER INFORMATION
    $viewer = Engine_Api::_()->user()->getViewer();
    $viewer_id = $viewer->getIdentity();

    $rating = $this->_getParam('rating');
    $document_id = $this->_getParam('document_id');

    $tableRating = Engine_Api::_()->getDbtable('ratings', 'eventdocument');
    $db = $tableRating->getAdapter();
    $db->beginTransaction();

    try {
      $tableRating->doEventdocumentRating($document_id, $viewer_id, $rating);

      $total = $tableRating->countRating($document_id);

      $eventdocument = Engine_Api::_()->getItem('eventdocument_document', $document_id);

      //UPDATE CURRENT AVERAGE RATING IN DOCUMENT TABLE
      $avg_rating = $tableRating->avgRating($document_id);

      $eventdocument->rating = $avg_rating;
      $eventdocument->save();

      //COMMIT
      $db->commit();
    } catch (Exception $e) {
      $db->rollBack();
      throw $e;
    }

    $data = array();
    $data[] = array(
        'total' => $total,
        'rating' => $avg_rating,
    );
    return $this->_helper->json($data);
    $data = Zend_Json::encode($data);
    $this->getResponse()->setBody($data);
  }

  //ACTION FOR DOCUMENT PUBLISH
  public function publishAction() {
    //CHECK USER VALIDATION
    if (!$this->_helper->requireUser()->isValid())
      return;

    //SMOOTHBOX
    if (null === $this->_helper->ajaxContext->getCurrentContext()) {
      $this->_helper->layout->setLayout('default-simple');
    } else {//NO LAYOUT
      $this->_helper->layout->disableLayout(true);
    }

    $document_id = $this->view->document_id = $this->_getParam('document_id');
    if (!$this->getRequest()->isPost())
      return;

    $eventdocument = Engine_Api::_()->getItem('eventdocument_document', $document_id);

    $viewer = Engine_Api::_()->user()->getViewer();
    $viewer_id = $viewer->getIdentity();

    if ($viewer_id == $eventdocument->owner_id) {
      $this->view->permission = true;
      $this->view->success = false;
      $db = Engine_Api::_()->getDbtable('documents', 'eventdocument')->getAdapter();
      $db->beginTransaction();
      try {
        $eventdocument->modified_date = new Zend_Db_Expr('NOW()');
        $eventdocument->draft = 0;
        $eventdocument->save();
        $db->commit();
        $this->view->success = true;
      } catch (Exception $e) {
        $db->rollback();
        throw $e;
      }

      //GET EVENT OBJECT
      $event = Engine_Api::_()->getItem('event', $eventdocument->event_id);

      //ADD ACTIVITY ONLY IF DOCUMENT IS PUBLISHED
      if ($eventdocument->draft == 0 && $eventdocument->approved == 1 && $eventdocument->status == 1 && $eventdocument->activity_feed == 0) {
        $api = Engine_Api::_()->getDbtable('actions', 'activity');
        $creator = Engine_Api::_()->getItem('user', $eventdocument->owner_id);
        $action = $api->addActivity($creator, $event, 'eventdocument_new');

        //MAKE SURE ACTION EXISTS BEFORE ATTACHING THE DOUCMENT TO THE ACTIVITY
        if ($action != null) {
          $api->attachActivity($action, $eventdocument);
          $eventdocument->activity_feed = 1;
          $eventdocument->save();
        }
      }
    } else {
      $this->view->permission = false;
    }

		if(Engine_Api::_()->getDbtable('modules', 'core')->isModuleEnabled('ynevent')) {
			$url = $this->_helper->url->url(array('id' => $eventdocument->event_id), 'event_profile');
		}
		else{
			$url = $this->_helper->url->url(array('id' => $eventdocument->event_id, 'tab' => Engine_Api::_()->eventdocument()->getTabId()), 'event_profile');
		}

    $this->_forward('success', 'utility', 'core', array(
        'smoothboxClose' => 2,
        'parentRedirect' => $url,
        'parentRedirectTime' => '2',
        'format' => 'smoothbox',
        'messages' => array('')
    ));
  }

  //ACTION FOR MAKE THE EVENTDOCUMENT FEATURED/UNFEATURED
  public function featuredAction() {
    //CHECK USER VALIDATION
    if (!$this->_helper->requireUser()->isValid())
      return;

    $document_id = $this->view->document_id = $this->_getParam('document_id');
    $eventdocument = Engine_Api::_()->getItem('eventdocument_document', $document_id);
    $this->view->featured = $eventdocument->featured;

    //SMOOTHBOX
    if (null === $this->_helper->ajaxContext->getCurrentContext()) {
      $this->_helper->layout->setLayout('default-simple');
    } else {//NO LAYOUT
      $this->_helper->layout->disableLayout(true);
    }

    if (!$this->getRequest()->isPost())
      return;

    //GET VIEWER INFORMATION
    $viewer = Engine_Api::_()->user()->getViewer();
    $viewer_id = $viewer->getIdentity();

    //CHECK THAT FEATURED ACTION IS ALLOWED BY ADMIN OR NOT
    $this->view->canMakeFeatured = Engine_Api::_()->getApi('settings', 'core')->getSetting('eventdocument.featured', 1);

    //GET EVENT OWNER ID
    $event_user_id = Engine_Api::_()->eventdocument()->eventUserId($eventdocument->event_id);

    //CHECK CAN MAKE FEATURED OR NOT(ONLY EVENT DOUCMENT CAN MAKE FEATURED/UN-FEATURED)
    if (($viewer_id == $event_user_id || $viewer->level_id == 1) && $this->view->canMakeFeatured == 1) {
      $this->view->permission = true;
      $this->view->success = false;
      $db = Engine_Api::_()->getDbtable('documents', 'eventdocument')->getAdapter();
      $db->beginTransaction();
      try {
        if ($eventdocument->featured == 0) {
          $eventdocument->featured = 1;
        } else {
          $eventdocument->featured = 0;
        }

        $eventdocument->save();
        $db->commit();
        $this->view->success = true;
      } catch (Exception $e) {
        $db->rollback();
        throw $e;
      }
    } else {
      $this->view->permission = false;
    }

		if(Engine_Api::_()->getDbtable('modules', 'core')->isModuleEnabled('ynevent')) {
			$url = $this->_helper->url->url(array('id' => $eventdocument->event_id), 'event_profile');
		}
		else{
			$url = $this->_helper->url->url(array('id' => $eventdocument->event_id, 'tab' => Engine_Api::_()->eventdocument()->getTabId()), 'event_profile');
		}

    $this->_forward('success', 'utility', 'core', array(
        'smoothboxClose' => 2,
        'parentRedirect' => $url,
        'parentRedirectTime' => '2',
        'format' => 'smoothbox',
        'messages' => array('')
    ));
  }

  //ACTION FOR DELETE DOCUMENT
  public function deleteAction() {
    //CHECK USER VALIDATION
    if (!$this->_helper->requireUser()->isValid())
      return;

    //GET VIEWER ID
    $viewer_id = Engine_Api::_()->user()->getViewer()->getIdentity();

    //GET EVENT ID
    $this->view->event_id = $event_id = $this->_getParam('event_id');

    //GET DOCUMENT TAB ID
    $this->view->tab_selected_id = Engine_Api::_()->eventdocument()->getTabId();

    //GET DOCUMETN OBJECT
    $eventdocument = Engine_Api::_()->getItem('eventdocument_document', $this->_getParam('document_id'));

    //SEND DOCUMENT TITLE TO TPL
    $this->view->title = $eventdocument->title;

    //GET EVENT OWNER ID
    $event_user_id = Engine_Api::_()->eventdocument()->eventUserId($eventdocument->event_id);

    //DOCUMENT OWNER AND EVENT OWNER CAN DELETE DOCUMENT
    if ($viewer_id != $eventdocument->owner_id && $viewer_id != $event_user_id) {
      return $this->_forward('requireauth', 'error', 'core');
    }

    //DELETE DOCUMENT FROM DATATBASE AND SCRIBD AFTER CONFIRMATION
    if ($this->getRequest()->isPost() && $this->getRequest()->getPost('confirm') == true) {

      //DELETE DOCUMENT BELONGINGS
      Engine_Api::_()->eventdocument()->deleteContent($eventdocument->document_id);

      //REDIRECT
			if(Engine_Api::_()->getDbtable('modules', 'core')->isModuleEnabled('ynevent')) {
				return $this->_helper->redirector->gotoRoute(array('id' => $event_id), 'event_profile', true);
			}
			else {
				return $this->_helper->redirector->gotoRoute(array('id' => $event_id, 'tab' => Engine_Api::_()->eventdocument()->getTabId()), 'event_profile', true);
			}
    }
  }

  /**
   * Upload a eventdocument from a file
   * @param string $local_info : relative path to file
   * @param int $rev_id : id of file to modify
   * @param string $access : public or private. Default is Public.
   * @return array containing doc_id, access_key, and secret_password if nessesary.
   */
  public function scribdUpload($local_info, $rev_id, $access, $secure_allow, $download, $filename_id) {
    try {

      //GET BASE PATH
      $base = Zend_Controller_Front::getInstance()->getBaseUrl();

      //STORAGE MODEL VERSION
      $storagemodule = Engine_Api::_()->getDbtable('modules', 'core')->getModule('storage');
      $storageversion = $storagemodule->version;
			if (!empty($_SERVER["HTTPS"]) && 'on' == strtolower($_SERVER["HTTPS"])) {
				if ($storageversion < '4.1.1') {
					$doc_base_url = "https://" . $_SERVER['HTTP_HOST'] . $base . "/";
				} else {
					$doc_base_url = "https://" . $_SERVER['HTTP_HOST'];
				}
			}
			else {
				if ($storageversion < '4.1.1') {
					$doc_base_url = "http://" . $_SERVER['HTTP_HOST'] . $base . "/";
				} else {
					$doc_base_url = "http://" . $_SERVER['HTTP_HOST'];
				}
			}

      $doc_base_url = str_replace("index.php/", '', $doc_base_url);
      $scribd_upload_url = $doc_base_url . $local_info['file_path'];

      $db = Engine_Db_Table::getDefaultAdapter();
      $type_array = $db->query("SHOW COLUMNS FROM engine4_storage_servicetypes LIKE 'enabled'")->fetch();

      if ($storageversion >= '4.1.6' && !empty($type_array)) {
        $storageServiceTypeTable = Engine_Api::_()->getDbtable('serviceTypes', 'storage');
        $storageServiceTypeTableName = $storageServiceTypeTable->info('name');

        $storageServiceTable = Engine_Api::_()->getDbtable('services', 'storage');
        $storageServiceTableName = $storageServiceTable->info('name');

        $select = $storageServiceTypeTable->select()
                        ->setIntegrityCheck(false)
                        ->from($storageServiceTypeTableName, array(''))
                        ->join($storageServiceTableName, "$storageServiceTypeTableName.servicetype_id = $storageServiceTableName.servicetype_id", array('enabled', 'default'))
                        ->where("$storageServiceTypeTableName.plugin = ?", "Storage_Service_Local")
                        ->where("$storageServiceTypeTableName.enabled = ?", 1)
                        ->limit(1);
        $storageCheck = $storageServiceTypeTable->fetchRow($select);
        if (!empty($storageCheck)) {
          if ($storageCheck->enabled == 1 && $storageCheck->default == 1) {
            $scribd_upload_url = $doc_base_url . $local_info['file_path'];
          } else {
            $scribd_upload_url = $local_info['file_path'];
          }
        }
      }

			//GET STORAGE FILE OBJECT	
			$storage_file = Engine_Api::_()->getItem('storage_file', $filename_id);
			$scribd_upload_url = $storage_file->temporary();

      $data = $this->scribdevent->upload("$scribd_upload_url", NULL, $access, $rev_id, $download, $secure_allow);
      $data['local_path'] = $scribd_upload_url;
    } catch (Exception $e) {
      $message = $e->getMessage();
      $this->view->excep_error = 1;
      $this->view->excep_message = $message;
    }
    return $data;
  }

}
