<?php

/**
 * SocialEngine
 *
 * @category   Application_Extensions
 * @package    Eventeventdocument
 * @copyright  Copyright 20011-2012 BigStep Technologies Pvt. Ltd.
 * @license    http://www.socialengineaddons.com/license/
 * @version    $Id: Controller.tpl 2012-01-25 9:40:21Z SocialEngineAddOns $
 * @author     SocialEngineAddOns
 */
include_once APPLICATION_PATH . '/application/modules/Eventdocument/Api/Scribdevent.php';

class Eventdocument_Widget_ProfileEventdocumentsController extends Engine_Content_Widget_Abstract {

  protected $_childCount;

  public function indexAction() {
    //DONT RENDER THIS IF NOT AUTHORIZED
    $viewer = Engine_Api::_()->user()->getViewer();
    $eventdocument_profiledoc = Zend_Registry::isRegistered('eventdocument_profiledoc') ? Zend_Registry::get('eventdocument_profiledoc') : null;

    if (!Engine_Api::_()->core()->hasSubject() || empty($eventdocument_profiledoc)) {
      return $this->setNoRender();
    }

    //GET VIEWER INFORMATION
    $this->view->viewer_id = $viewer_id = $viewer->getIdentity();
    if (!empty($viewer_id)) {
      $this->view->level_id = $level_id = $viewer->level_id;
    } else {
      $this->view->level_id = $level_id = Engine_Api::_()->getDbtable('levels', 'authorization')->fetchRow(array('type = ?' => "public"))->level_id;
    }

    //GET SUBJECT AND EVENT ID
    $event_subject = Engine_Api::_()->core()->getSubject('event');
    $this->view->event_id = $event_id = $event_subject->event_id;

    //SET NO RENDER IF VIEWER CAN NOT VIEW THE DOCUMENTS
    $can_view = $event_subject->authorization()->isAllowed($viewer, 'view');
    if ($this->view->level_id != 1) {
      if (empty($can_view)) {
        return $this->setNoRender();
      }
    }

    //GET SEARCHING PARAMETERS
    $this->view->page = $page = $this->_getParam('page', 1);
    $this->view->search = $search = $this->_getParam('search');
    $this->view->selectbox = $selectbox = $this->_getParam('selectbox');
    $this->view->checkbox = $checkbox = $this->_getParam('checkbox');
    $this->view->isAjax = $this->_getParam('isAjax', 0);

    $values = array();
    if (!empty($search)) {
      $values['search'] = $search;
    }
    if (!empty($selectbox) && $selectbox == 'featured') {
      $values['featured'] = 1;
      $values['orderby'] = 'document_id';
    } elseif (!empty($selectbox)) {
      $values['orderby'] = $selectbox;
    } else {
      $values['orderby'] = 'document_id';
    }
    if (!empty($checkbox) && $checkbox == 1) {
      $values['owner_id'] = $viewer_id;
    }

    //CHECK WHO CAN CREATE DOCUMENTS
    $this->view->can_create = Engine_Api::_()->authorization()->isAllowed($event_subject, $viewer, 'edcreate');

    //GET EVENT OWNER ID
    $this->view->event_user_id = $event_user_id = $event_subject->user_id;

    //BLOCK FOR UPDATING CONVERSION STATUS OF THE DOCUMENT
    $this->scribd_api_key = Engine_Api::_()->getApi('settings', 'core')->eventdocument_api_key;
    $this->scribd_secret = Engine_Api::_()->getApi('settings', 'core')->eventdocument_secret_key;
    $this->scribdevent = new Scribdevent($this->scribd_api_key, $this->scribd_secret);

    //DOCUMENT TABLE
    $documentTable = Engine_Api::_()->getDbtable('documents', 'eventdocument');

    //DOCUMENTS FOR SCRIBD CONVERSION
    $doc_forUpdate = $documentTable->updateDocs($event_id);

    foreach ($doc_forUpdate as $value) {

      if (empty($value->doc_id)) {
        continue;
      }

      $this->scribdevent->my_user_id = $value->owner_id;

      try {
        $stat = trim($this->scribdevent->getConversionStatus($value->doc_id));
      } catch (Exception $e) {
        $message = $e->getMessage();
      }

      if ($stat == 'DONE') {
        try {
          //GETTING DOCUMENT'S FULL TEXT
          $texturl = $this->scribdevent->getDownloadUrl($value->doc_id, 'txt');
          //for some reason, the URL comes back with leading and trailing spaces
          $texturl = trim($texturl['download_link']);

          $file_contents = file_get_contents($texturl);
          if (empty($file_contents)) {
            $site_url = $texturl;
            $ch = curl_init();
            $timeout = 0; //set to zero for no timeout
            curl_setopt($ch, CURLOPT_URL, $site_url);
            curl_setopt($ch, CURLOPT_CONNECTTIMEOUT, $timeout);

            ob_start();
            curl_exec($ch);
            curl_close($ch);
            $file_contents = ob_get_contents();
            ob_end_clean();
          }
          $full_text = $file_contents;
          $value->fulltext = $full_text;
          $value->save();

        } catch (Exception $e) {
          if ($e->getCode() == 619) {
            $value->status = 3;
            $value->save();

            //SEND EMAIL TO DOCUMENT OWNER IF EVENT DOCUMENT HAS BEEN DELETED FROM SCRIBD
            Engine_Api::_()->eventdocument()->emailDocumentDelete($value, $event_subject->title, $event_subject->user_id);
          }
        }
        
        if($value->status != 3 && $value->status != 2) {
            $setting = $this->scribdevent->getSettings($value->doc_id);
            $thumbnail_url = trim($setting['thumbnail_url']);          
            $value->thumbnail = $thumbnail_url;
            $value->status = 1;
            $value->save();
        
            //ADD ACTIVITY ONLY IF DOCUMENT IS PUBLISHED
            $eventdocument = Engine_Api::_()->getItem('eventdocument_document', $value->document_id);
            if ($eventdocument->draft == 0 && $eventdocument->approved == 1 && $eventdocument->status == 1 && $eventdocument->activity_feed == 0) {
              $api = Engine_Api::_()->getDbtable('actions', 'activity');
              $creator = Engine_Api::_()->getItem('user', $eventdocument->owner_id);
              $action = $api->addActivity($creator, $event_subject, 'eventdocument_new');

              //MAKE SURE ACTION EXISTS BEFORE ATTACHING THE DOUCMENT TO THE ACTIVITY
              if ($action != null) {
                $api->attachActivity($action, $eventdocument);
                $eventdocument->activity_feed = 1;
                $eventdocument->save();
              }
            }
        }
      } elseif ($stat == 'ERROR') {
        $value->status = 2;
        $value->save();
      }

      //DELETE DOCUMENT FROM SERVER IF ALLOWED BY ADMIN AND HAS STATUS ONE OR TWO
      $eventdocument_save_local_server = Engine_Api::_()->getApi('settings', 'core')->getSetting('eventdocument.save.local.server', 1);
      if ($eventdocument_save_local_server == 0 && ($value->status == 1 || $value->status == 2)) {
        Engine_Api::_()->eventdocument()->deleteServerDocument($value->document_id);
      }
    }

		//MAKE FEATURED/UN-FEATURED IS ALLOWED OR NOT
    $this->view->canMakeFeatured = Engine_Api::_()->getApi('settings', 'core')->getSetting('eventdocument.featured', 1);

    //CHECK THAT RATING IS VIEABLE OR NOT
    $this->view->show_rate = Engine_Api::_()->getApi('settings', 'core')->getSetting('eventdocument.rating', 1);

    //FETCH DOCUMENTS
    $values['event_id'] = $event_id;
    if ($viewer_id == $event_user_id || $level_id == 1) {
      $values['show_document'] = 0;
      $this->view->paginator = $paginator = $documentTable->getEventdocumentsPaginator($values);
    } else {
      $values['show_document'] = 1;
      $values['document_owner_id'] = $viewer_id;
      $this->view->paginator = $paginator = $documentTable->getEventdocumentsPaginator($values);
    }

    //10 DOCUMENTS PER PAGE
    $paginator->setItemCountPerPage(10);
    $this->view->paginator->setCurrentPageNumber($page);

    //CHECK THAT CAROUSEL IS VIEABLE OR NOT
    $this->view->show_carousel = Engine_Api::_()->getApi('settings', 'core')->getSetting('eventdocument.carousel', 1);

    $this->view->featureDocuments = array();

    $this->view->total_featureDocuments = 0;

    if (!empty($this->view->show_carousel)) {

      //FETCH DOCUMENTS
      $this->view->featureDocuments = $documentTable->featuredDocuments($event_id);

      $this->view->total_featureDocuments = Count($this->view->featureDocuments);
    }

    //ADD NUMBER OF DOCUMENTS IN TAB
    if ($paginator->getTotalItemCount() > 0) {
      $this->_childCount = $paginator->getTotalItemCount();
    }
  }

  public function getChildCount() {
    return $this->_childCount;
  }

}
