<?php

/**
 * SocialEngine
 *
 * @category   Application_Extensions
 * @package    Facelight
 * @copyright  Copyright 2015-2016 BigStep Technologies Pvt. Ltd.
 * @license    http://www.socialengineaddons.com/license/
 * @version    $Id: AdminMenusController.php 2015-05-15 00:00:00Z SocialEngineAddOns $
 * @author     SocialEngineAddOns
 */

class Facelight_AdminMenusController extends Core_Controller_Action_Admin {

    public function indexAction() {
        $this->view->navigation = Engine_Api::_()->getApi('menus', 'core')->getNavigation('facelight_admin_main', array(), 'facelight_admin_menus');
        $this->view->menusTable = $menusTable = Engine_Api::_()->getDbtable('menus', 'facelight');

        $this->view->menus = $menusTable->getAllMenus();
    }

    public function createAction() {
        $this->view->parent = $parent = $this->_getParam('parent', 0);


        // Get form
        $this->view->form = $form = new Facelight_Form_Admin_Menu_ItemCreate();
        if (empty($parent)) {
            $form->setTitle('Create New Link');
            //$form->removeElement('icon');
            $form->link->setLabel('URL (Note: Leave it blank to create it as a menu.)');
        } else {
            $form->link->setAttrib('required',true);
        }
        // Check stuff
        if (!$this->getRequest()->isPost()) {
            return;
        }
        if (!$form->isValid($this->getRequest()->getPost())) {
            return;
        }

        // Save
        $values = $form->getValues();
        $params = array();
        $menusTable = Engine_Api::_()->getDbtable('menus', 'facelight');
        if (!empty($values['icon'])) {
            $params['icon'] = $menusTable->setMenuIcon($form->icon);
        }
        $values = array_merge($values, array('params' => json_encode($params), 'parent' => $parent));
        $menuItem = $menusTable->createRow();
        $menuItem->setFromArray($values);
        $menuItem->save();
        $this->_forward('success', 'utility', 'core', array(
            'smoothboxClose' => 10,
            'parentRefresh' => 10,
            'messages' => array(Zend_Registry::get('Zend_Translate')->_('Added Successfully.'))
        ));
    }

    public function editAction() {
        $this->view->menu_id = $menu_id = $this->_getParam('menu_id', 0);

        $menusTable = Engine_Api::_()->getDbtable('menus', 'facelight');
        $menuItem = $menusTable->getMenuItem($menu_id);
        // Get form
        $this->view->form = $form = new Facelight_Form_Admin_Menu_ItemEdit();
        $form->populate($menuItem->toArray());
        if (empty($menuItem->parent)) {
            //$form->removeElement('icon');
            $form->setTitle('Edit Menu');
            $form->submit->setLabel('Edit Menu');
        }
        if (empty($menuItem->parent) && empty($menuItem->link)) {
            $form->removeElement('link');
        }elseif (!empty ($menuItem->link)) {
            $form->link->setAttrib('required',true);
        }
        // Check stuff
        if (!$this->getRequest()->isPost()) {
            return;
        }
        if (!$form->isValid($this->getRequest()->getPost())) {
            return;
        }

        // Save
        $values = $form->getValues();
        $params = $menuItem->params ? Zend_Json::decode($menuItem->params) : array();
        $parent = $menuItem->parent;
        if (!empty($values['icon'])) {
            $params['icon'] = $menusTable->setMenuIcon($form->icon);
        }
        $values = array_merge($values, array('params' => json_encode($params), 'parent' => $parent));
        $menuItem->setFromArray($values);
        $menuItem->save();
        $this->_forward('success', 'utility', 'core', array(
            'smoothboxClose' => 10,
            'parentRefresh' => 10,
            'messages' => array(Zend_Registry::get('Zend_Translate')->_('Edited Successfully.'))
        ));
    }

    public function deleteAction() {
        $this->view->menu_id = $menu_id = $this->_getParam('menu_id');
        $this->_helper->layout->setLayout('admin-simple');
        // Get menu item
        $this->view->form = $form = new Facelight_Form_Admin_Menu_ItemDelete();
        // Check stuff
        if (!$this->getRequest()->isPost()) {
            return;
        }
        if (!$form->isValid($this->getRequest()->getPost())) {
            return;
        }
        $menusTable = Engine_Api::_()->getDbtable('menus', 'facelight');
        $menusTable->deleteMenu($menu_id);
        $this->view->status = true;


        $this->_forward('success', 'utility', 'core', array(
            'smoothboxClose' => 10,
            'parentRefresh' => 10,
            'messages' => array(Zend_Registry::get('Zend_Translate')->_('Deleted'))
        ));
    }

    public function orderAction() {
        if (!$this->getRequest()->isPost()) {
            return;
        }
        $postData = $this->getRequest()->getPost();
        $menus = Engine_Api::_()->getDbtable('menus', 'facelight')->getAllMenus(array('parent' => $postData['parent']));
        foreach ($menus as $menuitem) {
            $order = $postData['admin_menus_item_' . $menuitem->getIdentity()];
            if (!$order) {
                $order = 999;
            }
            $menuitem->order = $order;
            $menuitem->save();
        }
        return;
    }
}
