<?php


/**
 * SocialEngine
 *
 * @category   Application_Extensions
 * @package    Instaclone
 * @copyright  Copyright 2015-2018 BigStep Technologies Pvt. Ltd.
 * @license    http://www.socialengineaddons.com/license/
 * @version    $Id: Layout.php 2018-04-05 00:00:00Z SocialEngineAddOns $
 * @author     SocialEngineAddOns
 */
class Instaclone_Form_Admin_Settings_Landingpage_Landing extends Engine_Form
{

  public function init()
  {
    $description = sprintf(Zend_Registry::get('Zend_Translate')->_("Here you can manage the elements present on Landing Page."));
    $this->setTitle("Landing Page");
    $this->setDescription("$description");
  
    $this->loadDefaultDecorators();
    $this->getDecorator('Description')->setOption('escape', false);

    $coreSettings = Engine_Api::_()->getApi('settings', 'core');
    $this->setAttrib('id', 'form-upload');

    // Get available files
    $logoOptions = Engine_Api::_()->instaclone()->getImages(array('application/modules/Instaclone/externals/images/insta_logo.png' => 'Default logo','' => "Text-only (No logo)"));
    $backgroundOptions = Engine_Api::_()->instaclone()->getImages(array('' => 'Default Image'));

    $this->addElement('Select', 'instaclone_landing_slider_logo', array(
      'label' => 'Select Logo',
      'description' => 'Select the logo for your website. [Note: You can upload logo from: "Appearance" > "File & Media Manager".]',
      'value' => $coreSettings->getSetting('instaclone.landing.slider.logo', 'application/modules/Instaclone/externals/images/insta_logo.png'),
      'multiOptions' => $logoOptions,
    ));

    $this->addElement('Text', 'instaclone_landing_slider_description1', array(
      'label' => 'Main Tagline on Landing Page',
      'description' => 'Enter the tagline text that you want to display on the landing page.',
      // 'style' => 'width:350px;',
      'value' => $coreSettings->getSetting("instaclone.landing.slider.description1", "Connect and share photos and videos to the world."),
    ));

    $this->addElement('radio', 'instaclone_landing_display_iosapp_url', array(
      'label' => 'Show IOS App URL?',
      'description' => 'If you enable this setting, this section will be present on Login Page, Landing Page and Sign up Page.',
      'multiOptions' => array('block' => 'Yes', 'none' => 'No'),
      'value' => $coreSettings->getSetting("instaclone.landing.display.iosapp.url", "block"),
      'onchange' => "showIosAppFields(this.value);",
    ));

    $this->addElement('Text', 'instaclone_landing_iosapp_url', array(
      'label' => 'Enter IOS App URL',
      'description' => 'Enter IOS App URL.',
      // 'style' => 'width:350px;',
      'value' => $coreSettings->getSetting("instaclone.landing.iosapp.url", "#"),
    ));

    $this->addElement('radio', 'instaclone_landing_display_androidapp_url', array(
      'label' => 'Show Android App URL?',
      'description' => 'If you enable this setting, this section will be present on Login Page, Landing Page and Sign up Page.',
      'multiOptions' => array('block' => 'Yes', 'none' => 'No'),
      'value' => $coreSettings->getSetting("instaclone.landing.display.androidapp.url", "block"),
      'onchange' => "showAndroidAppFields(this.value);",
    ));

    $this->addElement('Text', 'instaclone_landing_androidapp_url', array(
      'label' => 'Enter Android App URL',
      'description' => 'Enter the Android App URL.',
      // 'style' => 'width:350px;',
      'value' => $coreSettings->getSetting("instaclone.landing.androidapp.url", "#"),
    ));

    $this->addElement('Radio', 'instaclone_landing_sliderimage_location', array(
      'label' => 'Slider View',
      'description' => 'Please select the view of slider, images would be shown as per the view selected.',
      'required'  => true,
      'allowEmpty'  => false,
      'multiOptions' => array(
        'backgroundSlider' => 'Full Width Slider',
        'frontSlider' => 'Front Image',
      ),
      'onchange' =>'slideImageLocationChange(this.value)',
      'value' => $coreSettings->getSetting("instaclone.landing.sliderimage.location", "frontSlider"),
    ));

    $this->addElement('Text', 'instaclone_landing_sliderimage_heading', array(
      'label' => 'Heading',
      'description' => 'Enter the heading text you want to display on the image slider?',
      'value' => $coreSettings->getSetting("instaclone.landing.sliderimage.heading", "Share Your Ideas with Others"),
    ));

    $this->addElement( 'Textarea', 'instaclone_landing_sliderimage_paragraph', array(
      'label' => 'Paragraph',
      'description' => 'Enter the paragraph text you want to display on the image slider?',
      'attribs' => array('rows' => 5, 'cols' => 80 ),
      'value' => $coreSettings->getSetting("instaclone.landing.sliderimage.paragraph", "Grow Your Audience"),
    ));


    $this->addElement('Button', 'submit', array(
      'label' => 'Save Changes',
      'type' => 'submit',
      'decorators' => array(
        'ViewHelper',
      ),
    ));
  }

}
?>
