<?php

/**
 * SocialEngine
 *
 * @category   Application_Extensions
 * @package    Siteapi
 * @copyright  Copyright 2015-2016 BigStep Technologies Pvt. Ltd.
 * @license    http://www.socialengineaddons.com/license/
 * @version    IndexController.php 2015-09-17 00:00:00Z SocialEngineAddOns $
 * @author     SocialEngineAddOns
 */

class Livestreamingvideo_IndexController extends Siteapi_Controller_Action_Standard {

  public function init() {
    Engine_Api::_()->getApi('Core', 'siteapi')->setView();
    Engine_Api::_()->getApi('Core', 'siteapi')->setLocal();
    Engine_Api::_()->getApi('Core', 'siteapi')->setTranslate();
  }

  /*
  * Get settings of livestreaming
  */
  public function getSettingsAction() {
    $viewer = Engine_Api::_()->user()->getViewer();
    $viewer_id = $viewer->getIdentity();

    if(!$viewer_id)
      $this->respondWithError("unauthorized", "Please login to Broadcast");

    $settings['allow_recording'] = Engine_Api::_()->authorization()->getAdapter('levels')->getAllowed('livestreamingvideo', $viewer, "allow_recording");

    $settings['max_allowed_duration'] = min(Engine_Api::_()->authorization()->getAdapter('levels')->getAllowed('livestreamingvideo', $viewer, 'max_allowed_duration'), 90);

    // Quota related work
    $quota = Engine_Api::_()->authorization()->getAdapter('levels')->getAllowed('livestreamingvideo', $viewer, 'max_streamings');

    $current_count = Engine_Api::_()->getDbTable('streams' , 'livestreamingvideo')->getCountOfStreams($viewer->getIdentity());

    if ($current_count >= $quota && !empty($quota)) {
      $this->respondWithError('unauthorized', 'You have already created the maximum number of live streamings allowed.');
    }
    // end quota related work

    // Work for when loggedd-in user already go live with web
    $isAlreadyBroadcasting = Engine_Api::_()->getDbTable('streams' , 'livestreamingvideo')->isUserBroadcasting($viewer->getIdentity());

    if ($isAlreadyBroadcasting) {
      $settings['already_broadcasting'] = 1;
    }
    // End work for when loggedd-in user already go live with web

    $viewOptions = (array) Engine_Api::_()->authorization()->getAdapter('levels')->getAllowed('livestreamingvideo', $viewer, 'auth_view');
    $availableLabels = array(
      'everyone'  => 'Everyone',
      'networks'  => 'Networks Only',
      'friends'   => 'Friends Only',
      'onlyme'    => 'Only Me',
    );
    $settings['default'] = 'everyone';
    $settings['viewOptions'] = array_intersect_key($availableLabels, array_flip($viewOptions));

    $settings['channel_name'] = uniqid(rand());

    $settings['share_to_story'] = ((Engine_Api::_()->getDbtable('modules', 'core')->isModuleEnabled('sitestories') || Engine_Api::_()->getDbtable('modules', 'core')->isModuleEnabled('sitestoriesweb')) && Engine_Api::_()->getApi('settings', 'core')->getSetting('sitestories.enable.stories', 0));

    $settings['rToken'] = (int)(((float)rand()/(float)getrandmax())*100000000);

    $this->respondWithSuccess($settings);
  }

  /*
  * Start the broadcast
  */
  public function startVideoStreamingAction() {
  
    $this->validateRequestMethod('POST');
    Engine_Api::_()->getApi('Core', 'siteapi')->setTranslate();
    $viewer = Engine_Api::_()->user()->getViewer();
    $viewer_id = $viewer->getIdentity();

    if(!$viewer_id)
      $this->respondWithError("unauthorized","Please Login to Broadcast");

    $stream_name = $this->_getParam ("stream_name", null );
    if (empty($stream_name))
      $this->respondWithValidationError ('parameter_missing', 'Channel Name missing');

    $subject_type = "sitevideo_video";
    $title = $this->_getParam ("title", "Live Video" );
    $description = $this->_getParam("body","New broadcasted video.");
    $token = $this->_getParam('token');

    $streamTable = Engine_Api::_()->getDbtable( 'streams', 'livestreamingvideo' );

    $db = $streamTable->getAdapter();
    $db->beginTransaction ();
      
    try {
      $videoDbTable = Engine_Api::_()->getDbtable('videos', 'sitevideo');
      $newVideo = $videoDbTable->createRow();
      $newVideo->status = 0;
      $newVideo->title = $title;
      $newVideo->description = $description;
      $newVideo->search = 1;
      $newVideo->owner_type = "user";
      $newVideo->owner_id = $viewer_id;
      $newVideo->type = "upload";
      $newVideo->code = "mp4";
      $newVideo->synchronized = 1;
      $newVideo->save();
      
      // CREATE AUTH STUFF HERE
      $auth = Engine_Api::_()->authorization()->context;
      $roles = array('owner', 'owner_member', 'owner_member_member', 'owner_network','friends', 'registered', 'everyone');

      if (isset($_REQUEST['auth_view']))
        $videoAuth_view = $auth_view = $_REQUEST['auth_view'];
      else
        $videoAuth_view = $auth_view = "everyone";

      if(strstr($auth_view, "networks")){
        $videoAuth_view = 'owner_network';
      }
      elseif (strstr($auth_view, "friends")) {
        $videoAuth_view = 'owner_member';
      }
      elseif (strstr($auth_view, "onlyme")) {
        $videoAuth_view = 'owner';
      }
      elseif (strstr($auth_view, "everyone")) {
        $videoAuth_view = 'everyone';
      }
      
      $viewMax = array_search($videoAuth_view, $roles);
      foreach ($roles as $i => $role) {
        $auth->setAllowed($newVideo, $role, 'view', ($i <= $viewMax));
      }

      // Comment privacy
      $auth_comment = (isset($_REQUEST['auth_comment'])) ? $_REQUEST['auth_comment'] : "everyone";

      $commentMax = array_search($auth_comment, $roles);
      foreach ($roles as $i => $role) {
        $auth->setAllowed($newVideo, $role, 'comment', ($i <= $commentMax));
      }

      $video_id = $newVideo->getIdentity();

      $start_time = new DateTime(date('Y-m-d H:i:s'), new DateTimeZone('UTC'));
      $start_time = $start_time->format('Y-m-d H:i:s');

      $allowedTime = min(Engine_Api::_()->authorization()->getAdapter('levels')->getAllowed('livestreamingvideo', $viewer, 'max_allowed_duration'), 90);
      $end_time = date('Y-m-d H:i:s', strtotime('+' . $allowedTime . ' minutes', strtotime($start_time)));

      // Create New Stream
      $streamTable = Engine_Api::_()->getDbtable ( "streams", "livestreamingvideo" );
      $newStream = $streamTable->createRow();
      $newStream->name = $stream_name;
      $newStream->subject_type = $subject_type;
      $newStream->start_time = $start_time;
      $newStream->owner_id = $viewer_id;
      $newStream->end_time = $end_time;
      $newStream->title = $title;
      $newStream->token = $token;
      $newStream->video_id = $video_id;
      $newStream->description = $description;
      $newStream->subject_id =  $video_id;

      // save tags
      if(!empty($_REQUEST['toValues'])) {
        $newStream->tovalues = $_REQUEST['toValues'];
      }

      $newStream->save();
      foreach ($roles as $i => $role) {
        $auth->setAllowed($newStream, $role, 'view', ($i <= $viewMax));
      }

      $userIds = array();
      $params =  array (
        'stream_name' => $stream_name ,
        'main_subject_type' => $subject_type,
        'main_subject_id' => $newStream->subject_id,
        'allowedTime' => $allowedTime
      );
      
      $members = array();
      if($auth_view == 'friends') {
        $members = Engine_Api::_()->getApi('Siteapi_Core', 'livestreamingvideo')->getFriends($viewer);
      } elseif($auth_view == 'networks') {
        $network_id = Engine_Api::_()->getApi('Siteapi_Core', 'livestreamingvideo')->getNetwork($viewer);
        $members = Engine_Api::_()->getApi('Siteapi_Core', 'livestreamingvideo')->getMembersOfUserNetwork($network_id);        
      } elseif($auth_view == 'everyone') {
        $members = Engine_Api::_()->getApi('Siteapi_Core', 'livestreamingvideo')->getRegistedUsers();
      }

      if (isset($members) && count($members) > 0 ) {
          
        $userIds = array_column($members->toArray(), 'user_id');

        // remove the viewer from user list
        if (($key = array_search($viewer->getIdentity(), $userIds)) !== false) {
          unset($userIds[$key]);
        }

        if (count($userIds) > 0) {
          //Push notification work starts
          $tempMessage['message']['object_params'] = array(
            'type' => 'video',
            'id' => $newVideo->getIdentity(),
            'sender_id' => $viewer->getIdentity()
          );
          $tempMessage['message']['object_params'] = array_merge($params,$tempMessage['message']['object_params']);
          $getContentImages = Engine_Api::_()->getApi('Core', 'siteapi')->getContentImage($viewer);
          $tempMessage['message']['feed_title'] =  sprintf($this->translate('%s has started a live video'), $viewer->getTitle());
          $tempMessage['imgUrl'] = $getContentImages['image_icon'];
          $tempMessage['title'] = $viewer->getTitle();
          $tempMessage['ticker'] = $this->translate('new update');

          // For Android
          if (Engine_Api::_()->getDbtable('modules', 'core')->isModuleEnabled('siteandroidapp')) {
            $plugin = Engine_Api::_()->loadClass('Siteandroidapp_Plugin_Pushnotification');
            $gcmUsers = Engine_Api::_()->getApi('Siteapi_Core', 'livestreamingvideo')->getUsers(array('user_ids'=>$userIds));

            if ($gcmUsers)
              $plugin->sendBroadcastNotification($gcmUsers,$tempMessage);
          }
            
          // For iOS
          if (Engine_Api::_()->getDbtable('modules', 'core')->isModuleEnabled('siteiosapp')) {
            $iosPlugin = Engine_Api::_()->loadClass('Siteiosapp_Plugin_Pushnotification');
            $apnUsers = Engine_Api::_()->getApi('Siteapi_Core', 'livestreamingvideo')->getUsers(array('user_ids'=>$userIds), 0);

            if($apnUsers)
              $iosPlugin->sendBroadcastIosNotification($apnUsers, $tempMessage);
          }

          //Push notification work ends

          $membersIdsChunk = array_chunk($userIds, 10000);

          if (Engine_Api::_()->getDbtable('modules', 'core')->isModuleEnabled('sitelivestreaming')) {
            $view = Zend_Registry::isRegistered('Zend_View') ? Zend_Registry::get('Zend_View') : null;
            $url  = $view->url(array('action' => 'join', 'controller' => 'index', 'module' => 'sitelivestreaming', 'stream_id' => $newStream->getIdentity()), 'default', true);
            $link = "<a href='$url'>live video</a>";
            $params['link'] = $link;
          } else {
            $params['link'] = 'live video';
          }

          foreach ($membersIdsChunk as $membersId) {
            $dataArray = array('members' => $membersId, 'subject_type'=> $viewer->getType(), 'subject_id'=> $viewer->getIdentity(), 'object_type' => $newVideo->getType(),'object_id' => $newVideo->getIdentity(),'type' => 'livestreaming_video' ,'params' => (object) $params, 'date' => date('Y-m-d H:i:s'));
                      
            $finalData = array('data' => $dataArray);
            $data = json_encode($finalData);
            $agoraUrl = Engine_Api::_()->getApi('settings', 'core')->getSetting('livestreamingvideo.url');
            $apiURL = $agoraUrl.'send-notification';

            $curl = curl_init();
            curl_setopt_array($curl, array(
              CURLOPT_URL => $apiURL,
              CURLOPT_RETURNTRANSFER => true,
              CURLOPT_ENCODING => "",
              CURLOPT_MAXREDIRS => 10,
              CURLOPT_TIMEOUT => 0,
              CURLOPT_FOLLOWLOCATION => true,
              CURLOPT_HTTP_VERSION => CURL_HTTP_VERSION_1_1,
              CURLOPT_CUSTOMREQUEST => "POST",
              CURLOPT_POSTFIELDS =>$data,
              CURLOPT_HTTPHEADER => array("Content-Type: application/json")
            ));
            $response = curl_exec($curl);
            $statusCode = curl_getinfo($curl, CURLINFO_HTTP_CODE);
            curl_close($curl);
          }
        }
      }
      
      $db->commit();

      $response = array('video_id' => $newStream->video_id , "video_type" => $newVideo->getType(),'subject_type' => $subject_type , 'subject_id' => $newStream->subject_id);
                
      $this->respondWithSuccess($response);
    } catch ( Exception $e ) {
      $db->rollBack ();
      $this->respondWithError( 'internal_server_error', $e->getMessage() );
    }
  }

  public function stopVideoStreamingAction() {
    $this->validateRequestMethod('POST');
      
    $streamTable = Engine_Api::_()->getDbtable('streams' , 'livestreamingvideo');
    $db = $streamTable->getAdapter();
    $db->beginTransaction ();
    try {
      $viewer = Engine_Api::_()->user()->getViewer();
      $viewer_id = $viewer->getIdentity();
      $stream_name = $this->_getParam("stream_name", null);
      if(!$stream_name)
        $this->respondWithValidationError('parameter_missing' , 'stream_name missing');

      $streamTable = Engine_Api::_()->getDbtable('streams' , 'livestreamingvideo');
      $stream = $streamTable->getstream($stream_name);

      if(empty($stream->getIdentity()))
        $this->respondWithError("no_record");

      $stream->end_time = date('Y-m-d H:i:s');
      $stream->status = 'normal';
      $stream->save();
      $db->commit();

      $this->respondWithSuccess(array('video_id' => $stream->video_id , 'subject_type' => $stream->subject_type));
    } catch(Exception $e) {
      $db->rollBack ();
      $this->respondWithError('internal_server_error', $e->getMessage());
    }
  }

  public function stopStreamAction() {
    $uid = $this->_getParam("uid", "");
    if(!empty($uid)){
      Engine_Api::_()->getDbTable('streams' , 'livestreamingvideo')->stopActiveStreams($uid);
      $this->respondWithSuccess(array('flag' => true));
    }
    $this->respondWithSuccess(array('flag' => false));
  }

  public function deleteAction() {
    // Validate request methods
    $this->validateRequestMethod('DELETE');

    $streamTable = Engine_Api::_()->getDbtable('streams' , 'livestreamingvideo');
    $db = $streamTable->getAdapter();
    $db->beginTransaction ();
    try {
      $stream_name = $this->_getParam("stream_name");

      $streamTable = Engine_Api::_()->getDbtable('streams' , 'livestreamingvideo');
      $stream = $streamTable->getstream($stream_name);

      if(!$stream->stream_id)
        $this->respondWithError("no_record");

      // delete video first
      $subject = Engine_Api::_()->getItem($stream->subject_type , $stream->subject_id);
      if($subject)
        $subject->delete();

      $db->commit();
      $this->successResponseNoContent('no_content', true);
    } catch(Exception $e) {
      $db->rollBack();
      $this->respondWithError('internal_server_error', $e->getMessage());
    }
  }
  // it is extra and what is use of this api
  public function isLiveAction() {
    $this->validateRequestMethod();
    $viewer = Engine_Api::_()->user()->getViewer();
    $viewer_id = $viewer->getIdentity();
    $stream_name = $this->_getParam("stream_name", null);
    $values = array();

    if(!$stream_name)
      $this->respondWithValidationError('parameter_missing' , 'stream_name missing');
    
    $streamTable = Engine_Api::_()->getDbtable('streams' , 'livestreamingvideo');
    $stream = $streamTable->getstream($stream_name);
    $subject=null;
    if($stream)
      $isLive = 0;

    $expire_time = new DateTime(date('Y-m-d H:i:s'), new DateTimeZone('UTC'));
    $expire_time = $expire_time->format('Y-m-d H:i:s');

    if($stream->end_time >= $expire_time)
      $isLive = 1;
        
    $subject = Engine_Api::_()->getItem($stream->subject_type , $stream->subject_id);
    $videoUrl = Engine_Api::_()->getApi('Core', 'siteapi')->getVideoURL($subject);
	  $videoUrl = !empty($videoUrl) ? $videoUrl :'';
    $this->respondWithSuccess(array('isLive' => $isLive,"video_id"=>$stream->video_id,"subject_type"=>$stream->subject_type,"endType"=>$stream->status,'videoUrl'=>$videoUrl));     
  }
    
  public function shareVideoAction() {
    $this->validateRequestMethod('POST');
    $stream_name = $this->_getParam("stream_name",null);
    $endType = $this->_getParam("endType","normal");
    $view_count = $this->_getParam("view_count",0);

    if(!$stream_name)
      $this->respondWithValidationError('parameter_missing' , 'stream_name missing');
        
    $streamTable = Engine_Api::_()->getDbtable('streams' , 'livestreamingvideo');
    $stream = $streamTable->getstream($stream_name);
    if(!$stream)
      $this->respondWithError("no_record");

    //if no need to save video.........
    if($endType == 'normal') {
      $this->_normalEnd($stream);  
      $this->respondWithSuccess(array('channel_id' => $stream_name , 'endType' => 'normal'));
    }
    
    try {
      $path = $this->getVideoPath($stream);
      $stream->end_time = date('Y-m-d H:i:s');
      $stream->status = $endType;
      $stream->save();
      $video = Engine_Api::_()->getItem("sitevideo_video" , $stream->video_id);
      $video->view_count = $view_count;
      $video->save();

      $this->respondWithSuccess(array('video_id' => $stream->video_id , 'subject_type' => $stream->subject_type));
    } catch (Exception $e) {
      $this->respondWithError('internal_server_error', $e->getMessage());
    }
  }

  protected  function _normalEnd($streamObject) {
    $streamObject->status = 'normal';
    $streamObject->end_time = date('Y-m-d H:i:s');
    $streamObject->save();
    $subject = Engine_Api::_()->getItem($streamObject->subject_type , $streamObject->subject_id);
          
    if($subject)
      $subject->delete();    
  }

  public function getVideoPath($stream) {
    $curl = curl_init();
    $agorUrl = Engine_Api::_()->getApi('settings', 'core')->getSetting('livestreamingvideo.url');

    curl_setopt($curl, CURLOPT_RETURNTRANSFER, true);
    curl_setopt($curl, CURLOPT_URL, $agorUrl.'get-streaming-file?channel='.$stream->name);
    curl_setopt($curl, CURLOPT_HEADER, false);
    curl_setopt($curl, CURLOPT_SSL_VERIFYPEER, false);
    curl_setopt($curl, CURLOPT_FAILONERROR, true);

    $result = curl_exec($curl);
    if( !empty($result) ) {
      $result = Zend_Json::decode($result);
    }

    return $result;
  }

  public function getReactionsAction() {

    $response['reactionsEnabled'] = 0;
    if (Engine_Api::_()->getApi('Siteapi_Feed', 'advancedactivity')->isSitereactionPluginLive()) {
      if (Engine_Api::_()->getDbtable('modules', 'core')->isModuleEnabled('sitereaction') && Engine_Api::_()->getApi('settings', 'core')->getSetting('sitereaction.reaction.active', 1)) {
        $response['reactionsEnabled'] = 1;
        $reactions = array("like", "love", "wow", "haha", "sad", "angry");

        $reactionIconsTable = Engine_Api::_()->getDbTable('reactionicons', 'sitereaction');
        // get all reaction icons
        $reactionIcons = $reactionIconsTable->getReactions(array('orderby' => 'order'));
        $reactionIconsData = array();
        $baseUrl = Zend_Controller_Front::getInstance()->getBaseUrl();
        $baseUrl = @trim($baseUrl, "/");
        foreach ($reactionIcons as $reactionIcon) {
          if(Engine_Api::_()->getApi('settings', 'core')->getSetting('livestreamingvideo.reactions', 1) && in_array($reactionIcon->type, $reactions) && Engine_Api::_()->getDbtable('modules', 'core')->isModuleEnabled('sitelivestreaming'))
            $iconImages['reaction_image_icon'] =  Engine_Api::_()->getApi('Core', 'siteapi')->getHost().'/'. $baseUrl .'/application/modules/Sitelivestreaming/externals/images/reactions/'.$reactionIcon->type.'.gif';
          else
            $iconImages = Engine_Api::_()->getApi('Siteapi_Core', 'sitereaction')->getIcons($reactionIcon['type']);
          if(empty($iconImages))
            continue;
          $reactionIconsData[$reactionIcon['type']] = array(
            'caption' => Engine_Api::_()->getApi('Core', 'siteapi')->translate($reactionIcon->title),
            'order' => $reactionIcon->order,
            'reactionicon_id' => $reactionIcon->reactionicon_id,
            'reaction' => $reactionIcon->type,
            'icon' => $iconImages,
          );
        }

        $response['reactions'] = $reactionIconsData;
      }
    }
    $this->respondWithSuccess($response);
  }

}