<?php
/**
 * SocialEngine
 *
 * @category   Application_Extensions
 * @package    Sitereaction
 * @copyright  Copyright 2015-2016 BigStep Technologies Pvt. Ltd.
 * @license    http://www.socialengineaddons.com/license/
 * @version    IndexController.php 2015-09-17 00:00:00Z SocialEngineAddOns $
 * @author     SocialEngineAddOns
 */
class Nestedcomment_IndexController extends Siteapi_Controller_Action_Standard {
    /**
     * Handles HTTP request to like an activity feed item
     *
     * @return array
     */
    public $_totalComment = array();
    public function likeAction() {
        // Validate request methods
        $this->validateRequestMethod('POST');
        Engine_Api::_()->getApi('Core', 'siteapi')->setView();
        // Get Params
        $sendAppNotification = $this->getRequestParam('sendNotification', 1);
        $subject_id = $this->_getParam('subject_id');
        $subject_type = $this->_getParam('subject_type', 'activity_action');
        $subject = Engine_Api::_()->getItem($subject_type, $subject_id);
        $viewer = Engine_Api::_()->user()->getViewer();
        // Start transaction
        $db = Engine_Api::_()->getDbtable('likes', 'activity')->getAdapter();
        $db->beginTransaction();
        try {
            // Action
            // Check authorization
            if ($subject && !Engine_Api::_()->authorization()->isAllowed($subject, null, 'comment'))
                $this->respondWithError('unauthorized');
            //new reaction code start
            $reaction = $this->getRequestParam('reaction');
            $like = $reaction ? $subject->likes()->getLike($viewer) : null;
            $sendNotification = false;
            $shouldAddActivity = false;
            if (empty($like)) {
                $sendNotification = true;
                $like = $subject->likes()->addLike($viewer);
                $shouldAddActivity = $reaction && $reaction !== 'like';
            }
            if ($reaction) {
                $like->reaction = $reaction;
                $like->save();
            }
            // Stats
            Engine_Api::_()->getDbtable('statistics', 'core')->increment('core.likes');
            $db->commit();
        } catch (Exception $e) {
            $db->rollBack();
            $this->respondWithValidationError('validation_fail', 'You have already liked this.');
        }
        $this->successResponseNoContent('no_content');
    }
    /**
     * Handles HTTP request to like an activity feed item
     *
     * @return array
     */
    public function sendLikeNotitficationAction() {
        // Validate request methods
        $this->validateRequestMethod('POST');
        Engine_Api::_()->getApi('Core', 'siteapi')->setView();
        $reaction = $this->getRequestParam('reaction');
        $sendAppNotification = $this->getRequestParam('sendNotification', 1);
        $subject_id = $this->_getParam('subject_id');
        $subject_type = $this->_getParam('subject_type', 'activity_action');
        $subject = Engine_Api::_()->getItem($subject_type, $subject_id);
        $viewer = Engine_Api::_()->user()->getViewer();
        // Start transaction
        $db = Engine_Api::_()->getDbtable('likes', 'activity')->getAdapter();
        $db->beginTransaction();
        try {
            $like = $reaction ? $subject->likes()->getLike($viewer) : null;
            $shouldAddActivity = false;
            $sendNotification = true;
            $shouldAddActivity = $reaction && $reaction !== 'like';
            // Add activity
            if ($shouldAddActivity) {
                $api = Engine_Api::_()->getDbtable('actions', 'advancedactivity');
                if ($subject->getTypeInfoCommentable() < 2) {
                    $shouldAddActivity = in_array($subject->getType(), array('status'));
                    $attachment = $subject;
                    $attachmentOwner = Engine_Api::_()->getItemByGuid($subject_type . "_" . $subject_id);
                } else {
                    $attachment = $subject->getCommentObject();
                    $attachmentOwner = $attachment->getOwner();
                }
                // Add activity for owner of activity (if user and not viewer)
                if ($shouldAddActivity && $attachmentOwner->getType() == 'user' && $attachmentOwner->getIdentity() != $viewer->getIdentity()) {
                    $params = array(
                        'type' => $attachment->getMediaType(),
                        'owner' => $attachmentOwner->getGuid(),
                    );
                    $likeAction = $api->addActivity($viewer, $attachment, 'react', '', '', $params);
                    if ($likeAction) {
                        $api->attachActivity($likeAction, $attachment);
                    }
                }
            }
            //reaction code end
            // Add notification for owner of activity (if user and not viewer)
            if ($subject_type == 'user' && $subject_id != $viewer->getIdentity()) {
                $actionOwner = Engine_Api::_()->getItemByGuid($subject_type . "_" . $subject_id);
                $notificationType = isset($like->reaction) && $like->reaction !== 'like' ? 'reacted' : 'liked';
                Engine_Api::_()->getApi('Siteapi_Core', 'activity')->addNotification($actionOwner, $viewer, $subject, $notificationType, array(
                    'label' => 'post'
                ));
            }
        } catch (Exception $e) {
            //Blank Exception 
        }
        $this->successResponseNoContent('no_content');
    }
    
    /**
     * Set the uploaded photo from activity post.
     *
     * @return object
     */
    private function _setPhoto($photo, $subject) {
        if ($photo instanceof Zend_Form_Element_File) {
            $file = $photo->getFileName();
        } else if (is_array($photo) && !empty($photo['tmp_name'])) {
            $file = $photo['tmp_name'];
        } else if (is_string($photo) && file_exists($photo)) {
            $file = $photo;
        } else {
            throw new Group_Model_Exception('invalid argument passed to setPhoto');
        }
        $fileName = $photo['name'];
        $name = basename($file);
        $extension = ltrim(strrchr($fileName, '.'), '.');
        $path = APPLICATION_PATH . DIRECTORY_SEPARATOR . 'temporary';
        $base = rtrim(substr(basename($fileName), 0, strrpos(basename($fileName), '.')), '.');
        $params = array(
            'parent_type' => $subject->getType(),
            'parent_id' => $subject->getIdentity(),
            'user_id' => $subject->owner_id,
            'name' => $fileName,
        );
        $filesTable = Engine_Api::_()->getDbtable('files', 'storage');
// Resize image (main)
        $mainPath = $path . DIRECTORY_SEPARATOR . $base . '_m.' . $extension;
        $image = Engine_Image::factory();
        $image->open($file)
                ->resize(720, 720)
                ->write($mainPath)
                ->destroy();
// Resize image (normal)
        $normalPath = $path . DIRECTORY_SEPARATOR . $base . '_in.' . $extension;
        $image = Engine_Image::factory();
        $image->open($file)
                ->resize(140, 160)
                ->write($normalPath)
                ->destroy();
// Store
        try {
            $iMain = $filesTable->createFile($mainPath, $params);
            $iIconNormal = $filesTable->createFile($normalPath, $params);
            $iMain->bridge($iIconNormal, 'thumb.normal');
        } catch (Exception $e) {
            $this->respondWithValidationError('internal_server_error', $e->getMessage());
        }
// Remove temp files
        @unlink($mainPath);
        @unlink($normalPath);
// Update row
        $subject->modified_date = date('Y-m-d H:i:s');
        $subject->file_id = $iMain->file_id;
        $subject->save();
        return $subject;
    }
    
    /*
     * Reply on comment 
     * return @rrray
     */
    public function replyAction() {
        if (!Zend_Registry::isRegistered('Zend_Translate'))
            Engine_Api::_()->getApi('Core', 'siteapi')->setTranslate();
        Engine_Api::_()->getApi('Core', 'siteapi')->setView();
        Engine_Api::_()->getApi('Core', 'siteapi')->setLocal();
        $send_notification = $this->getRequestParam('send_notification', 1);
        // Make sure user exists
        $this->validateRequestMethod('POST');
        if (!$this->_helper->requireUser()->isValid())
            return;
        $isShare = $this->_getParam('isShare');
        $settings = Engine_Api::_()->getApi('settings', 'core');
        if (!empty($settings->aaf_composer_value) && ($settings->aaf_composer_value != ($settings->aaf_list_view_value + $settings->aaf_publish_str_value))) {
            //invalid data
        }
        //TRY ATTACHMENT GETTING STUFF
        $attachment = null;
        $body = '';
        $attachmentData = $this->getRequestParam('attachment_id', null);
        $attachmentType = $this->getRequestParam('attachment_type', null);
        // Start transaction
        $db = Engine_Api::_()->getDbtable('actions', 'advancedactivity')->getAdapter();
        $db->beginTransaction();
        try {
            $viewer = Engine_Api::_()->user()->getViewer();
            $action_id = $this->_getParam('action_id', null);
            $action = Engine_Api::_()->getDbtable('actions', 'advancedactivity')->getActionById($action_id);
            $actionOwner = Engine_Api::_()->getItemByGuid($action->subject_type . "_" . $action->subject_id);
            $postData = $_REQUEST;
            if (isset($postData['body']) && !empty($postData['body']))
                $body = $postData['body'];
            // Check authorization
            if (!$action->authorization()->isAllowed($viewer, 'comment'))
                $this->respondWithError('unauthorized');
            // Add the comment
            $subject = $viewer;
            if (Engine_Api::_()->advancedactivity()->isBaseOnContentOwner($viewer, $action->getObject()))
                $subject = $action->getObject();
            if ($subject->getType() == 'siteevent_event') {
                $subject = $subject->getParent();
            }
            $row = $action->comments()->addComment($subject, $body);
            $row->parent_comment_id = $this->_getParam('comment_id', null);
            $row->save();
            // Notifications
            $notifyApi = Engine_Api::_()->getDbtable('notifications', 'activity');
            // Add notification for owner of activity (if user and not viewer)
            if(!empty($send_notification))
            {
                if ($action->subject_type == 'user' && $action->subject_id != $viewer->getIdentity()) {
                    $notifyApi->addNotification($actionOwner, $subject, $action, 'replied', array(
                        'label' => 'post'
                    ));
                }
                // Add a notification for all users that commented or like except the viewer and poster
                // @todo we should probably limit this
                $commentedUserNotifications = array();
                foreach ($action->comments()->getAllCommentsUsers() as $notifyUser) {
                    if ($notifyUser->getType() == 'user' && $notifyUser->getIdentity() != $viewer->getIdentity() && $notifyUser->getIdentity() != $actionOwner->getIdentity()) {
                        $commentedUserNotifications[] = $notifyUser->getIdentity();
                        $notifyApi->addNotification($notifyUser, $subject, $action, 'replied_replied', array(
                            'label' => 'post'
                        ));
                    }
                }
                // Add a notification for all users that commented or like except the viewer and poster
                // @todo we should probably limit this
                foreach ($action->likes()->getAllLikesUsers() as $notifyUser) {
                    if (in_array($notifyUser->getIdentity(), $commentedUserNotifications))
                        continue;
                    if ($notifyUser->getType() == 'user' && $notifyUser->getIdentity() != $viewer->getIdentity() && $notifyUser->getIdentity() != $actionOwner->getIdentity()) {
                        $notifyApi->addNotification($notifyUser, $subject, $action, 'liked_replied', array(
                            'label' => 'post'
                        ));
                    }
                }
                //PAGE COMMENT CREATE NOTIFICATION WORK
                $object_type = $action->object_type;
                $object_id = $action->object_id;
                if ($object_type == 'sitepage_page' && Engine_Api::_()->getDbtable('modules', 'core')->isModuleEnabled('sitepage')) {
                    if (Engine_Api::_()->getDbtable('modules', 'core')->getModule('sitepage')->version) {
                        $sitepage = Engine_Api::_()->getItem('sitepage_page', $object_id);
                        Engine_Api::_()->sitepage()->sendNotificationEmail($sitepage, $action, 'sitepage_activityreply', '', 'Activity Reply');
                    }
                } else if ($object_type == 'sitegroup_group') {
                    $sitegroup = Engine_Api::_()->getItem('sitegroup_group', $object_id);
                    Engine_Api::_()->sitegroup()->sendNotificationEmail($sitegroup, $action, 'sitepage_activityreply', '', 'Activity Reply');
                } else if ($object_type == 'sitestore_store') {
                    $sitestore = Engine_Api::_()->getItem('sitestore_store', $object_id);
                    Engine_Api::_()->sitestore()->sendNotificationEmail($sitestore, $action, 'sitepage_activityreply', '', 'Activity Reply');
                } else if ($object_type == 'sitebusiness_business') {
                    $sitebusiness = Engine_Api::_()->getItem('sitebusiness_business', $object_id);
                    Engine_Api::_()->sitebusiness()->sendNotificationEmail($sitebusiness, $action, 'sitebusiness_activityreply', '', 'Activity Reply');
                } else if ($object_type == 'siteevent_event') {
                    $siteevent = Engine_Api::_()->getItem('siteevent_event', $object_id);
                    Engine_Api::_()->siteevent()->sendNotificationEmail($siteevent, $action, 'siteevent_activityreply', '', 'Activity Reply', null, 'comment', $viewer);
                }
            
            }
            // Stats
            //Engine_Api::_()->getDbtable('statistics', 'core')->increment('core.comments');
            $attachment = null;
            //Reaction post work start 
            if (isset($attachmentType) && !empty($attachmentType)) {
                if ($attachmentType == 'sticker' && isset($attachmentData))
                    $attachment = Engine_Api::_()->getItemByGuid($attachmentData);
                if ($attachmentType == 'photo' && !empty($_FILES['photo'])) {
                    $table = Engine_Api::_()->getDbtable('albums', 'album');
                    $type = $this->getRequestParam('image_type', 'comment');
                    $album = $this->getSpecialAlbum($viewer, $type);
                    $photoTable = Engine_Api::_()->getDbtable('photos', 'album');
                    $photo = $photoTable->createRow();
                    $photo->owner_type = 'user';
                    $photo->owner_id = $viewer->getIdentity();
                    $photo->save();
// Set the photo
                    $photo = $this->_setPhoto($_FILES['photo'], $photo);
                    $photo->order = $photo->photo_id;
                    $photo->album_id = $album->album_id;
                    $photo->save();
                    if (!$album->photo_id) {
                        $album->photo_id = $photo->getIdentity();
                        $album->save();
                    }
                    $auth = Engine_Api::_()->authorization()->context;
                    $auth->setAllowed($photo, 'everyone', 'view', true);
                    $auth->setAllowed($photo, 'everyone', 'comment', true);
                    $attachment = $photo;
                }
            }
            if ($attachment && isset($row->attachment_type) && isset($row->attachment_id)) {
                $row->attachment_type = $attachment->getType();
                $row->attachment_id = $attachment->getIdentity();
                $row->save();
            }
            $composerDatas = !empty($this->getRequestParam('composer')) ? Zend_Json::decode($this->getRequestParam('composer', null)) : array();
            $tagsArray = array();
            parse_str($composerDatas['tag'], $tagsArray);
            if (!empty($tagsArray)) {
//                if ($action) {
//                    $actionParams = (array) $action->params;
//                    $action->params = array_merge((array) $action->params, array('tags' => $tagsArray));
//                    $action->save();
//                }
                $type_name = Zend_Registry::get('Zend_Translate')->translate('post');
                if (is_array($type_name)) {
                    $type_name = $type_name[0];
                } else {
                    $type_name = 'post';
                }
                $notificationAPi = Engine_Api::_()->getDbtable('notifications', 'activity');
                if(!empty($send_notification))
                {
                    foreach ($tagsArray as $key => $tagStrValue) {
                        $tag = Engine_Api::_()->getItemByGuid($key);
                        if (in_array($tag->getIdentity(), $commentedUserNotifications))
                            continue;
                        if ($action && $tag && ($tag instanceof User_Model_User) && !$tag->isSelf($viewer)) {
                            $notificationAPi->addNotification($tag, $viewer, $action, 'tagged', array(
                                'object_type_name' => $type_name,
                                'label' => $type_name,
                            ));
                        } else if ($tag && ($tag instanceof Sitepage_Model_Page)) {
                            $subject_title = $viewer->getTitle();
                            $page_title = $tag->getTitle();
                            foreach ($tag->getPageAdmins() as $owner) {
                                if ($action && $owner && ($owner instanceof User_Model_User) && !$owner->isSelf($viewer)) {
                                    $notificationAPi->addNotification($owner, $viewer, $action, 'sitepage_tagged', array(
                                        'subject_title' => $subject_title,
                                        'label' => $type_name,
                                        'object_type_name' => $type_name,
                                        'page_title' => $page_title
                                    ));
                                }
                            }
                        } else if ($tag && ($tag instanceof Sitebusiness_Model_Business)) {
                            $subject_title = $viewer->getTitle();
                            $business_title = $tag->getTitle();
                            foreach ($tag->getBusinessAdmins() as $owner) {
                                if ($action && $owner && ($owner instanceof User_Model_User) && !$owner->isSelf($viewer)) {
                                    $notificationAPi->addNotification($owner, $viewer, $action, 'sitebusiness_tagged', array(
                                        'subject_title' => $subject_title,
                                        'label' => $type_name,
                                        'object_type_name' => $type_name,
                                        'business_title' => $business_title
                                    ));
                                }
                            }
                        } else if ($tag && ($tag instanceof Sitegroup_Model_Group)) {
                            $subject_title = $viewer->getTitle();
                            $store_title = $tag->getTitle();
                            foreach ($tag->getGroupAdmins() as $owner) {
                                if ($action && $owner && ($owner instanceof User_Model_User) && !$owner->isSelf($viewer)) {
                                    $notificationAPi->addNotification($owner, $viewer, $action, 'sitegroup_tagged', array(
                                        'subject_title' => $subject_title,
                                        'label' => $type_name,
                                        'object_type_name' => $type_name,
                                        'group_title' => $store_title
                                    ));
                                }
                            }
                        } else if ($tag && ($tag instanceof Sitestore_Model_Store)) {
                            $subject_title = $viewer->getTitle();
                            $store_title = $tag->getTitle();
                            foreach ($tag->getStoreAdmins() as $owner) {
                                if ($action && $owner && ($owner instanceof User_Model_User) && !$owner->isSelf($viewer)) {
                                    $notificationAPi->addNotification($owner, $viewer, $action, 'sitestore_tagged', array(
                                        'subject_title' => $subject_title,
                                        'label' => $type_name,
                                        'object_type_name' => $type_name,
                                        'store_title' => $store_title
                                    ));
                                }
                            }
                        } else if ($tag && ($tag instanceof Core_Model_Item_Abstract)) {
                            $subject_title = $viewer->getTitle();
                            $item_type = Zend_Registry::get('Zend_Translate')->translate($tag->getShortType());
                            $item_title = $tag->getTitle();
                            $owner = $tag->getOwner();
                            if ($action && $owner && ($owner instanceof User_Model_User) && !$owner->isSelf($viewer)) {
                                $notificationAPi->addNotification($owner, $viewer, $action, 'aaf_tagged', array(
                                    'subject_title' => $subject_title,
                                    'label' => $type_name,
                                    'object_type_name' => $type_name,
                                    'item_title' => $item_title,
                                    'item_type' => $item_type
                                ));
                            }
                            if (($tag instanceof Group_Model_Group)) {
                                foreach ($tag->getOfficerList()->getAll() as $offices) {
                                    $owner = Engine_Api::_()->getItem('user', $offices->child_id);
                                    if ($action && $owner && ($owner instanceof User_Model_User) && !$owner->isSelf($viewer)) {
                                        $notificationAPi->addNotification($owner, $viewer, $action, 'aaf_tagged', array(
                                            'subject_title' => $subject_title,
                                            'label' => $type_name,
                                            'object_type_name' => $type_name,
                                            'item_title' => $item_title,
                                            'item_type' => $item_type
                                        ));
                                    }
                                }
                            }
                        }
                    }
                }
                if ($action) {
                    $data = array_merge((array) $action->params, array('tags' => $tagsArray));
                    $row->params = Zend_Json::encode($data);
                }
                $row->save();
            }
            $canComment = $action->authorization()->isAllowed($viewer, 'comment');
            $canDelete = $action->authorization()->isAllowed($viewer, 'edit');
            Engine_Api::_()->getDbtable('statistics', 'core')->increment('core.comments');
            $commentInfo = array();
            $poster = Engine_Api::_()->getItem($row->poster_type, $row->poster_id);
            $commentInfo["subject_id"] = $subject->getIdentity();
            $commentInfo["comment_id"] = $row->comment_id;
            // Add images
            $getContentImages = Engine_Api::_()->getApi('Core', 'siteapi')->getContentImage($poster);
            $commentInfo = array_merge($commentInfo, $getContentImages);
            //to provide the same image names as in likes-comment response
            $getContentImages = array();
            $getContentImages = Engine_Api::_()->getApi('Core', 'siteapi')->getContentImage($poster, false, 'author');
            $commentInfo = array_merge($commentInfo, $getContentImages);
            $commentInfo["author_title"] = $poster->getTitle();
            $commentInfo["user_id"] = $poster->getIdentity();
            $commentInfo["comment_body"] = $row->body;
            $commentInfo["comment_date"] = $row->creation_date;
            $commentInfo["params"] = isset($row->params) ? $row->params : "";
            if (Engine_Api::_()->getApi('Siteapi_Feed', 'advancedactivity')->isSitestickerPluginLive()) {
                if (isset($row->attachment_type) && !empty($row->attachment_type) && isset($row->attachment_id) && !empty($row->attachment_id)) {
                    $attachment = Engine_Api::_()->getItem($row->attachment_type, $row->attachment_id);
                    $getContentImages = Engine_Api::_()->getApi('Core', 'siteapi')->getContentImage($attachment, false);
                    
                    //image height and width
                    $params = Engine_Api::_()->getApi('Siteapi_Feed', 'advancedactivity')->getPhotoUrl($attachment, "thumb.profile");
                    $getHost = $getParentHost = Engine_Api::_()->getApi('Core', 'siteapi')->getHost();
                    $baseParentUrl = Zend_Controller_Front::getInstance()->getBaseUrl();
                    $baseParentUrl = @trim($baseParentUrl, "/");
                    $staticBaseUrl = Engine_Api::_()->getApi('settings', 'core')->getSetting('core.static.baseurl', null);
                    // Check IF default service "Local Storage" or not.
                    $getDefaultStorageId = Engine_Api::_()->getDbtable('services', 'storage')->getDefaultServiceIdentity();
                    $getDefaultStorageType = Engine_Api::_()->getDbtable('services', 'storage')->getService($getDefaultStorageId)->getType();
                    $host = '';
                    if ($getDefaultStorageType == 'local')
                        $host = !empty($staticBaseUrl) ? $staticBaseUrl : $getParentHost;
                    $imageUrl = $params['url'];
                    $imageUrl = (!strstr($imageUrl, "application/modules")) ? $host . $imageUrl : $imageUrl;
                    if (!strstr($imageUrl, 'http'))
                        $imageUrl = $getHost . DIRECTORY_SEPARATOR . $baseParentUrl . $imageUrl;
                    ;
                    try {
                        if (!empty($params)) {
                            $getContentImages = array(
                                "image_profile" => $imageUrl,
                                "size" => $params['params']
                            );
                        }
                    } catch (Exception $ex) {
                        
                    }
                    
                    $commentInfo['attachment'] = $getContentImages;
                    $commentInfo['attachment_type'] = $row->attachment_type;
                    $commentInfo['attachment_id'] = $row->attachment_id;
                }
            }
            
               $commentInfo['gutterMenu'] = $this->_gutterMenus($action,$canDelete,$poster,$row,1);
            if (!empty($canComment)) {
                $isLiked = $row->likes()->isLike($viewer);
                if (empty($isLiked)) {
                    $likeInfo["name"] = "like";
                    $likeInfo["label"] = $this->translate("Like");
                    $likeInfo["url"] = "like";
                    $likeInfo["urlParams"] = array(
                        "action_id" => $action->getIdentity(),
                        "subject_type" => $action->getType(),
                        "subject_id" => $action->getIdentity(),
                        "comment_id" => $row->comment_id
                    );
                    $likeInfo["isLike"] = 0;
                } else {
                    $likeInfo["name"] = "unlike";
                    $likeInfo["label"] = $this->translate("Unlike");
                    $likeInfo["url"] = "unlike";
                    $likeInfo["urlParams"] = array(
                        "action_id" => $action->getIdentity(),
                        "subject_type" => $action->getType(),
                        "subject_id" => $action->getIdentity(),
                        "comment_id" => $row->comment_id
                    );
                    $likeInfo["isLike"] = 1;
                }
                $commentInfo["like_count"] = $row->likes()->getLikeCount();
                $commentInfo["like"] = $likeInfo;
            } else {
                $commentInfo["like"] = null;
            }
            $db->commit();
            $this->respondWithSuccess($commentInfo);
        } catch (Exception $e) {
            $db->rollBack();
            $this->respondWithValidationError('internal_server_error', $e->getMessage());
        }
    }
    
    public function replyEditAction() {
        $this->validateRequestMethod('POST');
        // Make sure user exists
        if (!$this->_helper->requireUser()->isValid())
            return;
        $isShare = $this->_getParam('isShare');
        $settings = Engine_Api::_()->getApi('settings', 'core');
        if (!empty($settings->aaf_composer_value) && ($settings->aaf_composer_value != ($settings->aaf_list_view_value + $settings->aaf_publish_str_value))) {
            
        }
        $attachmentData = $this->getRequestParam('attachment_id', null);
        $attachmentType = $this->getRequestParam('attachment_type', null);
        // Start transaction
        $db = Engine_Api::_()->getDbtable('actions', 'advancedactivity')->getAdapter();
        $db->beginTransaction();
        try {
            $viewer = Engine_Api::_()->user()->getViewer();
            $action_id = $this->_getParam('action_id', null);
            $action = Engine_Api::_()->getDbtable('actions', 'advancedactivity')->getActionById($action_id);
            $actionOwner = Engine_Api::_()->getItemByGuid($action->subject_type . "_" . $action->subject_id);
            $data = $_REQUEST;
            $body = '';
            if (isset($_REQUEST['body']))
                $body = $_REQUEST['body'];
            // Check authorization
            if (!Engine_Api::_()->authorization()->isAllowed($action->getCommentObject(), null, 'comment'))
                $this->respondWithError('unauthorized');
            if (!$action->authorization()->isAllowed($viewer, 'edit')) {
                $this->respondWithError('unauthorized');
            }
            // Add the comment
            $subject = $viewer;
            if (Engine_Api::_()->advancedactivity()->isBaseOnContentOwner($viewer, $action->getObject()))
                $subject = $action->getObject();
            if (!empty($subject) && $subject->getType() == 'siteevent_event') {
                $subject = $subject->getParent();
            }
            $comment_id = $this->_getParam('comment_id', null);
            $row = $action->comments()->getComment($comment_id);
            $row->body = $body;
            $row->save();
            $attachment = null;
            //Reaction post work start 
            if (isset($attachmentType) && !empty($attachmentType)) {
                if ($attachmentType == 'sticker' && isset($attachmentData))
                    $attachment = Engine_Api::_()->getItemByGuid($attachmentData);
                if ($attachmentType == 'photo' && !empty($_FILES['photo'])) {
                    $table = Engine_Api::_()->getDbtable('albums', 'album');
                    $type = $this->getRequestParam('image_type', 'comment');
                    $album = $this->getSpecialAlbum($viewer, $type);
                    $photoTable = Engine_Api::_()->getDbtable('photos', 'album');
                    $photo = $photoTable->createRow();
                    $photo->owner_type = 'user';
                    $photo->owner_id = $viewer->getIdentity();
                    $photo->save();
// Set the photo
                    $photo = $this->_setPhoto($_FILES['photo'], $photo);
                    $photo->order = $photo->photo_id;
                    $photo->album_id = $album->album_id;
                    $photo->save();
                    if (!$album->photo_id) {
                        $album->photo_id = $photo->getIdentity();
                        $album->save();
                    }
                    $auth = Engine_Api::_()->authorization()->context;
                    $auth->setAllowed($photo, 'everyone', 'view', true);
                    $auth->setAllowed($photo, 'everyone', 'comment', true);
                    $attachment = $photo;
                }
            }
            if ($attachment && isset($row->attachment_type) && isset($row->attachment_id)) {
                $row->attachment_type = $attachment->getType();
                $row->attachment_id = $attachment->getIdentity();
                $row->save();
            }
            $compossor_data = $this->getRequestParam('composer', null);
            $composerDatas = !empty($compossor_data) ? Zend_Json::decode($compossor_data) : array();
            $tagsArray = array();
            parse_str($composerDatas['tag'], $tagsArray);
            if (!empty($tagsArray)) {
//                if ($action) {
//                    $actionParams = (array) $action->params;
//                    $action->params = array_merge((array) $action->params, array('tags' => $tagsArray));
//                    $action->save();
//                }
                $viewer = Engine_Api::_()->_()->user()->getViewer();
                $type_name = Zend_Registry::get('Zend_Translate')->translate('post');
                if (is_array($type_name)) {
                    $type_name = $type_name[0];
                } else {
                    $type_name = 'post';
                }
                $notificationAPi = Engine_Api::_()->getDbtable('notifications', 'activity');
                foreach ($tagsArray as $key => $tagStrValue) {
                    $tag = Engine_Api::_()->getItemByGuid($key);
                    if (in_array($tag->getIdentity(), $commentedUserNotifications))
                        continue;
                    if ($action && $tag && ($tag instanceof User_Model_User) && !$tag->isSelf($viewer)) {
                        $notificationAPi->addNotification($tag, $viewer, $action, 'tagged', array(
                            'object_type_name' => $type_name,
                            'label' => $type_name,
                        ));
                    } else if ($tag && ($tag instanceof Sitepage_Model_Page)) {
                        $subject_title = $viewer->getTitle();
                        $page_title = $tag->getTitle();
                        foreach ($tag->getPageAdmins() as $owner) {
                            if ($action && $owner && ($owner instanceof User_Model_User) && !$owner->isSelf($viewer)) {
                                $notificationAPi->addNotification($owner, $viewer, $action, 'sitepage_tagged', array(
                                    'subject_title' => $subject_title,
                                    'label' => $type_name,
                                    'object_type_name' => $type_name,
                                    'page_title' => $page_title
                                ));
                            }
                        }
                    } else if ($tag && ($tag instanceof Sitebusiness_Model_Business)) {
                        $subject_title = $viewer->getTitle();
                        $business_title = $tag->getTitle();
                        foreach ($tag->getBusinessAdmins() as $owner) {
                            if ($action && $owner && ($owner instanceof User_Model_User) && !$owner->isSelf($viewer)) {
                                $notificationAPi->addNotification($owner, $viewer, $action, 'sitebusiness_tagged', array(
                                    'subject_title' => $subject_title,
                                    'label' => $type_name,
                                    'object_type_name' => $type_name,
                                    'business_title' => $business_title
                                ));
                            }
                        }
                    } else if ($tag && ($tag instanceof Sitegroup_Model_Group)) {
                        $subject_title = $viewer->getTitle();
                        $store_title = $tag->getTitle();
                        foreach ($tag->getGroupAdmins() as $owner) {
                            if ($action && $owner && ($owner instanceof User_Model_User) && !$owner->isSelf($viewer)) {
                                $notificationAPi->addNotification($owner, $viewer, $action, 'sitegroup_tagged', array(
                                    'subject_title' => $subject_title,
                                    'label' => $type_name,
                                    'object_type_name' => $type_name,
                                    'group_title' => $store_title
                                ));
                            }
                        }
                    } else if ($tag && ($tag instanceof Sitestore_Model_Store)) {
                        $subject_title = $viewer->getTitle();
                        $store_title = $tag->getTitle();
                        foreach ($tag->getStoreAdmins() as $owner) {
                            if ($action && $owner && ($owner instanceof User_Model_User) && !$owner->isSelf($viewer)) {
                                $notificationAPi->addNotification($owner, $viewer, $action, 'sitestore_tagged', array(
                                    'subject_title' => $subject_title,
                                    'label' => $type_name,
                                    'object_type_name' => $type_name,
                                    'store_title' => $store_title
                                ));
                            }
                        }
                    } else if ($tag && ($tag instanceof Core_Model_Item_Abstract)) {
                        $subject_title = $viewer->getTitle();
                        $item_type = Zend_Registry::get('Zend_Translate')->translate($tag->getShortType());
                        $item_title = $tag->getTitle();
                        $owner = $tag->getOwner();
                        if ($action && $owner && ($owner instanceof User_Model_User) && !$owner->isSelf($viewer)) {
                            $notificationAPi->addNotification($owner, $viewer, $action, 'aaf_tagged', array(
                                'subject_title' => $subject_title,
                                'label' => $type_name,
                                'object_type_name' => $type_name,
                                'item_title' => $item_title,
                                'item_type' => $item_type
                            ));
                        }
                        if (($tag instanceof Group_Model_Group)) {
                            foreach ($tag->getOfficerList()->getAll() as $offices) {
                                $owner = Engine_Api::_()->getItem('user', $offices->child_id);
                                if ($action && $owner && ($owner instanceof User_Model_User) && !$owner->isSelf($viewer)) {
                                    $notificationAPi->addNotification($owner, $viewer, $action, 'aaf_tagged', array(
                                        'subject_title' => $subject_title,
                                        'label' => $type_name,
                                        'object_type_name' => $type_name,
                                        'item_title' => $item_title,
                                        'item_type' => $item_type
                                    ));
                                }
                            }
                        }
                    }
                }
                if ($action) {
                    $data = array_merge((array) $action->params, array('tags' => $tagsArray));
                    $row->params = Zend_Json::encode($data);
                }
                $row->save();
            }
            $commentInfo = $this->_getCommentInfo($action, $subject, $row);
            $db->commit();
            $this->respondWithSuccess($commentInfo);
        } catch (Exception $e) {
            $db->rollBack();
            
        }
    }
    private function _getCommentInfo($action = array(), $subject = array(), $row = array()) {
        $viewer = Engine_Api::_()->user()->getViewer();
        $canComment = $action->authorization()->isAllowed($viewer, 'edit');
        $canDelete = $action->authorization()->isAllowed($viewer, 'edit');
        Engine_Api::_()->getDbtable('statistics', 'core')->increment('core.comments');
        $commentInfo = array();
        $poster = Engine_Api::_()->getItem($row->poster_type, $row->poster_id);
        $commentInfo["subject_id"] = $subject->getIdentity();
        $commentInfo["comment_id"] = $row->comment_id;
        // Add images
        $getContentImages = Engine_Api::_()->getApi('Core', 'siteapi')->getContentImage($poster);
        $commentInfo = array_merge($commentInfo, $getContentImages);
        //to provide the same image names as in likes-comment response
        $getContentImages = array();
        $getContentImages = Engine_Api::_()->getApi('Core', 'siteapi')->getContentImage($poster, false, 'author');
        $commentInfo = array_merge($commentInfo, $getContentImages);
        $commentInfo["author_title"] = $poster->getTitle();
        $commentInfo["user_id"] = $poster->getIdentity();
        $commentInfo["comment_body"] = $row->body;
        $commentInfo["comment_date"] = $row->creation_date;
        $commentInfo["params"] = isset($row->params) ? $row->params : "";
        if (Engine_Api::_()->getApi('Siteapi_Feed', 'advancedactivity')->isSitestickerPluginLive()) {
            if (isset($row->attachment_type) && !empty($row->attachment_type) && isset($row->attachment_id) && !empty($row->attachment_id)) {
                $attachment = Engine_Api::_()->getItem($row->attachment_type, $row->attachment_id);
                $getContentImages = Engine_Api::_()->getApi('Core', 'siteapi')->getContentImage($attachment, false);
                $commentInfo['attachment'] = $getContentImages;
                $commentInfo['attachment_type'] = $row->attachment_type;
                $commentInfo['attachment_id'] = $row->attachment_id;
            }
        }
        if (!empty($canDelete) || $poster->isSelf($viewer)) {
            $commentInfo["delete"] = array(
                "name" => "delete",
                "label" => $this->translate("Delete"),
                "url" => "comment-delete",
                'urlParams' => array(
                    "action_id" => $action->getIdentity(),
                    "subject_type" => $subject->getType(),
                    "subject_id" => $subject->getIdentity(),
                    "comment_id" => $row->comment_id
                )
            );
            $commentInfo["edit"] = array(
                "name" => "edit",
                "label" => $this->translate('Edit'),
                "url" => "advancedcomments/update",
                'urlParams' => array(
                    "action_id" => $action->getIdentity(),
                    "subject_type" => $subject->getType(),
                    "subject_id" => $subject->getIdentity(),
                    "comment_id" => $row->comment_id
                )
            );
        } else {
            $commentInfo["delete"] = null;
        }
        if (!empty($canComment)) {
            $isLiked = $row->likes()->isLike($viewer);
            if (empty($isLiked)) {
                $likeInfo["name"] = "like";
                $likeInfo["label"] = $this->translate("Like");
                $likeInfo["url"] = "like";
                $likeInfo["urlParams"] = array(
                    "action_id" => $action->getIdentity(),
                    "subject_type" => $subject->getType(),
                    "subject_id" => $subject->getIdentity(),
                    "comment_id" => $row->getIdentity()
                );
                $likeInfo["isLike"] = 0;
            } else {
                $likeInfo["name"] = "unlike";
                $likeInfo["label"] = $this->translate("Unlike");
                $likeInfo["url"] = "unlike";
                $likeInfo["urlParams"] = array(
                    "action_id" => $action->getIdentity(),
                    "subject_type" => $subject->getType(),
                    "subject_id" => $subject->getIdentity(),
                    "comment_id" => $row->getIdentity()
                );
                $likeInfo["isLike"] = 1;
            }
            $commentInfo["like_count"] = $row->likes()->getLikeCount();
            $commentInfo["like"] = $likeInfo;
            $replyInfo["name"] = "reply";
            $replyInfo["label"] = $this->translate('Reply');
            $replyInfo["url"] = "advancedcomments/comment";
            $replyInfo['urlParams'] = array(
                "action_id" => $action->getIdentity(),
                "subject_type" => $subject->getType(),
                "subject_id" => $subject->getIdentity(),
                "comment_id" => $row->getIdentity()
            );
            $commentInfo["isReply"] = 1;
            $commentInfo["reply"] = $replyInfo;
        } else {
            $commentInfo["like"] = null;
        }
        return $commentInfo;
    }
    public function commentAction() {
        if (!$this->_helper->requireUser()->isValid()) {
            return;
        }
        if (!Zend_Registry::isRegistered('Zend_Translate'))
            Engine_Api::_()->getApi('Core', 'siteapi')->setTranslate();
        Engine_Api::_()->getApi('Core', 'siteapi')->setView();
        $viewer = Engine_Api::_()->user()->getViewer();
        $subject_id = $this->_getParam('subject_id');
        $subject_type = $this->_getParam('subject_type', 'activity_action');
        $subject = Engine_Api::_()->getItem($subject_type, $subject_id);
        $attachment = null;
        $body = '';
        $attachmentData = $this->getRequestParam('attachment_id');
        $attachmentType = $this->getRequestParam('attachment_type');
        $postData = $_REQUEST;
        $subjectParent = $subject;
        if (strpos($subject->getType(), "sitepage") !== false) {
            if ($subject->getType() == 'sitepage_page') {
                $subjectParent = $subject;
            } elseif ($subject->getType() == 'sitepagemusic_playlist') {
                $subjectParent = $subject->getParentType();
            } elseif ($subject->getType() == 'sitepagenote_photo') {
                $subjectParent = $subject->getParent()->getParent()->getParent();
            } elseif ($subject->getType() == 'sitepageevent_photo') {
                $subjectParent = $subject->getEvent()->getParentPage();
            } else {
                $subjectParent = $subject->getParent();
            }
            $pageApi = Engine_Api::_()->sitepage();
            $canComment = $pageApi->isManageAdmin($subjectParent, 'comment');
            if (empty($canComment)) {
                //to do for error
                return;
            }
        } elseif (strpos($subject->getType(), "sitebusiness") !== false) {
            if ($subject->getType() == 'sitebusiness_business') {
                $subjectParent = $subject;
            } elseif ($subject->getType() == 'sitebusinessnote_photo') {
                $subjectParent = $subject->getParent()->getParent()->getParent();
            } elseif ($subject->getType() == 'sitebusinessmusic_playlist') {
                $subjectParent = $subject->getParentType();
            } else {
                $subjectParent = $subject->getParent();
            }
            $businessApi = Engine_Api::_()->sitebusiness();
            $canComment = $businessApi->isManageAdmin($subjectParent, 'comment');
            if (empty($canComment)) {
                //return error
                return;
            }
        } elseif (strpos($subject->getType(), "sitegroup") !== false) {
            if ($subject->getType() == 'sitegroup_group') {
                $subjectParent = $subject;
            } elseif ($subject->getType() == 'sitegroupmusic_playlist') {
                $subjectParent = $subject->getParentType();
            } elseif ($subject->getType() == 'sitegroupnote_photo') {
                $subjectParent = $subject->getParent()->getParent()->getParent();
            } elseif ($subject->getType() == 'sitegroupevent_photo') {
                $subjectParent = $subject->getEvent()->getParentPage();
            } else {
                $subjectParent = $subject->getParent();
            }
            $groupApi = Engine_Api::_()->sitegroup();
            $canComment = $groupApi->isManageAdmin($subjectParent, 'comment');
            if (empty($canComment)) {
                //return error
                return;
            }
        } elseif (!$this->_helper->requireAuth()->setAuthParams(null, null, 'comment')->isValid()) {
            //return error
        }
        //composer data
        $composer_data = $this->getRequestParam('composer', null);
        $composerDatas = !empty($composer_data) ? Zend_Json::decode($composer_data) : array();
        $postData = $_REQUEST;
        if (isset($postData['body']) && !empty($postData['body']))
            $body = $postData['body'];
        if (empty($body) && !isset($attachmentType) && empty($attachmentType))
            $this->respondWithError('validation_fail');
        $tagsArray = array();
        $tagString = '';
        $comment_id = $postData['comment_id'];
        $db = $subject->comments()->getCommentTable()->getAdapter();
        $db->beginTransaction();
        $db = Engine_Api::_()->getDbtable('comments', 'nestedcomment')->comments($subject)->getCommentTable()->getAdapter();
        $db->beginTransaction();
        try {
            //For comment work owner or second user
            $baseOnContentOwner = Engine_Api::_()->seaocore()->baseOnContentOwner($viewer, $subjectParent);
            if ($baseOnContentOwner) {
                $comment = Engine_Api::_()->getDbtable('comments', 'nestedcomment')->comments($subject)->addComment($subjectParent, $body);
            } else {
                $comment = Engine_Api::_()->getDbtable('comments', 'nestedcomment')->comments($subject)->addComment($viewer, $body);
            }
            //reply on comment
            if (!empty($comment_id)) {
                $comment->parent_comment_id = $comment_id;
            }
            //gag user work
            $tagsArray = array();
            parse_str($composerDatas['tag'], $tagsArray);
            if (!empty($tagsArray)) {
                if ($subject) {
                    $data = array_merge((array) $subject, array('tags' => $tagsArray));
                    $comment->params = Zend_Json::encode($data);
                }
            }
            $comment->save();
            if (empty($comment))
                $this->respondWithError('unauthorized');
            $activityApi = Engine_Api::_()->getDbtable('actions', 'activity');
            $notifyApi = Engine_Api::_()->getDbtable('notifications', 'activity');
            $subjectOwner = $subject->getOwner('user');
            //Reaction post work start 
            if (isset($attachmentType) && !empty($attachmentType)) {
                if ($attachmentType == 'sticker' && isset($attachmentData))
                    $attachment = Engine_Api::_()->getItemByGuid($attachmentData);
                if ($attachmentType == 'photo' && !empty($_FILES['photo'])) {
                    $table = Engine_Api::_()->getDbtable('albums', 'album');
                    $type = $this->getRequestParam('image_type', 'comment');
                    $album = $this->getSpecialAlbum($viewer, $type);
                    $photoTable = Engine_Api::_()->getDbtable('photos', 'album');
                    $photo = $photoTable->createRow();
                    $photo->owner_type = 'user';
                    $photo->owner_id = $viewer->getIdentity();
                    $photo->save();
// Set the photo
                    $photo = $this->_setPhoto($_FILES['photo'], $photo);
                    $photo->order = $photo->photo_id;
                    $photo->album_id = $album->album_id;
                    $photo->save();
                    if (!$album->photo_id) {
                        $album->photo_id = $photo->getIdentity();
                        $album->save();
                    }
                    $auth = Engine_Api::_()->authorization()->context;
                    $auth->setAllowed($photo, 'everyone', 'view', true);
                    $auth->setAllowed($photo, 'everyone', 'comment', true);
                    $attachment = $photo;
                }

                if($attachmentType == 'gifphoto') {
                    $plugin = Engine_Api::_()->loadClass('Sitegifplayer_Plugin_Composer_GifPhoto');
                    $method = 'onAttachGifPhoto';
                    if (!empty($postData['gif_guid']))
                        $attachmentData['gif_guid'] = $postData['gif_guid'];
                    
                    $attachmentData['gif_code'] = $postData['code'];
                    $attachmentData['title'] = $postData['title'];
                    $attachment = $plugin->$method($attachmentData);
                }
            }
            //attachment work
            if ($attachment) {
                if (isset($comment->attachment_type))
                    $comment->attachment_type = ( $attachment ? $attachment->getType() : '' );
                if (isset($comment->attachment_id))
                    $comment->attachment_id = ( $attachment ? $attachment->getIdentity() : 0 );
                $comment->save();
            }
            $canComment = Engine_Api::_()->authorization()->isAllowed($subject, null, 'comment');
            $canDelete = Engine_Api::_()->authorization()->isAllowed($subject, null, 'edit');
            Engine_Api::_()->getDbtable('statistics', 'core')->increment('core.comments');
            $commentInfo = array();
            $poster = Engine_Api::_()->getItem($comment->poster_type, $comment->poster_id);
            $commentInfo["subject_id"] = $subject_id;
            $commentInfo["comment_id"] = $comment->comment_id;
            // Add images
            $getContentImages = Engine_Api::_()->getApi('Core', 'siteapi')->getContentImage($poster);
            $commentInfo = array_merge($commentInfo, $getContentImages);
            //to provide the same image names as in likes-comment response
            $getContentImages = array();
            $getContentImages = Engine_Api::_()->getApi('Core', 'siteapi')->getContentImage($poster, false, 'author');
            $commentInfo = array_merge($commentInfo, $getContentImages);
            $commentInfo["author_title"] = $poster->getTitle();
            $commentInfo["user_id"] = $poster->getIdentity();
            $commentInfo["comment_body"] = $comment->body;
            $commentInfo["comment_date"] = $comment->creation_date;
            //Member verification Work...............
            $commentInfo['showVerifyIcon'] = Engine_Api::_()->getApi('Core', 'siteapi')->getVerifyInfo($poster);
            $commentInfo["params"] = isset($comment->params) ? $comment->params : "";
                        if (Engine_Api::_()->getApi('Siteapi_Feed', 'advancedactivity')->isSitestickerPluginLive()) {
                if (isset($comment->attachment_type) && !empty($comment->attachment_type) && isset($comment->attachment_id) && !empty($comment->attachment_id)) {
                    $attachment = Engine_Api::_()->getItem($comment->attachment_type, $comment->attachment_id);
                    $params = Engine_Api::_()->getApi('Siteapi_Feed', 'advancedactivity')->getPhotoUrl($attachment, "thumb.profile");
                    $getHost = $getParentHost = Engine_Api::_()->getApi('Core', 'siteapi')->getHost();
                    $baseParentUrl = Zend_Controller_Front::getInstance()->getBaseUrl();
                    $baseParentUrl = @trim($baseParentUrl, "/");
                    $staticBaseUrl = Engine_Api::_()->getApi('settings', 'core')->getSetting('core.static.baseurl', null);
                    // Check IF default service "Local Storage" or not.
                    $getDefaultStorageId = Engine_Api::_()->getDbtable('services', 'storage')->getDefaultServiceIdentity();
                    $getDefaultStorageType = Engine_Api::_()->getDbtable('services', 'storage')->getService($getDefaultStorageId)->getType();
                    $host = '';
                    if ($getDefaultStorageType == 'local')
                        $host = !empty($staticBaseUrl) ? $staticBaseUrl : $getParentHost;

                    $imageUrl = $params['url'];
                    $imageUrl = (!strstr($imageUrl, "application/modules")) ? $host . $imageUrl : $imageUrl;
                    if (!strstr($imageUrl, 'http'))
                        $imageUrl = $getHost . DIRECTORY_SEPARATOR . $baseParentUrl . $imageUrl;
                    ;
                    try {
                        if (!empty($params)) {
                            $getContentImages = array(
                                "image_profile" => $imageUrl,
                                "size" => $params['params']
                            );
                        }
                    } catch (Exception $ex) {
                        
                    }
                    $commentInfo['attachment'] = $getContentImages;
                    $commentInfo['attachment_type'] = $comment->attachment_type;
                    $commentInfo['attachment_id'] = $comment->attachment_id;
                }
            }
                $commentInfo['gutterMenu'] = $this->_gutterMenus($subject,$canDelete,$poster,$comment);
            if (!empty($canDelete) || $poster->isSelf($viewer)) {
                $commentInfo["delete"] = array(
                    "name" => "delete",
                    "label" => $this->translate("Delete"),
                    "url" => "comment-delete",
                    'urlParams' => array(
                        "action_id" => $subject->getIdentity(),
                        "subject_type" => $subject->getType(),
                        "subject_id" => $subject->getIdentity(),
                        "comment_id" => $comment->comment_id
                    )
                );
            } else {
                $commentInfo["delete"] = null;
            }
            if (!empty($canComment)) {
                $isLiked = $comment->likes()->isLike($viewer);
                if (empty($isLiked)) {
                    $likeInfo["name"] = "like";
                    $likeInfo["label"] = $this->translate("Like");
                    $likeInfo["url"] = "like";
                    $likeInfo["urlParams"] = array(
                        "action_id" => $subject->getIdentity(),
                        "subject_type" => $subject->getType(),
                        "subject_id" => $subject->getIdentity(),
                        "comment_id" => $comment->getIdentity()
                    );
                    $likeInfo["isLike"] = 0;
                } else {
                    $likeInfo["name"] = "unlike";
                    $likeInfo["label"] = $this->translate("Unlike");
                    $likeInfo["url"] = "unlike";
                    $likeInfo["urlParams"] = array(
                        "action_id" => $subject->getIdentity(),
                        "subject_type" => $subject->getType(),
                        "subject_id" => $subject->getIdentity(),
                        "comment_id" => $comment->getIdentity()
                    );
                    $likeInfo["isLike"] = 1;
                }
                $commentInfo["like_count"] = $comment->likes()->getLikeCount();
                $commentInfo["like"] = $likeInfo;
            } else {
                $commentInfo["like"] = null;
            }
            if (!empty($canComment)) {
                $replyInfo["name"] = "reply";
                $replyInfo["label"] = $this->translate('Reply');
                $replyInfo["url"] = "advancedcomments/comment";
                $replyInfo['urlParams'] = array(
                    "action_id" => $subject->getIdentity(),
                    "subject_type" => $subject->getType(),
                    "subject_id" => $subject->getIdentity(),
                    "comment_id" => $comment->comment_id
                );
                $commentInfo["isReply"] = 1;
                $commentInfo["reply"] = $replyInfo;
            }
            $db->commit();
            $this->respondWithSuccess($commentInfo);
        } catch (Exception $e) {
            $db->rollBack();
        }
    }
    public function addCommentNotificationsAction() {
        $this->validateRequestMethod('POST');
        if (!Zend_Registry::isRegistered('Zend_Translate'))
            Engine_Api::_()->getApi('Core', 'siteapi')->setTranslate();
        Engine_Api::_()->getApi('Core', 'siteapi')->setView();
        $viewer = Engine_Api::_()->user()->getViewer();
        $subject_id = $this->_getParam('subject_id');
        $subject_type = $this->_getParam('subject_type', 'activity_action');
        $subject = Engine_Api::_()->getItem($subject_type, $subject_id);
        $attachment = null;
        $body = '';
        $attachmentData = $this->getRequestParam('attachment_id');
        $attachmentType = $this->getRequestParam('attachment_type');
        $subjectParent = $subject;
        $db = Engine_Api::_()->getDbtable('actions', 'activity')->getAdapter();
        $db->beginTransaction();
        try {
            if (strpos($subject->getType(), "sitepage") !== false) {
                if ($subject->getType() == 'sitepage_page') {
                    $subjectParent = $subject;
                } elseif ($subject->getType() == 'sitepagemusic_playlist') {
                    $subjectParent = $subject->getParentType();
                } elseif ($subject->getType() == 'sitepagenote_photo') {
                    $subjectParent = $subject->getParent()->getParent()->getParent();
                } elseif ($subject->getType() == 'sitepageevent_photo') {
                    $subjectParent = $subject->getEvent()->getParentPage();
                } else {
                    $subjectParent = $subject->getParent();
                }
            } elseif (strpos($subject->getType(), "sitebusiness") !== false) {
                if ($subject->getType() == 'sitebusiness_business') {
                    $subjectParent = $subject;
                } elseif ($subject->getType() == 'sitebusinessnote_photo') {
                    $subjectParent = $subject->getParent()->getParent()->getParent();
                } elseif ($subject->getType() == 'sitebusinessmusic_playlist') {
                    $subjectParent = $subject->getParentType();
                } else {
                    $subjectParent = $subject->getParent();
                }
            } elseif (strpos($subject->getType(), "sitegroup") !== false) {
                if ($subject->getType() == 'sitegroup_group') {
                    $subjectParent = $subject;
                } elseif ($subject->getType() == 'sitegroupmusic_playlist') {
                    $subjectParent = $subject->getParentType();
                } elseif ($subject->getType() == 'sitegroupnote_photo') {
                    $subjectParent = $subject->getParent()->getParent()->getParent();
                } elseif ($subject->getType() == 'sitegroupevent_photo') {
                    $subjectParent = $subject->getEvent()->getParentPage();
                } else {
                    $subjectParent = $subject->getParent();
                }
            }
            $activityApi = Engine_Api::_()->getDbtable('actions', 'activity');
            $notifyApi = Engine_Api::_()->getDbtable('notifications', 'activity');
            $subjectOwner = $subject->getOwner('user');
            $postData = $_REQUEST;
            $comment_id = $this->getRequestParam('comment_id');
            $comment = $subject->comments()->getComment($comment_id);
            if (empty($comment))
                $this->respondWithError('validation_fail');
            $body = $comment->body;
            $listingtypeName = '';
            // Activity
            if (empty($comment->parent_comment_id)) {
                $action = $activityApi->addActivity($viewer, $subject, 'comment_' . $subject->getType(), $body, array(
                    'owner' => $subjectOwner->getGuid(),
                    'body' => $body,
                    'listingtype' => $listingtypeName
                ));
            } else {
                $action = $activityApi->addActivity($viewer, $subject, 'nestedcomment_' . $subject->getType(), $body, array(
                    'owner' => $subjectOwner->getGuid(),
                    'body' => $body,
                    'listingtype' => $listingtypeName
                ));
            }
            //if any attchement
            if (isset($comment->attachment_type) && !empty($comment->attachment_type) && isset($comment->attachment_id) && !empty($comment->attachment_id)) {
                $attachment = Engine_Api::_()->getItem($comment->attachment_type, $comment->attachment_id);
                if ($action && $attachment) {
                    $activityApi->attachActivity($action, $attachment);
                }
            }
            //for tag user
            if (isset($comment->params) && !empty($comment->params)) {
                if (is_array($comment->params) && count($comment->params) > 0) {
                    $tagsArray = $param['tags'];
                } else {
                    $temp = json_decode($comment->params);
                    $tagsArray = $temp->tags;
                }
            }
            $userIds = array();
            $allowedNotification = Engine_Api::_()->getApi('settings', 'core')->getSetting('aaf.notification.onoff.enable', 1);
            if ($allowedNotification) {
                $offNotification = Engine_Api::_()->getDbtable('notificationsettings', 'advancedactivity');
                $userIds = $offNotification->getUserIdsByActionId($action->getIdentity());
            }
            $type_name = Engine_Api::_()->getApi('Core', 'siteapi')->translate("post");
            $notificationAPi = Engine_Api::_()->getDbtable('notifications', 'activity');
            foreach ($tagsArray as $key => $tagStrValue) {
                $tag = Engine_Api::_()->getItemByGuid($key);
                if ($action && $tag && ($tag instanceof User_Model_User) && !$tag->isSelf($viewer) && !in_array($tag->getIdentity(), $userIds)) {
                    $notificationAPi->addNotification($tag, $viewer, $action, 'tagged', array(
                        'object_type_name' => $type_name,
                        'label' => $type_name,
                    ));
                } else if ($tag && ($tag instanceof Sitepage_Model_Page)) {
                    $subject_title = $viewer->getTitle();
                    $page_title = $tag->getTitle();
                    foreach ($tag->getPageAdmins() as $owner) {
                        if ($action && $owner && ($owner instanceof User_Model_User) && !$owner->isSelf($viewer) && !in_array($owner->getIdentity(), $userIds)) {
                            $notificationAPi->addNotification($owner, $viewer, $action, 'sitepage_tagged', array(
                                'subject_title' => $subject_title,
                                'label' => $type_name,
                                'object_type_name' => $type_name,
                                'page_title' => $page_title
                            ));
                        }
                    }
                } else if ($tag && ($tag instanceof Sitebusiness_Model_Business)) {
                    $subject_title = $viewer->getTitle();
                    $business_title = $tag->getTitle();
                    foreach ($tag->getBusinessAdmins() as $owner) {
                        if ($action && $owner && ($owner instanceof User_Model_User) && !$owner->isSelf($viewer) && !in_array($owner->getIdentity(), $userIds)) {
                            $notificationAPi->addNotification($owner, $viewer, $action, 'sitebusiness_tagged', array(
                                'subject_title' => $subject_title,
                                'label' => $type_name,
                                'object_type_name' => $type_name,
                                'business_title' => $business_title
                            ));
                        }
                    }
                } else if ($tag && ($tag instanceof Sitegroup_Model_Group)) {
                    $subject_title = $viewer->getTitle();
                    $store_title = $tag->getTitle();
                    foreach ($tag->getGroupAdmins() as $owner) {
                        if ($action && $owner && ($owner instanceof User_Model_User) && !$owner->isSelf($viewer) && !in_array($owner->getIdentity(), $userIds)) {
                            $notificationAPi->addNotification($owner, $viewer, $action, 'sitegroup_tagged', array(
                                'subject_title' => $subject_title,
                                'label' => $type_name,
                                'object_type_name' => $type_name,
                                'group_title' => $store_title
                            ));
                        }
                    }
                } else if ($tag && ($tag instanceof Sitestore_Model_Store)) {
                    $subject_title = $viewer->getTitle();
                    $store_title = $tag->getTitle();
                    foreach ($tag->getStoreAdmins() as $owner) {
                        if ($action && $owner && ($owner instanceof User_Model_User) && !$owner->isSelf($viewer) && !in_array($owner->getIdentity(), $userIds)) {
                            $notificationAPi->addNotification($owner, $viewer, $action, 'sitestore_tagged', array(
                                'subject_title' => $subject_title,
                                'label' => $type_name,
                                'object_type_name' => $type_name,
                                'store_title' => $store_title
                            ));
                        }
                    }
                } else if ($tag && ($tag instanceof Core_Model_Item_Abstract)) {
                    $subject_title = $viewer->getTitle();
                    $item_type = Zend_Registry::get('Zend_Translate')->translate($tag->getShortType());
                    $item_title = $tag->getTitle();
                    $owner = $tag->getOwner();
                    if ($action && $owner && ($owner instanceof User_Model_User) && !$owner->isSelf($viewer) && !in_array($owner->getIdentity(), $userIds)) {
                        $notificationAPi->addNotification($owner, $viewer, $action, 'aaf_tagged', array(
                            'subject_title' => $subject_title,
                            'label' => $type_name,
                            'object_type_name' => $type_name,
                            'item_title' => $item_title,
                            'item_type' => $item_type
                        ));
                    }
                    if (($tag instanceof Group_Model_Group)) {
                        foreach ($tag->getOfficerList()->getAll() as $offices) {
                            $owner = Engine_Api::_()->getItem('user', $offices->child_id);
                            if ($action && $owner && ($owner instanceof User_Model_User) && !$owner->isSelf($viewer) && !in_array($owner->getIdentity(), $userIds)) {
                                $notificationAPi->addNotification($owner, $viewer, $action, 'aaf_tagged', array(
                                    'subject_title' => $subject_title,
                                    'label' => $type_name,
                                    'object_type_name' => $type_name,
                                    'item_title' => $item_title,
                                    'item_type' => $item_type
                                ));
                            }
                        }
                    }
                }
            }
            if ((strpos($subject->getType(), "sitepage") === false) || (strpos($subject->getType(), "sitegroup") === false) || (strpos($subject->getType(), "sitestore") === false ) || (strpos($subject->getType(), "sitebusiness") === false) || (strpos($subject->getType(), "sitestoreproduct") !== false)) {
                if ($subjectOwner->getType() == 'user' && $subjectOwner->getIdentity() != $viewer->getIdentity() && !in_array($subjectOwner->getIdentity(), $userIds)) {
                    //start check for page admin and page owner
                    if ($baseOnContentOwner) {
                        $notifyApi->addNotification($subjectOwner, $subjectParent, $subject, 'replied', array(
                            'label' => $subject->getShortType()
                        ));
                    } else {
                        $notifyApi->addNotification($subjectOwner, $viewer, $subject, 'replied', array(
                            'label' => $subject->getShortType()
                        ));
                    }
                    //end check for page admin and page owner
                }
            }
            // Add a notification for all users that commented or like except the viewer and poster
            // @todo we should probably limit this
            $commentedUserNotifications = array();
            foreach (Engine_Api::_()->getDbtable('comments', 'nestedcomment')->comments($subject)->getAllCommentsUsers() as $notifyUser) {
                if ($notifyUser->getIdentity() == $viewer->getIdentity() || $notifyUser->getIdentity() == $subjectOwner->getIdentity() || in_array($notifyUser->getIdentity(), $userIds))
                    continue;
                // Don't send a notification if the user both commented and liked this
                $commentedUserNotifications[] = $notifyUser->getIdentity();
                //start check for page admin and page owner
                if ($baseOnContentOwner) {
                    $notifyApi->addNotification($notifyUser, $subjectParent, $subject, 'replied_replied', array(
                        'label' => $subject->getShortType()
                    ));
                } else {
                    $notifyApi->addNotification($notifyUser, $viewer, $subject, 'replied_replied', array(
                        'label' => $subject->getShortType()
                    ));
                }
                //end check for page admin and page owner
            }
            // Add a notification for all users that liked
            // @todo we should probably limit this
            foreach (Engine_Api::_()->getDbtable('likes', 'nestedcomment')->likes($subject)->getAllLikesUsers() as $notifyUser) {
                // Skip viewer and owner
                if ($notifyUser->getIdentity() == $viewer->getIdentity() || $notifyUser->getIdentity() == $subjectOwner->getIdentity() || in_array($notifyUser->getIdentity(), $userIds))
                    continue;
                // Don't send a notification if the user both commented and liked this
                if (in_array($notifyUser->getIdentity(), $commentedUserNotifications))
                    continue;
                //start check for page admin and page owner
                if ($baseOnContentOwner) {
                    $notifyApi->addNotification($notifyUser, $subjectParent, $subject, 'liked_replied', array(
                        'label' => $subject->getShortType()
                    ));
                } else {
                    $notifyApi->addNotification($notifyUser, $viewer, $subject, 'liked_replied', array(
                        'label' => $subject->getShortType()
                    ));
                }
                //end check for page admin and page owner
            }
            //Send notification to Page admins
            if (strpos($subject->getType(), "sitepage") !== false && Engine_Api::_()->getDbtable('modules', 'core')->getModule('sitepage')) {
                $sitepageVersion = Engine_Api::_()->getDbtable('modules', 'core')->getModule('sitepage')->version;
                if ($sitepageVersion >= '4.2.9p3') {
                    Engine_Api::_()->sitepage()->itemCommentLike($subject, 'sitepage_contentreply', $baseOnContentOwner);
                }
            } elseif (strpos($subject->getType(), "sitegroup") !== false && Engine_Api::_()->getDbtable('modules', 'core')->getModule('sitegroup')) {
                Engine_Api::_()->sitegroup()->itemCommentLike($subject, 'sitegroup_contentreply', $baseOnContentOwner);
            } elseif (strpos($subject->getType(), "sitebusiness") !== false && Engine_Api::_()->getDbtable('modules', 'core')->getModule('sitebusiness')) {
                Engine_Api::_()->sitebusiness()->itemCommentLike($subject, 'sitebusiness_contentreply', $baseOnContentOwner);
            } elseif (strpos($subject->getType(), "sitestore") !== false && strpos($subject->getType(), "sitestoreproduct") === false && Engine_Api::_()->getDbtable('modules', 'core')->getModule('sitestore')) {
                Engine_Api::_()->sitestore()->itemCommentLike($subject, 'sitestore_contentreply', $baseOnContentOwner);
            } elseif (strpos($subject->getType(), "siteevent") !== false && Engine_Api::_()->getDbtable('modules', 'core')->getModule('siteevent')) {
                Engine_Api::_()->siteevent()->itemCommentLike($subject, 'siteevent_contentreply', $baseOnContentOwner, 'comment');
            }
            $db->commit();
            $this->successResponseNoContent('no_content');
        } catch (Exception $e) {
            $db->rollBack();
            $this->respondWithValidationError('internal_server_error', $e->getMessage());
        }
    }
    public function updateAction() {
        $this->validateRequestMethod('POST');
        if (!$this->_helper->requireUser()->isValid()) {
            $this->respondWithError('unauthorized');
        }
        $viewer = Engine_Api::_()->user()->getViewer();
        $subject_id = $this->_getParam('subject_id');
        $subject_type = $this->_getParam('subject_type', 'activity_action');
        $subject = Engine_Api::_()->getItem($subject_type, $subject_id);
        $subjectParent = $subject;
        $viewer_id = $viewer->getIdentity();
        $listingtypeName = "";
        //GET USER LEVEL ID
        if (!empty($viewer_id)) {
            $level_id = $viewer->level_id;
        } else {
            $level_id = Engine_Api::_()->getDbtable('levels', 'authorization')->fetchRow(array('type = ?' => "public"))->level_id;
        }
        $autorizationApi = Engine_Api::_()->authorization();
        if (strpos($subject->getType(), "sitepage") !== false) {
            if ($subject->getType() == 'sitepage_page') {
                $subjectParent = $subject;
            } elseif ($subject->getType() == 'sitepagemusic_playlist') {
                $subjectParent = $subject->getParentType();
            } elseif ($subject->getType() == 'sitepagenote_photo') {
                $subjectParent = $subject->getParent()->getParent()->getParent();
            } else {
                $subjectParent = $subject->getParent();
            }
            $pageApi = Engine_Api::_()->sitepage();
            $canComment = $pageApi->isManageAdmin($subjectParent, 'comment');
            if (empty($canComment)) {
                $this->respondWithError('unauthorized');
            }
        } elseif (strpos($subject->getType(), "sitebusiness") !== false) {
            if ($subject->getType() == 'sitebusiness_business') {
                $subjectParent = $subject;
            } elseif ($subject->getType() == 'sitebusinessnote_photo') {
                $subjectParent = $subject->getParent()->getParent()->getParent();
            } elseif ($subject->getType() == 'sitebusinessmusic_playlist') {
                $subjectParent = $subject->getParentType();
            } else {
                $subjectParent = $subject->getParent();
            }
            $businessApi = Engine_Api::_()->sitebusiness();
            $canComment = $businessApi->isManageAdmin($subjectParent, 'comment');
            if (empty($canComment)) {
                $this->respondWithError('unauthorized');
            }
        } elseif ($subject->getType() == 'sitereview_review') {
            $listingtype_id = $subject->getParent()->listingtype_id;
            $canComment = $autorizationApi->getPermission($level_id, 'sitereview_listing', "review_reply_listtype_$listingtype_id");
            if (empty($canComment)) {
                $this->respondWithError('unauthorized');
            }
        } elseif ($subject->getType() == 'sitereview_listing') {
            $listingtype_id = $subject->listingtype_id;
            $listingtypeName = strtolower(Engine_Api::_()->getDbTable('listingtypes', 'sitereview')->getListingTypeColumn($listingtype_id, 'title_singular'));
            $canComment = $subject->authorization()->isAllowed($viewer, 'comment');
            if (!empty($canComment))
                $canComment = $subject->authorization()->isAllowed($viewer, "comment_listtype_$listingtype_id");
            if (empty($canComment)) {
                $this->respondWithError('unauthorized');
            }
        } elseif (strpos($subject->getType(), "sitegroup") !== false) {
            if ($subject->getType() == 'sitegroup_group') {
                $subjectParent = $subject;
            } elseif ($subject->getType() == 'sitegroupmusic_playlist') {
                $subjectParent = $subject->getParentType();
            } elseif ($subject->getType() == 'sitegroupnote_photo') {
                $subjectParent = $subject->getParent()->getParent()->getParent();
            } elseif ($subject->getType() == 'sitegroupevent_photo') {
                $subjectParent = $subject->getEvent()->getParentPage();
            } else {
                $subjectParent = $subject->getParent();
            }
            $groupApi = Engine_Api::_()->sitegroup();
            $canComment = $groupApi->isManageAdmin($subjectParent, 'comment');
            if (empty($canComment)) {
                $this->respondWithError('unauthorized');
            }
        } elseif (strpos($subject->getType(), "sitestore") !== false && strpos($subject->getType(), "sitestoreproduct") === false) {
            if ($subject->getType() == 'sitestore_store') {
                $subjectParent = $subject;
            } elseif ($subject->getType() == 'sitestoremusic_playlist') {
                $subjectParent = $subject->getParentType();
            } elseif ($subject->getType() == 'sitestorenote_photo') {
                $subjectParent = $subject->getParent()->getParent()->getParent();
            } elseif ($subject->getType() == 'sitestoreevent_photo') {
                $subjectParent = $subject->getEvent()->getParentPage();
            } else {
                $subjectParent = $subject->getParent();
            }
            $storeApi = Engine_Api::_()->sitestore();
            $canComment = $storeApi->isManageAdmin($subjectParent, 'comment');
            if (empty($canComment)) {
                $this->respondWithError('unauthorized');
            }
        } elseif (!$this->_helper->requireAuth()->setAuthParams($subject, $viewer, 'comment')->isValid()) {
            $this->respondWithError('unauthorized');
        }
        if ($subject->getType() == 'siteevent_event') {
            $subjectParent = Engine_Api::_()->getItem($subject->getParent()->getType(), $subject->getParent()->getIdentity());
        }
        $data = $this->_getAllParams();
        // Process
        // Filter HTML
        $body = $_POST['body'];
        $db = Engine_Api::_()->getDbtable('comments', 'nestedcomment')->comments($subject)->getCommentTable()->getAdapter();
        $db->beginTransaction();
        try {
            $comment = Engine_Api::_()->getItem('core_comment', $this->_getParam('comment_id'));
            $comment->body = $body;
            $comment->save();
            $activityApi = Engine_Api::_()->getDbtable('actions', 'activity');
            $notifyApi = Engine_Api::_()->getDbtable('notifications', 'activity');
            $subjectOwner = $subject->getOwner('user');
            //TRY ATTACHMENT GETTING STUFF
            $attachment = null;
            $attachmentData = $this->getRequestParam('attachment_id', null);
            $attachmentType = $this->getRequestParam('attachment_type', null);
//            if ($comment->attachment_type) {
//                if (!in_array($comment->attachment_type, array('sitereaction_sticker'))) {
//                    $attachment = Engine_Api::_()->getItem($comment->attachment_type, $comment->attachment_id);
//                    $attachment->delete();
//                }
//                $comment->attachment_type = '';
//                $comment->attachment_id = 0;
//                $comment->save();
//            }
            $attachment = null;
            //Reaction post work start 
            if (isset($attachmentType) && !empty($attachmentType)) {
                if ($attachmentType == 'sticker' && isset($attachmentData))
                    $attachment = Engine_Api::_()->getItemByGuid($attachmentData);
                if ($attachmentType == 'photo' && !empty($_FILES['photo'])) {
                    $table = Engine_Api::_()->getDbtable('albums', 'album');
                    $type = $this->getRequestParam('image_type', 'comment');
                    $album = $this->getSpecialAlbum($viewer, $type);
                    $photoTable = Engine_Api::_()->getDbtable('photos', 'album');
                    $photo = $photoTable->createRow();
                    $photo->owner_type = 'user';
                    $photo->owner_id = $viewer->getIdentity();
                    $photo->save();
// Set the photo
                    $photo = $this->_setPhoto($_FILES['photo'], $photo);
                    $photo->order = $photo->photo_id;
                    $photo->album_id = $album->album_id;
                    $photo->save();
                    if (!$album->photo_id) {
                        $album->photo_id = $photo->getIdentity();
                        $album->save();
                    }
                    $auth = Engine_Api::_()->authorization()->context;
                    $auth->setAllowed($photo, 'everyone', 'view', true);
                    $auth->setAllowed($photo, 'everyone', 'comment', true);
                    $attachment = $photo;
                }
            }
            if ($attachment && isset($comment->attachment_type) && isset($comment->attachment_id)) {
                $comment->attachment_type = $attachment->getType();
                $comment->attachment_id = $attachment->getIdentity();
                $comment->save();
            }
            //REBUILD PRIVACY
            $actionTable = Engine_Api::_()->getDbtable('actions', 'activity');
            foreach ($actionTable->getActionsByObject($subject) as $action) {
                $action->delete();
            }
            // Activity
            if (empty($comment->parent_comment_id)) {
                $action = $activityApi->addActivity($viewer, $subject, 'comment_' . $subject->getType(), $body, array(
                    'owner' => $subjectOwner->getGuid(),
                    'body' => $body,
                    'listingtype' => $listingtypeName
                ));
            } else {
                $action = $activityApi->addActivity($viewer, $subject, 'nestedcomment_' . $subject->getType(), $body, array(
                    'owner' => $subjectOwner->getGuid(),
                    'body' => $body,
                    'listingtype' => $listingtypeName
                ));
            }
            //TRY TO ATTACH IF NECESSARY
            if ($action && $attachment) {
                $activityApi->attachActivity($action, $attachment);
            }
            $composerDatas = $this->getRequest()->getParam('composer', null);
            $userIds = array();
            $allowedNotification = Engine_Api::_()->getApi('settings', 'core')->getSetting('aaf.notification.onoff.enable', 1);
            if ($allowedNotification) {
                $offNotification = Engine_Api::_()->getDbtable('notificationsettings', 'advancedactivity');
                $userIds = $offNotification->getUserIdsByActionId($action->getIdentity());
            }
            $tagsArray = array();
            parse_str($composerDatas['tag'], $tagsArray);
            if (!empty($tagsArray)) {
                if ($action) {
                    $actionParams = (array) $action->params;
                    $action->params = array_merge((array) $action->params, array('tags' => $tagsArray));
                    $action->save();
                }
                $viewer = Engine_Api::_()->_()->user()->getViewer();
                $type_name = Zend_Registry::get('Zend_Translate')->translate('post');
                if (is_array($type_name)) {
                    $type_name = $type_name[0];
                } else {
                    $type_name = 'post';
                }
                $notificationAPi = Engine_Api::_()->getDbtable('notifications', 'activity');
                foreach ($tagsArray as $key => $tagStrValue) {
                    $tag = Engine_Api::_()->getItemByGuid($key);
                    if ($tag && ($tag instanceof User_Model_User) && !$tag->isSelf($viewer) && !in_array($tag->getIdentity(), $userIds)) {
                        $notificationAPi->addNotification($tag, $viewer, $action, 'tagged', array(
                            'object_type_name' => $type_name,
                            'label' => $type_name,
                        ));
                    } else if ($tag && ($tag instanceof Sitepage_Model_Page)) {
                        $subject_title = $viewer->getTitle();
                        $page_title = $tag->getTitle();
                        foreach ($tag->getPageAdmins() as $owner) {
                            if ($action && $owner && ($owner instanceof User_Model_User) && !$owner->isSelf($viewer) && !in_array($owner->getIdentity(), $userIds)) {
                                $notificationAPi->addNotification($owner, $viewer, $action, 'sitepage_tagged', array(
                                    'subject_title' => $subject_title,
                                    'label' => $type_name,
                                    'object_type_name' => $type_name,
                                    'page_title' => $page_title
                                ));
                            }
                        }
                    } else if ($tag && ($tag instanceof Sitebusiness_Model_Business)) {
                        $subject_title = $viewer->getTitle();
                        $business_title = $tag->getTitle();
                        foreach ($tag->getBusinessAdmins() as $owner) {
                            if ($action && $owner && ($owner instanceof User_Model_User) && !$owner->isSelf($viewer) && !in_array($owner->getIdentity(), $userIds)) {
                                $notificationAPi->addNotification($owner, $viewer, $action, 'sitebusiness_tagged', array(
                                    'subject_title' => $subject_title,
                                    'label' => $type_name,
                                    'object_type_name' => $type_name,
                                    'business_title' => $business_title
                                ));
                            }
                        }
                    } else if ($tag && ($tag instanceof Sitegroup_Model_Group)) {
                        $subject_title = $viewer->getTitle();
                        $store_title = $tag->getTitle();
                        foreach ($tag->getGroupAdmins() as $owner) {
                            if ($action && $owner && ($owner instanceof User_Model_User) && !$owner->isSelf($viewer) && !in_array($owner->getIdentity(), $userIds)) {
                                $notificationAPi->addNotification($owner, $viewer, $action, 'sitegroup_tagged', array(
                                    'subject_title' => $subject_title,
                                    'label' => $type_name,
                                    'object_type_name' => $type_name,
                                    'group_title' => $store_title
                                ));
                            }
                        }
                    } else if ($tag && ($tag instanceof Sitestore_Model_Store)) {
                        $subject_title = $viewer->getTitle();
                        $store_title = $tag->getTitle();
                        foreach ($tag->getStoreAdmins() as $owner) {
                            if ($action && $owner && ($owner instanceof User_Model_User) && !$owner->isSelf($viewer) && !in_array($owner->getIdentity(), $userIds)) {
                                $notificationAPi->addNotification($owner, $viewer, $action, 'sitestore_tagged', array(
                                    'subject_title' => $subject_title,
                                    'label' => $type_name,
                                    'object_type_name' => $type_name,
                                    'store_title' => $store_title
                                ));
                            }
                        }
                    } else if ($tag && ($tag instanceof Core_Model_Item_Abstract)) {
                        $subject_title = $viewer->getTitle();
                        $item_type = Zend_Registry::get('Zend_Translate')->translate($tag->getShortType());
                        $item_title = $tag->getTitle();
                        $owner = $tag->getOwner();
                        if ($action && $owner && ($owner instanceof User_Model_User) && !$owner->isSelf($viewer) && !in_array($owner->getIdentity(), $userIds)) {
                            $notificationAPi->addNotification($owner, $viewer, $action, 'aaf_tagged', array(
                                'subject_title' => $subject_title,
                                'label' => $type_name,
                                'object_type_name' => $type_name,
                                'item_title' => $item_title,
                                'item_type' => $item_type
                            ));
                        }
                        if (($tag instanceof Group_Model_Group)) {
                            foreach ($tag->getOfficerList()->getAll() as $offices) {
                                $owner = Engine_Api::_()->getItem('user', $offices->child_id);
                                if ($action && $owner && ($owner instanceof User_Model_User) && !$owner->isSelf($viewer) && !in_array($owner->getIdentity(), $userIds)) {
                                    $notificationAPi->addNotification($owner, $viewer, $action, 'aaf_tagged', array(
                                        'subject_title' => $subject_title,
                                        'label' => $type_name,
                                        'object_type_name' => $type_name,
                                        'item_title' => $item_title,
                                        'item_type' => $item_type
                                    ));
                                }
                            }
                        }
                    }
                }
                $data = array_merge((array) $action->params, array('tags' => $tagsArray));
                $comment->params = Zend_Json::encode($data);
                $comment->save();
            }
            if ($attachment) {
                if (isset($comment->attachment_type))
                    $comment->attachment_type = ( $attachment ? $attachment->getType() : '' );
                if (isset($comment->attachment_id))
                    $comment->attachment_id = ( $attachment ? $attachment->getIdentity() : 0 );
                $comment->save();
            }
            $db->commit();
            $canComment = Engine_Api::_()->authorization()->isAllowed($subject, null, 'comment');
            $canDelete = Engine_Api::_()->authorization()->isAllowed($subject, null, 'edit');
            Engine_Api::_()->getDbtable('statistics', 'core')->increment('core.comments');
            $commentInfo = array();
            $poster = Engine_Api::_()->getItem($comment->poster_type, $comment->poster_id);
            $commentInfo["subject_id"] = $subject_id;
            $commentInfo["comment_id"] = $comment->comment_id;
            // Add images
            $getContentImages = Engine_Api::_()->getApi('Core', 'siteapi')->getContentImage($poster);
            $commentInfo = array_merge($commentInfo, $getContentImages);
            //to provide the same image names as in likes-comment response
            $getContentImages = array();
            $getContentImages = Engine_Api::_()->getApi('Core', 'siteapi')->getContentImage($poster, false, 'author');
            $commentInfo = array_merge($commentInfo, $getContentImages);
            $commentInfo["author_title"] = $poster->getTitle();
            $commentInfo["user_id"] = $poster->getIdentity();
            $commentInfo["comment_body"] = $comment->body;
            $commentInfo["comment_date"] = $comment->creation_date;
            $commentInfo["params"] = isset($comment->params) ? $comment->params : "";
            if (Engine_Api::_()->getApi('Siteapi_Feed', 'advancedactivity')->isSitestickerPluginLive()) {
                if (isset($comment->attachment_type) && !empty($comment->attachment_type) && isset($comment->attachment_id) && !empty($comment->attachment_id)) {
                    $attachment = Engine_Api::_()->getItem($comment->attachment_type, $comment->attachment_id);
                    $getContentImages = Engine_Api::_()->getApi('Core', 'siteapi')->getContentImage($attachment, false);
                    $commentInfo['attachment'] = $getContentImages;
                    $commentInfo['attachment_type'] = $comment->attachment_type;
                    $commentInfo['attachment_id'] = $comment->attachment_id;
                }
            }
            if (!empty($canDelete) || $poster->isSelf($viewer)) {
                $commentInfo["delete"] = array(
                    "name" => "delete",
                    "label" => $this->translate("Delete"),
                    "url" => "comment-delete",
                    'urlParams' => array(
                        "action_id" => $action->getIdentity(),
                        "subject_type" => $action->getObject()->getType(),
                        "subject_id" => $action->getObject()->getIdentity(),
                        "comment_id" => $row->comment_id
                    )
                );
                $commentInfo["edit"] = array(
                    "name" => "edit",
                    "label" => $this->translate('Edit'),
                    "url" => "advancedcomments/reply-edit",
                    'urlParams' => array(
                        "action_id" => $action->getIdentity(),
                        "subject_type" => $action->getObject()->getType(),
                        "subject_id" => $action->getObject()->getIdentity(),
                        "comment_id" => $row->comment_id
                    )
                );
            } else {
                $commentInfo["delete"] = null;
                $commentInfo["edit"] = null;
            }
            if (!empty($canComment)) {
                $isLiked = $comment->likes()->isLike($viewer);
                if (empty($isLiked)) {
                    $likeInfo["name"] = "like";
                    $likeInfo["label"] = $this->translate("Like");
                    $likeInfo["url"] = "like";
                    $likeInfo["urlParams"] = array(
                        "action_id" => $subject->getIdentity(),
                        "subject_type" => $subject->getType(),
                        "subject_id" => $subject->getIdentity(),
                        "comment_id" => $comment->getIdentity()
                    );
                    $likeInfo["isLike"] = 0;
                } else {
                    $likeInfo["name"] = "unlike";
                    $likeInfo["label"] = $this->translate("Unlike");
                    $likeInfo["url"] = "unlike";
                    $likeInfo["urlParams"] = array(
                        "action_id" => $subject->getIdentity(),
                        "subject_type" => $subject->getType(),
                        "subject_id" => $subject->getIdentity(),
                        "comment_id" => $comment->getIdentity()
                    );
                    $likeInfo["isLike"] = 1;
                }
                $commentInfo["like_count"] = $comment->likes()->getLikeCount();
                $commentInfo["like"] = $likeInfo;
            } else {
                $commentInfo["like"] = null;
            }
            $this->respondWithSuccess($commentInfo);
        } catch (Exception $e) {
            $db->rollBack();
           
        }
    }
    private function _getReplyCommentInfo($action, $comment_id, $param = array()) {
        $viewer = Engine_Api::_()->user()->getViewer();
        if (empty($action) || empty($comment_id))
            return array();
        $page = $this->getRequestParam('page', null);
        $limit = $this->getRequestParam('limit', null);
        $commentSelect = $action->comments()->getCommentSelect();
        $commentSelect->where("parent_comment_id = ?", $comment_id);
        $commentSelect->order('comment_id DESC');
        $param = array();
        $param['page'] = $page;
        $param['limit'] = $limit;
        $comments = Zend_Paginator::factory($commentSelect);
        if (!empty($param['page']) && !empty($param['limit'])) {
            $comments->setCurrentPageNumber($param['page']);
            $comments->setItemCountPerPage($param['limit']);
            $comments->setCurrentPageNumber($page);
            $comments->setItemCountPerPage($limit);
        } else {
            $comments->setCurrentPageNumber(1);
            $comments->setItemCountPerPage(4);
        }
        $getTotalCommentCount = $comments->getTotalItemCount();
        $canComment = $action->authorization()->isAllowed($viewer, 'comment');
        $canDelete = $action->authorization()->isAllowed($viewer, 'edit');
        if (count($comments) <= 0)
            return array();
        $action_id = $action->getIdentity();
        $comments = $comments->getIterator();
        if ($page) {
            $i = 0;
            $l = count($comments) - 1;
            $d = 1;
            $e = $l + 1;
        } else {
            $i = count($comments) - 1;
            $l = count($comments);
            $d = -1;
            $e = -1;
        }
        for (; $i != $e; $i += $d) {
            $comment = $comments[$i];
            $poster = Engine_Api::_()->getItem($comment->poster_type, $comment->poster_id);
            $commentInfo = array();
            $commentInfo["subject_id"] = $action->getIdentity();
            $commentInfo["comment_id"] = $comment->comment_id;
            // Add images
            $getContentImages = Engine_Api::_()->getApi('Core', 'siteapi')->getContentImage($poster, false, 'author');
            $commentInfo = array_merge($commentInfo, $getContentImages);
            $commentInfo["author_title"] = $poster->getTitle();
            $commentInfo["user_id"] = $poster->getIdentity();
            $commentInfo["comment_body"] = $comment->body;
            $commentInfo["comment_date"] = $comment->creation_date;
            $commentInfo["params"] = isset($comment->params) ? $comment->params : "";
            if (Engine_Api::_()->getApi('Siteapi_Feed', 'advancedactivity')->isSitestickerPluginLive()) {
                if (isset($comment->attachment_type) && !empty($comment->attachment_type) && isset($comment->attachment_id) && !empty($comment->attachment_id) && ($comment->attachment_type == 'sitereaction_sticker' || $comment->attachment_type == 'album_photo')) {
                                                                    $attachment = Engine_Api::_()->getItem($comment->attachment_type, $comment->attachment_id);
                        $params = Engine_Api::_()->getApi('Siteapi_Feed', 'advancedactivity')->getPhotoUrl($attachment, "thumb.profile");
                        $getHost = $getParentHost = Engine_Api::_()->getApi('Core', 'siteapi')->getHost();
                        $baseParentUrl = Zend_Controller_Front::getInstance()->getBaseUrl();
                        $baseParentUrl = @trim($baseParentUrl, "/");
                        $staticBaseUrl = Engine_Api::_()->getApi('settings', 'core')->getSetting('core.static.baseurl', null);
                        // Check IF default service "Local Storage" or not.
                        $getDefaultStorageId = Engine_Api::_()->getDbtable('services', 'storage')->getDefaultServiceIdentity();
                        $getDefaultStorageType = Engine_Api::_()->getDbtable('services', 'storage')->getService($getDefaultStorageId)->getType();
                        $host = '';
                        if ($getDefaultStorageType == 'local')
                            $host = !empty($staticBaseUrl) ? $staticBaseUrl : $getParentHost;
                        $imageUrl = $params['url'];
                        $imageUrl = (!strstr($imageUrl, "application/modules")) ? $host . $imageUrl : $imageUrl;
                        if (!strstr($imageUrl, 'http'))
                            $imageUrl = $getHost . DIRECTORY_SEPARATOR . $baseParentUrl . $imageUrl;
                        ;
                        try {
                            if (!empty($params)) {
                                $getContentImages = array(
                                    "image_profile" => $imageUrl,
                                    "size" => $params['params']
                                );
                            }
                        } catch (Exception $ex) {
                            
                        }
                        $commentInfo['attachment'] = $getContentImages;
                        $commentInfo['attachment_type'] = $comment->attachment_type;
                        $commentInfo['attachment_id'] = $comment->attachment_id;
                }
            }
            
            $commentInfo['gutterMenu'] = $this->_gutterMenus($action,$canDelete,$poster,$comment);
            if (!empty($canComment)) {
                $isLiked = $comment->likes()->isLike($viewer);
                if (empty($isLiked)) {
                    $likeInfo["name"] = "like";
                    $likeInfo["label"] = $this->translate('Like');
                    $likeInfo["url"] = "like";
                    $likeInfo['urlParams'] = array(
                        "action_id" => $action->getIdentity(),
                        "subject_type" => $action->getType(),
                        "subject_id" => $action->getIdentity(),
                        "comment_id" => $comment->comment_id
                    );
                    $likeInfo["isLike"] = 0;
                } else {
                    $likeInfo["name"] = "unlike";
                    $likeInfo["label"] = $this->translate('Unlike');
                    $likeInfo["url"] = "unlike";
                    $likeInfo['urlParams'] = array(
                        "action_id" => $subject_id,
                        "subject_type" => $action->getType(),
                        "subject_id" => $action->getIdentity(),
                        "comment_id" => $comment->comment_id
                    );
                    $likeInfo["isLike"] = 1;
                }
                $commentInfo["like_count"] = $comment->likes()->getLikeCount();
                $commentInfo["like"] = $likeInfo;
            } else {
                $commentInfo["like"] = null;
            }
            if (!empty($canComment)) {
                $replyInfo["name"] = "reply";
                $replyInfo["label"] = $this->translate('Reply');
                $replyInfo["url"] = "advancedcomments/comment";
                $replyInfo['urlParams'] = array(
                    "action_id" => $subject_id,
                    "subject_type" => $action->getType(),
                    "subject_id" => $action->getIdentity(),
                    "comment_id" => $comment->comment_id
                );
                $commentInfo["isReply"] = 1;
                $commentInfo["reply"] = $replyInfo;
            } else {
                $commentInfo["reply"] = null;
            }
            $lastComment = $this->_getLastComment($action, $comment);
            $commentInfo['reply_on_comment'] = $lastComment['reply_on_comment'];
            $commentInfo['reply_count'] = $lastComment['totalReplyCount'];
            $allComments[] = $commentInfo;
        }
        return array(
            "all_reply" => $allComments,
            "reply_count" => $getTotalCommentCount
        );
        //return $allComments;
    }
    
    public function likesCommentsAction() {
// Validate request methods
        $this->validateRequestMethod();
        Engine_Api::_()->getApi('Core', 'siteapi')->setView();
        $subject_id = $this->_getParam('subject_id');
        $subject_type = $this->_getParam('subject_type', 'activity_action');
        $action = Engine_Api::_()->getItem($subject_type, $subject_id);
        $comment_id = $this->getRequestParam('comment_id', 0);
        $page = $this->getRequestParam('page', null);
        $limit = $this->getRequestParam('limit', null);
        $viewer = Engine_Api::_()->user()->getViewer();
        $bodyParams = $likeUsersArray = $allComments = array();
        $getAllLikesUsers = $action->likes()->getAllLikesUsers();
        $likes = $action->likes()->getLikePaginator();
// Likes
        $isLike = $action->likes()->isLike($viewer);
        $viewAllLikes = $this->getRequestParam('viewAllLikes', $this->getRequestParam('view_all_likes', 0));
        if (!empty($viewAllLikes)) {
            foreach ($getAllLikesUsers as $user) {
                $tempUserArray = Engine_Api::_()->getApi('Core', 'siteapi')->validateUserArray($user);
                // Add images
                $getContentImages = Engine_Api::_()->getApi('Core', 'siteapi')->getContentImage($user);
                $tempUserArray = array_merge($tempUserArray, $getContentImages);
                $likeUsersArray[] = $tempUserArray;
            }
            $bodyParams['viewAllLikesBy'] = $likeUsersArray;
        }
        $canComment = $action->authorization()->isAllowed($viewer, 'comment');
        $canDelete = $action->authorization()->isAllowed($viewer, 'edit');
// If has a page, display oldest to newest
        if (null !== $page) {
            $commentSelect = $action->comments()->getCommentSelect();
            $commentSelect->order('comment_id ' . $this->getRequestParam('order', 'DESC'));
            if (!empty($comment_id)) {
                $commentSelect->where("comment_id = ?", $comment_id);
            } else {
                $commentSelect->where("parent_comment_id = ?", 0);
            }
            $comments = Zend_Paginator::factory($commentSelect);
            $comments->setCurrentPageNumber($page);
            $comments->setItemCountPerPage($limit);
        } else {
// If not has a page, show the
            $commentSelect = $action->comments()->getCommentSelect();
            $commentSelect->order('comment_id ' . $this->getRequestParam('order', 'DESC'));
            if (!empty($comment_id)) {
                $commentSelect->where("comment_id = ?", $comment_id);
            } else {
                $commentSelect->where("parent_comment_id = ?", 0);
            }
            $comments = Zend_Paginator::factory($commentSelect);
            $comments->setCurrentPageNumber(1);
            $comments->setItemCountPerPage(4);
        }
        
        // Hide if can't post and no comments
        if (!$canComment && !$canDelete && count($comments) <= 0 && count($likes) <= 0)
            $this->respondWithError('unauthorized');
        $getTotalCommentCount = $comments->getTotalItemCount();
        $viewAllComments = $this->getRequestParam('viewAllComments', $this->getRequestParam('view_all_comments', 0));
        if (!empty($viewAllComments)) {
// Iterate over the comments backwards (or forwards!)
            $comments = $comments->getIterator();
            if ($page) {
                $i = 0;
                $l = count($comments) - 1;
                $d = 1;
                $e = $l + 1;
            } else {
                $i = count($comments) - 1;
                $l = count($comments);
                $d = -1;
                $e = -1;
            }
            for (; $i != $e; $i += $d) {
                $comment = $comments[$i];
                $poster = Engine_Api::_()->getItem($comment->poster_type, $comment->poster_id);
                $commentInfo = array();
                $commentInfo["subject_id"] = $subject_id;
                $commentInfo["comment_id"] = $comment->comment_id;
                // Add images
                $getContentImages = Engine_Api::_()->getApi('Core', 'siteapi')->getContentImage($poster, false, 'author');
                $commentInfo = array_merge($commentInfo, $getContentImages);
                $commentInfo["author_title"] = $poster->getTitle();
                $commentInfo["user_id"] = $poster->getIdentity();
                $commentInfo["comment_body"] = $comment->body;
                $commentInfo["comment_date"] = $comment->creation_date;
                $commentInfo["params"] = isset($comment->params) ? $comment->params : "";
                if (Engine_Api::_()->getApi('Siteapi_Feed', 'advancedactivity')->isSitestickerPluginLive()) {
                    if (isset($comment->attachment_type) && !empty($comment->attachment_type) && isset($comment->attachment_id) && !empty($comment->attachment_id) && ($comment->attachment_type == 'sitereaction_sticker' || $comment->attachment_type == 'album_photo')) {
                        $attachment = Engine_Api::_()->getItem($comment->attachment_type, $comment->attachment_id);
                        $params = Engine_Api::_()->getApi('Siteapi_Feed', 'advancedactivity')->getPhotoUrl($attachment, "thumb.profile");
                        $getHost = Engine_Api::_()->getApi('Core', 'siteapi')->getHost();
                        $baseParentUrl = Zend_Controller_Front::getInstance()->getBaseUrl();
                        $baseParentUrl = @trim($baseParentUrl, "/");
                        $imageUrl = $params['url'];
                        if (!strstr($imageUrl, 'http'))
                            $imageUrl = $getHost . DIRECTORY_SEPARATOR . $baseParentUrl . $imageUrl;
                        ;
                        try {
                            if (!empty($params)) {
                                $getContentImages = array(
                                    "image_profile" => $imageUrl,
                                    "size" => $params['params']
                                );
                            }
                        } catch (Exception $ex) {
                            
                        }
                        $commentInfo['attachment'] = $getContentImages;
                        $commentInfo['attachment_type'] = $comment->attachment_type;
                        $commentInfo['attachment_id'] = $comment->attachment_id;
                    }
                }
                $commentInfo['gutterMenu'] = $this->_gutterMenus($action,$canDelete,$poster,$comment);
                
            if (!empty($canDelete) || $poster->isSelf($viewer)) {
                $commentInfo["delete"] = array(
                    "name" => "delete",
                    "label" => $this->translate("Delete"),
                    "url" => "comment-delete",
                    'urlParams' => array(
                        "action_id" => $action->getIdentity(),
                        "subject_type" => $action->getType(),
                        "subject_id" => $action->getIdentity(),
                        "comment_id" => $comment->comment_id
                    )
                );
            } else {
                $commentInfo["delete"] = null;
            }
            
                if (!empty($canComment)) {
                    $isLiked = $comment->likes()->isLike($viewer);
                    if (empty($isLiked)) {
                        $likeInfo["name"] = "like";
                        $likeInfo["label"] = $this->translate('Like');
                        $likeInfo["url"] = "like";
                        $likeInfo['urlParams'] = array(
                            "action_id" => $subject_id,
                            "subject_type" => $action->getType(),
                            "subject_id" => $action->getIdentity(),
                            "comment_id" => $comment->getIdentity()
                        );
                        $likeInfo["isLike"] = 0;
                    } else {
                        $likeInfo["name"] = "unlike";
                        $likeInfo["label"] = $this->translate('Unlike');
                        $likeInfo["url"] = "unlike";
                        $likeInfo['urlParams'] = array(
                            "action_id" => $subject_id,
                            "subject_type" => $action->getType(),
                            "subject_id" => $action->getIdentity(),
                            "comment_id" => $comment->getIdentity()
                        );
                        $likeInfo["isLike"] = 1;
                    }
                    $commentInfo["like_count"] = $comment->likes()->getLikeCount();
                    $commentInfo["like"] = $likeInfo;
                } else {
                    $commentInfo["like"] = null;
                }
                if (!empty($canComment)) {
                    $replyInfo["name"] = "reply";
                    $replyInfo["label"] = $this->translate('Reply');
                    $replyInfo["url"] = "advancedcomments/comment";
                    $replyInfo['urlParams'] = array(
                        "action_id" => $subject_id,
                        "subject_type" => $action->getType(),
                        "subject_id" => $action->getIdentity(),
                        "comment_id" => $comment->comment_id
                    );
                    $commentInfo["isReply"] = 1;
                    $commentInfo["reply"] = $replyInfo;
                }
                if ($comment_id) {
                    $reply_on_comment = $this->_getReplyCommentInfo($action, $comment->comment_id, array());
                    if (count($reply_on_comment)) {
                        $commentInfo['reply_on_comment'] = $reply_on_comment['all_reply'];
                        $commentInfo['reply_count'] = $reply_on_comment['reply_count'];
                    }
                } else {
                    $lastComment = $this->_getLastComment($action, $comment);
                    $commentInfo['reply_on_comment'] = $lastComment['reply_on_comment'];
                    $commentInfo['reply_count'] = $lastComment['totalReplyCount'];
                }
                $allComments[] = $commentInfo;
            }
            $bodyParams['viewAllComments'] = $allComments;
        }
// FOLLOWING ARE THE GENRAL INFORMATION OF THE PLUGIN, WHICH WILL RETURN IN EVERY CALLING.
        $bodyParams['isLike'] = !empty($isLike) ? 1 : 0;
        $bodyParams['canComment'] = $canComment;
        $bodyParams['canDelete'] = $canDelete;
        $bodyParams['getTotalItemCount'] = $getTotalCommentCount;
        $bodyParams['getTotalComments'] = $this->_totalCommentCount($action);
        $bodyParams['getTotalLikes'] = $likes->getTotalItemCount();
        $this->respondWithSuccess($bodyParams);
    }
    public function commentEditAction() {
        // Make sure user exists
        $this->validateRequestMethod('POST');
        if (!$this->_helper->requireUser()->isValid())
            $this->respondWithError('unauthorized');
        // Make form
        $isShare = $this->_getParam('isShare');
        $settings = Engine_Api::_()->getApi('settings', 'core');
        if (!empty($settings->aaf_composer_value) && ($settings->aaf_composer_value != ($settings->aaf_list_view_value + $settings->aaf_publish_str_value))) {
            $this->respondWithError('unauthorized', "Invalid data");
        }
        // Start transaction
        $db = Engine_Api::_()->getDbtable('actions', 'advancedactivity')->getAdapter();
        $db->beginTransaction();
        try {
            $viewer = Engine_Api::_()->user()->getViewer();
            $action_id = $this->view->action_id = $this->_getParam('action_id', null);
            $action = Engine_Api::_()->getDbtable('actions', 'advancedactivity')->getActionById($action_id);
            $actionOwner = Engine_Api::_()->getItemByGuid($action->subject_type . "_" . $action->subject_id);
            $body = $this->_getParam('body', '');
            // Check authorization
            if (!Engine_Api::_()->authorization()->isAllowed($action->getCommentObject(), null, 'comment'))
                $this->respondWithError('unauthorized', 'This user is not allowed to comment on this item.');
            // Add the comment
            $subject = $viewer;
            if (Engine_Api::_()->advancedactivity()->isBaseOnContentOwner($viewer, $action->getObject()))
                $subject = $action->getObject();
            if ($subject->getType() == 'siteevent_event') {
                $subject = $subject->getParent();
            }
            $row = $action->comments()->getComment($this->_getParam('comment_id', null));
            $row->body = $body;
            $row->save();
            $attachment = null;
            if (isset($_FILES['photo']) && !empty($_FILES['photo'])) {
                $photoValues = $this->composeUpload();
                $attachmentPhotoValue = $photoValues['photo_id'];
                $attachmentType = $photoValues['type'];
            }
            if ($attachmentPhotoValue && $attachmentType) {
                $attachment = Engine_Api::_()->getItem('album_photo', $attachmentPhotoValue);
                if (isset($row->attachment_type))
                    $row->attachment_type = ( $attachment ? $attachment->getType() : '' );
                if (isset($row->attachment_id))
                    $row->attachment_id = ( $attachment ? $attachment->getIdentity() : 0 );
                $row->save();
            }
//            } elseif (!$attachmentPhotoValue && !$attachmentType) {
//                if (isset($row->attachment_type))
//                    $row->attachment_type = '';
//                if (isset($row->attachment_id))
//                    $row->attachment_id = '';
//                $row->save();
//            }
            $attachmentData = $this->getRequestParam('attachment_id');
            $attachmentType = $this->getRequestParam('attachment_type');
            $composerDatas = $this->getRequestParam('composer');
            if (!empty($composerDatas)) {
                $composerDatas = Zend_Json::decode($composerDatas);
            } else {
                $composerDatas = array();
            }
            if ($attachmentData && $attachmentType === 'sticker') {
                $attachment = Engine_Api::_()->getItemByGuid($attachmentData);
                if ($attachment && isset($row->attachment_type) && isset($row->attachment_id)) {
                    $row->attachment_type = $attachment->getType();
                    $row->attachment_id = $attachment->getIdentity();
                    $row->save();
                }
            }
            $db->commit();
        } catch (Exception $e) {
            $db->rollBack();
        }
        $tagsArray = array();
        parse_str($composerDatas['tag'], $tagsArray);
        if (!empty($tagsArray)) {
            $type_name = $this->translate('post');
            if (is_array($type_name)) {
                $type_name = $type_name[0];
            } else {
                $type_name = 'post';
            }
            $notificationAPi = Engine_Api::_()->getDbtable('notifications', 'activity');
            foreach ($tagsArray as $key => $tagStrValue) {
                $tag = Engine_Api::_()->getItemByGuid($key);
                if (in_array($tag->getIdentity(), $commentedUserNotifications))
                    continue;
                if ($action && $tag && ($tag instanceof User_Model_User) && !$tag->isSelf($viewer) && !in_array($tag->getIdentity(), $userIds)) {
                    $notificationAPi->addNotification($tag, $viewer, $action, 'tagged', array(
                        'object_type_name' => $type_name,
                        'label' => $type_name,
                    ));
                } else if ($tag && ($tag instanceof Sitepage_Model_Page)) {
                    $subject_title = $viewer->getTitle();
                    $page_title = $tag->getTitle();
                    foreach ($tag->getPageAdmins() as $owner) {
                        if ($action && $owner && ($owner instanceof User_Model_User) && !$owner->isSelf($viewer) && !in_array($owner->getIdentity(), $userIds)) {
                            $notificationAPi->addNotification($owner, $viewer, $action, 'sitepage_tagged', array(
                                'subject_title' => $subject_title,
                                'label' => $type_name,
                                'object_type_name' => $type_name,
                                'page_title' => $page_title
                            ));
                        }
                    }
                } else if ($tag && ($tag instanceof Sitebusiness_Model_Business)) {
                    $subject_title = $viewer->getTitle();
                    $business_title = $tag->getTitle();
                    foreach ($tag->getBusinessAdmins() as $owner) {
                        if ($action && $owner && ($owner instanceof User_Model_User) && !$owner->isSelf($viewer) && !in_array($owner->getIdentity(), $userIds)) {
                            $notificationAPi->addNotification($owner, $viewer, $action, 'sitebusiness_tagged', array(
                                'subject_title' => $subject_title,
                                'label' => $type_name,
                                'object_type_name' => $type_name,
                                'business_title' => $business_title
                            ));
                        }
                    }
                } else if ($tag && ($tag instanceof Sitegroup_Model_Group)) {
                    $subject_title = $viewer->getTitle();
                    $store_title = $tag->getTitle();
                    foreach ($tag->getGroupAdmins() as $owner) {
                        if ($action && $owner && ($owner instanceof User_Model_User) && !$owner->isSelf($viewer) && !in_array($owner->getIdentity(), $userIds)) {
                            $notificationAPi->addNotification($owner, $viewer, $action, 'sitegroup_tagged', array(
                                'subject_title' => $subject_title,
                                'label' => $type_name,
                                'object_type_name' => $type_name,
                                'group_title' => $store_title
                            ));
                        }
                    }
                } else if ($tag && ($tag instanceof Sitestore_Model_Store)) {
                    $subject_title = $viewer->getTitle();
                    $store_title = $tag->getTitle();
                    foreach ($tag->getStoreAdmins() as $owner) {
                        if ($action && $owner && ($owner instanceof User_Model_User) && !$owner->isSelf($viewer) && !in_array($owner->getIdentity(), $userIds)) {
                            $notificationAPi->addNotification($owner, $viewer, $action, 'sitestore_tagged', array(
                                'subject_title' => $subject_title,
                                'label' => $type_name,
                                'object_type_name' => $type_name,
                                'store_title' => $store_title
                            ));
                        }
                    }
                } else if ($tag && ($tag instanceof Core_Model_Item_Abstract)) {
                    $subject_title = $viewer->getTitle();
                    $item_type = Zend_Registry::get('Zend_Translate')->translate($tag->getShortType());
                    $item_title = $tag->getTitle();
                    $owner = $tag->getOwner();
                    if ($action && $owner && ($owner instanceof User_Model_User) && !$owner->isSelf($viewer) && !in_array($owner->getIdentity(), $userIds)) {
                        $notificationAPi->addNotification($owner, $viewer, $action, 'aaf_tagged', array(
                            'subject_title' => $subject_title,
                            'label' => $type_name,
                            'object_type_name' => $type_name,
                            'item_title' => $item_title,
                            'item_type' => $item_type
                        ));
                    }
                    if (($tag instanceof Group_Model_Group)) {
                        foreach ($tag->getOfficerList()->getAll() as $offices) {
                            $owner = Engine_Api::_()->getItem('user', $offices->child_id);
                            if ($action && $owner && ($owner instanceof User_Model_User) && !$owner->isSelf($viewer) && !in_array($owner->getIdentity(), $userIds)) {
                                $notificationAPi->addNotification($owner, $viewer, $action, 'aaf_tagged', array(
                                    'subject_title' => $subject_title,
                                    'label' => $type_name,
                                    'object_type_name' => $type_name,
                                    'item_title' => $item_title,
                                    'item_type' => $item_type
                                ));
                            }
                        }
                    }
                }
            }
            if ($action) {
                $data = array_merge((array) $action->params, array('tags' => $tagsArray));
                $row->params = Zend_Json::encode($data);
            }
            $row->save();
        }
        try {
            $canComment = Engine_Api::_()->authorization()->isAllowed($action->getObject(), null, 'comment');
            $canDelete = Engine_Api::_()->authorization()->isAllowed($action->getObject(), null, 'edit');
            $commentInfo = array();
            $poster = Engine_Api::_()->getItem($row->poster_type, $row->poster_id);
            $commentInfo["action_id"] = $action->getIdentity();
            $commentInfo["comment_id"] = $row->comment_id;
            // Add images
            $getContentImages = Engine_Api::_()->getApi('Core', 'siteapi')->getContentImage($poster);
            $commentInfo = array_merge($commentInfo, $getContentImages);
            //to provide the same image names as in likes-comment response
            $getContentImages = array();
            $getContentImages = Engine_Api::_()->getApi('Core', 'siteapi')->getContentImage($poster, false, 'author');
            $commentInfo = array_merge($commentInfo, $getContentImages);
            $commentInfo["author_title"] = $poster->getTitle();
            $commentInfo["user_id"] = $poster->getIdentity();
            $commentInfo["comment_body"] = $row->body;
            if (isset($row->params) && !empty($row->params))
                $commentInfo["userTag"] = Engine_Api::_()->getApi('Siteapi_Feed', 'advancedactivity')->tagUserArray($row->params);
            else {
                $commentInfo["userTag"] = '';
            }
            $commentInfo["params"] = isset($row->params) ? $row->params : "";
            $commentInfo["comment_date"] = $row->creation_date;
            if (Engine_Api::_()->getApi('Siteapi_Feed', 'advancedactivity')->isSitestickerPluginLive()) {
                if (isset($row->attachment_type) && !empty($row->attachment_type) && isset($comment->attachment_id) && !empty($row->attachment_id)) {
                    $attachment = Engine_Api::_()->getItem($row->attachment_type, $row->attachment_id);
                    $getContentImages = Engine_Api::_()->getApi('Core', 'siteapi')->getContentImage($attachment, false);
                    $commentInfo['attachment'] = $getContentImages;
                    $commentInfo['attachment_type'] = $row->attachment_type;
                    $commentInfo['attachment_id'] = $row->attachment_id;
                }
            }
            $commentInfo['gutterMenu'] = $this->_gutterMenus($action,$canDelete,$poster,$row);
            if (!empty($canComment)) {
                $isLiked = $row->likes()->isLike($viewer);
                if (empty($isLiked)) {
                    $likeInfo["name"] = "like";
                    $likeInfo["label"] = $this->translate("Like");
                    $likeInfo["url"] = "like";
                    $likeInfo["urlParams"] = array(
                        "action_id" => $action->getIdentity(),
                        "subject_type" => $action->getType(),
                        "subject_id" => $action->getIdentity(),
                        "comment_id" => $row->comment_id
                    );
                    $likeInfo["isLike"] = 0;
                } else {
                    $likeInfo["name"] = "unlike";
                    $likeInfo["label"] = $this->translate("Unlike");
                    $likeInfo["url"] = "unlike";
                    $likeInfo["urlParams"] = array(
                        "action_id" => $action->getIdentity(),
                        "subject_type" => $action->getType(),
                        "subject_id" => $action->getIdentity(),
                        "comment_id" => $row->comment_id
                    );
                    $likeInfo["isLike"] = 1;
                }
                $commentInfo["like_count"] = $row->likes()->getLikeCount();
                $commentInfo["like"] = $likeInfo;
                $replyInfo["name"] = "reply";
                $replyInfo["label"] = $this->translate("Reply");
                $replyInfo["url"] = "advancedcomments/reply";
                $replyInfo["urlParams"] = array(
                    "action_id" => $action->getIdentity(),
                    "subject_type" => $action->getType(),
                    "subject_id" => $action->getIdentity(),
                    "comment_id" => $row->comment_id
                );
                $replyInfo["isReply"] = 1;
                $commentInfo["reply"] = $replyInfo;
            } else {
                $commentInfo["like"] = null;
            }
            $this->respondWithSuccess($commentInfo);
        } catch (Exception $ex) {
            $this->respondWithValidationError('internal_server_error', $ex->getMessage());
        }
    }
    public function composeUpload() {
        if (empty($_FILES['photo'])) {
            return;
        }
        // Get album
        $viewer = Engine_Api::_()->user()->getViewer();
        $table = Engine_Api::_()->getDbtable('albums', 'album');
        $db = $table->getAdapter();
        $db->beginTransaction();
        try {
            $type = $this->_getParam('type', 'comment');
            if (empty($type))
                $type = 'comment';
            $album = $this->getSpecialAlbum($viewer, $type);
            if (Engine_Api::_()->hasModuleBootstrap('sitealbum')) {
                $photoTable = Engine_Api::_()->getDbtable('photos', 'sitealbum');
            } else {
                $photoTable = Engine_Api::_()->getDbtable('photos', 'album');
            }
            $photo = $photoTable->createRow();
            $photo->setFromArray(array(
                'owner_type' => 'user',
                'owner_id' => Engine_Api::_()->user()->getViewer()->getIdentity()
            ));
            $photo->save();
            $photo->setPhoto($_FILES['photo']);
            $photo->order = $photo->photo_id;
            $photo->album_id = $album->album_id;
            $photo->save();
            if (!$album->photo_id) {
                $album->photo_id = $photo->getIdentity();
                $album->save();
            }
            // Authorizations
            $auth = Engine_Api::_()->authorization()->context;
            $auth->setAllowed($photo, 'everyone', 'view', true);
            $auth->setAllowed($photo, 'everyone', 'comment', true);
            $db->commit();
            return array(
                "photo_id" => $photo->getIdentity(),
                "type" => $type
            );
        } catch (Exception $e) {
            $db->rollBack();
            //throw $e;
        }
    }
    public function getSpecialAlbum(User_Model_User $user, $type) {
        if (!in_array($type, array('comment'))) {
            return;
        }
        $table = Engine_Api::_()->getDbtable('albums', 'album');
        $select = $table->select()
                ->where('owner_type = ?', $user->getType())
                ->where('owner_id = ?', $user->getIdentity())
                ->where('type = ?', $type)
                ->order('album_id ASC')
                ->limit(1);
        $album = $table->fetchRow($select);
        // Create wall photos album if it doesn't exist yet
        if (null === $album) {
            $translate = Zend_Registry::get('Zend_Translate');
            $album = $table->createRow();
            $album->owner_type = 'user';
            $album->owner_id = $user->getIdentity();
            $album->title = $this->translate(ucfirst(str_replace("_", " ", $type)) . ' Photos');
            $album->type = $type;
            $album->search = 1;
            $album->save();
            // Authorizations
            $auth = Engine_Api::_()->authorization()->context;
            $roles = array('owner', 'owner_member', 'owner_member_member', 'owner_network', 'registered', 'everyone');
            foreach ($roles as $i => $role) {
                $auth->setAllowed($album, $role, 'view', true);
                $auth->setAllowed($album, $role, 'comment', true);
            }
        }
        return $album;
    }
    private function _getAllReplyComment($action, $comment, $allComments = array(), $parentComment = array()) {
        $viewer = Engine_Api::_()->user()->getViewer();
        $page = $this->getRequestParam('page', null);
        $limit = $this->getRequestParam('limit', null);
        $param = array();
        $param['page'] = $page;
        $param['limit'] = $limit;
        $commentSelect = $action->comments()->getCommentSelect();
        if (!empty($comment) && $comment->comment_id) {
            $commentSelect->where("parent_comment_id = ?", $comment->comment_id);
            $commentSelect->order('comment_id ' . $this->getRequestParam('order', 'DESC'));
        }
        $comments = Zend_Paginator::factory($commentSelect);
        if (!empty($param['page']) && !empty($param['limit'])) {
            $comments->setCurrentPageNumber($param['page']);
            $comments->setItemCountPerPage($param['limit']);
        } else {
            $comments->setCurrentPageNumber(1);
            $comments->setItemCountPerPage(25);
        }
        $canComment = $action->authorization()->isAllowed($viewer, 'comment');
        $canDelete = $action->authorization()->isAllowed($viewer, 'edit');
        if (count($comments) > 0) {
            $action_id = $action->getIdentity();
            $comments = $comments->getIterator();
            if ($page) {
                $i = 0;
                $l = count($comments) - 1;
                $d = 1;
                $e = $l + 1;
            } else {
                $i = count($comments) - 1;
                $l = count($comments);
                $d = -1;
                $e = -1;
            }
            for (; $i != $e; $i += $d) {
                $comment = $comments[$i];
                $this->_getAllReplyComment($action, $comment, $allComments, $parentComment);
                if (!empty($comment) && isset($comment->poster_type) && !empty($comment->poster_type)) {
                    $poster = Engine_Api::_()->getItem($comment->poster_type, $comment->poster_id);
                    $commentInfo = array();
                    $commentInfo["subject_id"] = $action->getIdentity();
                    $commentInfo["comment_id"] = $comment->comment_id;
                    // Add images
                    $getContentImages = Engine_Api::_()->getApi('Core', 'siteapi')->getContentImage($poster, false, 'author');
                    $commentInfo = array_merge($commentInfo, $getContentImages);
                    $commentInfo["author_title"] = $poster->getTitle();
                    $commentInfo["user_id"] = $poster->getIdentity();
                    $commentInfo["comment_body"] = $comment->body;
                    $commentInfo["comment_date"] = $comment->creation_date;
                    $commentInfo["params"] = isset($comment->params) ? $comment->params : "";
                    if (Engine_Api::_()->getApi('Siteapi_Feed', 'advancedactivity')->isSitestickerPluginLive()) {
                        if (isset($comment->attachment_type) && !empty($comment->attachment_type) && isset($comment->attachment_id) && !empty($comment->attachment_id) && ($comment->attachment_type == 'sitereaction_sticker' || $comment->attachment_type == 'album_photo')) {
                            $attachment = Engine_Api::_()->getItem($comment->attachment_type, $comment->attachment_id);
                            $getContentImages = Engine_Api::_()->getApi('Core', 'siteapi')->getContentImage($attachment, false);
                            $commentInfo['attachment'] = $getContentImages;
                            $commentInfo['attachment_type'] = $comment->attachment_type;
                            $commentInfo['attachment_id'] = $comment->attachment_id;
                        }
                    }
                    if (!empty($canDelete) || $poster->isSelf($viewer)) {
                        $commentInfo["delete"] = array(
                            "name" => "delete",
                            "label" => $this->translate('Delete'),
                            "url" => "comment-delete",
                            'urlParams' => array(
                                "action_id" => $action->getIdentity(),
                                "subject_type" => $action->getType(),
                                "subject_id" => $action->getIdentity(),
                                "comment_id" => $comment->comment_id
                            )
                        );
                        $commentInfo["edit"] = array(
                            "name" => "edit",
                            "label" => $this->translate('Edit'),
                            "url" => "advancedcomments/update",
                            'urlParams' => array(
                                "action_id" => $action->getIdentity(),
                                "subject_type" => $action->getType(),
                                "subject_id" => $action->getIdentity(),
                                "comment_id" => $comment->comment_id
                            )
                        );
                    } else {
                        $commentInfo["delete"] = null;
                        $commentInfo["edit"] = null;
                    }
                    if (!empty($canComment)) {
                        $isLiked = $comment->likes()->isLike($viewer);
                        if (empty($isLiked)) {
                            $likeInfo["name"] = "like";
                            $likeInfo["label"] = $this->translate('Like');
                            $likeInfo["url"] = "like";
                            $likeInfo['urlParams'] = array(
                                "action_id" => $action->getIdentity(),
                                "subject_type" => $action->getType(),
                                "subject_id" => $action->getIdentity(),
                                "comment_id" => $comment->comment_id
                            );
                            $likeInfo["isLike"] = 0;
                        } else {
                            $likeInfo["name"] = "unlike";
                            $likeInfo["label"] = $this->translate('Unlike');
                            $likeInfo["url"] = "unlike";
                            $likeInfo['urlParams'] = array(
                                "action_id" => $action->getIdentity(),
                                "subject_type" => $action->getType(),
                                "subject_id" => $action->getIdentity(),
                                "comment_id" => $comment->comment_id
                            );
                            $likeInfo["isLike"] = 1;
                        }
                        $commentInfo["like_count"] = $comment->likes()->getLikeCount();
                        $commentInfo["like"] = $likeInfo;
                    } else {
                        $commentInfo["like"] = null;
                    }
                    $replyInfo["name"] = "reply";
                    $replyInfo["label"] = $this->translate('Reply');
                    $replyInfo["url"] = "advancedcomments/comment";
                    $replyInfo['urlParams'] = array(
                        "action_id" => $action->getIdentity(),
                        "subject_type" => $action->getType(),
                        "subject_id" => $action->getIdentity(),
                        "comment_id" => $comment->comment_id
                    );
                    $commentInfo["isReply"] = 1;
                    $commentInfo["reply"] = $replyInfo;
                    if (!empty($commentInfo))
                        $this->_totalComment['reply_on_comment'][] = $commentInfo;
                }
            }
        }
        else {
            return $comment;
        }
//        $_totalComment=array("comment"=>$allComments,
//            "parentComment"=>$parentComment);
        return $this->_totalComment;
    }
    public function _getLastComment($action, $comment) {
        $viewer = Engine_Api::_()->user()->getViewer();
        $page = $this->getRequestParam('page', null);
        $limit = $this->getRequestParam('limit', null);
        $param = array();
        $lastComment = array();
        $param['page'] = $page;
        $param['limit'] = $limit;
        $getTotalCommentCount = 0;
        if (!empty($comment) && $comment->comment_id) {
            $commentSelect = $action->comments()->getCommentSelect();
            $commentSelect->where("parent_comment_id = ?", $comment->comment_id);
            $commentSelect->order('comment_id ' . 'DESC');
            $commentSelect->limit(1);
            $comments = Zend_Paginator::factory($commentSelect);
            if (!empty($param['page']) && !empty($param['limit'])) {
                $comments->setCurrentPageNumber($param['page']);
                $comments->setItemCountPerPage($param['limit']);
            } else {
                $comments->setCurrentPageNumber(1);
                $comments->setItemCountPerPage(25);
            }
            $getTotalCommentCount = $comments->getTotalItemCount();
        }
        if ($getTotalCommentCount <= 0)
            return array(
                "reply_on_comment" => null,
                "totalReplyCount" => 0
            );
        $canComment = $action->authorization()->isAllowed($viewer, 'comment');
        $canDelete = $action->authorization()->isAllowed($viewer, 'edit');
        $action_id = $action->getIdentity();
        $comments = $comments->getIterator();
        if ($page) {
            $i = 0;
            $l = count($comments) - 1;
            $d = 1;
            $e = $l + 1;
        } else {
            $i = count($comments) - 1;
            $l = count($comments);
            $d = -1;
            $e = -1;
        }
        for (; $i != $e; $i += $d) {
            $comment = $comments[$i];
            if (!empty($comment) && isset($comment->poster_type) && !empty($comment->poster_type)) {
                $poster = Engine_Api::_()->getItem($comment->poster_type, $comment->poster_id);
                $commentInfo = array();
                $commentInfo["subject_id"] = $action->getIdentity();
                $commentInfo["comment_id"] = $comment->comment_id;
                // Add images
                $getContentImages = Engine_Api::_()->getApi('Core', 'siteapi')->getContentImage($poster, false, 'author');
                $commentInfo = array_merge($commentInfo, $getContentImages);
                $commentInfo["author_title"] = $poster->getTitle();
                $commentInfo["user_id"] = $poster->getIdentity();
                $commentInfo["comment_body"] = $comment->body;
                $commentInfo["comment_date"] = $comment->creation_date;
                $commentInfo["params"] = isset($comment->params) ? $comment->params : "";
                if (Engine_Api::_()->getApi('Siteapi_Feed', 'advancedactivity')->isSitestickerPluginLive()) {
                    if (isset($comment->attachment_type) && !empty($comment->attachment_type) && isset($comment->attachment_id) && !empty($comment->attachment_id) && ($comment->attachment_type == 'sitereaction_sticker' || $comment->attachment_type == 'album_photo')) {
                                                                       $attachment = Engine_Api::_()->getItem($comment->attachment_type, $comment->attachment_id);
                        $params = Engine_Api::_()->getApi('Siteapi_Feed', 'advancedactivity')->getPhotoUrl($attachment, "thumb.profile");
                        $getHost = $getParentHost = Engine_Api::_()->getApi('Core', 'siteapi')->getHost();
                        $baseParentUrl = Zend_Controller_Front::getInstance()->getBaseUrl();
                        $baseParentUrl = @trim($baseParentUrl, "/");
                        $staticBaseUrl = Engine_Api::_()->getApi('settings', 'core')->getSetting('core.static.baseurl', null);
                        // Check IF default service "Local Storage" or not.
                        $getDefaultStorageId = Engine_Api::_()->getDbtable('services', 'storage')->getDefaultServiceIdentity();
                        $getDefaultStorageType = Engine_Api::_()->getDbtable('services', 'storage')->getService($getDefaultStorageId)->getType();
                        $host = '';
                        if ($getDefaultStorageType == 'local')
                            $host = !empty($staticBaseUrl) ? $staticBaseUrl : $getParentHost;
                        $imageUrl = $params['url'];
                        $imageUrl = (!strstr($imageUrl, "application/modules")) ? $host . $imageUrl : $imageUrl;
                        if (!strstr($imageUrl, 'http'))
                            $imageUrl = $getHost . DIRECTORY_SEPARATOR . $baseParentUrl . $imageUrl;
                        ;
                        try {
                            if (!empty($params)) {
                                $getContentImages = array(
                                    "image_profile" => $imageUrl,
                                    "size" => $params['params']
                                );
                            }
                        } catch (Exception $ex) {
                            
                        }
                        $commentInfo['attachment'] = $getContentImages;
                        $commentInfo['attachment_type'] = $comment->attachment_type;
                        $commentInfo['attachment_id'] = $comment->attachment_id;
                    }
                }
                  $commentInfo['gutterMenu'] = $this->_gutterMenus($action,$canDelete,$poster,$comment);
                if (!empty($canComment)) {
                    $isLiked = $comment->likes()->isLike($viewer);
                    if (empty($isLiked)) {
                        $likeInfo["name"] = "like";
                        $likeInfo["label"] = $this->translate('Like');
                        $likeInfo["url"] = "like";
                        $likeInfo['urlParams'] = array(
                            "action_id" => $action->getIdentity(),
                            "subject_type" => $action->getType(),
                            "subject_id" => $action->getIdentity(),
                            "comment_id" => $comment->comment_id
                        );
                        $likeInfo["isLike"] = 0;
                    } else {
                        $likeInfo["name"] = "unlike";
                        $likeInfo["label"] = $this->translate('Unlike');
                        $likeInfo["url"] = "unlike";
                        $likeInfo['urlParams'] = array(
                            "action_id" => $action->getIdentity(),
                            "subject_type" => $action->getType(),
                            "subject_id" => $action->getIdentity(),
                            "comment_id" => $comment->comment_id
                        );
                        $likeInfo["isLike"] = 1;
                    }
                    $commentInfo["like_count"] = $comment->likes()->getLikeCount();
                    $commentInfo["like"] = $likeInfo;
                } else {
                    $commentInfo["like"] = null;
                }
                if (!empty($canComment)) {
                    $replyInfo["name"] = "reply";
                    $replyInfo["label"] = $this->translate('Reply');
                    $replyInfo["url"] = "advancedcomments/comment";
                    $replyInfo['urlParams'] = array(
                        "action_id" => $action->getIdentity(),
                        "subject_type" => $action->getType(),
                        "subject_id" => $action->getIdentity(),
                        "comment_id" => $comment->comment_id
                    );
                    $commentInfo["isReply"] = 1;
                    $commentInfo["reply"] = $replyInfo;
                } else {
                    $commentInfo["reply"] = null;
                }
                if (!empty($commentInfo))
                    $lastComment['reply_on_comment'][] = $commentInfo;
            }
            break;
        }
        $lastComment['totalReplyCount'] = $getTotalCommentCount;
        return $lastComment;
    }
    private function _totalCommentCount($action) {
        $commentSelect = $action->comments()->getCommentSelect();
        $commentSelect->order('comment_id ' . 'DESC');
        $comments = Zend_Paginator::factory($commentSelect);
        $comments->setCurrentPageNumber(1);
        $comments->setItemCountPerPage(25);
        $getTotalCommentCount = $comments->getTotalItemCount();
        return $getTotalCommentCount;
    }
    
    private function _gutterMenus($action,$canDelete,$poster,$comment,$isReply=0){
        $viewer = Engine_Api::_()->user()->getViewer();
        $enabledAdvComment = Engine_Api::_()->getDbtable('modules', 'core')->isModuleEnabled('nestedcomment');
        if (!empty($canDelete) || $poster->isSelf($viewer)) {
            $editUrl = $isReply ? "advancedcomments/reply-edit" :"advancedcomments/comment-edit";
            if(isset($comment->resource_type))
                $editUrl = ($comment->resource_type != 'activity_action') ? "advancedcomments/update": $editUrl;
            $menus[] = array(
                "name" => "comment_edit",
                "label" => Engine_Api::_()->getApi('Core', 'siteapi')->translate('Edit'),
                "url" => $editUrl,
                'urlParams' => array(
                    "action_id" => $action->getIdentity(),
                    "subject_type" => $action->getType(),
                    "subject_id" => $action->getIdentity(),
                    "comment_id" => $comment->comment_id
                )
            );
            
            $menus[] = array(
                "name" => "comment_delete",
                "label" => Engine_Api::_()->getApi('Core', 'siteapi')->translate('Delete'),
                "url" => "comment-delete",
                'urlParams' => array(
                    "action_id" => $action->getIdentity(),
                    "subject_type" => $action->getType(),
                    "subject_id" => $action->getIdentity(),
                    "comment_id" => $comment->comment_id
                )
            );

           
        }
        
        $canCopy = $this->_canCopy($comment);
        if($canCopy)
        $menus[] = array(
                "name" => "comment_copy",
                "label" => Engine_Api::_()->getApi('Core', 'siteapi')->translate('Copy'),
                
            );
        $menus[] = array(
                "name" => "comment_cancel",
                "label" => Engine_Api::_()->getApi('Core', 'siteapi')->translate('Cancel'),
                
            );
        return $menus;
        
        
    }
    
    private function _canCopy($comment){
        if(!empty($comment->body)){
                return 1;
            }
        else
            return 0;
    }

}
?>
