<?php

/**
 * SocialEngine
 *
 * @category   Application_Extensions
 * @package    Peopleyoumayknow
 * @copyright  Copyright 2009-2010 BigStep Technologies Pvt. Ltd.
 * @license    http://www.socialengineaddons.com/license/
 * @version    $Id: ModInfo.php 2010-08-27 9:40:21Z SocialEngineAddOns $
 * @author     SocialEngineAddOns
 */
class Peopleyoumayknow_Api_ModInfo extends Core_Api_Abstract {

  /**
   * Return array, when loggd-in user view the "view page" or "viewall listing page" then required supported modules name for suggestion.
   */
  public function getModNameForOldFunction() {
	return array(
		'friend',
		'group',
		'friendphoto',
		'event',
		'classified',
		'album',
		'video',
		'music',
		'blog',
		'poll',
		'forum',
		'document',
		'list',
		'sitepage',
		'sitepagealbum',
		'sitepagedocument',
		'sitepagepoll',
		'sitepagevideo',
		'sitepageevent',
		'sitepagenote',
		'sitepagereview',
		'sitepagemusic',
		'sitepageoffer',
		'recipe'
	);
  }

  /**
   * Return array, when loggd-in user delete any content which integrate with suggestion then its suggestions shoould be deleted modules name are following.
   */
  public function getModWhenDeleteContent() {
	return array(
		'group',
		'blog',
		'event',
		'album',
		'classified',
		'video',
		'music_playlist',
		'poll',
		'forum',
		'document',
		'list',
		'sitepagepoll_poll',
		'sitepageevent_event',
		'sitepagereview_review',
		'sitepagenote_note',
		'sitepagedocument_document',
		'sitepagevideo_video',
		'sitepage_album',
		'sitepage_page',
		'sitepagemusic_playlist',
		'sitepageoffer_offer',
		'recipe'
	);
  }

  /**
   * Find out the Modules name which support of "Suggestion/Recommendation Plugin" and "Enabled".
   *
   * @param $modName: Optional, If want to check only this modules then return TRUE and FALSE.
   * @return "Array" or "TRUE or FALSE".
   */
  public function getSupportedMods($modName = null) {
	$modSupport = false;
	$moduleArray = array(
		'friend' => 0,
		'messagefriend' => 0,
		'friendfewfriend' => 0,
		'friendphoto' => 0,
		'album' => 1,
		'blog' => 1,
		'classified' => 1,
		'document' => 1,
		'event' => 1,
		'forum' => 1,
		'group' => 1,
		'list' => 1,
		'music' => 1,
		'poll' => 1,
		'video' => 1,
		'sitepage' => 1,
		'recipe' => 1,
		'sitepagevideo' => 1,
		'sitepagenote' => 1,
		'sitepagedocument' => 1,
		'sitepageevent' => 1,
		'sitepagepoll' => 1,
		'sitepagereview' => 1,
		'sitepagealbum' => 1,
		'sitepagemusic' => 1,
		'sitepageoffer' => 1,
		'photo' => 0,
	);

	if (empty($modName)) {// If we are not pass any module name then we will return array of modules which should be enabled and support to suggestion plugin.
	  foreach ($moduleArray as $moduleName => $flag) {
		$isModEnabled = $this->isModEnabled($moduleName);
		if (!empty($isModEnabled) || empty($flag)) {
		  $supportModArray[] = $moduleName;
		}
	  }
	  $modSupport = $supportModArray;
	} else {// If we are passing module name then we will return 0/1, 1) plugin should be support of suggestion plugin 2) should be enabled.
	  $isModEnabled = $this->isModEnabled($modName);
	  $isModSupport = array_key_exists($modName, $moduleArray);
	  if (!empty($isModSupport) && (empty($moduleArray[$modName]) || !empty($isModEnabled))) {
		$modSupport = true;
	  }
	}
	return $modSupport;
  }

  /**
   * Find out the modules enabled or disabled.
   *
   * @param $modName: Module name, which we find out that this module "Enabled" or "Disabled".
   * @return true or false.
   */
  public function isModEnabled($modName) {
	if ($modName != 'friend') {
	  return Engine_Api::_()->getDbtable('modules', 'core')->isModuleEnabled($modName);
	}
	return true;
  }

  /**
   * Function which reaturn the information of the plugin. If $pluginname is empty then function will return all modules info else return perticular modules info.
   *
   * @param $pluginname: Module name.
   * @return Array
   */
  public function getPluginDetailed($pluginname = null) {

	if (empty($pluginname)) {
	  $getSupportMod = $this->getSupportedMods();
	} else {
	  $getSupportMod[] = $pluginname;
	}

	foreach ($getSupportMod as $modName) {
	  $modInfo[$modName] = $this->getPluginInfos($modName);
	}

	return $modInfo;
  }

  /**
   * Find out the modules complete information, which required in suggestion plugin for the modules.
   *
   * @param $modName: Module name.
   * @return Array
   */
  public function getPluginInfos($modName) {
	$view = Zend_Registry::isRegistered('Zend_View') ? Zend_Registry::get('Zend_View') : null;
	$pluginInfo = null;
	$isModule = true;
	switch ($modName) {
	  case 'messagefriend':
		$pluginInfo['pluginName'] = 'user';
		$pluginInfo['templateInfoFlag'] = 'messagefriend';
		$pluginInfo['displayName'] = 'Send Message';
		$pluginInfo['itemType'] = 'user';
		$pluginInfo['notificationType'] = '';
		$pluginInfo['buttonLabel'] = '';
		$pluginInfo['idColumnName'] = 'user_id';
		$pluginInfo['findFriendFunName'] = '';
		$isModule = false;
		break;
	  case 'fewfriend':
	  case 'friendfewfriend':
		$pluginInfo['pluginName'] = 'user';
		$pluginInfo['templateInfoFlag'] = 'friend';
		$pluginInfo['defaultFriendship'] = true;
		$pluginInfo['displayName'] = 'Friend';
		$pluginInfo['itemType'] = 'user';
		$pluginInfo['notificationType'] = 'friend_suggestion';
		$pluginInfo['buttonLabel'] = '';
		$pluginInfo['idColumnName'] = 'user_id';
		$pluginInfo['findFriendFunName'] = 'few_friend_suggestion';
		$isModule = false;
		break;
	  case 'friendphoto':
		$pluginInfo['pluginName'] = 'user';
		$pluginInfo['templateInfoFlag'] = 'photo';
		$pluginInfo['displayName'] = 'Suggest Picture';
		$pluginInfo['itemType'] = 'user';
		$pluginInfo['notificationType'] = '';
		$pluginInfo['buttonLabel'] = '';
		$pluginInfo['idColumnName'] = 'user_id';
		$pluginInfo['findFriendFunName'] = '';
		$isModule = false;
		break;
	  case 'friend':
		$pluginInfo['pluginName'] = 'user';
		$pluginInfo['templateInfoFlag'] = 'friend';
		$pluginInfo['defaultFriendship'] = true;
		$pluginInfo['displayName'] = 'Friend';
		$pluginInfo['itemType'] = 'user';
		$pluginInfo['notificationType'] = 'friend_suggestion';
		$pluginInfo['buttonLabel'] = $view->translate('View this Friend');
		$pluginInfo['idColumnName'] = 'user_id';
		$pluginInfo['findFriendFunName'] = 'add_friend_suggestion';
		$isModule = false;
		break;
	  case 'accept_request':
		$pluginInfo['findFriendFunName'] = 'add_friend_suggestion';
		$isModule = false;
		break;
	  case 'few_friend':
		$pluginInfo['notificationType'] = 'friend_suggestion';
		$pluginInfo['findFriendFunName'] = 'few_friend_suggestion';
		$pluginInfo['modName'] = 'friend';
		$isModule = false;
		break;
	  default:
		$pluginInfo['pluginName'] = $modName;
		$pluginInfo['templateInfoFlag'] = $modName;
		$pluginInfo['displayName'] = ucfirst($modName);
		$pluginInfo['itemType'] = $modName;
		$pluginInfo['notificationType'] = $modName . '_suggestion';
		$buttonLabelFlag = 'View this ' . ucfirst($modName);
		$pluginInfo['buttonLabel'] = $view->translate($buttonLabelFlag);
		$pluginInfo['idColumnName'] = $modName . '_id';
		$pluginInfo['ownerColumnName'] = 'owner_id';
		break;
	}

	if (!empty($isModule)) {
	  if (!Engine_Api::_()->getDbtable('modules', 'core')->isModuleEnabled($pluginInfo['pluginName'])) {
		return;
	  }
	}
	return $pluginInfo;
  }

  /**
   * Return the name of functions name array for pass module name. So pass modules will return the results for widgets only from the returned functions.
   *
   * @param $modName: Module Name.
   * @param $is_viewer: There are deffrent function return for "Loggden User" or "Loggdeout User".
   * @return Array.
   */
  public function getFunArray($modName, $is_viewer = null) {

	if (empty($modName)) {
	  return;
	}

	$viewer_id = Engine_Api::_()->user()->getViewer()->getIdentity();
	if (!empty($is_viewer)) {
	  $viewer_id = 0;
	}

	$getSuggMod = Engine_Api::_()->getApi('settings', 'core')->getSetting($modName . '.sugg.mod', 1);
	$modInfoArray = array('popularMod' => 0);

	switch ($modName) {
	  case 'messagefriend':
		$modInfoArray = array('messagefriend_mix_sugg' => 0);
		break;
	  case 'fewfriend':
	  case 'friendfewfriend':
		$modInfoArray = array('friendfewfriend_mix_sugg' => 0);
		break;
	  case 'friendphoto':
		$modInfoArray = array('friendphoto_mix_sugg' => 0);
		break;
	  case 'friend':
		$modInfoArray = array('friend_mix_sugg' => 0);
		break;
	}

	if (empty($viewer_id) || !empty($is_recommendation)) { // For loggd-out user
	  foreach ($modInfoArray as $funName => $status) {
		if (empty($status)) {
		  $funNameArray[] = $funName;
		}
	  }
	} else {
	  $funNameArray = array_keys($modInfoArray);
	}
	$modInfo[$modName] = $funNameArray;
	return $modInfo;
  }

  /**
   * Getting the order for SQL  according to the modules.
   *
   * @param $modName: Module Name.
   * @return Array.
   */
  public function getOrder($modName) {
	return array();
  }

  /**
   * Getting modules special condition. Result( Suggestion ) will depend on these conditions.
   *
   * @param $modName: Module Name.
   * @return Array.
   */
  public function getModCondition($modName) {
	return array('search' => 1);
  }

  /**
   * Getting module name from the entity. We are using this on viewal page.
   * @return Array.
   */
  public function getModName() {
	return array(
		'page_video' => 'sitepagevideo',
		'page_note' => 'sitepagenote',
		'page_document' => 'sitepagedocument',
		'page_event' => 'sitepageevent',
		'page_poll' => 'sitepagepoll',
		'page_review' => 'sitepagereview',
		'page_album' => 'sitepagealbum',
		'page_music' => 'sitepagemusic',
		'page_offer' => 'sitepageoffer'
	);
  }

}
?>