<?php

/**
 * SocialEngine
 *
 * @category   Application_Extensions
 * @package    Primemessenger
 * @copyright  Copyright 2017-2018 BigStep Technologies Pvt. Ltd.
 * @license    http://www.socialengineaddons.com/license/
 * @version    AdminSettingsController.php 2017-06-30 00:00:00Z SocialEngineAddOns $
 * @author     SocialEngineAddOns
 */
use PrimeMessenger\Primemessenger\Migration;
use PrimeMessenger\Primemessenger\Synchronization;

class PrimeMessenger_AdminSettingsController extends Core_Controller_Action_Admin {

    CONST DATA_PATH = 'data';
    CONST SYNC_PATH = 'sync';

    public function init() {
        Zend_Registry::get('Autoloader')->addResourceType('primemessenger_synchronize', 'synchronize', 'Synchronize');
        Zend_Registry::get('Autoloader')->addResourceType('primemessenger_migrate', 'migrate', 'Migrate');
    }

    public function indexAction() {
        $this->view->navigation = $navigation = Engine_Api::_()->getApi('menus', 'core')
                ->getNavigation('primemessenger_admin_main', array(), 'primemessenger_admin_settings_index');

        $this->view->form = $form = new Primemessenger_Form_Admin_Configuration();
        if (!$this->getRequest()->isPost() || !$form->isValid($this->_getAllParams())) {
            return;
        }

        $values = $form->getValues();
        if (!empty($values['primemessenger_error'])) {
            $form->addError($values['primemessenger_error']);
            return;
        }

        unset($values['primemessenger_error']);
        foreach ($values as $key => $value) {
            Engine_Api::_()->getApi('settings', 'core')->setSetting($key, $value);
        }

        $form->addNotice('Your changes have been saved.');
    }

    public function synchronizeAction() {
        $this->view->navigation = $navigation = Engine_Api::_()->getApi('menus', 'core')
            ->getNavigation('primemessenger_admin_main', array(), 'primemessenger_admin_settings_synchronize');

        $this->view->form = $form = new Primemessenger_Form_Admin_Synchronize();

        $hasMigrated = Engine_Api::_()->primemessenger()->hasMigrated();
        $hasCompletedMigration = Engine_Api::_()->primemessenger()->isPrimeMessengerActive();

        if (!$hasMigrated || !$hasCompletedMigration) {
            $form->addError('You have not migrated Channelize yet or migration is still in process.You can synchronize once migration completes.');
            return;
        }

        if (!$this->getRequest()->isPost() || !$form->isValid($this->_getAllParams())) {
            return;
        }
        $this->_createTarFileAndSynchronize();
    }
    
    public function migrateAction() {
        $this->view->navigation = $navigation = Engine_Api::_()->getApi('menus', 'core')
            ->getNavigation('primemessenger_admin_main', array(), 'primemessenger_admin_settings_migrate');

        $hasMigrated = Engine_Api::_()->primemessenger()->hasMigrated();
        $hasCompletedMigration = Engine_Api::_()->primemessenger()->isPrimeMessengerActive();

        if ($hasMigrated && !$hasCompletedMigration ) {
            $this->view->hasMigrated = true;
            $this->view->activationform = $form = new Primemessenger_Form_Admin_MigrateCompleted();
            if ($this->getRequest()->isPost() && $form->isValid($this->_getAllParams())) {
               Engine_Api::_()->getApi('settings', 'core')->setSetting('primemessenger_migrationactivated', true);
               $this->view->hasCompletedMigration = true;
            }
            return;
        }
        
        else if ($hasMigrated && $hasCompletedMigration ) {
            $this->view->hasCompletedMigration = true;
            $this->view->hasMigrated = true;
            return;
        }
        
        $this->view->form = $form = new Primemessenger_Form_Admin_Migrate();
        if (!$this->getRequest()->isPost() || !$form->isValid($this->_getAllParams())) {
            return;
        }

        $selectedMigrationModule = $form->getValues()['primemessenger_module'] ? $form->getValues()['primemessenger_module'] : 'Users';


        $isPrimeMessengerConfigured = Engine_Api::_()->primemessenger()->isPrimeMessengerConfigured();
        if (!$isPrimeMessengerConfigured) {
            $form->addError('You have not configured Channelize yet. Please configure Channelize in configuration tab before migration.');
            return;
        }

        $this->_createTarFileAndMigrate($selectedMigrationModule);

        // This entry ensures that user has migrated data.
        Engine_Api::_()->getApi('settings', 'core')->setSetting('primemessenger_migrate', true);
    }

    public function faqAction() {
        $this->view->navigation = Engine_Api::_()->getApi('menus', 'core')
                ->getNavigation('primemessenger_admin_main', array(), 'primemessenger_admin_settings_faq');
        $this->view->faq_id = $faq_id = $this->_getParam('faq', 'faq_1');
    }

protected function _createTarFileAndMigrate($selectedMigrationModule) {
    // Set time limit
    @set_time_limit(0);
    @ini_set('max_execution_time', 600);
    @ini_set('memory_limit', '-1');
    ignore_user_abort(true); // Not sure if we should do this
    // Make data path directory if not exist or clean data directory if exist.
    $dataPath = APPLICATION_PATH . '/application/modules/Primemessenger/' . self::DATA_PATH;
    if (!file_exists($dataPath)) {
      mkdir($dataPath);
    } else {
      array_map('unlink', glob($dataPath . '/*'));
    }
    $this->_dataPath = $dataPath;

    // Delete data.tar file if exist
    if (file_exists($dataPath . '.tar')) {
      unlink($dataPath . '.tar');
    }

    // Set database configurations
    try {
      $this->_setDatabaseConfig();
    } catch (Exception $e) {
      $errorOutput = '';
      while (ob_get_level() > 0) {
        $errorOutput .= ob_get_clean();
      }
      echo Zend_Json::encode(array(
          'status' => false,
          'error' => $e->getMessage(),
      ));
      // We want an error
      //$this->_ignoreShutdown = true;
      error_reporting(0);
      trigger_error($e->getMessage(), E_USER_ERROR);
      exit();
    }

    $this->view->submit = true;
    // Check for index or build if not found

    $migrators = $selectedMigrationModule == 'Users' ? [$this->_getUserMigrator()] : $this->_getAllMigrators($selectedMigrationModule);

    $messages = array();
    foreach ($migrators as $migrator) {
      $migrator->run();
      $messages = array_merge($messages, $migrator->getMessages());
      $hasError = $migrator->hasError();
      $hasWarning = $migrator->hasWarning();
      if (!empty($hasError) || !empty($hasWarning)) {
        $this->view->hasError = $hasError;
        $this->view->hasWarning = $hasWarning;
        $this->view->messages = $migrator->getMessages();
        return;
      }
    }

    // Create tar file
    $this->_createTarFile();

    // Migrate Files
    $this->_migrate();

    $this->view->messages = $messages;
  }

    protected function _createTarFileAndSynchronize() {
        // Set time limit
        @set_time_limit(0);
        @ini_set('max_execution_time', 600);
        @ini_set('memory_limit', '-1');
        ignore_user_abort(true); // Not sure if we should do this
        // Make data path directory if not exist or clean data directory if exist.
        $dataPath = APPLICATION_PATH . '/application/modules/Primemessenger/' . self::SYNC_PATH;
        if (!file_exists($dataPath)) {
            mkdir($dataPath);
        } else {
            array_map('unlink', glob($dataPath . '/*'));
        }
        $this->_dataPath = $dataPath;

        // Delete data.tar file if exist
        if (file_exists($dataPath . '.tar')) {
            unlink($dataPath . '.tar');
        }
        // Set database configurations
        try {
            $this->_setDatabaseConfig();
        } catch (Exception $e) {
            $errorOutput = '';
            while (ob_get_level() > 0) {
                $errorOutput .= ob_get_clean();
            }
            echo Zend_Json::encode(array(
                'status' => false,
                'error' => $e->getMessage(),
            ));
            // We want an error
            //$this->_ignoreShutdown = true;
            error_reporting(0);
            trigger_error($e->getMessage(), E_USER_ERROR);
            exit();
        }

        $this->view->submit = true;

        // Check for index or build if not found
        $migrator = $this->_getUserMigrator('Synchronize');
        $migrator->run();
        $message = $migrator->getMessages();
        $hasError = $migrator->hasError();
        $hasWarning = $migrator->hasWarning();
            if (!empty($hasError) || !empty($hasWarning)) {
                $this->view->hasError = $hasError;
                $this->view->hasWarning = $hasWarning;
                $this->view->messages = $migrator->getMessages();
                return;
            }

        // Create tar file
        $this->_createTarFile();

        $this->_synchronize();

        $this->view->messages = $message;
    }

    protected function _createTarFile() {
        try {
            $phar = new PharData($this->_dataPath . '.tar');
            $phar->buildFromDirectory($this->_dataPath);
        } catch (Exception $e) {
            $errorOutput = '';
            while (ob_get_level() > 0) {
                $errorOutput .= ob_get_clean();
            }
            echo Zend_Json::encode(array(
                'status' => false,
                'error' => $e->getMessage(),
            ));
            // We want an error
            //$this->_ignoreShutdown = true;
            error_reporting(0);
            trigger_error($e->getMessage(), E_USER_ERROR);
            exit();
        }
    }

    protected function _migrate() {
        try {
            // Get all super admins
            $superadmins = Engine_Api::_()->user()->getSuperAdmins();
            $userData = array();
            foreach($superadmins as $superadmin) {
                $userData[] = array(
                    'email' => $superadmin->email,
                    'name' => $superadmin->getTitle()
                );
            }
            $migration = new Migration();
            $curlFile = new \CurlFile($this->_dataPath . '.tar');
            $migration->migrate(array(
                'userData' => json_encode($userData),
                'file' => $curlFile
            ));
        } catch (Exception $e) {
            $errorOutput = '';
            while (ob_get_level() > 0) {
                $errorOutput .= ob_get_clean();
            }
            echo Zend_Json::encode(array(
                'status' => false,
                'error' => $e->getMessage(),
            ));
            // We want an error
            //$this->_ignoreShutdown = true;
            error_reporting(0);
            trigger_error($e->getMessage(), E_USER_ERROR);
            exit();
        }
    }

    protected function _synchronize() {
        try {
            // Get all super admins
            $superadmins = Engine_Api::_()->user()->getSuperAdmins();
            $userData = array();
            foreach($superadmins as $superadmin) {
                $userData[] = array(
                    'email' => $superadmin->email,
                    'name' => $superadmin->getTitle()
                );
            }

            $synchronization = new synchronization();
            $curlFile = new \CurlFile($this->_dataPath . '.tar');
            $synchronization->synchronize(array(
                'userData' => $userData,
                'file' => $curlFile
            ));
        } catch (Exception $e) {
            $errorOutput = '';
            while (ob_get_level() > 0) {
                $errorOutput .= ob_get_clean();
            }
            echo Zend_Json::encode(array(
                'status' => false,
                'error' => $e->getMessage(),
            ));
            // We want an error
            //$this->_ignoreShutdown = true;
            error_reporting(0);
            trigger_error($e->getMessage(), E_USER_ERROR);
            exit();
        }
    }

    protected function _setDatabaseConfig() {
        // Check to database config file
        $fromDbConfigFile = APPLICATION_PATH . '/application/settings/database.php';
        if (!is_file($fromDbConfigFile)) {
            throw new Engine_Exception('Version 4 database config was not found.');
        }

        // Get from database config
        $fromDbConfigFile = include $fromDbConfigFile;
        if (!is_array($fromDbConfigFile) ||
                empty($fromDbConfigFile['adapter']) ||
                empty($fromDbConfigFile['params'])) {
            throw new Engine_Exception('Invalid version 4 database configuration.');
        }

        // Make from adapter and check connection
        $fromDbConfig = array(
            'adapter' => $fromDbConfigFile['adapter'],
            'params' => array(
                'host' => $fromDbConfigFile['params']['host'],
                'username' => $fromDbConfigFile['params']['username'],
                'password' => $fromDbConfigFile['params']['password'],
                'dbname' => $fromDbConfigFile['params']['dbname'],
                'charset' => $fromDbConfigFile['params']['charset'],
                'adapterNamespace' => $fromDbConfigFile['params']['adapterNamespace'],
                'fromPrefix' => $fromDbConfigFile['tablePrefix'],
            ),
        );

        try {
            $fromDb = Zend_db::factory($fromDbConfig['adapter'], $fromDbConfig['params']);
            $fromDb->getServerVersion(); // Forces connection
        } catch (Exception $e) {
            throw new Engine_Exception('Database connection error: ' . $e->getMessage());
        }

        // Save all info for later
        $this->_fromDb = $fromDb;
        $this->_fromPrefix = $fromDbConfig['params']['fromPrefix'];
    }

  protected function _getAllMigrators($selectedMigrationModule) {
    $migrators = array();
    $priorities = array();
    foreach ($this->_listMigrators($selectedMigrationModule) as $type) {
      $migrator = $this->_getMigrator($type, [], $selectedMigrationModule);
      $priorities[$type] = $migrator->getPriority();
      $migrators[$type] = $migrator;
    }

    // Add Common User Migrator . . 
    $userMigrator = $this->_getUserMigrator();
    $priorities['Users'] = $userMigrator->getPriority();
    $migrators['Users'] = $userMigrator;

    arsort($priorities);

    $sortedMigrators = array();
    foreach ($priorities as $type => $priority) {
      $sortedMigrators[] = $migrators[$type];
    }

    return $sortedMigrators;
  }

  protected function _listMigrators($selectedMigrationModule) {
    $types = array();
    $path = __DIR__ . '/../migrate/' . $selectedMigrationModule . '/';
    foreach (scandir($path) as $child) {
      if (strlen($child) <= 4)
        continue;
      if (substr($child, -4) !== '.php')
        continue;
      if (stripos($child, 'Abstract') !== false)
        continue;
      $types[] = substr($child, 0, -4);
    }
    return $types;
  }

/**
   * @param string $type
   * @param array $params
   * @return PrimeMessenger_Migrate_Abstract
   */
  protected function _getMigrator($type, $params = array(), $selectedMigrationModule) {
    $class = 'PrimeMessenger_Migrate_' . $selectedMigrationModule . '_' .
            str_replace(' ', '', ucwords(trim(preg_replace('/[^a-zA-Z0-9_]+/', ' ', $type))));

    if (!class_exists($class, false)) {
      $autoloader = Zend_Registry::get('Autoloader');
      $autoloader->autoload($class);
      if (!class_exists($class, false)) {
        throw new Engine_Exception('Class not found: ' . $class);
      }
    }

    return new $class(array_merge($params, array(
                'fromDb' => $this->_fromDb,
                'fromPrefix' => $this->_fromPrefix,
                'dataPath' => $this->_dataPath
    )));
  }

  protected function _getUserMigrator($dir ='Migrate') {
    $class = 'PrimeMessenger_'.$dir.'_Users';
    
    if (!class_exists($class, false)) {
      $autoloader = Zend_Registry::get('Autoloader');
      $autoloader->autoload($class);
      if (!class_exists($class, false)) {
        throw new Engine_Exception('Class not found: ' . $class);
      }
    }

    return new $class(array(
        'fromDb' => $this->_fromDb,
        'fromPrefix' => $this->_fromPrefix,
        'dataPath' => $this->_dataPath
    ));
  }

}