<?php

/**
 * SocialEngine
 *
 * @category   Application_Extensions
 * @package    Primemessenger
 * @copyright  Copyright 2017-2018 BigStep Technologies Pvt. Ltd.
 * @license    http://www.socialengineaddons.com/license/
 * @version    ChatRoomMessages.php 2017-06-30 00:00:00Z SocialEngineAddOns $
 * @author     SocialEngineAddOns
 */

require_once APPLICATION_PATH . '/application/modules/Primemessenger/getid3/getid3.php';

class PrimeMessenger_Migrate_CometChat_ChatRoomMessages extends PrimeMessenger_Migrate_DbAbstract {

  protected $_fromTable = 'cometchat_chatroommessages';
  protected $_warningMessage = array();
  protected $_priority = 900;
  protected $_jsonFileName = 'chat-messages';
  protected $_ignoredTerms = [];

  protected function _initPre() {
    $this->_fromTable = 'cometchat_chatroommessages';
    $this->_ignoredTerms = ['javascript:jqcc', 'CC^CONTROL','has successfully sent an audio/video broadcast request'];
  }

  protected function _translateRow(array $data, array &$jsonData) {

    // return for not having body
    if(!$data['message']){
      return;
    }

    if (!$this->isRoomExist($data) || $this->hasIgnoredTerms($data['message'])) {
      return;
    }
    $recipients = $this->getRecieptents($data);

    $anchorHTML = $this->convertHtmltoArray($data['message'], 'a');
    $imgHTML = $this->convertHtmltoArray($data['message'], 'img');
    $messageHasFile = count($imgHTML) || count($anchorHTML);
    $messageHasSmiley = !count($anchorHTML) && count($imgHTML);

    if ($messageHasSmiley) {
      $message = $this->getSmileyContent($data['message']);
      if (trim($message)=='') {
        return;
      }
      $attachmentType = 'text';
      $attachementData = [];
    } else if ($messageHasFile) {
      $message = '';
      $attachement = $this->getAttachement($data['message']);
      if(!$attachement['fileExist']){
        return;
      }
      $attachmentType = $attachement['attachmentType'];
      $attachementData = $attachement['attachementData'];
    } else {
      $message = $data['message'];
      $attachmentType = 'text';
      $attachementData = [];
    }

    // $timeZone = Engine_Api::_()->getApi('settings', 'core')->getSetting('core.locale.timezone');
    // date_default_timezone_set("$timeZone");
    
    $newData = array();
    $newData['messageId'] = $data['id'];
    $newData['roomId'] = $data['chatroomid'];
    $newData['body'] = $message;
    $newData['ownerId'] = $data['userid'];
    $newData['createdAt'] = date('Y-m-d H:i:s', $data['sent']);
    $newData['recipients'] = array_values(array_filter($recipients));
    $newData['attachmentType'] = $attachmentType;
    $newData['attachmentData'] = $attachementData;
    
    $jsonData[] =  $newData;
  }

  public function hasIgnoredTerms($message) {

    foreach ($this->_ignoredTerms as $ignoredTerm) {
      if (strpos($message, $ignoredTerm) === FALSE) {
        continue;
      } else {
        return true;
      }
    }
    return false;
  }

  public function getRecieptents($data) {
    $recipients = $this->getFromDb()->select()
            ->from('cometchat_chatrooms_users' , 'userid')
            ->where('chatroomid = (?)', $data['chatroomid'])
            ->distinct()
            ->query()
            ->fetchAll(Zend_Db::FETCH_COLUMN);
    return array_unique($recipients);
  }

  public function isRoomExist($data) {
    $roomId = $this->getFromDb()->select()
            ->from('cometchat_chatrooms', 'id')
            ->where('id = (?)', $data['chatroomid'])
            ->query()
            ->fetchColumn();
    $isRoomExist = $roomId ? true : false;
    return $isRoomExist;
  }

  public function getSmileyContent($message) {
    $messageDom = new DOMDocument();
    $messageDom->loadHTML($message);
    $messageText = $messageDom->textContent;
    return $messageText;
  }

  public function getAttachement($message) {
    $anchorHTML = $this->convertHtmltoArray($message, 'a');
    $imgHTML = $this->convertHtmltoArray($message, 'img');

    if (count($anchorHTML) && !count($imgHTML)) {
      return $this->getDocumentAttachementData($anchorHTML);
    }
    return $this->getMediaAttachementData($anchorHTML, $imgHTML);
  }

  public function getDocumentAttachementData($anchorHTML) {

    $fileUrl = $this->filterUrl($anchorHTML['href']);
    $fileInfo = $this->getFileInformation($fileUrl,'file');
    return $this->getAttachementData($fileInfo);
  }

  public function getMediaAttachementData($anchorHTML, $imgHTML) {

    $fileUrl = $this->filterUrl($anchorHTML['href']);
    $fileType = $imgHTML['type'] ? $imgHTML['type'] : 'image';
    $fileInfo = $this->getFileInformation($fileUrl,$fileType);
    $thumbnailUrl = $this->filterThumbnailUrl($imgHTML['src'], $fileUrl);

    return $this->getAttachementData($fileInfo , $thumbnailUrl);
  }

  public function filterUrl($fileUrl) {
    if (substr($fileUrl, 0, strlen('//')) === '//') {
      $fileUrl = substr($fileUrl, strlen('//'));
    }
    return $this->addhttp($fileUrl);
  }

  public function filterThumbnailUrl($thumbnailUrl, $fileUrl) {
    if (!filter_var($thumbnailUrl, FILTER_VALIDATE_URL)) {
      $modBaseUrl = substr($fileUrl, 0, strpos($fileUrl, "/cometchat"));
      $thumbnailUrl = $modBaseUrl . $thumbnailUrl;
    }
    return $this->addhttp($thumbnailUrl);
  }

  public function getAttachementData($fileInfo , $thumbnailUrl = null) {
    $fileExist = !$fileInfo['error'] ? true : false;
    $attachmentData = array(
        'name' => $fileInfo['filename'],
        'mimeType' => $fileInfo['fileType'] . '/' . $fileInfo['fileformat'],
        'size' => $fileInfo['filesize'],
        'extension' => $fileInfo['fileformat'],
        'fileUrl' => $fileInfo['fileUrl'],
        'thumbnailUrl' => $thumbnailUrl
    );

    if (in_array($fileInfo['fileType'], ['audio', 'video'])) {
        $attachementData['duration'] = $fileInfo['playtime_seconds'];
    }

    $attachment = ['attachmentType' => $fileInfo['fileType'], 'attachementData' => $attachmentData,'fileExist' => $fileExist];
    return $attachment;
  }

  public function addhttp($url) {
    $host = 'http';
    if (isset($_SERVER['HTTPS']) && $_SERVER['HTTPS'] != 'off') {
        $host = 'https';
    } 
    if (!preg_match("~^(?:f|ht)tps?://~i", $url)) {
        $url = $host."://" . $url;
    }
    return $url;
  }

  public function convertHtmltoArray($content, $tg) {
    $dom = new DOMDocument;
    $dom->loadHTML($content);
    $attr = array();
    foreach ($dom->getElementsByTagName($tg) as $tag) {
      foreach ($tag->attributes as $attribName => $attribNodeVal) {
        $attr[$attribName] = $tag->getAttribute($attribName);
      }
    }
    return $attr;
  }

  private function getFileInformation($file,$fileType)
  {
    $tmpfname = tempnam("/tmp", "getID3");
    $localtempfile = fopen($tmpfname, "w");
    $fileContent = file_get_contents($file);

    fwrite($localtempfile, $fileContent);
    fclose($localtempfile);

    $getID3 = new getID3;
    $fileInfo = $getID3->analyze($tmpfname);

    unlink($tmpfname);
    fclose($fileContent);

    $urlParts = parse_url($file);
    parse_str($urlParts['query'], $queryParts);

    $fileInfo['filename'] = $queryParts['unencryptedfilename'];
    $fileInfo['fileUrl'] = $file;
    $fileInfo['fileType'] = $fileType;

    return $fileInfo;
  }
}