<?php

/**
 * SocialEngine
 *
 * @category   Application_Extensions
 * @package    Primemessenger
 * @copyright  Copyright 2017-2018 BigStep Technologies Pvt. Ltd.
 * @license    http://www.socialengineaddons.com/license/
 * @version    MessagesConversations.php 2017-06-30 00:00:00Z SocialEngineAddOns $
 * @author     SocialEngineAddOns
 */

//use PrimeMessenger\JsonCollectionParser\Parser;

class PrimeMessenger_Migrate_Messages_MessagesConversations extends PrimeMessenger_Migrate_DbAbstract {

    protected $_fromTable = 'engine4_messages_conversations';
    protected $_warningMessage = array();
    protected $_priority = 150;
    protected $_jsonFileName = 'chat';
    protected $chats= array();
    protected $roomMergingRecords = array();
    protected $userChatData = array();

    protected function _initPre() {
        $this->_fromTable = $this->getFromPrefix() . 'messages_conversations';
    }

    public function _runPre(){
        // Get Room Merging File . .
        $path = $this->_dataPath . '/rooms_merging_records.json';
        $json = file_get_contents($path);
        $this->roomMergingRecords = json_decode($json, true);
    }

    protected function _translateRow(array $rawData, array &$newData) {
        
        if(!$this->roomMergingRecords[$rawData['conversation_id']]){
           return;
        }

        // Get chat members
        $members = $this->getFromDb()->select()
                ->from($this->getfromPrefix() . 'messages_recipients', 'user_id')
                ->where('conversation_id = ?', $rawData['conversation_id'])
                ->query()
                ->fetchAll(Zend_Db::FETCH_COLUMN);
        $members = array_values(array_filter($members));
        
        if(count($members)<2){
            return;
        }

        //Get Creation date
        $creationDate = null;
        if ($rawData['recipients'] > 1) {
            $creationDate = $this->getFromDb()->select()
                    ->from($this->getfromPrefix() . 'messages_messages', 'date')
                    ->where('conversation_id = ?', $rawData['conversation_id'])
                    ->order(array('message_id ASC'))
                    ->query()
                    ->fetchColumn();
        }

        $data = array();
        $data['_id'] = (string) $rawData['conversation_id'];

        // This is for removing title key from one-to-one conversation
        //if($data['memberCount'] > 2){
            $data['title'] = $rawData['title'] ? $rawData['title'] : 'untitled';
        //}

        $data['ownerId'] = (string) $rawData['user_id'];
        $data['resourceType'] = 'user';
        $updatedAt = $this->getFormatedDate($this->getUpdatedAt($this->roomMergingRecords[$rawData['conversation_id']]["mergeRooms"],$rawData['modified']));

        $data['_membersList'] = $this->getModifiedMembersList($members,$rawData['conversation_id'],$data['ownerId'],$this->roomMergingRecords[$rawData['conversation_id']]["lastMessageId"],$updatedAt);
        
        $data['memberCount'] = count($data['_membersList']);
        $data['isGroup'] = $data['memberCount'] > 2 ? true : false;
    
        // Need To Discuss . . . 
        $data['members'] = array_column($data['_membersList'],'userId');
        
        if($creationDate){
           $data['createdAt'] = ['$date' => $this->getFormatedDate($creationDate)];
        }

        $this->updateUserChatData($data['_membersList'],$rawData['conversation_id']);
        $newData[] = $data;
    }

    public function _runPost(){
        $path = $this->_dataPath . '/users_chat.json';
        file_put_contents($path, json_encode($this->userChatData));
    }

    private function getUpdatedAt($mergeRooms,$roomUpdatedAt) {
        if(count($mergeRooms) ==0){
            return $roomUpdatedAt;
        }

        foreach($mergeRooms as $mergeRoomId) {
            $mergeRoomDate = $this->getFromDb()->select()
                    ->from($this->getfromPrefix() . 'messages_conversations', 'modified')
                    ->where('conversation_id = ?', $mergeRoomId)
                    ->query()
                    ->fetchColumn();
            if($mergeRoomDate > $roomUpdatedAt){
                $roomUpdatedAt = $mergeRoomDate;
            }
        }
        return $roomUpdatedAt;
    }

    private function updateUserChatData($members,$chatId) {
        foreach($members as $member) {
            if($this->userChatData[$member['userId']]){
                $mebersChats = $this->userChatData[$member['userId']];
                array_push($mebersChats, (string) $chatId);
                $this->userChatData[$member['userId']] = $mebersChats;
            }
            else{
                $this->userChatData[$member['userId']] = [(string)$chatId];
            }
        }
        return $this->userChatData;
    }



    private function getModifiedMembersList($members,$roomId,$ownerId,$lastMessageId ,$updatedAt) {
        $membersList = [];
        foreach($members as $memberKey => $memberId) { 
            $user = Engine_Api::_()->getItem('user', $memberId);
            
            if(count($members)== 2){
                $blockedUserIds = $this->getFromDb()->select()
                    ->from($this->getfromPrefix() . 'user_block', 'blocked_user_id')
                    ->where('user_id = ?', $memberId)
                    ->query()
                    ->fetchAll(Zend_Db::FETCH_COLUMN);
                $otherMembId = $memberKey == 0 ? $members[1] : $members[0];
                $isActive = in_array($otherMembId, $blockedUserIds) ? false : true;
            }
            else{
                $isActive = true;
            }

            $isAdmin = $memberId == $ownerId ? true : false;
            $memberList = [
                            "id" => $this->getGuid(),
                            "userId"=> (string) $memberId,
                            "chatId" => (string) $roomId,
                            "newMessageCount"=> 0,
                            "mute" => false,
                            "isActive" => $isActive,
                            "isDeleted" => false,
                            "isAdmin" => $isAdmin,
                            "resourceType" => "user",
                            "lastMessageId" => $lastMessageId,
                            "updatedAt" => ['$date' => $updatedAt]
                        ];
            array_push($membersList,$memberList);
        }
        
        return $membersList;
    }

    private function getGuid()
    {
        if (function_exists('com_create_guid') === true)
        {
            return trim(com_create_guid(), '{}');
        }

        return sprintf('%04X%04X-%04X-%04X-%04X-%04X%04X%04X', mt_rand(0, 65535), mt_rand(0, 65535), mt_rand(0, 65535), mt_rand(16384, 20479), mt_rand(32768, 49151), mt_rand(0, 65535), mt_rand(0, 65535), mt_rand(0, 65535));
    }

    private function getFormatedDate($date)
    {
        $timeStamp = strtotime($date);
        
        // For fixing 0000-00-00 date in database . 
        if($timeStamp<0 || $timeStamp == false){
          $formatedDate = date("c");
        }
        else{
          $formatedDate = date(DATE_ISO8601, $timeStamp);
        }
        return $formatedDate;
    }

}
