<?php

/**
 * SocialEngine
 *
 * @category   Application_Extensions
 * @package    Primemessenger
 * @copyright  Copyright 2017-2018 BigStep Technologies Pvt. Ltd.
 * @license    http://www.socialengineaddons.com/license/
 * @version    MessagesMessages.php 2017-06-30 00:00:00Z SocialEngineAddOns $
 * @author     SocialEngineAddOns
 */
require_once APPLICATION_PATH . '/application/modules/Primemessenger/getid3/getid3.php';

class PrimeMessenger_Migrate_MessagesMessages extends PrimeMessenger_Migrate_DbAbstract {

    protected $_fromTable = 'engine4_messages_messages';
    protected $_warningMessage = array();
    protected $_priority = 100;
    protected $_jsonFileName = 'chat-messages';

    protected function _initPre() {
        $this->_fromTable = $this->getFromPrefix() . 'messages_messages';
    }

    protected function _translateRow(array $rawData, array &$newData) {
        $attachmentType = 'text';
        $attachmentData = array();

        // If Message have no body then not migrate..
        if(!$rawData['body']){
           return;
        }

        // Get attachment data
        if (!empty($rawData['attachment_type']) && !empty($rawData['attachment_id'])) {

            $isItem = Engine_Api::_()->hasItemType($rawData['attachment_type']);

            if(!$isItem){
                return;
            }

            $attachment = Engine_Api::_()->getItem($rawData['attachment_type'], $rawData['attachment_id']);
            if ($attachment instanceof Core_Model_Link) {
                $attachmentType = 'link';
                $attachmentData = array(
                    'title' => $attachment->title,
                    'description' => $attachment->description,
                    'thumbnailUrl' => !empty($attachment->photo_id) ? $this->_getFileUrl($attachment, 'normal') : null,
                    'url' => $attachment->uri
                );
            } else if ($attachment instanceof Video_Model_Video && !$attachment->file_id) {
                $attachmentType = 'link';
                $attachmentData = array(
                    'title' => $attachment->title,
                    'description' => $attachment->description,
                    'thumbnailUrl' => !empty($attachment->photo_id) ? $this->_getFileUrl($attachment, 'normal') : null
                );
                if ($attachment->type = 'youtube') {
                    $attachmentData['url'] = 'www.youtube.com/embed/' . $attachment->code;
                } else {
                    $attachmentData['url'] = 'player.vimeo.com/video/embed/' . $attachment->code;
                }
            } else if (!empty($attachment->file_id)) {
                $storageFile = Engine_Api::_()->storage()->get($attachment->file_id);
                $attachmentType = $storageFile->mime_major;

                if ($attachmentType == 'application') {
                    $attachmentType = 'audio';
                }

                $attachmentData = array(
                    'name' => $storageFile->name,
                    'mimeType' => $storageFile->mime_major . '/' . $storageFile->mime_minor,
                    'size' => $storageFile->size,
                    'extension' => $storageFile->extension,
                    'fileUrl' => $this->_getFileUrl($storageFile->getHref()),
                    'thumbnailUrl' => $this->_getFileUrl($attachment, 'normal')
                );

                if (in_array($attachmentType, ['audio', 'video'])) {
                    $attachmentData['duration'] = $this->getAudioVideoDuration($attachmentData['fileUrl']);
                }
            }
        }

        // Get message recipients
        $recipients = $this->getFromDb()->select()
                ->from($this->getfromPrefix() . 'messages_recipients', 'user_id')
                ->where('conversation_id = ?', $rawData['conversation_id'])
                ->query()
                ->fetchAll(Zend_Db::FETCH_COLUMN);

        // Get room id
        $path = $this->_dataPath . '/rooms_merging_records.json';
        $json = file_get_contents($path);
        $roomMergingRecords = json_decode($json, true);
        $roomId = $roomMergingRecords[$rawData['conversation_id']];

        $data = array();
        $data['roomId'] = $roomId;
        $data['messageId'] = $rawData['message_id'];
        $data['body'] = $rawData['body'];
        $data['ownerId'] = $rawData['user_id'];
        $data['createdAt'] = $rawData['date'];
        $data['recipients'] = $recipients;
        $data['attachmentType'] = $attachmentType;
        $data['attachmentData'] = $attachmentData;

        $newData[] = $data;
    }

    private function getAudioVideoDuration($file)
    {
        // Copy remote file locally to scan with getID3()
        if ($fpRemote = fopen($file, 'rb')) {
            $localtempfilename = tempnam('/tmp', 'getID3');
            if ($fpLocal = fopen($localtempfilename, 'wb')) {
                while ($buffer = fread($fpRemote, 8192)) {
                    fwrite($fpLocal, $buffer);
                }
                fclose($fpLocal);
                // Initialize getID3 engine
                $getID3 = new getID3;
                $fileInfo = $getID3->analyze($localtempfilename);
                $duration = $this->convertTimeIntoSeconds($fileInfo['playtime_string']);
 
                // Delete temporary file
                unlink($localtempfilename);
            }
            fclose($fpRemote);
            return $duration;
        }
    }

    private function convertTimeIntoSeconds($time)
    {
        $time = explode(':', $time);
        if (count($time) == 1) {
            $timeInSeconds = $time[0];
        } elseif(count($time) == 2) {
            $timeInSeconds = $time[0] * 60 + $time[1];
        } elseif(count($time) == 3) {
            $timeInSeconds = $time[0] * 3600 + $time[1] * 60 + $time[2];
        }
        return $timeInSeconds;
    }
}
