<?php

/**
 * SocialEngine
 *
 * @category   Application_Extensions
 * @package    Recipe
 * @copyright  Copyright 2009-2010 BigStep Technologies Pvt. Ltd.
 * @license    http://www.socialengineaddons.com/license/
 * @version    $Id: Core.php 6590 2010-12-31 9:40:21Z SocialEngineAddOns $
 * @author     SocialEngineAddOns
 */
class Recipe_Api_Core extends Core_Api_Abstract {
  const IMAGE_WIDTH = 720;
  const IMAGE_HEIGHT = 720;
  const THUMB_WIDTH = 140;
  const THUMB_HEIGHT = 160;

  public function createPhoto($params, $file) {

    if ($file instanceof Storage_Model_File) {
      $params['file_id'] = $file->getIdentity();
    } else {
      // Get image info and resize
      $file = is_string($file) ? $file : $file['tmp_name'];
      $name = basename($file);
      $path = dirname($file);
      $extension = ltrim(strrchr($file, '.'), '.');

      $mainName = $path . '/m_' . $name . '.' . $extension;
      $thumbName = $path . '/t_' . $name . '.' . $extension;

      $image = Engine_Image::factory();
      $image->open($file)
          ->resize(self::IMAGE_WIDTH, self::IMAGE_HEIGHT)
          ->write($mainName)
          ->destroy();

      $image = Engine_Image::factory();
      $image->open($file)
          ->resize(self::THUMB_WIDTH, self::THUMB_HEIGHT)
          ->write($thumbName)
          ->destroy();

      // Store photos
      $photo_params = array(
              'parent_id' => $params['recipe_id'],
              'parent_type' => 'recipe',
      );

      $photoFile = Engine_Api::_()->storage()->create($mainName, $photo_params);
      $thumbFile = Engine_Api::_()->storage()->create($thumbName, $photo_params);
      $photoFile->bridge($thumbFile, 'thumb.normal');

      $params['file_id'] = $photoFile->file_id; // This might be wrong
      $params['photo_id'] = $photoFile->file_id;

      // Remove temp files
      @unlink($mainName);
      @unlink($thumbName);
    }

    $row = Engine_Api::_()->getDbtable('photos', 'recipe')->createRow();
    $row->setFromArray($params);
    $row->save();
    return $row;
  }

  public function getRecipesPaginator($params = array(), $customParams = null) {

    $paginator = Zend_Paginator::factory($this->getRecipesSelect($params, $customParams));
    if (!empty($params['page'])) {
      $paginator->setCurrentPageNumber($params['page']);
    }

    if (!empty($params['limit'])) {
      $paginator->setItemCountPerPage($params['limit']);
    }

    return $paginator;
  }

  // GET RECIPE SELECT QUERY
  public function getRecipesSelect($params = array(), $customParams = null) {

    $table = Engine_Api::_()->getDbtable('recipes', 'recipe');
    $rName = $table->info('name');

    $tmTable = Engine_Api::_()->getDbtable('TagMaps', 'core');
    $tmName = $tmTable->info('name');

    $searchTable = Engine_Api::_()->fields()->getTable('recipe', 'search')->info('name');

    $locationTable = Engine_Api::_()->getDbtable('locations', 'recipe');
    $locationName = $locationTable->info('name');


    $select = $table->select();
    if (!empty($params['type']) && empty($params['orderby'])) {
      if ($params['type'] == 'browse') {
        $order = Engine_Api::_()->getApi('settings', 'core')->getSetting('recipe.browseorder', 1);
        switch ($order) {
          case "1":
            $select->order($rName . '.creation_date DESC');
            break;
          case "2":
            $select->order($rName . '.view_count DESC');
            break;
          case "3":
            $select->order($rName . '.title');
            break;
          case "4":
            $select->order($rName . '.sponsored' . ' DESC');
            break;
          case "5":
            $select->order($rName . '.featured' . ' DESC');
            break;
          case "6":
            $select->order($rName . '.sponsored' . ' DESC');
            $select->order($rName . '.featured' . ' DESC');
            break;
          case "7":
            $select->order($rName . '.featured' . ' DESC');
            $select->order($rName . '.sponsored' . ' DESC');
            break;
        }
      }
    }


    if (!empty($params['orderby']) && $params['orderby'] == "title") {
      $select->order($rName . '.' . $params['orderby']);
    } else if (!empty($params['orderby'])) {
      $select->order($rName . '.' . $params['orderby'] . ' DESC');
    }
    $select->order($rName . '.creation_date DESC');
    $select = $select
            ->setIntegrityCheck(false)
            ->from($rName)
            ->joinLeft($locationName, "$rName.recipe_id = $locationName.recipe_id   ", array($locationName . '.location'))
            ->group($rName . '.recipe_id');

    if (!empty($params['type'])) {
      if ($params['type'] == 'browse' || $params['type'] == 'home') {
        $select = $select
                ->where($rName . '.approved = ?', '1')
                ->where($rName . '.draft = ?', '1');
        $stusShow = Engine_Api::_()->getApi('settings', 'core')->getSetting('recipe.status.show', 1);
        if ($stusShow == 0) {
          $select = $select
                  ->where($rName . '.closed = ?', '0');
        }
      } elseif ($params['type'] == 'browse_home_zero') {
        $select = $select
                ->where($rName . '.closed = ?', '0')
                ->where($rName . '.approved = ?', '1')
                ->where($rName . '.draft = ?', '1');
      }
      $select->where($rName . ".search = ?", 1);
    }
    if (isset($customParams)) {
      $select = $select
              ->setIntegrityCheck(false)
              ->joinLeft($searchTable, "$searchTable.item_id = $rName.recipe_id");

      $searchParts = Engine_Api::_()->fields()->getSearchQuery('recipe', $customParams);
      foreach ($searchParts as $k => $v) {
        $enable = Engine_Api::_()->getApi('settings', 'core')->getSetting('recipe.proximitysearch', 1);
        if (empty($enable)) {
          $select->where("`{$searchTable}`.{$k}", $v);
        } else {
          if ($k != 'location = ?') {
            $select->where("`{$searchTable}`.{$k}", $v);
          } else {
            if (isset($params['locationmiles']) && empty($params['locationmiles'])) {
              $select->where("`{$searchTable}`.location LIKE ?", "%" . $v . "%");
            } else {

              $longitude = 0;
              $latitude = 0;

              $locationTable = Engine_Api::_()->getDbtable('locations', 'recipe');
              $locationName = $locationTable->info('name');
              $selectLocQuery = $locationTable->select()->where('location = ?', $v);
              $locationValue = $locationTable->fetchRow($selectLocQuery);

              if (empty($locationValue)) {
                $locationResults = Engine_Api::_()->getApi('geoLocation', 'seaocore')->getLatLong(array('location' => $v, 'module' => 'Recipes'));
                if(!empty($locationResults['latitude']) && !empty($locationResults['longitude'])) {
                    $latitude = $locationResults['latitude'];
                    $longitude = $locationResults['longitude'];
                }
              } else {
                $latitude = (float) $locationValue->latitude;
                $longitude = (float) $locationValue->longitude;
              }

              $radius = $params['locationmiles']; // in miles

              $flage = Engine_Api::_()->getApi('settings', 'core')->getSetting('recipe.proximity.search.kilometer', 0);
              if (!empty($flage)) {
                $radius = $radius * (0.621371192);
              }
              //$latitudeRadians = deg2rad($latitude);
        $latitudeSin = "sin(radians($latitude))";
        $latitudeCos = "cos(radians($latitude))";

              $sqlstring = "((degrees(acos($latitudeSin * sin(radians($locationName.latitude)) + $latitudeCos * cos(radians($locationName.latitude)) * cos(radians($longitude - $locationName.longitude)))) * 69.172 <= " . "'" . $radius . "'";
              $sqlstring .= ") OR (" . $locationName . ".latitude = '" . $latitude . "' AND  " . $locationName . ".longitude= '" . $longitude . "'))";
              $select->where($sqlstring);

              $valueTable = Engine_Api::_()->fields()->getTable('recipe', 'values');
              $valueName = $valueTable->info('name');
              $metaName = Engine_Api::_()->fields()->getTable('recipe', 'meta')->info('name');

              $select->join($valueName, "$rName.recipe_id = $valueName.item_id", array())
                  ->join($metaName, $metaName . '.field_id = ' . $valueName . '.field_id', array());
            }
          }
        }
      }
    }

    if (isset($params['city']) && !empty($params['city'])) {
      $valueTable = Engine_Api::_()->fields()->getTable('recipe', 'values');
      $valueName = $valueTable->info('name');
      $metaName = Engine_Api::_()->fields()->getTable('recipe', 'meta')->info('name');

      $select->join($valueName, "$rName.recipe_id = $valueName.item_id", array())
          ->join($metaName, $metaName . '.field_id = ' . $valueName . '.field_id', array())
          ->where($locationName . ".city = ?", $params['city']);
    }

    // Start Network work
    if (!empty($params['type'])) {
      if ($params['type'] == 'browse' || $params['type'] == 'home') {

        $enableNetwork = Engine_Api::_()->getApi('settings', 'core')->getSetting('recipe.network', 0);
        if (!empty($enableNetwork) || (isset($params['show']) && $params['show'] == "3")) {
          $viewer = Engine_Api::_()->user()->getViewer();
          $networkMembershipTable = Engine_Api::_()->getDbtable('membership', 'network');
          $viewerNetwork = $networkMembershipTable->fetchRow(array('user_id = ?' => $viewer->getIdentity()));
          if (!empty($viewerNetwork)) {
            $networkMembershipName = $networkMembershipTable->info('name');
            $select
                ->join($networkMembershipName, "`{$rName}`.owner_id = `{$networkMembershipName}`.user_id  ", null)
                ->join($networkMembershipName, "`{$networkMembershipName}`.`resource_id`=`{$networkMembershipName}_2`.resource_id", null)
                ->where("`{$networkMembershipName}_2`.user_id = ? ", $viewer->getIdentity())
            ;
          }
        }
      }
    }
    // End Network work
    if (!empty($params['user_id']) && is_numeric($params['user_id'])) {
      $select->where($rName . '.owner_id = ?', $params['user_id']);
    }

    if (!empty($params['user']) && $params['user'] instanceof User_Model_User) {
      $select->where($rName . '.owner_id = ?', $params['user_id']->getIdentity());
    }

    if (!empty($params['users'])) {
      $str = (string) ( is_array($params['users']) ? "'" . join("', '", $params['users']) . "'" : $params['users'] );
      $select->where($rName . '.owner_id in (?)', new Zend_Db_Expr($str));
    }

    if (empty($params['users']) && isset($params['show']) && $params['show'] == '2') {
      $select->where($rName . '.owner_id = ?', '0');
    }

    if (!empty($params['tag'])) {
      $select
          ->setIntegrityCheck(false)
          ->joinLeft($tmName, "$tmName.resource_id = $rName.recipe_id")
          ->where($tmName . '.resource_type = ?', 'recipe')
          ->where($tmName . '.tag_id = ?', $params['tag']);
    }

    if (!empty($params['category'])) {
      $select->where($rName . '.category_id = ?', $params['category']);
    }

    if (!empty($params['subcategory'])) {
      $select->where($rName . '.subcategory_id = ?', $params['subcategory']);
    }

    if (isset($params['closed']) && $params['closed'] != "") {
      $select->where($rName . '.closed = ?', $params['closed']);
    }

    // Could we use the search indexer for this?
    if (!empty($params['search'])) {


      $tagName = Engine_Api::_()->getDbtable('Tags', 'core')->info('name');
      $select
          ->setIntegrityCheck(false)
          ->joinLeft($tmName, "$tmName.resource_id = $rName.recipe_id and " . $tmName . ".resource_type = 'recipe'")
          ->joinLeft($tagName, "$tagName.tag_id = $tmName.tag_id");

      $select->where($rName . ".title LIKE ? OR " . $rName . ".body LIKE ? OR " . $tagName . ".text LIKE ? ", '%' . $params['search'] . '%');
    }

    if (!empty($params['start_date'])) {
      $select->where($rName . ".creation_date > ?", date('Y-m-d', $params['start_date']));
    }

    if (!empty($params['end_date'])) {
      $select->where($rName . ".creation_date < ?", date('Y-m-d', $params['end_date']));
    }

    if (!empty($params['has_photo'])) {
      $select->where($rName . ".photo_id > ?", 0);
    }

    return $select;
  }

  // CHECK VIDEO PLUGIN ENABLE / DISABLE
  public function enableVideoPlugin() {
    return Engine_Api::_()->getDbtable('modules', 'core')->isModuleEnabled('video');
  }

  // GET CATEGORIES RECIPE
  public function getCategories($home_page_display=0) {

    $cateTable = Engine_Api::_()->getDbtable('categories', 'recipe');
    $cateName = $cateTable->info('name');

    $select = $cateTable->select()->where('cat_dependency =?', 0)->order('cat_order');

    if (!empty($home_page_display)) {
      $table = Engine_Api::_()->getDbtable('recipes', 'recipe');
      $rName = $table->info('name');
      $select->setIntegrityCheck(false)
          ->from($cateName)
          ->joinLeft($rName, $rName . '.category_id = ' . $cateName . '.category_id', array('count(' . $rName . '.category_id ) as count'))
          ->where($rName . '.approved = 1')
          ->where($rName . '.draft = ?', '1')
          ->where($rName . '.closed = ?', '0')
          ->group($cateName . '.category_id');
    }
    return $cateTable->fetchAll($select);
  }

  // GET CATEGORY
  public function getCategory($category_id) {
    return Engine_Api::_()->getDbtable('categories', 'recipe')->find($category_id)->current();
  }

  // GET SubCATEGORY
  public function getSubCategory($subcategory_id) {
    return Engine_Api::_()->getDbtable('categories', 'recipe')->find($subcategory_id)->current();
  }

  // GET RECIPE VIEW PAGE LINK
  public function getHref($recipe_id, $owner_id, $slug =null) {

    $params = array_merge(array('user_id' => $owner_id, 'recipe_id' => $recipe_id, 'slug' => $slug));
    return Zend_Controller_Front::getInstance()->getRouter()
        ->assemble($params, 'recipe_entry_view', true);
  }

  // GET THE RATINGS OF RECIPE
  public function getRatings($recipe_id) {
    return Engine_Api::_()->getDbTable('ratings', 'recipe')->getRatings($recipe_id);
  }

  // CHECK RATING FOR RECIPE
  public function checkRated($recipe_id, $user_id) {
    return Engine_Api::_()->getDbTable('ratings', 'recipe')->checkRated($recipe_id, $user_id);
  }

  // SET THE RATING OF RECIPE
  public function setRating($recipe_id, $user_id, $rating) {
    if (!$this->checkRated($recipe_id, $user_id)) {
      // create rating
      Engine_Api::_()->getDbTable('ratings', 'recipe')->insert(array(
              'recipe_id' => $recipe_id,
              'user_id' => $user_id,
              'rating' => $rating
      ));
    }
  }

  // COUNTING THE RATING OF RECIPE
  public function ratingCount($recipe_id) {
    return Engine_Api::_()->getDbtable('ratings', 'recipe')->ratingCount($recipe_id);
  }

  // GET LINK OF PHOTO VIEW PAGE
  public function getHreflink($image, $params = array()) {

    $params = array_merge(array(
                'route' => 'recipe_image_specific',
                'reset' => true,
                'recipe_id' => $image->collection_id,
                'photo_id' => $image->getIdentity(),
            ), $params);
    $route = $params['route'];
    $reset = $params['reset'];
    unset($params['route']);
    unset($params['reset']);

    return Zend_Controller_Front::getInstance()->getRouter()
        ->assemble($params, $route, $reset);
  }

  // get recipe recipe relative to recipe owner
  public function userRecipe($owner_id, $recipe_id) {

    $limit = 10;
    $table = Engine_Api::_()->getDbtable('recipes', 'recipe');
    $rName = $table->info('name');
    $select = $table->select()
            ->where($rName . '.closed = ?', '0')
            ->where($rName . '.approved = ?', '1')
            ->where($rName . '.draft = ?', '1')
            ->where($rName . '.recipe_id <> ?', $recipe_id)
            ->where($rName . '.owner_id = ?', $owner_id);
    $select->where($rName . ".search = ?", 1);
    $limit = (int) Engine_Api::_()->getApi('settings', 'core')->getSetting('recipe.userrecipe.widgets', 3);

    // Start Network work
    $enableNetwork = Engine_Api::_()->getApi('settings', 'core')->getSetting('recipe.network', 0);
    if (!empty($enableNetwork)) {
      $viewer = Engine_Api::_()->user()->getViewer();
      $networkMembershipTable = Engine_Api::_()->getDbtable('membership', 'network');
      $viewerNetwork = $networkMembershipTable->fetchRow(array('user_id = ?' => $viewer->getIdentity()));

      if (!empty($viewerNetwork)) {
        $select->setIntegrityCheck(false)
            ->from($rName);
        $networkMembershipName = $networkMembershipTable->info('name');
        $select
            ->join($networkMembershipName, "`{$rName}`.owner_id = `{$networkMembershipName}`.user_id  ", null)
            ->join($networkMembershipName, "`{$networkMembershipName}`.`resource_id`=`{$networkMembershipName}_2`.resource_id", null)
            ->where("`{$networkMembershipName}_2`.user_id = ? ", $viewer->getIdentity())
            ->group($rName . '.recipe_id')
        ;
      }
    }
    // End Network work
    $select = $select->limit($limit);

    return $table->fetchALL($select);
  }

  // get lising according to requerment
  public function getLising($recipetype, $params =array()) {

    $limit = 10;
    $table = Engine_Api::_()->getDbtable('recipes', 'recipe');
    $rName = $table->info('name');
    $coreTable = Engine_Api::_()->getDbtable('likes', 'core');
    $coreName = $coreTable->info('name');
    $select = $table->select()
            ->where($rName . '.closed = ?', '0')
            ->where($rName . '.approved = ?', '1')
            ->where($rName . '.draft = ?', '1');
    $select->where($rName . ".search = ?", 1);
    // Start Network work
    $enableNetwork = Engine_Api::_()->getApi('settings', 'core')->getSetting('recipe.network', 0);
    if (!empty($enableNetwork)) {
      $viewer = Engine_Api::_()->user()->getViewer();
      $networkMembershipTable = Engine_Api::_()->getDbtable('membership', 'network');
      $viewerNetwork = $networkMembershipTable->fetchRow(array('user_id = ?' => $viewer->getIdentity()));

      if (!empty($viewerNetwork)) {
        $select->setIntegrityCheck(false)
            ->from($rName);
        $networkMembershipName = $networkMembershipTable->info('name');
        $select
            ->join($networkMembershipName, "`{$rName}`.owner_id = `{$networkMembershipName}`.user_id  ", null)
            ->join($networkMembershipName, "`{$networkMembershipName}`.`resource_id`=`{$networkMembershipName}_2`.resource_id", null)
            ->where("`{$networkMembershipName}_2`.user_id = ? ", $viewer->getIdentity())
            ->group($rName . ".recipe_id")
        ;
      }
    }
    // End Network work

    if ($recipetype == 'Most Viewed') {
      $select = $select->where($rName . '.view_count <> ?', '0')->order($rName . '.view_count DESC');
      $ShowViewArray = Engine_Api::_()->getApi('settings', 'core')->getSetting('recipe.ajax.widgets.layout', array("0" => "1", "1" => "2", "2" => "3"));
      $limit = 0;
      $temp_limit = 0;
      if (in_array("2", $ShowViewArray))
        $limit = (int) Engine_Api::_()->getApi('settings', 'core')->getSetting('recipe.popular.thums', 15);
      if (in_array("1", $ShowViewArray))
        $temp_limit = (int) Engine_Api::_()->getApi('settings', 'core')->getSetting('recipe.popular.widgets', 10);
      if ($limit < $temp_limit) {
        $limit = $temp_limit;
      }
    }
    if ($recipetype == 'Most Viewed Recipe') {
      $select = $select->where($rName . '.view_count <> ?', '0')->order($rName . '.view_count DESC');
      $limit = (int) Engine_Api::_()->getApi('settings', 'core')->getSetting('recipe.popular.widgets', 10);
    }
    if ($recipetype == 'Recently Posted Recipe') {
      $select = $select->order($rName . '.creation_date DESC');
      $limit = (int) Engine_Api::_()->getApi('settings', 'core')->getSetting('recipe.recent.widgets', 10);
    }

    if ($recipetype == 'Random Recipe') {
      $select->order('RAND() DESC ');
      $limit = (int) Engine_Api::_()->getApi('settings', 'core')->getSetting('recipe.random.widgets', 10);
    }
    if ($recipetype == 'Most Commented') {
      $select = $select->where($rName . '.comment_count <> ?', '0')->order($rName . '.comment_count DESC');
      $limit = (int) Engine_Api::_()->getApi('settings', 'core')->getSetting('recipe.comment.widgets', 3);
    }

    if ($recipetype == 'Most Rated') {
      $select = $select->where($rName . '.rating <> ?', '0')->order($rName . '.rating DESC');
      $limit = (int) Engine_Api::_()->getApi('settings', 'core')->getSetting('recipe.rate.widgets', 3);
    }

    if ($recipetype == 'Recently Posted') {
      $select = $select->order($rName . '.creation_date DESC');
      $ShowViewArray = Engine_Api::_()->getApi('settings', 'core')->getSetting('recipe.ajax.widgets.layout', array("0" => "1", "1" => "2", "2" => "3"));
      $limit = 0;
      $temp_limit = 0;
      if (in_array("2", $ShowViewArray))
        $limit = (int) Engine_Api::_()->getApi('settings', 'core')->getSetting('recipe.recent.thumbs', 15);
      if (in_array("1", $ShowViewArray))
        $temp_limit = (int) Engine_Api::_()->getApi('settings', 'core')->getSetting('recipe.recent.widgets', 10);

      if ($limit < $temp_limit) {
        $limit = $temp_limit;
      }
    }

    if ($recipetype == 'Featured') {
      $select = $select->where($rName . '.featured = ?', '1');
      $ShowViewArray = Engine_Api::_()->getApi('settings', 'core')->getSetting('recipe.ajax.widgets.layout', array("0" => "1", "1" => "2", "2" => "3"));
      $limit = 0;
      $temp_limit = 0;
      if (in_array("2", $ShowViewArray))
        $limit = (int) Engine_Api::_()->getApi('settings', 'core')->getSetting('recipe.featured.thumbs', 15);
      if (in_array("1", $ShowViewArray))
        $temp_limit = (int) Engine_Api::_()->getApi('settings', 'core')->getSetting('recipe.featured.recipe', 10);

      if ($limit < $temp_limit) {
        $limit = $temp_limit;
      }
    }
    if ($recipetype == 'Sponosred') {
      $select = $select->where($rName . '.sponsored = ?', '1');
      $ShowViewArray = Engine_Api::_()->getApi('settings', 'core')->getSetting('recipe.ajax.widgets.layout', array("0" => "1", "1" => "2", "2" => "3"));
      $limit = 0;
      $temp_limit = 0;
      if (in_array("2", $ShowViewArray))
        $limit = (int) Engine_Api::_()->getApi('settings', 'core')->getSetting('recipe.sponsored.thumbs', 15);
      if (in_array("1", $ShowViewArray))
        $temp_limit = (int) Engine_Api::_()->getApi('settings', 'core')->getSetting('recipe.sponsored.recipe', 10);

      if ($limit < $temp_limit) {
        $limit = $temp_limit;
      }
    }
    if ($recipetype == 'Sponsored Recipe') {
      $select = $select->where($rName . '.sponsored = ?', '1');
      $limit = (int) Engine_Api::_()->getApi('settings', 'core')->getSetting('recipe.sponserdrecipe.widgets', 4);
    }

    if ($recipetype == 'Total Sponsored Recipe') {
      $select = $select->where($rName . '.sponsored = ?', '1');
    }

    if ($recipetype == 'Sponsored Recipe AJAX') {
      $select = $select->where($rName . '.sponsored = ?', '1');

      $limit = (int) Engine_Api::_()->getApi('settings', 'core')->getSetting('recipe.sponserdrecipe.widgets', 4) * 2;
    }
    if ($recipetype == 'Featured Slideshow') {
      $select = $select->where($rName . '.featured = ?', '1');
      $limit = (int) Engine_Api::_()->getApi('settings', 'core')->getSetting('recipe.feature.widgets', 10);
    }

    if ($recipetype == 'Most Likes') {
      $enableNetwork = Engine_Api::_()->getApi('settings', 'core')->getSetting('recipe.network', 0);

      $viewer = Engine_Api::_()->user()->getViewer();
      $networkMembershipTable = Engine_Api::_()->getDbtable('membership', 'network');
      $viewerNetwork = $networkMembershipTable->fetchRow(array('user_id = ?' => $viewer->getIdentity()));

      if (empty($viewerNetwork) || empty($enableNetwork)) {
        $select->setIntegrityCheck(false)
            ->from($rName);
      }

      $select->join($coreName, "$rName.recipe_id = $coreName.resource_id   ", array('COUNT( ' . $coreName . '.resource_id ) as count_likes'))
          ->group($coreName . '.resource_id')
          ->where($coreName . '.resource_type = ?', 'recipe');
      $select = $select->order('count_likes DESC');
      $limit = (int) Engine_Api::_()->getApi('settings', 'core')->getSetting('recipe.likes.widgets', 3);
    }

    if ($recipetype == 'Random') {
      $select->order('RAND() DESC ');
      $ShowViewArray = Engine_Api::_()->getApi('settings', 'core')->getSetting('recipe.ajax.widgets.layout', array("0" => "1", "1" => "2", "2" => "3"));
      $limit = 0;
      $temp_limit = 0;
      if (in_array("2", $ShowViewArray))
        $limit = (int) Engine_Api::_()->getApi('settings', 'core')->getSetting('recipe.random.thumbs', 15);
      if (in_array("1", $ShowViewArray))
        $temp_limit = (int) Engine_Api::_()->getApi('settings', 'core')->getSetting('recipe.random.widgets', 10);
      if ($limit < $temp_limit) {
        $limit = $temp_limit;
      }
    } else if ($recipetype == 'Featured Slideshow') {
      $select->order('RAND() DESC ');
    } else {
      $select->order($rName . '.recipe_id DESC');
    }

    if (isset($params['limit']) && !empty($params['limit'])) {
      $limit = $params['limit'];
    }

    if (($recipetype == 'Sponsored Recipe AJAX' || $recipetype == 'Sponsored Recipe' ) && !empty($params['start_index'])) {
      $select = $select->limit($limit, $params['start_index']);
    } else {
      if ($recipetype != 'Total Sponsored Recipe') {
        $select = $select->limit($limit);
      }
    }

    if ($recipetype == 'Recently Posted' || $recipetype == 'Most Viewed' || $recipetype == 'Random' || $recipetype == 'Featured' || $recipetype == 'Sponosred') {
      $locationTable = Engine_Api::_()->getDbtable('locations', 'recipe');
      $locationName = $locationTable->info('name');

      $enableNetwork = Engine_Api::_()->getApi('settings', 'core')->getSetting('recipe.network', 0);
      $viewer = Engine_Api::_()->user()->getViewer();
      $networkMembershipTable = Engine_Api::_()->getDbtable('membership', 'network');
      $viewerNetwork = $networkMembershipTable->fetchRow(array('user_id = ?' => $viewer->getIdentity()));

      if (empty($viewerNetwork) || empty($enableNetwork)) {
        $select->setIntegrityCheck(false)
            ->from($rName);
      }
      $select->joinLeft($locationName, "$rName.recipe_id = $locationName.recipe_id   ", array('location'))
          ->group("$rName.recipe_id");
    }

    if ($recipetype == 'Season Recipe') {
      $limit = (int) Engine_Api::_()->getApi('settings', 'core')->getSetting('recipe.season.recipe', 3);
      $today = date('m');
      $select_end_month = $table->select()->from($rName, array('end_month'));
      $result_end_month = $select_end_month->query()->fetchAll();
      $end_month = array();
      $count_result = count($result_end_month);
      $end_month = '';
			if (!empty ($result_end_month[0]))
      $end_month.= $result_end_month[0]['end_month'];
      $i = 1;
      while ($i < $count_result) {
        $end_month.= ',' . $result_end_month[$i]['end_month'];
        $i++;
      }
			if (!empty($end_month))
      $select = $select->where($rName . '.start_month = ?', $today)->where($rName . '.end_month IN (' . $end_month . ')');
			$select->limit($limit);
    }

    return $table->fetchALL($select);
  }

  // get lising according to Discussion
  public function getDiscussedRecipe($recipetype, $params =array()) {

    $recipetable = Engine_Api::_()->getDbTable('recipes', 'recipe');
    $recipe_tableName = $recipetable->info('name');

    $topictable = Engine_Api::_()->getDbTable('topics', 'recipe');
    $topic_tableName = $topictable->info('name');
    $select = $recipetable->select()->setIntegrityCheck(false)
            ->from($recipe_tableName)
            ->join($topic_tableName, $topic_tableName . '.recipe_id = ' . $recipe_tableName . '.recipe_id', array('count(*) as counttopics', '(sum(post_count) - count(*) ) as total_count'))
            ->where($recipe_tableName . '.closed = ?', '0')
            ->where($recipe_tableName . '.approved = ?', '1')
            ->where($recipe_tableName . '.draft = ?', '1')
            ->where($topic_tableName . '.post_count > ?', '1')
            ->group($topic_tableName . '.recipe_id')
            ->order('total_count DESC')
            ->order('counttopics DESC')
            ->limit(Engine_Api::_()->getApi('settings', 'core')->getSetting('recipe.mostdiscussed.widgets', 10));
    $select->where($recipe_tableName . ".search = ?", 1);

    // Start Network work
    $enableNetwork = Engine_Api::_()->getApi('settings', 'core')->getSetting('recipe.network', 0);
    if (!empty($enableNetwork)) {
      $viewer = Engine_Api::_()->user()->getViewer();
      $networkMembershipTable = Engine_Api::_()->getDbtable('membership', 'network');
      $viewerNetwork = $networkMembershipTable->fetchRow(array('user_id = ?' => $viewer->getIdentity()));

      if (!empty($viewerNetwork)) {

        $networkMembershipName = $networkMembershipTable->info('name');
        $select
            ->join($networkMembershipName, "`{$recipe_tableName}`.owner_id = `{$networkMembershipName}`.user_id  ", null)
            ->join($networkMembershipName, "`{$networkMembershipName}`.`resource_id`=`{$networkMembershipName}_2`.resource_id", null)
            ->where("`{$networkMembershipName}_2`.user_id = ? ", $viewer->getIdentity())
        ;
      }
    }
    // End Network work
    return $recipetable->fetchALL($select);
  }

// APROVED/ DISAPROVED EMAIL NOTIFICATION FOR CLASSIFEID
  public function aprovedEmailNotification(Core_Model_Item_Abstract $object, $params=array()) {

    $email = Engine_Api::_()->getApi('settings', 'core')->core_mail_from;

    Engine_Api::_()->getApi('mail', 'core')->sendSystem($params['mail_id'], 'RECIPE_APPROVED_EMAIL_NOTIFICATION', array(
            'host' => $_SERVER['HTTP_HOST'],
            'subject' => $params['subject'],
            'title' => $params['title'],
            'message' => $params['message'],
            'object_link' => $this->getHref($object->recipe_id, $object->owner_id, $object->getSlug()),
            'email' => $email,
            'queue' => false
    ));
  }

  // TURNCATION OF STRINGS
  public function turncation($string, $length=null) {

    if (empty($length)) {
      $length = Engine_Api::_()->getApi('settings', 'core')->getSetting('recipe.title.turncation', 16);
    }

    $string = strip_tags($string);
    return Engine_String::strlen($string) > $length ? Engine_String::substr($string, 0, ($length - 3)) . '...' : $string;
  }

  // Check location
  public function enableLocation($params=array()) {
    $recipe_recent_info = Zend_Registry::get('recipe_recent_info');
    if (!empty($recipe_recent_info)) {
      $check = Engine_Api::_()->getApi('settings', 'core')->getSetting('recipe.location', 1);

      if (!empty($check)) {
        $metaTable = Engine_Api::_()->fields()->getTable('recipe', 'meta');
        $metaName = $metaTable->info('name');


        $select = $metaTable->select()
                ->setIntegrityCheck(false)
                ->where($metaName . '.type = ?', 'Location');

        $row = $metaTable->fetchRow($select);
        if (empty($row))
          $check = 0;
      }
    } else {
      exit();
    }

    return $check;
  }

  // Get location
  public function getLocation($params=array()) {

    $valueTable = Engine_Api::_()->fields()->getTable('recipe', 'values');
    $valueName = $valueTable->info('name');
    $metaName = Engine_Api::_()->fields()->getTable('recipe', 'meta')->info('name');

    $locationTable = Engine_Api::_()->getDbtable('locations', 'recipe');
    $locationName = $locationTable->info('name');

    $select = $valueTable->select()
            ->setIntegrityCheck(false)
            ->from($valueName)
            ->join($metaName, $metaName . '.field_id = ' . $valueName . '.field_id', array())
            ->join($locationName, $locationName . '.recipe_id = ' . $valueName . '.item_id', array($locationName . '.*'))
            ->where($metaName . '.type = ?', 'Location')
            ->order($metaName . '.field_id');

    if (isset($params['id'])) {
      $select->where($valueName . '.item_id = ?', $params['id']);
      return $valueTable->fetchRow($select);
    }

    if (isset($params['recipe_ids'])) {

      $idsStr = (string) ( is_array($params['recipe_ids']) ? "'" . join("', '", $params['recipe_ids']) . "'" : $params['recipe_ids'] );

      $select->where($valueName . '.item_id IN (?)', new Zend_Db_Expr($idsStr));
      return $valueTable->fetchAll($select);
    }
  }

  // Set location
  public function setLocation($id) {

    $valueTable = Engine_Api::_()->fields()->getTable('recipe', 'values');
    $valueName = $valueTable->info('name');
    $metaName = Engine_Api::_()->fields()->getTable('recipe', 'meta')->info('name');

    $select = $valueTable->select()
            ->setIntegrityCheck(false)
            ->from($valueName)
            ->join($metaName, $metaName . '.field_id = ' . $valueName . '.field_id', array())
            ->where($metaName . '.type = ?', 'Location')
            ->where($valueName . '.item_id = ?', $id)
            ->order($metaName . '.field_id');

    $location = $valueTable->fetchRow($select);

    if (!empty($location)) {
      $locationTable = Engine_Api::_()->getDbtable('locations', 'recipe');
      $locationName = $locationTable->info('name');
      $selectLocIdQuery = $locationTable->select()->where('recipe_id = ?', $id);
      $locationRow = $locationTable->fetchRow($selectLocIdQuery);

      $selectLocQuery = $locationTable->select()->where('location = ?', $location->value);
      $locationValue = $locationTable->fetchRow($selectLocQuery);
      $table = Engine_Api::_()->getDbtable('modules', 'core');
      $select = $table->select()->where('name = ?', 'seaocore');
      $row = $table->fetchRow($select);
      $enableSocialengineaddon = 0;
      if (!empty($row)) {
        if (!empty($row->enabled))
          $enableSocialengineaddon = 1;
      }

      if (empty($locationValue)) {
        $getSEALocation = array();
        if (!empty($enableSocialengineaddon)) {
          $getSEALocation = Engine_Api::_()->getDbtable('locations', 'seaocore')->getLocation(array('location' => $location->value));
        }
        if (empty($getSEALocation)) {
          $locationLocal = $location->value;
          $urladdress = str_replace(" ", "+", $locationLocal);
          // Initialize delay in geocode speed
          $delay = 0;
          // Iterate through the rows, geocoding each address
          $geocode_pending = true;
          while ($geocode_pending) {
            $request_url = "https://maps.googleapis.com/maps/api/geocode/json?address=$urladdress";
            $ch = curl_init();
            $timeout = 5;
            curl_setopt($ch, CURLOPT_URL, $request_url);
            curl_setopt($ch, CURLOPT_CONNECTTIMEOUT, $timeout);
            ob_start();
            curl_exec($ch);
            curl_close($ch);
              
						$get_value = ob_get_contents();
						if (empty($get_value)) {
						$get_value = @file_get_contents($request_url);
						}
						$json_resopnse = !empty($get_value) ? Zend_Json::decode($get_value) : array();
              
            ob_end_clean();
            $status = $json_resopnse['status'];
            if (strcmp($status, "OK") == 0) {
              // Successful geocode
              $geocode_pending = false;
              $result = $json_resopnse['results'];

              // Format: Longitude, Latitude, Altitude
              $lat = $result[0]['geometry']['location']['lat'];
              $lng = $result[0]['geometry']['location']['lng'];
              $f_address = $result[0]['formatted_address'];


              $len_add = count($result[0]['address_components']);

              $address = '';
              $country = '';
              $state = '';
              $zip_code = '';
              $city = '';
              for ($i = 0; $i < $len_add; $i++) {
                $types_location = $result[0]['address_components'][$i]['types'][0];

                if ($types_location == 'country') {

                  $country = $result[0]['address_components'][$i]['long_name'];
                } else if ($types_location == 'administrative_area_level_1') {
                  $state = $result[0]['address_components'][$i]['long_name'];
                } else if ($types_location == 'administrative_area_level_2') {
                  $city = $result[0]['address_components'][$i]['long_name'];
                } else if ($types_location == 'postal_code' || $types_location == 'zip_code') {
                  $zip_code = $result[0]['address_components'][$i]['long_name'];
                } else if ($types_location == 'street_address') {
                  if ($address == '')
                    $address = $result[0]['address_components'][$i]['long_name'];
                  else
                    $address= $address . ',' . $result[0]['address_components'][$i]['long_name'];
                }else if ($types_location == 'locality') {
                  if ($address == '')
                    $address = $result[0]['address_components'][$i]['long_name'];
                  else
                    $address= $address . ',' . $result[0]['address_components'][$i]['long_name'];
                }else if ($types_location == 'route') {
                  if ($address == '')
                    $address = $result[0]['address_components'][$i]['long_name'];
                  else
                    $address= $address . ',' . $result[0]['address_components'][$i]['long_name'];
                }else if ($types_location == 'sublocality') {
                  if ($address == '')
                    $address = $result[0]['address_components'][$i]['long_name'];
                  else
                    $address= $address . ',' . $result[0]['address_components'][$i]['long_name'];
                }
              }
              $db = Engine_Db_Table::getDefaultAdapter();
              $db->beginTransaction();

              try {
                // Create recipe
                $loctionV = array();
                $loctionV['recipe_id'] = $id;
                $loctionV['latitude'] = $lat;
                $loctionV['location'] = $locationLocal;
                $loctionV['longitude'] = $lng;
                $loctionV['formatted_address'] = $f_address;
                $loctionV['country'] = $country;
                $loctionV['state'] = $state;
                $loctionV['zipcode'] = $zip_code;
                $loctionV['city'] = $city;
                $loctionV['address'] = $address;
                $loctionV['zoom'] = 16;
                if (empty($locationRow))
                  $locationRow = $locationTable->createRow();

                $locationRow->setFromArray($loctionV);
                $locationRow->save();
                // Commit
                $db->commit();
                if (!empty($enableSocialengineaddon)) {
                   $location = Engine_Api::_()->getDbtable('locations', 'seaocore')->setLocation($loctionV);
                }

              } catch (Exception $e) {
                $db->rollBack();
                throw $e;
              }
            } else if (strcmp($status, "620") == 0) {
              // sent geocodes too fast
              $delay += 100000;
            } else {
              // failure to geocode
              $geocode_pending = false;
              echo "Address " . $locationLocal . " failed to geocoded. ";
              echo "Received status " . $status . "\n";
            }
            usleep($delay);
          }
        } else {
          $db = Engine_Db_Table::getDefaultAdapter();
          $db->beginTransaction();

          try {
            // Create recipe
            $loctionV = array();
            if (empty($locationRow))
              $locationRow = $locationTable->createRow();
            $value = $getSEALocation->toarray();
						unset($value['location_id']);
            $value['recipe_id'] = $id;
            $locationRow->setFromArray($value);
            $locationRow->save();
            // Commit
            $db->commit();
          } catch (Exception $e) {
            $db->rollBack();
            throw $e;
          }
        }
      } else {
        $db = Engine_Db_Table::getDefaultAdapter();
        $db->beginTransaction();

        try {
          // Create recipe
          $loctionV = array();
          if (empty($locationRow))
            $locationRow = $locationTable->createRow();
          $value = $locationValue->toarray();
          unset($value['location_id']);
          $value['recipe_id'] = $id;
          $locationRow->setFromArray($value);
          $locationRow->save();
          // Commit
          $db->commit();
        } catch (Exception $e) {
          $db->rollBack();
          throw $e;
        }
      }
    }
  }

  public function getUserCategrories($category_id, $subcategory_id) {

    $tables = Engine_Api::_()->getDbTable('categories', 'recipe');
    $recipetableName = $tables->info('name');
    $select = $tables->select()
            ->from($recipetableName, 'category_name')
            ->where('category_id = ?', $category_id)
            ->orwhere('category_id = ?', $subcategory_id)
            ->order('category_id');
    $tablesInfo = $tables->fetchAll($select)->toarray();
    return $tablesInfo;
  }

  public function getArchiveRecipe($user_id = null) {
    $table = Engine_Api::_()->getDbtable('recipes', 'recipe');
    $rName = $table->info('name');

    $select = $table->select()
            ->from($rName);

    if (!empty($params['user_id']) && is_numeric($params['user_id'])) {
      $select->where($rName . '.owner_id = ?', $params['user_id']);
    }
    return $table->fetchAll($select);
  }

  public function getcategoryslug($categoryname) {
    if (strlen($categoryname) > 32) {
      $categoryname = Engine_String::substr($categoryname, 0, 32) . '...';
    }
    $categoryname = preg_replace('/([a-z])([A-Z])/', '$1 $2', $categoryname);
    $categoryname = preg_replace('/[^a-z0-9-]+/i', '-', $categoryname);
    $categoryname = preg_replace('/-+/', '-', $categoryname);
    $categoryname = trim($categoryname, '-');
    if (!$categoryname) {
      $categoryname = '-';
    }
    return $categoryname;
  }

  public function removeMapLink($string) {
    if (!empty($string)) {
      $reqStartMapPaterrn = (!empty($_ENV["HTTPS"]) && 'on' == strtolower($_ENV["HTTPS"])) ? "https://":"http://" . 'maps.google.com/?q=';
      $reqEndPatern = '>map</a>]';
      $positionMapStart = strpos($string, $reqStartMapPaterrn);
      if ($positionMapStart !== false) {
        $reqStartPatern = "<a";
        $positionStart = strpos($string, $reqStartPatern, ($positionMapStart - 10));
        $positionEnd = strpos($string, $reqEndPatern, $positionStart);
        if ($positionStart < $positionMapStart && $positionMapStart < $positionEnd)
          $string = substr_replace($string, "", $positionStart - 1, ($positionEnd + 10) - $positionStart);
      }
    }
    return $string;
  }

  public function allowVideo($subject_recipe, $viewer) {
    $flage = true;
    // Check for video
    $allowed_upload_videoEnable = $this->enableVideoPlugin();
    if (empty($allowed_upload_videoEnable))
      return false;
    $allowed_upload_video_video = Engine_Api::_()->authorization()->getPermission($viewer->level_id, 'video', 'create');
    if (empty($allowed_upload_video_video))
      return false;
    $allowed_upload_video = Engine_Api::_()->authorization()->isAllowed($subject_recipe, $viewer, 'video');
    if (empty($allowed_upload_video))
      return false;
    return (bool) $flage;
  }
  
//   //Check for member level setings base of Listing Owner.
//   public function allowOverviewOfOwner($user) {
//     $flage = true;
//     // Check for overview
//     $flage = Engine_Api::_()->authorization()->getPermission($user->level_id, 'recipe', 'overview'); 
//     return (bool) $flage;
//   }


  public function recent_friendrecipe() {
    $limit = (int) Engine_Api::_()->getApi('settings', 'core')->getSetting('recipe.recentlyfriend_view', 3);
    $viewer_id = Engine_Api::_()->user()->getViewer()->getIdentity();
    $viewtable = Engine_Api::_()->getDbtable('vieweds', 'recipe');
    $viewname = $viewtable->info('name');

    $membership_table = Engine_Api::_()->getDbtable('membership', 'user');
    $member_name = $membership_table->info('name');

    $recipe_table = Engine_Api::_()->getDbtable('recipes', 'recipe');
    $recipe_name = $recipe_table->info('name');

    $select = $recipe_table->select()
            ->setIntegrityCheck(false)
            ->from($recipe_name)
            ->joinInner($viewname, "$recipe_name . recipe_id = $viewname . recipe_id")
            ->joinInner($member_name, "$member_name . user_id = $viewname . viewer_id", NULL)
            ->where($member_name . '.resource_id = ?', $viewer_id)
            ->where($viewname . '.viewer_id <> ?', $viewer_id)
            ->where($member_name . '.active = ?', 1)
            ->group($viewname . '.recipe_id')
            ->order($viewname . '.date DESC');


    $select = $select->limit($limit);
    $recentlyfriend = $recipe_table->fetchAll($select);

    return $recentlyfriend;
  }

  public function recent_viewrecipe() {

    $recipetable = Engine_Api::_()->getDbtable('recipes', 'recipe');
    $recipeName = $recipetable->info('name');
    $viewtable = Engine_Api::_()->getDbtable('vieweds', 'recipe');
    $viewName = $viewtable->info('name');

    $select = $recipetable->select();
    $select = $select
            ->setIntegrityCheck(false)
            ->from($recipeName)
            ->join($viewName, $recipeName . '.recipe_id = ' . $viewName . '.recipe_id', array('date'))
            ->where($recipeName . '.closed = ?', '0')
            ->where($recipeName . '.approved = ?', '1')
            ->where($recipeName . '.draft = ?', '1')
            ->group($viewName . '.recipe_id')
            ->order($viewName . '.date DESC');
    $select->where($recipeName . ".search = ?", 1);
    // Start Network work
    $enableNetwork = Engine_Api::_()->getApi('settings', 'core')->getSetting('recipe.network', 0);
    if (!empty($enableNetwork)) {
      $viewer = Engine_Api::_()->user()->getViewer();
      $networkMembershipTable = Engine_Api::_()->getDbtable('membership', 'network');
      $viewerNetwork = $networkMembershipTable->fetchRow(array('user_id = ?' => $viewer->getIdentity()));

      if (!empty($viewerNetwork)) {
        $networkMembershipName = $networkMembershipTable->info('name');
        $select
            ->join($networkMembershipName, "`{$recipeName}`.owner_id = `{$networkMembershipName}`.user_id  ", null)
            ->join($networkMembershipName, "`{$networkMembershipName}`.`resource_id`=`{$networkMembershipName}_2`.resource_id", null)
            ->where("`{$networkMembershipName}_2`.user_id = ? ", $viewer->getIdentity());
      }
    }
    // End Network work
    $select = $select->limit((int) Engine_Api::_()->getApi('settings', 'core')->getSetting('recipe.recently.view', 3));
    $row = $recipetable->fetchAll($select);
    return $row;
  }

  public function getPopularLocation() {
    $limit = Engine_Api::_()->getApi('settings', 'core')->getSetting('recipe.popular.locations', 10);
    $recipetable = Engine_Api::_()->getDbtable('recipes', 'recipe');
    $recipeName = $recipetable->info('name');
    $locationTable = Engine_Api::_()->getDbtable('locations', 'recipe');
    $locationName = $locationTable->info('name');

    $valueTable = Engine_Api::_()->fields()->getTable('recipe', 'values');
    $valueName = $valueTable->info('name');
    $metaName = Engine_Api::_()->fields()->getTable('recipe', 'meta')->info('name');

    $select = $recipetable->select()
            ->setIntegrityCheck(false)
            ->from($recipeName, null)
            ->join($locationName, "$recipeName.recipe_id = $locationName.recipe_id", array("city", "count(city) as count_location"))
            ->join($valueName, "$recipeName.recipe_id = $valueName.item_id", array())
            ->join($metaName, $metaName . '.field_id = ' . $valueName . '.field_id', array())

            // $locationValue = $locationTable->fetchRow($selectLocQuery);
            ->group("city")
            ->order("count_location DESC")
            ->limit($limit);

    $select->where($recipeName . '.closed = ?', '0')
        ->where($recipeName . '.approved = ?', '1')
        ->where($recipeName . '.draft = ?', '1')
        ->where($recipeName . ".search = ?", 1);
    // Start Network work
    $enableNetwork = Engine_Api::_()->getApi('settings', 'core')->getSetting('recipe.network', 0);
    if (!empty($enableNetwork)) {
      $viewer = Engine_Api::_()->user()->getViewer();
      $networkMembershipTable = Engine_Api::_()->getDbtable('membership', 'network');
      $viewerNetwork = $networkMembershipTable->fetchRow(array('user_id = ?' => $viewer->getIdentity()));

      if (!empty($viewerNetwork)) {
        $networkMembershipName = $networkMembershipTable->info('name');
        $select
            ->join($networkMembershipName, "`{$recipeName}`.owner_id = `{$networkMembershipName}`.user_id  ", null)
            ->join($networkMembershipName, "`{$networkMembershipName}`.`resource_id`=`{$networkMembershipName}_2`.resource_id", null)
            ->where("`{$networkMembershipName}_2`.user_id = ? ", $viewer->getIdentity());
      }
    }
    // End Network work

    return $recipetable->fetchAll($select);
  }

  /**
   * Plugin which return the error, if Siteadmin not using correct version for the plugin.
   *
   */
  public function isModulesSupport() {
    $modArray = array(
        'suggestion' => '4.2.3',
    );
    $finalModules = array();
    foreach ($modArray as $key => $value) {
      $isModEnabled = Engine_Api::_()->getDbtable('modules', 'core')->isModuleEnabled($key);
      if (!empty($isModEnabled)) {
        $getModVersion = Engine_Api::_()->getDbtable('modules', 'core')->getModule($key);
        $isModSupport = $this->checkVersion($getModVersion->version, $value);
        if (empty($isModSupport)) {
          $finalModules[] = $getModVersion->title;
        }
      }
    }
    return $finalModules;
  }
    private function checkVersion($databaseVersion, $checkDependancyVersion) {
        $f = $databaseVersion;
        $s = $checkDependancyVersion;
        if (strcasecmp($f, $s) == 0)
            return -1;

        $fArr = explode(".", $f);
        $sArr = explode('.', $s);
        if (count($fArr) <= count($sArr))
            $count = count($fArr);
        else
            $count = count($sArr);

        for ($i = 0; $i < $count; $i++) {
            $fValue = $fArr[$i];
            $sValue = $sArr[$i];
            if (is_numeric($fValue) && is_numeric($sValue)) {
                if ($fValue > $sValue)
                    return 1;
                elseif ($fValue < $sValue)
                    return 0;
                else {
                    if (($i + 1) == $count) {
                        return -1;
                    } else
                        continue;
                }
            }
            elseif (is_string($fValue) && is_numeric($sValue)) {
                $fsArr = explode("p", $fValue);

                if ($fsArr[0] > $sValue)
                    return 1;
                elseif ($fsArr[0] < $sValue)
                    return 0;
                else {
                    return 1;
                }
            } elseif (is_numeric($fValue) && is_string($sValue)) {
                $ssArr = explode("p", $sValue);

                if ($fValue > $ssArr[0])
                    return 1;
                elseif ($fValue < $ssArr[0])
                    return 0;
                else {
                    return 0;
                }
            } elseif (is_string($fValue) && is_string($sValue)) {
                $fsArr = explode("p", $fValue);
                $ssArr = explode("p", $sValue);
                if ($fsArr[0] > $ssArr[0])
                    return 1;
                elseif ($fsArr[0] < $ssArr[0])
                    return 0;
                else {
                    if ($fsArr[1] > $ssArr[1])
                        return 1;
                    elseif ($fsArr[1] < $ssArr[1])
                        return 0;
                    else {
                        return -1;
                    }
                }
            }
        }
    }
}
