<?php

/**
 * SocialEngine
 *
 * @category   Application_Extensions
 * @package    Recipe
 * @copyright  Copyright 2009-2010 BigStep Technologies Pvt. Ltd.
 * @license    http://www.socialengineaddons.com/license/
 * @version    $Id: Level.php 6590 2010-12-31 9:40:21Z SocialEngineAddOns $
 * @author     SocialEngineAddOns
 */
class Recipe_Form_Admin_Settings_Level extends Authorization_Form_Admin_Level_Abstract {

  public function init() {
    parent::init();

    // My stuff
    $this
        ->setTitle('Member Level Settings')
        ->setDescription("RECIPE_FORM_ADMIN_LEVEL_DESCRIPTION");

    // Element: view
    $this->addElement('Radio', 'view', array(
            'label' => 'Allow Viewing of Recipes?',
            'description' => 'Do you want to let members view recipes? If set to no, some other settings on this page may not apply.',
            'multiOptions' => array(
                    2 => 'Yes, allow viewing of all recipes, even private ones.',
                    1 => 'Yes, allow viewing of recipes.',
                    0 => 'No, do not allow recipes to be viewed.',
            ),
            'value' => ( $this->isModerator() ? 2 : 1 ),
    ));
    if (!$this->isModerator()) {
      unset($this->view->options[2]);
    }

    if (!$this->isPublic()) {

      // Element: create
      $this->addElement('Radio', 'create', array(
              'label' => 'Allow Creation of Recipes?',
              'description' => 'RECIPE_FORM_ADMIN_LEVEL_CREATE_DESCRIPTION',
              'multiOptions' => array(
                      1 => 'Yes, allow creation of recipes.',
                      0 => 'No, do not allow recipes to be created.'
              ),
              'value' => 1,
      ));

      // Element: edit
      $this->addElement('Radio', 'edit', array(
              'label' => 'Allow Editing of Recipes?',
              'description' => 'Do you want to let members edit recipes? If set to no, some other settings on this page may not apply.',
              'multiOptions' => array(
                      2 => 'Yes, allow members to edit all recipes.',
                      1 => 'Yes, allow members to edit their own recipes.',
                      0 => 'No, do not allow members to edit their recipes.',
              ),
              'value' => ( $this->isModerator() ? 2 : 1 ),
      ));
      if (!$this->isModerator()) {
        unset($this->edit->options[2]);
      }

      // Element: delete
      $this->addElement('Radio', 'delete', array(
              'label' => 'Allow Deletion of Recipes?',
              'description' => 'Do you want to let members delete recipes? If set to no, some other settings on this page may not apply.',
              'multiOptions' => array(
                      2 => 'Yes, allow members to delete all recipes.',
                      1 => 'Yes, allow members to delete their own recipes.',
                      0 => 'No, do not allow members to delete their recipes.',
              ),
              'value' => ( $this->isModerator() ? 2 : 1 ),
      ));
      if (!$this->isModerator()) {
        unset($this->delete->options[2]);
      }

      // Element: comment
      $this->addElement('Radio', 'comment', array(
              'label' => 'Allow Commenting on Recipes?',
              'description' => 'Do you want to let members of this level comment on recipes?',
              'multiOptions' => array(
                      2 => 'Yes, allow members to comment on all recipes, including private ones.',
                      1 => 'Yes, allow members to comment on recipes.',
                      0 => 'No, do not allow members to comment on recipes.',
              ),
              'value' => ( $this->isModerator() ? 2 : 1 ),
      ));
      if (!$this->isModerator()) {
        unset($this->comment->options[2]);
      }

      //Element: overview
//       $this->addElement('Radio', 'overview', array(
// 				'label' => 'Allow Overview?',
// 				'description' => 'Do you want to let members enter rich Overview for their recipes?',
// 				'multiOptions' => array(
// 								1 => 'Yes',
// 								0 => 'No'
// 				),
// 				'value' => 1,
//       ));
      
      // Element: photo
      $this->addElement('Radio', 'photo', array(
              'label' => 'Allow Uploading of Photos?',
              'description' => 'Do you want to let members upload photos to recipes? If set to no, the option to upload photos will not appear.',
              'multiOptions' => array(
                      2 => 'Yes, allow photo uploading to recipes, including private ones.',
                      1 => 'Yes, allow photo uploading to recipes.',
                      0 => 'No, do not allow photo uploading.'
              ),
              'value' => ( $this->isModerator() ? 2 : 1 ),
      ));
      if (!$this->isModerator()) {
        unset($this->photo->options[2]);
      }

      // Element: auth_view
      $this->addElement('MultiCheckbox', 'auth_view', array(
              'label' => 'Recipe Privacy',
              'description' => 'RECIPE_FORM_ADMIN_LEVEL_AUTHVIEW_DESCRIPTION',
              'multiOptions' => array(
                      'everyone' => 'Everyone',
                      'registered' => 'All Registered Members',
                      'owner_network' => 'Friends and Networks',
                      'owner_member_member' => 'Friends of Friends',
                      'owner_member' => 'Friends Only',
                      'owner' => 'Just Me'
              ),
              'value' => array('everyone', 'registered', 'owner_network', 'owner_member_member', 'owner_member', 'owner')
      ));

      // Element: auth_comment
      $this->addElement('MultiCheckbox', 'auth_comment', array(
              'label' => 'Recipe Comment Options',
              'description' => 'RECIPE_FORM_ADMIN_LEVEL_AUTHCOMMENT_DESCRIPTION',
              'multiOptions' => array(
                      'everyone' => 'Everyone',
                      'registered' => 'All Registered Members',
                      'owner_network' => 'Friends and Networks',
                      'owner_member_member' => 'Friends of Friends',
                      'owner_member' => 'Friends Only',
                      'owner' => 'Just Me'
              ),
              'value' => array('everyone', 'registered', 'owner_network', 'owner_member_member', 'owner_member', 'owner')
      ));

      //Element: auth_photo
      $this->addElement('MultiCheckbox', 'auth_photo', array(
              'label' => 'Photo Upload Options',
              'description' => 'Your users can choose from any of the options checked below when they decide who can upload the photos in their recipe. If you do not check any options, everyone will be allowed to create.',
              'multiOptions' => array(
                      'registered' => 'All Registered Members',
                      'owner_network' => 'Friends and Networks',
                      'owner_member_member' => 'Friends of Friends',
                      'owner_member' => 'Friends Only',
                      'owner' => 'Just Me'
              ),
              'value' => array('registered', 'owner_network', 'owner_member_member', 'owner_member', 'owner')
      ));

      //Element: video
      $this->addElement('Radio', 'video', array(
              'label' => 'Allow Uploading of Videos?',
              'description' => 'Do you want to let members upload Videos to recipes?',
              'multiOptions' => array(
                      1 => 'Yes, allow video uploading to recipes.',
                      0 => 'No, do not allow video uploading.'
              ),
              'value' => 1,
      ));

      //Element: auth_video
      $this->addElement('MultiCheckbox', 'auth_video', array(
              'label' => 'Video Upload Options',
              'description' => 'Your users can choose from any of the options checked below when they decide who can upload the videos in their recipe. If you do not check any options, everyone will be allowed to create.',
              'multiOptions' => array(
                      'registered' => 'All Registered Members',
                      'owner_network' => 'Friends and Networks',
                      'owner_member_member' => 'Friends of Friends',
                      'owner_member' => 'Friends Only',
                      'owner' => 'Just Me'
              ),
              'value' => array('registered', 'owner_network', 'owner_member_member', 'owner_member', 'owner')
      ));

      //Element: approved
      $this->addElement('Radio', 'approved', array(
              'label' => 'Recipe Approval Moderation',
              'description' => 'Do you want new Recipe to be automatically approved?',
              'multiOptions' => array(
                      1 => 'Yes, automatically approve Recipe.',
                      0 => 'No, site admin approval will be required for all Recipe.'
              ),
              'value' => 1,
      ));

      //Element: featured
      $this->addElement('Radio', 'featured', array(
              'label' => 'Recipe Featured Moderation',
              'description' => 'Do you want new Recipe to be automatically made featured?',
              'multiOptions' => array(
                      1 => 'Yes, automatically make Recipe featured.',
                      0 => 'No, site admin will be making Recipe featured.'
              ),
              'value' => 1,
      ));

      //Element: sponsored
      $this->addElement('Radio', 'sponsored', array(
              'label' => 'Recipe Sponsored Moderation',
              'description' => 'Do you want new Recipe to be automatically made Sponsored?',
              'multiOptions' => array(
                      1 => 'Yes, automatically make Recipe Sponsored.',
                      0 => 'No, site admin will be making Recipe Sponsored.'
              ),
              'value' => 1,
      ));

      // Element: max
      $this->addElement('Text', 'max', array(
              'label' => 'Maximum Allowed Recipes',
              'description' => 'Enter the maximum number of allowed recipes. The field must contain an integer, use zero for unlimited.',
              'validators' => array(
                      array('Int', true),
                      new Engine_Validate_AtLeast(0),
              ),
      ));
    }
  }

}
