<?php

/**
 * SocialEngine
 *
 * @category   Application_Extensions
 * @package    Recipe
 * @copyright  Copyright 2009-2010 BigStep Technologies Pvt. Ltd.
 * @license    http://www.socialengineaddons.com/license/
 * @version    $Id: Widget.php 6590 2010-12-31 9:40:21Z SocialEngineAddOns $
 * @author     SocialEngineAddOns
 */
class recipe_Form_Admin_Widget extends Engine_Form {

  public function init() {
    $this
        ->setTitle('General Settings')
        ->setDescription('Configure the general settings for the various widgets available with this plugin.');

    // VALUE FOR FEATURE recipe IN SLIDESHOW
    $this->addElement('Text', 'recipe_feature_widgets', array(
            'label' => 'Featured Recipes Slideshow Widget',
            'maxlength' => '3',
            'description' => 'How many recipes will be shown in featured recipes slideshow widget? Note that from all the featured recipes, these many recipes will be picked up randomly to be shown in the slideshow. (value can not be empty or zero).',
            'required' => true,
            'value' => Engine_Api::_()->getApi('settings', 'core')->getSetting('recipe.feature.widgets', 10),
            'validators' => array(
                    array('Int', true),
                    array('GreaterThan', true, array(0)),
            ),
    ));

    // VALUE FOR SPONSORED recipe IN CAROUSAL
    $this->addElement('Text', 'recipe_sponserdrecipe_widgets', array(
            'label' => 'Sponsored Recipes Carousel Widget',
            'maxlength' => '3',
            'description' => 'How many recipes will be shown in one view of the sponsored recipes carousel widget? Note that this carousel is AJAX based and users will be able to browse through all the sponsored recipes. (value can not be empty or zero).',
            'required' => true,
            'value' => Engine_Api::_()->getApi('settings', 'core')->getSetting('recipe.sponserdrecipe.widgets', 4),
            'validators' => array(
                    array('Int', true),
                    array('GreaterThan', true, array(0)),
            ),
    ));
    // VALUE FOR Sponsored Interval
    $this->addElement('Text', 'recipe_sponsored_interval', array(
            'label' => 'Sponsored Curosal Speed',
            'maxlength' => '3',
            'allowEmpty' => false,
            'required' => true,
            'description' => 'What maximum Curosal Speed should be applied to the Sponsored Widget.',
            'value' => Engine_Api::_()->getApi('settings', 'core')->getSetting('recipe.sponsored.interval', 300),
            'validators' => array(
                    array('Int', true),
                    array('GreaterThan', true, array(0)),
            ),
    ));
    // VALUE FOR TOPRATINGS
    $this->addElement('Text', 'recipe_rate_widgets', array(
            'label' => 'Top Rated Recipes Widget',
            'maxlength' => '3',
            'description' => 'How many recipes will be shown in the top rated recipes widget (value can not be empty or zero) ?',
            'required' => true,
            'value' => Engine_Api::_()->getApi('settings', 'core')->getSetting('recipe.rate.widgets', 3),
            'validators' => array(
                    array('Int', true),
                    array('GreaterThan', true, array(0)),
            ),
    ));

    // VALUE FOR MOSTCOMMENT
    $this->addElement('Text', 'recipe_comment_widgets', array(
            'label' => 'Most Commented Recipes Widget',
            'maxlength' => '3',
            'description' => 'How many recipes will be shown in the most commented recipes widget (value can not be empty or zero) ?',
            'required' => true,
            'value' => Engine_Api::_()->getApi('settings', 'core')->getSetting('recipe.comment.widgets', 3),
            'validators' => array(
                    array('Int', true),
                    array('GreaterThan', true, array(0)),
            ),
    ));

    // VALUE FOR MOSTLIKE
    $this->addElement('Text', 'recipe_likes_widgets', array(
            'label' => 'Most Liked Recipes Widget',
            'maxlength' => '3',
            'description' => 'How many recipes will be shown in the most liked recipes widget (value can not be empty or zero) ?',
            'required' => true,
            'value' => Engine_Api::_()->getApi('settings', 'core')->getSetting('recipe.likes.widgets', 3),
            'validators' => array(
                    array('Int', true),
                    array('GreaterThan', true, array(0)),
            ),
    ));

    // VALUE FOR USER recipe RECIPE
    $this->addElement('Text', 'recipe_userrecipe_widgets', array(
            'label' => 'Owner Recipes Widget',
            'maxlength' => '3',
            'description' => 'How many recipes will be shown in the user recipes  widget (value can not be empty or zero) ?',
            'required' => true,
            'value' => Engine_Api::_()->getApi('settings', 'core')->getSetting('recipe.userrecipe.widgets', 3),
            'validators' => array(
                    array('Int', true),
                    array('GreaterThan', true, array(0)),
            ),
    ));

    // VALUE FOR AJAX LAYOUT
    $this->addElement('MultiCheckbox', 'recipe_ajax_widgets_layout', array(
            'description' => "Choose the view types that you want to be available for recipes on the recipes home and browse pages.",
            'label' => 'Views on Recipes Home and Browse pages',
            'multiOptions' => array("1" => "List View", "2" => "Grid View", "3" => "Map View"),
            'value' => Engine_Api::_()->getApi('settings', 'core')->getSetting('recipe.ajax.widgets.layout', array("0" => "1", "1" => "2", "2" => "3")),
    ));
    // VALUE FOR AJAX LAYOUT ORDER
    $this->addElement('Radio', 'recipe_ajax_layouts_oder', array(
            'description' => 'Select a default view type for Recipes on the Main Recipes Home Widget and Browse Recipes.',
            'label' => 'Default View on Recipes Home Widget and Browse Recipes',
            'multiOptions' => array("1" => "List View", "2" => "Grid View", "3" => "Map View"),
            'value' => Engine_Api::_()->getApi('settings', 'core')->getSetting('recipe.ajax.layouts.oder', 1),
    ));
    // VALUE FOR RECIPE SHOW IN AJAX WIDGETS
    $this->addElement('MultiCheckbox', 'recipe_ajax_widgets_recipe', array(
            'description' => "Choose the ajax tabs that you want to be there in the Main Recipes Home Widget.",
            'label' => 'Ajax Tabs of Main Recipes Home Widget',
            // 'required' => true,
            'multiOptions' => array("1" => "Recent", "2" => "Most Popular", "3" => "Random", "4" => "Featured", "5" => "Sponsored"),
            'value' => Engine_Api::_()->getApi('settings', 'core')->getSetting('recipe.ajax.widgets.recipe', array("0" => "1", "1" => "2", "2" => "3", "3" => "4", "4" => "5")),
    ));


    // VALUE FOR POPULAR IN RECIPE VIEW
    $this->addElement('Text', 'recipe_popular_widgets', array(
            'label' => 'Popular Recipes Widget',
            'maxlength' => '3',
            'description' => 'How many recipes will be shown in the popular recipes widget (value can not be empty or zero) ?',
            'required' => true,
            'value' => Engine_Api::_()->getApi('settings', 'core')->getSetting('recipe.popular.widgets', 10),
            'validators' => array(
                    array('Int', true),
                    array('GreaterThan', true, array(0)),
            ),
    ));

    // VALUE FOR POPULAR IN GRID VIEW
    $this->addElement('Text', 'recipe_popular_thumbs', array(
            'label' => 'Popular Recipes Widget Grid View',
            'maxlength' => '3',
            'description' => 'How many recipes will be shown in the popular recipes widget in image view (value can not be empty or zero) ?',
            'required' => true,
            'value' => Engine_Api::_()->getApi('settings', 'core')->getSetting('recipe.popular.thumbs', 15),
            'validators' => array(
                    array('Int', true),
                    array('GreaterThan', true, array(0)),
            ),
    ));

    // VALUE FOR RECENT IN RECIPE VIEW
    $this->addElement('Text', 'recipe_recent_widgets', array(
            'label' => 'Recent Recipes Widget',
            'maxlength' => '3',
            'description' => 'How many recipes will be shown in the recent recipes widget (value can not be empty or zero) ?',
            'required' => true,
            'value' => Engine_Api::_()->getApi('settings', 'core')->getSetting('recipe.recent.widgets', 10),
            'validators' => array(
                    array('Int', true),
                    array('GreaterThan', true, array(0)),
            ),
    ));

    // VALUE FOR RECENT IN GRID VIEW
    $this->addElement('Text', 'recipe_recent_thumbs', array(
            'label' => 'Recent Recipes Widget Grid View',
            'maxlength' => '3',
            'description' => 'How many recipes will be shown in the recent recipes widget in image view (value can not be empty or zero) ?',
            'required' => true,
            'value' => Engine_Api::_()->getApi('settings', 'core')->getSetting('recipe.recent.thumbs', 15),
            'validators' => array(
                    array('Int', true),
                    array('GreaterThan', true, array(0)),
            ),
    ));

    // VALUE FOR RANDON IN RECIPE VIEW
    $this->addElement('Text', 'recipe_random_widgets', array(
            'label' => 'Random Recipes Widget',
            'maxlength' => '3',
            'description' => 'How many recipes will be shown in the random recipes  widget (value can not be empty or zero) ?',
            'required' => true,
            'value' => Engine_Api::_()->getApi('settings', 'core')->getSetting('recipe.random.widgets', 10),
            'validators' => array(
                    array('Int', true),
                    array('GreaterThan', true, array(0)),
            ),
    ));

    // VALUE FOR RANDOM IN GRID VIEW
    $this->addElement('Text', 'recipe_random_thumbs', array(
            'label' => 'Random Recipes Widget Grid View',
            'maxlength' => '3',
            'description' => 'How many recipes will be shown in the random recipes  widget in image view (value can not be empty or zero) ?',
            'required' => true,
            'value' => Engine_Api::_()->getApi('settings', 'core')->getSetting('recipe.random.thumbs', 15),
            'validators' => array(
                    array('Int', true),
                    array('GreaterThan', true, array(0)),
            ),
    ));

    // VALUE FOR RANDOM IN SITEPAGE VIEW
    $this->addElement('Text', 'recipe_featured_recipe', array(
            'label' => 'Featured Recipes Widget',
            'maxlength' => '3',
            'description' => 'How many recipes will be shown in the featured recipes widget (value can not be empty or zero) ?',
            'required' => true,
            'value' => Engine_Api::_()->getApi('settings', 'core')->getSetting('recipe.featured.recipe', 10),
            'validators' => array(
                    array('Int', true),
                    array('GreaterThan', true, array(0)),
            ),
    ));

    // VALUE FOR RANDOM IN GRID VIEW
    $this->addElement('Text', 'recipe_featured_thumbs', array(
            'label' => 'Featured Recipes Widget Grid View',
            'maxlength' => '3',
            'description' => 'How many recipes will be shown in the featured recipes widget in image view (value can not be empty or zero) ?',
            'required' => true,
            'value' => Engine_Api::_()->getApi('settings', 'core')->getSetting('recipe.featured.thumbs', 15),
            'validators' => array(
                    array('Int', true),
                    array('GreaterThan', true, array(0)),
            ),
    ));

    // VALUE FOR SPONSORED IN RECIPE VIEW
    $this->addElement('Text', 'recipe_sponsored_recipe', array(
            'label' => 'Sponsored Pages Widget',
            'maxlength' => '3',
            'description' => 'How many recipes will be shown in the sponsored recipes widget (value can not be empty or zero) ?',
            'required' => true,
            'value' => Engine_Api::_()->getApi('settings', 'core')->getSetting('recipe.sponsored.recipe', 10),
            'validators' => array(
                    array('Int', true),
                    array('GreaterThan', true, array(0)),
            ),
    ));

    // VALUE FOR SPONSORED IN GRID VIEW
    $this->addElement('Text', 'recipe_sponosred_thumbs', array(
            'label' => 'Sponsored Pages Widget Grid View',
            'maxlength' => '3',
            'description' => 'How many recipes will be shown in the sponsored recipes widget in image view (value can not be empty or zero) ?',
            'required' => true,
            'value' => Engine_Api::_()->getApi('settings', 'core')->getSetting('recipe.sponosred.thumbs', 15),
            'validators' => array(
                    array('Int', true),
                    array('GreaterThan', true, array(0)),
            ),
    ));

    // VALUE FOR RANDOM IN GRID VIEW
    $this->addElement('Text', 'recipe_suggest_recipes', array(
            'label' => 'Suggest Recipes Widget',
            'maxlength' => '3',
            'description' => 'How many Recipes will be shown in the suggest recipes  widget (value can not be empty or zero) ?',
            'required' => true,
            'value' => Engine_Api::_()->getApi('settings', 'core')->getSetting('recipe.suggest.recipes', 5),
            'validators' => array(
                    array('Int', true),
                    array('GreaterThan', true, array(0)),
            ),
    ));

    // VALUE FOR RANDOM IN GRID VIEW
    $this->addElement('Text', 'recipe_recently_view', array(
            'label' => 'Recently Viewed Recipes Widget',
            'maxlength' => '3',
            'description' => 'How many recipes will be shown in the recently view recipes  widget in image view (value can not be empty or zero) ?',
            'required' => true,
            'value' => Engine_Api::_()->getApi('settings', 'core')->getSetting('recipe.recently.view', 3),
            'validators' => array(
                    array('Int', true),
                    array('GreaterThan', true, array(0)),
            ),
    ));

    // VALUE FOR RANDOM IN GRID VIEW
    $this->addElement('Text', 'recipe_recentlyfriend_view', array(
            'label' => 'Recently Friend View Recipes Widget',
            'maxlength' => '3',
            'description' => 'How many recipes will be shown in the recently friend view recipes  widget in image view (value can not be empty or zero) ?',
            'required' => true,
            'value' => Engine_Api::_()->getApi('settings', 'core')->getSetting('recipe.recentlyfriend_view', 3),
            'validators' => array(
                    array('Int', true),
                    array('GreaterThan', true, array(0)),
            ),
    ));
    // VALUE FOR RANDOM IN GRID VIEW
    $this->addElement('Text', 'recipe_recipelike_view', array(
            'label' => 'Recipe Likes',
            'maxlength' => '3',
            'description' => 'How many recipes will be shown in the  view recipes  widget in image view (value can not be empty or zero) ?',
            'required' => true,
            'value' => Engine_Api::_()->getApi('settings', 'core')->getSetting('recipe.recipelike.view', 3),
            'validators' => array(
                    array('Int', true),
                    array('GreaterThan', true, array(0)),
            ),
    ));

    // VALUE FOR POPULAR IN RECIPE VIEW
    $this->addElement('Text', 'recipe_mostdiscussed_widgets', array(
            'label' => 'Most Discussed Recipes Widget',
            'maxlength' => '3',
            'description' => 'How many recipes will be shown in the most discussed recipes widget (value can not be empty or zero) ?',
            'required' => true,
            'value' => Engine_Api::_()->getApi('settings', 'core')->getSetting('recipe.mostdiscussed.widgets', 10),
            'validators' => array(
                    array('Int', true),
                    array('GreaterThan', true, array(0)),
            ),
    ));
    $this->addElement('Text', 'recipe_popular_locations', array(
            'label' => 'Popular Locations Widget',
            'maxlength' => '3',
            'description' => 'How many locations will be shown in the popular locations widget (value can not be empty or zero) ?',
            'required' => true,
            'value' => Engine_Api::_()->getApi('settings', 'core')->getSetting('recipe.popular.locations', 10),
            'validators' => array(
                    array('Int', true),
                    array('GreaterThan', true, array(0)),
            ),
    ));

    $this->addElement('Text', 'recipe_season_recipe', array(
            'label' => 'Season\'s Recipes Widget',
            'maxlength' => '3',
            'description' => 'How many recipes will be shown in the Season\'s Recipes Widget (value can not be empty or zero) ?',
            'required' => true,
            'value' => Engine_Api::_()->getApi('settings', 'core')->getSetting('recipe.season.recipe', 3),
            'validators' => array(
                    array('Int', true),
                    array('GreaterThan', true, array(0)),
            ),
    ));

    $this->addElement('Button', 'submit', array(
            'label' => 'Save Changes',
            'type' => 'submit',
            'ignore' => true
    ));
  }

}
?>
