<?php

/**
 * SocialEngine
 *
 * @category   Application_Extensions
 * @package    Recipe
 * @copyright  Copyright 2009-2010 BigStep Technologies Pvt. Ltd.
 * @license    http://www.socialengineaddons.com/license/
 * @version    $Id: AlbumController.php 6590 2010-12-31 9:40:21Z SocialEngineAddOns $
 * @author     SocialEngineAddOns
 */
class Recipe_AlbumController extends Core_Controller_Action_Standard {

  public function init() {

    if (!$this->_helper->requireAuth()->setAuthParams('recipe', null, 'view')->isValid())
      return;

    $ajaxContext = $this->_helper->getHelper('AjaxContext');
    $ajaxContext
        ->addActionContext('rate', 'json')
        ->addActionContext('validation', 'html')
        ->initContext();

    $id = $this->_getParam('recipe_id', $this->_getParam('id', null));
    if ($id) {

      $recipe = Engine_Api::_()->getItem('recipe', $id);
      if ($recipe) {
        Engine_Api::_()->core()->setSubject($recipe);
      }
    }
  }

  public function editphotosAction() {

    if (!$this->_helper->requireUser()->isValid())
      return;

    $this->view->recipe_id = $recipe_id = $this->_getParam('recipe_id');
    $viewer = Engine_Api::_()->user()->getViewer();

    $this->view->recipe = $recipe = Engine_Api::_()->getItem('recipe', $recipe_id);
    $this->view->owner_id = $owner_id = $recipe['owner_id'];

    if (empty($recipe)) {
      return $this->_forward('requireauth', 'error', 'core');
    }

    // Check auth
    if (!$this->_helper->requireAuth()->setAuthParams($recipe, $viewer, 'edit')->isValid()) {
      return;
    }
    $viewer_id = $viewer->getIdentity();
    $this->view->TabActive = "photo";
    if (Engine_Api::_()->recipe()->allowVideo($recipe, $viewer)) {
      $this->view->allowed_upload_video = 1;
    }

    $subject_recipe = Engine_Api::_()->core()->getSubject();
    $allowed_upload_photo = Engine_Api::_()->authorization()->isAllowed($subject_recipe, $viewer, 'photo');

    if ($allowed_upload_photo) {
      $this->view->allowed_upload_photo = $allowed_upload_photo;
    }

    if (empty($this->view->allowed_upload_photo)) {
      return $this->_forward('requireauth', 'error', 'core');
    }

    if (!$this->_helper->requireUser()->isValid())
      return;

    if (!$this->_helper->requireSubject('recipe')->isValid())
      return;

    if (!$this->_helper->requireAuth()->setAuthParams('recipe', null, 'edit')->isValid())
      return;

    // Prepare data
    $recipe = Engine_Api::_()->core()->getSubject();

    // Prepare data
    $this->view->album = $album = $recipe->getSingletonAlbum();
    $this->view->paginator = $paginator = $album->getCollectiblesPaginator();
    $paginator->setCurrentPageNumber($this->_getParam('page'));
    $paginator->setItemCountPerPage($paginator->getTotalItemCount());
    $this->view->count = $count = count($paginator);

    // Make form
    $this->view->form = $form = new Recipe_Form_Album_Photos();

    foreach ($paginator as $photo) {

      $subform = new Recipe_Form_Photo_SubEdit(array('elementsBelongTo' => $photo->getGuid()));
      $subform->populate($photo->toArray());
      $form->addSubForm($subform, $photo->getGuid());
      $form->cover->addMultiOption($photo->file_id, $photo->file_id);
    }
    if (!$this->getRequest()->isPost()) {
      return;
    }

    if (!$form->isValid($this->getRequest()->getPost())) {
      return;
    }

    $table = $album->getTable();
    $db = $table->getAdapter();
    $db->beginTransaction();
    try {
      $values = $form->getValues();
      if (!empty($values['cover'])) {

        $album->photo_id = $values['cover'];
        $album->save();

        $recipe->photo_id = $values['cover'];
        $recipe->save();
      }

      // Process
      foreach ($paginator as $photo) {

        $subform = $form->getSubForm($photo->getGuid());
        $values = $subform->getValues();
        $values = $values[$photo->getGuid()];

        //unset($values['photo_id']);
        if (isset($values['delete']) && $values['delete'] == '1') {
          $photo->delete();
        } else {
          $photo->setFromArray($values);
          $photo->save();
        }
      }
      $db->commit();
    } catch (Exception $e) {
      $db->rollBack();
      throw $e;
    }
    return $this->_helper->redirector->gotoRoute(array('action' => 'editphotos', 'recipe_id' => $album->recipe_id), 'recipe_specific', true);
  }

}