<?php

/**
 * SocialEngine
 *
 * @category   Application_Extensions
 * @package    Recipe
 * @copyright  Copyright 2009-2010 BigStep Technologies Pvt. Ltd.
 * @license    http://www.socialengineaddons.com/license/
 * @version    $Id: PhotoController.php 6590 2010-12-31 9:40:21Z SocialEngineAddOns $
 * @author     SocialEngineAddOns
 */
class Recipe_PhotoController extends Core_Controller_Action_Standard {

  protected $_navigation;

  public function init() {

    // set subject for photo
    $content_id = $this->_getParam('content_id');

    if (!Engine_Api::_()->core()->hasSubject()) {

      if (0 != ($photo_id = (int) $this->_getParam('photo_id')) &&
          null != ($photo = Engine_Api::_()->getItem('recipe_photo', $photo_id))) {
        Engine_Api::_()->core()->setSubject($photo);
      } else if (0 != ($recipe_id = (int) $this->_getParam('recipe_id')) &&
          null != ($recipe = Engine_Api::_()->getItem('recipe', $recipe_id))) {
        Engine_Api::_()->core()->setSubject($recipe);
      }
    }
    $this->_helper->requireUser->addActionRequires(array(
            'upload',
            'upload-photo', // Not sure if this is the right
            'edit',
    ));

    $this->_helper->requireSubject->setActionRequireTypes(array(
            'recipe' => 'recipe',
            'upload' => 'recipe',
            'view' => 'recipe_photo',
            'edit' => 'recipe_photo',
    ));
  }

  public function uploadAction() {

    if (!$this->_helper->requireAuth()->setAuthParams('recipe', null, 'view')->isValid())
      return;

    $this->view->recipe_id = $recipe_id = $this->_getParam('recipe_id');
    $viewer = Engine_Api::_()->user()->getViewer();
    $this->view->TabActive = "photo";
    $this->view->recipe = $recipe = Engine_Api::_()->getItem('recipe', $recipe_id);
    $this->view->owner_id = $owner_id = $recipe['owner_id'];
    $this->view->viewer_id = $viewer_id = $viewer->getIdentity();

    $this->view->allowed_upload_photo = $allowed_upload_photo = 0;
    $this->view->allowed_upload_video = 0;
  
    // Check for video
    if (Engine_Api::_()->recipe()->allowVideo($recipe, $viewer)) {
      $this->view->allowed_upload_video = 1;
    }


    $allowed_upload_photo = Engine_Api::_()->authorization()->isAllowed($recipe, $viewer, 'photo');

    if ($allowed_upload_photo) {
      $this->view->allowed_upload_photo = $allowed_upload_photo;
    }

    if (empty($this->view->allowed_upload_photo)) {
      return $this->_forward('requireauth', 'error', 'core');
    }

    if (isset($_GET['ul']) || isset($_FILES['Filedata']))
      return $this->_forward('upload-photo', null, null, array('format' => 'json', 'recipe_id' => (int) $recipe->getIdentity()));

    $viewer = Engine_Api::_()->user()->getViewer();
    $recipe = Engine_Api::_()->core()->getSubject();

    $album = $recipe->getSingletonAlbum();

    $this->view->recipe_id = $recipe->recipe_id;

    $this->view->form = $form = new Recipe_Form_Photo_Upload();
    $form->file->setAttrib('data', array('recipe_id' => $recipe->getIdentity()));

    if (!$this->getRequest()->isPost()) {
      return;
    }

    if (!$form->isValid($this->getRequest()->getPost())) {
      return;
    }

    // Process
    $table = Engine_Api::_()->getItemTable('recipe_photo');
    $db = $table->getAdapter();
    $db->beginTransaction();

    try {

      $values = $form->getValues();
      $params = array(
              'recipe_id' => $recipe->getIdentity(),
              'user_id' => $viewer->getIdentity(),
      );

      // Add action and attachments
      $count = count($values['file']);
      $api = Engine_Api::_()->getDbtable('actions', 'activity');
      $action = $api->addActivity(Engine_Api::_()->user()->getViewer(), $recipe, 'recipe_photo_upload', null, array('count' => count($values['file']), 'title' => $recipe->title));

      // Do other stuff
      $count = 0;

      foreach ($values['file'] as $photo_id) {
        $photo = Engine_Api::_()->getItem("recipe_photo", $photo_id);

        if (!($photo instanceof Core_Model_Item_Abstract) || !$photo->getIdentity())
          continue;

        $photo->collection_id = $album->album_id;
        $photo->album_id = $album->album_id;
        $photo->save();

        if ($recipe->photo_id == 0) {
          $recipe->photo_id = $photo->file_id;
          $recipe->save();
        }

        if ($action instanceof Activity_Model_Action && $count < 8) {
          $api->attachActivity($action, $photo, Activity_Model_Action::ATTACH_MULTI);
        }
        $count++;
      }

      $db->commit();
    } catch (Exception $e) {
      $db->rollBack();
      throw $e;
    }

    if ($owner_id == $viewer_id) {
      return $this->_helper->redirector->gotoRoute(array('action' => 'editphotos', 'recipe_id' => $album->recipe_id), 'recipe_specific', true);
    } else {
      $content_id = $this->_getParam('content_id');
      return $this->_helper->redirector->gotoRoute(array('recipe_id' => $album->recipe_id, 'user_id' => $owner_id, 'slug' => $recipe->getSlug(), 'tab' => $content_id), 'recipe_entry_view', true);
    }
  }

  public function uploadPhotoAction() {

    $recipe = Engine_Api::_()->getItem('recipe', (int) $this->_getParam('recipe_id'));

    if (!$this->_helper->requireUser()->checkRequire()) {
      $this->view->status = false;
      $this->view->error = Zend_Registry::get('Zend_Translate')->_('Max file size limit exceeded (probably).');
      return;
    }

    if (!$this->getRequest()->isPost()) {
      $this->view->status = false;
      $this->view->error = Zend_Registry::get('Zend_Translate')->_('Invalid request method');
      return;
    }

    $values = $this->getRequest()->getPost();
    $response = Seaocore_Service_FancyUpload::upload();

    if(!empty($response['error'])) {
      $this->view->status = false;
      $this->view->error = Zend_Registry::get('Zend_Translate')->_('Invalid Upload') . $response['error'];
      return;
    }

    if(empty($response['path']) || empty(file_exists($response['path']))) {
      $this->view->status = false;
      $this->view->error = Zend_Registry::get('Zend_Translate')->_('No file');
      return;
    }

    $db = Engine_Api::_()->getDbtable('photos', 'recipe')->getAdapter();
    $db->beginTransaction();

    try {
      $viewer = Engine_Api::_()->user()->getViewer();
      $album = $recipe->getSingletonAlbum();

      $params = array(
              // We can set them now since only one album is allowed
              'collection_id' => $album->getIdentity(),
              'album_id' => $album->getIdentity(),
              'recipe_id' => $recipe->getIdentity(),
              'user_id' => $viewer->getIdentity(),
      );
      $photo_id = Engine_Api::_()->recipe()->createPhoto($params, $response['path'])->photo_id;

      if (!$recipe->photo_id) {
        $recipe->photo_id = $photo_id;
        $recipe->save();
      }

      $this->view->status = true;
      // $this->view->name = $response['name'];
      $this->view->photo_id = $photo_id;
      $db->commit();
    } catch (Exception $e) {
      $db->rollBack();
      $this->view->status = false;
      $this->view->error = Zend_Registry::get('Zend_Translate')->_($e->getMessage());
      // throw $e;
      return;
    }
    @unlink($response['path']);
  }

  // EDITING OF PHOTOS TITLE AND DISCRIPTION
  public function editAction() {

    $photo = Engine_Api::_()->core()->getSubject();
    $this->view->viewer_id = $viewer_id = Engine_Api::_()->user()->getViewer()->getIdentity();
    $this->view->canEdit = $photo->authorization()->isAllowed(null, 'edit');
    if (empty($this->view->canEdit) && $photo->user_id == $viewer_id)
      $this->view->canEdit = 1;
    if (empty($this->view->canEdit))
      return $this->_forward('requireauth', 'error', 'core');

    $this->view->form = $form = new Recipe_Form_Photo_Edit();

    if (!$this->getRequest()->isPost()) {
      $form->populate($photo->toArray());
      return;
    }

    if (!$form->isValid($this->getRequest()->getPost())) {
      return;
    }

    // Process
    $db = Engine_Api::_()->getDbtable('photos', 'recipe')->getAdapter();
    $db->beginTransaction();

    try {
      $photo->setFromArray($form->getValues())->save();

      $db->commit();
    } catch (Exception $e) {
      $db->rollBack();
      throw $e;
    }
    return $this->_forward('success', 'utility', 'core', array(
            'messages' => array(Zend_Registry::get('Zend_Translate')->_('Changes saved')),
            'layout' => 'default-simple',
            'parentRefresh' => true,
            'closeSmoothbox' => true,
    ));
  }

  // DELETE PHOTO
  public function removeAction() {

    $viewer = Engine_Api::_()->user()->getViewer();

    $photo_id = (int) $this->_getParam('photo_id');

    $photo = Engine_Api::_()->getItem('recipe_photo', $photo_id);
    $event = $photo->getParent('recipe');
    $isajax = (int) $this->_getParam('isajax');

    if ($isajax) {
      $db = $photo->getTable()->getAdapter();
      $db->beginTransaction();

      try {
        $photo->delete();
        $db->commit();
      } catch (Exception $e) {
        $db->rollBack();
        throw $e;
      }
      return $this->_helper->json(array());
    }
    $this->view->form = $form = new Recipe_Form_Photo_Delete();

    if (!$this->getRequest()->isPost()) {
      $form->populate($photo->toArray());
      return;
    }

    if (!$form->isValid($this->getRequest()->getPost())) {
      return;
    }

    $db = $photo->getTable()->getAdapter();
    $db->beginTransaction();

    try {
      $photo->delete();

      $db->commit();
    } catch (Exception $e) {
      $db->rollBack();
      throw $e;
    }
    return $this->_forward('success', 'utility', 'core', array(
            'messages' => array(Zend_Registry::get('Zend_Translate')->_('Photo deleted')),
            'layout' => 'default-simple',
            'parentRedirect' => $event->getHref(),
            'closeSmoothbox' => true,
    ));
  }

  // VIEW PHOTO
  public function viewAction() { 

    $viewer = Engine_Api::_()->user()->getViewer();

    // retrive to photos
    $this->view->image = $photo = Engine_Api::_()->core()->getSubject();

    $this->view->canEdit = $photo->authorization()->isAllowed(null, 'edit');

    $this->view->canDelete = $photo->authorization()->isAllowed(null, 'delete');

    // retrive to recipe details base on photos
    $this->view->recipe = $recipe = $photo->getCollection();

    // retrive viewr_id
    $this->view->viewer_id = $viewer_id = Engine_Api::_()->user()->getViewer()->getIdentity();
    if (empty($this->view->canEdit) && $photo->user_id == $viewer_id)
      $this->view->canEdit = 1;
    if (empty($this->view->canDelete) && $photo->user_id == $viewer_id)
      $this->view->canDelete = 1;
    // retrive recipe details for recipe_id
    $recipe = Engine_Api::_()->getItem('recipe', $recipe->recipe_id);

    if (!empty($viewer_id)) {  
      $this->view->report = $report = (int) Engine_Api::_()->getApi('settings', 'core')->getSetting('recipe.report', 1);
      $this->view->share = $share = (int) Engine_Api::_()->getApi('settings', 'core')->getSetting('recipe.share', 1);
    }
     $this->view->enablePinit = Engine_Api::_()->getApi('settings', 'core')->getSetting('seaocore.photo.pinit', 0);
  }
}