<?php

/**
 * SocialEngine
 *
 * @category   Application_Extensions
 * @package    Recipe
 * @copyright  Copyright 2009-2010 BigStep Technologies Pvt. Ltd.
 * @license    http://www.socialengineaddons.com/license/
 * @version    $Id: PostController.php 6590 2010-12-31 9:40:21Z SocialEngineAddOns $
 * @author     SocialEngineAddOns
 */
class Recipe_PostController extends Core_Controller_Action_Standard {

  public function init() {
    if (Engine_Api::_()->core()->hasSubject())
      return;

    if (0 != ($post_id = (int) $this->_getParam('post_id')) &&
        null != ($post = Engine_Api::_()->getItem('recipe_post', $post_id))) {
      Engine_Api::_()->core()->setSubject($post);
    } else if (0 != ($topic_id = (int) $this->_getParam('topic_id')) &&
        null != ($topic = Engine_Api::_()->getItem('recipe_topic', $topic_id))) {
      Engine_Api::_()->core()->setSubject($topic);
    }
    $this->_helper->requireUser->addActionRequires(array(
            'edit',
            'delete',
    ));

    $this->_helper->requireSubject->setActionRequireTypes(array(
            'edit' => 'recipe_post',
            'delete' => 'recipe_post',
    ));
  }

  public function editAction() {
    $post = Engine_Api::_()->core()->getSubject('recipe_post');
    $recipe = $post->getParent('recipe');
    $viewer = Engine_Api::_()->user()->getViewer();

    if (!$recipe->isOwner($viewer) && !$post->isOwner($viewer)) {
      return $this->_helper->requireAuth->forward();
    }

    $this->view->form = $form = new Recipe_Form_Post_Edit();

    if (!$this->getRequest()->isPost()) {
      $form->populate($post->toArray());
      return;
    }

    if (!$form->isValid($this->getRequest()->getPost())) {
      return;
    }

    // Process
    $table = $post->getTable();
    $db = $table->getAdapter();
    $db->beginTransaction();

    try {
      $post->setFromArray($form->getValues());
      $post->modified_date = date('Y-m-d H:i:s');
      $post->save();
      $db->commit();
    } catch (Exception $e) {
      $db->rollBack();
      throw $e;
    }

    // Try to get topic
    return $this->_forward('success', 'utility', 'core', array(
            'closeSmoothbox' => true,
            'parentRefresh' => true,
    ));
  }

  public function deleteAction() {
    $post = Engine_Api::_()->core()->getSubject('recipe_post');
    $recipe = $post->getParent('recipe');
    $viewer = Engine_Api::_()->user()->getViewer();

    if (!$recipe->isOwner($viewer) && !$post->isOwner($viewer)) {
      return $this->_helper->requireAuth->forward();
    }

    $this->view->form = $form = new Recipe_Form_Post_Delete();

    if (!$this->getRequest()->isPost()) {
      return;
    }

    if (!$form->isValid($this->getRequest()->getPost())) {
      return;
    }

    // Process
    $table = $post->getTable();
    $db = $table->getAdapter();
    $db->beginTransaction();
    $topic_id = $post->topic_id;
    try {
      $post->delete();
      $db->commit();
    } catch (Exception $e) {
      $db->rollBack();
      throw $e;
    }

    // Try to get topic
    $topic = Engine_Api::_()->getItem('recipe_topic', $topic_id);

    $href = ( null == $topic ? $recipe->getHref() : $topic->getHref() );
    return $this->_forward('success', 'utility', 'core', array(
            'closeSmoothbox' => true,
            'parentRedirect' => $href,
            'messages' => array(Zend_Registry::get('Zend_Translate')->_('Post deleted.')),
    ));
  }

  public function canEdit($user) {
    return $this->getParent()->getParent()->authorization()->isAllowed($user, 'edit') || $this->isOwner($user);
  }

}