<?php

/**
 * SocialEngine
 *
 * @category   Application_Extensions 
 * @package    Sitead
 * @copyright  Copyright 2009-2011 BigStep Technologies Pvt. Ltd.
 * @license    http://www.socialengineaddons.com/license/
 * @version    $Id: Cash.php 2011-02-16 9:40:21Z SocialEngineAddOns $
 * @author     SocialEngineAddOns
 */
class Sitead_Plugin_Gateway_Cheque extends Engine_Payment_Plugin_Abstract {

  protected $_gatewayInfo;
  protected $_gateway;
  // General

  /**
   * Constructor
   */
  public function __construct(Zend_Db_Table_Row_Abstract $gatewayInfo) {
    $this->_gatewayInfo = $gatewayInfo;
  }

  /**
   * Get the service API
   *
   * @return Engine_Service_PayPal
   */
  public function getService() {
    return $this->getGateway()->getService();
  }

  /**
   * Get the gateway object
   *
   * @return Engine_Payment_Gateway
   */
  public function getGateway() {
    if (null == $this->_gateway) {
      $class = 'Engine_Payment_Gateway_Bank';
      Engine_Loader::loadClass($class);
      $gateway = new $class(array(
        'config' => (array) $this->_gatewayInfo->config,
        'testMode' => $this->_gatewayInfo->test_mode,
        'currency' => Engine_Api::_()->getApi('settings', 'core')->getSetting('payment.currency', 'USD'),
      ));
      if (!($gateway instanceof Engine_Payment_Gateway)) {
        $error_msg1 = Zend_Registry::get('Zend_Translate')->_('Plugin class not instance of Engine_Payment_Gateway');
        throw new Engine_Exception($error_msg1);
      }
      $this->_gateway = $gateway;
    }
    return $this->_gateway;
  }

  // Actions

  /**
   * Create a transaction object from specified parameters
   *
   * @return Engine_Payment_Transaction
   */
  public function createTransaction(array $params) {
    $transaction = new Engine_Payment_Transaction($params);
    $transaction->process($this->getGateway());
    return $transaction;
  }

  /**
   * Create an ipn object from specified parameters
   *
   * @return Engine_Payment_Ipn
   */
  public function createIpn(array $params) {
    $ipn = new Engine_Payment_Ipn($params);
    $ipn->process($this->getGateway());
    return $ipn;
  }

  public function detectIpn(array $params)
  {
    return false; // Never detect this as an IPN, or it will break real IPNs
  }

  /**
   * Generate href to a page detailing the order
   *
   * @param string $transactionId
   * @return string
   */
  public function getOrderDetailLink($orderId) {
    return false;
  }

  /**
   * Generate href to a page detailing the transaction
   *
   * @param string $transactionId
   * @return string
   */
  public function getTransactionDetailLink($transactionId) {
    return false;
  }

  /**
   * Get raw data about an order or recurring payment profile
   *
   * @param string $orderId
   * @return array
   */
  public function getOrderDetails($orderId) {
    return false;
  }

  /**
   * Get raw data about a transaction
   *
   * @param $transactionId
   * @return array
   */
  public function getTransactionDetails($transactionId) {
    return false;
  }

  // Forms
  public function getGatewayUserForm(){
    $form = new Payment_Form_Gateway_Cheque(array('settings'=>$this->_gatewayInfo->config));
    $form->populate((array) $this->_gatewayInfo->config);
    return $form;
  }

  /**
   * Get the admin form for editing the gateway info
   *
   * @return Engine_Form
   */
  public function getAdminGatewayForm() {
    return new Payment_Form_Admin_Gateway_Cheque();
  }

  public function processAdminGatewayForm(array $values) {
    return $values;
  }

  // IPN

  /**
   * Process an IPN
   *
   * @param Engine_Payment_Ipn $ipn
   * @return Engine_Payment_Plugin_Abstract
   */
  public function onIpn(Engine_Payment_Ipn $ipn) {
    throw new Engine_Payment_Plugin_Exception('Not implemented');
  }

  /**
   * Create a transaction for a advertiesment
   *
   * @param User_Model_User $user
   * @param Zend_Db_Table_Row_Abstract $userad
   * @param Sitead_Model_Package $package
   * @param array $params
   * @return Engine_Payment_Gateway_Transaction
   */
  public function createUserSiteadTransaction(User_Model_User $user, Zend_Db_Table_Row_Abstract $userad, Sitead_Model_Package $package, array $params = array()) {
    // This is a one-time fee
    // set parameters
    // create an object for view

    if (Engine_Api::_()->hasModuleBootstrap('sitecredit')) {
      //SESSION SET OF CREDITS.     
      $creditSession = new Zend_Session_Namespace('credit_package_payment_'.$package->getType());

      if (!empty($creditSession->packagePaymentCreditDetail)) {
        $creditDetail = unserialize($creditSession->packagePaymentCreditDetail);
        if(!empty($creditDetail['credit_amount']))
        $package->price =$package->price-$creditDetail['credit_amount'];
      }
    }

    $params['price'] = $package->price;

    // Create transaction
    $transaction = $this->createTransaction($params);

    return $transaction;
  }

  /**
   * Process return of advertiesment transaction
   *
   * @param Payment_Model_Order $order
   * @param array $params
   */
  public function onUseradTransactionReturn(
  Payment_Model_Order $order, array $params = array()) {
    // Check that gateways match
    if ($order->gateway_id != $this->_gatewayInfo->gateway_id) {
      throw new Engine_Payment_Plugin_Exception('Gateways do not match');
    }

    // Get related info
    $user = $order->getUser();
    $userad = $order->getSource();
    $package = $userad->getPackage();


    if (Engine_Api::_()->hasModuleBootstrap('sitecredit')) {
      //SESSION SET OF CREDITS.     
      $creditSession = new Zend_Session_Namespace('credit_package_payment_'.$package->getType());

      if (!empty($creditSession->packagePaymentCreditDetail)) {
        $creditDetail = unserialize($creditSession->packagePaymentCreditDetail);
        if(!empty($creditDetail['credit_amount']))
          $package->price =$package->price-$creditDetail['credit_amount'];
      }
    } 

    if ($userad->payment_status == 'pending') {
      return 'pending';
    }

    // Check for cancel state - the user cancelled the transaction
    if ($params['state'] == 'cancel') {
      // Cancel order and advertiesment?
      $order->onCancel();
      $userad->onPaymentFailure();
      // send notification
      if ($userad->didStatusChange()) {
        // SEND OVERDUE MAIL HERE
        Engine_Api::_()->sitead()->sendMail("OVERDUE", $userad->userad_id);
      }
      // Error
      throw new Payment_Model_Exception('Your payment has been cancelled and ' .
              'not been charged. If this is not correct, please try again later.');
    }

    // Update order with profile info and complete status?
    $order->state = 'pending';
    $order->gateway_transaction_id = crc32(microtime() . $order->order_id);
    $order->save();

    // Insert transaction
    $transactionsTable = Engine_Api::_()->getDbtable('transactions', 'sitead');
    $transactionsParams = array(
        'user_id' => $order->user_id,
        'gateway_id' => $this->_gatewayInfo->gateway_id,
        'timestamp' => new Zend_Db_Expr('NOW()'),
        'order_id' => $order->order_id,
        'type' => 'payment',
        'state' => 'pending',
        'gateway_transaction_id' => crc32(microtime() . $order->order_id),
        'amount' => $package->price, // @todo use this or gross (-fee)?
        'currency' => $this->getGateway()->getCurrency(),
    );
    $transaction_id = $transactionsTable->insert($transactionsParams);
    
    if(Engine_Api::_()->hasModuleBootstrap('sitegateway')) {
      $transactionParams = array_merge($transactionsParams, array('resource_type' => $order->source_type, 'resource_id' => $order->source_id));
      Engine_Api::_()->sitegateway()->insertTransactions($transactionParams);
    }    

    $transaction = Engine_Api::_()->getItem('sitead_transaction', $transaction_id);
    if(isset($_FILES['file']) && !empty($_FILES['file']['name'])) {
      $transaction->setPhoto($_FILES['file']);
    }

    // Get benefit setting
    $giveBenefit = Engine_Api::_()->getDbtable('transactions', 'sitead')
                    ->getBenefitStatus($user);

    // Check payment status
    if ($giveBenefit) {

      // Update advertiesment info
      $userad->gateway_id = $this->_gatewayInfo->gateway_id;
      $userad->gateway_profile_id = crc32(microtime() . $order->order_id);

      // Payment success
      $userad->onPaymentPending();

      // send notification
      if ($userad->didStatusChange()) {

        // SEND ACTIVE MAIL HERE
        Engine_Api::_()->sitead()->sendMail("ACTIVE", $userad->userad_id);
      }


      if (Engine_Api::_()->hasModuleBootstrap('sitecredit')) {
          //SESSION SET OF CREDITS.
          $param['user_id']=$user->getIdentity();
          $creditSession = new Zend_Session_Namespace('credit_package_payment_'.$package->getType());

          if (!empty($creditSession->packagePaymentCreditDetail)) {
              $creditDetail = unserialize($creditSession->packagePaymentCreditDetail);
              if($creditDetail['credit_points']) {
                  $param['type_id']=$order->order_id;
                  $param['credit_point']= -$creditDetail['credit_points'];
                  $param['type']= 'sitead_package';
                  $param['reason']='used credits for package purchase';
                  $param['resource_type']=$order->source_type;
                  $param['resource_id']=$order->source_id;
                  $credit_table = Engine_Api::_()->getDbtable('credits','sitecredit');    
                  $credit_table->insertCredit($param);
              }
          }
          $creditSession->packagePaymentCreditDetail = null;
      }

      return 'pending';
    } else {

      // Update advertiesment info
      $userad->gateway_id = $this->_gatewayInfo->gateway_id;
      $userad->gateway_profile_id = crc32(microtime() . $order->order_id);

      // Payment pending
      $userad->onPaymentPending();

      // send notification
      if ($userad->didStatusChange()) {
        // SEND PENDING MAIL HERE
        Engine_Api::_()->sitead()->sendMail("PENDING", $userad->userad_id);
      }

      return 'pending';
    } 
  }

  /**
   * Process ipn of advertiesment transaction
   *
   * @param Payment_Model_Order $order
   * @param Engine_Payment_Ipn $ipn
   */
  public function onUseradTransactionIpn(
  Payment_Model_Order $order, Engine_Payment_Ipn $ipn) {

  }

  public function cancelUserad($transactionId, $note = null) {

    return $this;
  }

  // SEv4 Specific

  /**
   * Create a transaction for a subscription
   *
   * @param User_Model_User $user
   * @param Zend_Db_Table_Row_Abstract $userad
   * @param Zend_Db_Table_Row_Abstract $package
   * @param array $params
   * @return Engine_Payment_Gateway_Transaction
   */
  public function createSubscriptionTransaction(User_Model_User $user, Zend_Db_Table_Row_Abstract $userad, Payment_Model_Package $package, array $params = array()) {

  }

  /**
   * Process return of subscription transaction
   *
   * @param Payment_Model_Order $order
   * @param array $params
   */
  public function onSubscriptionTransactionReturn(
  Payment_Model_Order $order, array $params = array()) {

  }

  /**
   * Process ipn of subscription transaction
   *
   * @param Payment_Model_Order $order
   * @param Engine_Payment_Ipn $ipn
   */
  public function onSubscriptionTransactionIpn(
  Payment_Model_Order $order, Engine_Payment_Ipn $ipn) {

  }

  /**
   * Cancel a subscription (i.e. disable the recurring payment profile)
   *
   * @params $transactionId
   * @return Engine_Payment_Plugin_Abstract
   */
  public function cancelSubscription($transactionId, $note = null) {

  }

}