<?php 
 /**
 * SocialEngine
 *
 * @category   Application_Extensions
 * @package    Siteaddlink
 * @copyright  Copyright 2019-2020 BigStep Technologies Pvt. Ltd.
 * @license    http://www.socialengineaddons.com/license/
 * @version    $Id: AdminMenusController.php 2019-09-18 18:02:08Z SocialEngineAddOns $
 * @author     SocialEngineAddOns
 */
class Siteaddlink_AdminMenusController extends Core_Controller_Action_Admin {

  protected $_menus;
  protected $_enabledModuleNames;

  public function init() {
    $this->view->navigation = $navigation = Engine_Api::_()->getApi('menus', 'core')
      ->getNavigation('siteaddlink_admin_main', array(), 'siteaddlink_admin_main_menus');
    $this->_enabledModuleNames = Engine_Api::_()->getDbtable('modules', 'core')->getEnabledModuleNames();
  }

  public function indexAction() {

    // Get menu items
    Engine_Api::_()->siteaddlink()->addMenuItems();
    $this->view->selectedMenuName = $name = 'siteaddlink_navigation';
    // Get menu items
    $menuItemsTable = Engine_Api::_()->getDbtable('menuItems', 'core');
    $menuItemsSelect = $menuItemsTable->select()
      ->where('menu = ?', $name)
      ->order('order');
    if (!empty($this->_enabledModuleNames)) {
      $menuItemsSelect->where('module IN(?)', $this->_enabledModuleNames);
    }
    $this->view->menuItems = $menuItems = $menuItemsTable->fetchAll($menuItemsSelect);
  }

  public function createAction() {
    $this->view->name = $name = $this->_getParam('name', 'siteaddlink_navigation');

    // Get list of menus
    // Get form
    $this->view->form = $form = new Siteaddlink_Form_Admin_Menu_ItemCreate();

    // Check stuff
    if (!$this->getRequest()->isPost()) {
      return;
    }
    if (!$form->isValid($this->getRequest()->getPost())) {
      return;
    }

    // Save
    $values = $form->getValues();
    $label = $values['label'];
    unset($values['label']);

    $menuItemsTable = Engine_Api::_()->getDbtable('menuItems', 'core');

    $menuItem = $menuItemsTable->createRow();
    $menuItem->label = $label;
    $menuItem->params = $values;
    $menuItem->menu = $name;
    $menuItem->module = 'siteaddlink'; // Need to do this to prevent it from being hidden
    $menuItem->plugin = '';
    $menuItem->submenu = '';
    $menuItem->custom = 1;
    $menuItem->save();

    $menuItem->name = 'custom_' . sprintf('%d', $menuItem->id);
    $menuItem->save();

    $this->view->status = true;
    $this->view->form = null;
  }

  public function editAction() {
    $this->view->name = $name = $this->_getParam('name');

    // Get menu item
    $menuItemsTable = Engine_Api::_()->getDbtable('menuItems', 'core');
    $menuItemsSelect = $menuItemsTable->select()
      ->where('name = ?', $name);
    if (!empty($this->_enabledModuleNames)) {
      $menuItemsSelect->where('module IN(?)', $this->_enabledModuleNames);
    }
    $this->view->menuItem = $menuItem = $menuItemsTable->fetchRow($menuItemsSelect);

    if (!$menuItem) {
      throw new Core_Model_Exception('missing menu item');
    }

    // Get form
    $this->view->form = $form = new Siteaddlink_Form_Admin_Menu_ItemEdit();

    // Make safe
    $menuItemData = $menuItem->toArray();
    if (isset($menuItemData['params']) && is_array($menuItemData['params'])) {
      $menuItemData = array_merge($menuItemData, $menuItemData['params']);
    }
    if (!$menuItem->custom) {
      $form->removeElement('uri');
    }
    unset($menuItemData['params']);

    // Check stuff
    if (!$this->getRequest()->isPost()) {
      $form->populate($menuItemData);
      return;
    }
    if (!$form->isValid($this->getRequest()->getPost())) {
      return;
    }

    // Save
    $values = $form->getValues();

    $menuItem->label = $values['label'];
    $menuItem->enabled = !empty($values['enabled']);
    unset($values['label']);
    unset($values['enabled']);

    if ($menuItem->custom) {
      $menuItem->params = $values;
    }

    $menuItem->params = $this->updateParam($values, 'iconUrl', $menuItem->params);
    $menuItem->params = $this->updateParam($values, 'target', $menuItem->params);

    if (empty($menuItem->params)) {
      $menuItem->params = '';
    }
    $menuItem->save();

    $this->view->status = true;
    $this->view->form = null;
  }

  public function deleteAction() {
    $this->view->name = $name = $this->_getParam('name');

    // Get menu item
    $menuItemsTable = Engine_Api::_()->getDbtable('menuItems', 'core');
    $menuItemsSelect = $menuItemsTable->select()
      ->where('name = ?', $name)
      ->order('order ASC');
    if (!empty($this->_enabledModuleNames)) {
      $menuItemsSelect->where('module IN(?)', $this->_enabledModuleNames);
    }
    $this->view->menuItem = $menuItem = $menuItemsTable->fetchRow($menuItemsSelect);

    if (!$menuItem || !$menuItem->custom) {
      throw new Core_Model_Exception('missing menu item');
    }

    // Get form
    $this->view->form = $form = new Core_Form_Admin_Menu_ItemDelete();

    // Check stuff
    if (!$this->getRequest()->isPost()) {
      return;
    }
    if (!$form->isValid($this->getRequest()->getPost())) {
      return;
    }

    $menuItem->delete();

    $this->view->form = null;
    $this->view->status = true;
  }

  public function orderAction() {
    if (!$this->getRequest()->isPost()) {
      return;
    }

    $table = Engine_Api::_()->getDbtable('menuItems', 'core');
    $menuitems = $table->fetchAll($table->select()->where('menu = ?', $this->getRequest()->getParam('menu')));
    foreach ($menuitems as $menuitem) {
      $order = $this->getRequest()->getParam('admin_menus_item_' . $menuitem->name);
      if (!$order) {
        $order = 999;
      }
      $menuitem->order = $order;
      $menuitem->save();
    }
    return;
  }

  public function updateParam($formValues, $paramName, $params) {
    if (!empty($formValues[$paramName])) {
      if (!empty($params)) {
        return $params = array_merge($params, array($paramName => $formValues[$paramName]));
      }
      return array($paramName => $formValues[$paramName]);
    } elseif (isset($params[$paramName])) {
      // Remove the $paramName
      $tempParams = array();
      foreach ($params as $key => $item) {
        if ($key != $paramName) {
          $tempParams[$key] = $item;
        }
      }
      return $tempParams;
    }
    return $params;
  }

}