<?php

/**
 * SocialEngine
 *
 * @category   Application_Extensions
 * @package    Siteandroidapp
 * @copyright  Copyright 2015-2016 BigStep Technologies Pvt. Ltd.
 * @license    http://www.socialengineaddons.com/license/
 * @version    Settings.php 2015-10-01 00:00:00Z SocialEngineAddOns $
 * @author     SocialEngineAddOns
 */
class Siteandroidapp_Form_Admin_AppBuilder_Settings extends Engine_Form {

    protected $_doWeHaveLatestVersion;
    protected $_enabledTabName;
    protected $_enabledModules;
    protected $_appBuilderParams;

    public function getDoWeHaveLatestVersion() {
        return $this->_doWeHaveLatestVersion;
    }

    public function setDoWeHaveLatestVersion($doWeHavelatestVersion) {
        $this->_doWeHaveLatestVersion = $doWeHavelatestVersion;
        return $this;
    }

    public function getEnabledTabName() {
        return $this->_enabledTabName;
    }

    public function setEnabledTabName($enabledTabName) {
        $this->_enabledTabName = $enabledTabName;
        return $this;
    }

    public function init() {
        $package = Zend_Controller_Front::getInstance()->getRequest()->getParam('package', '');
        $tab = Zend_Controller_Front::getInstance()->getRequest()->getParam('tab', 1);
        $subTab = Zend_Controller_Front::getInstance()->getRequest()->getParam('subTab', 1);
        $this->_appBuilderParams = Engine_Api::_()->getApi('core', 'siteandroidapp')->getSettingsFile();

        if (empty($package)) {
            $this->addElement('Select', 'package', array(
                'label' => 'Select Your Mobile Apps Subscription Plan',
                'required' => true,
                'allowEmpty' => false,
                'multiOptions' => array(
                    '' => '',
                    'starter' => 'Mobile Starter',
                    'pro' => 'Mobile Pro'
                ),
                'value' => $package,
                'onchange' => 'selectPackage()',
            ));
        } else {
            $APIModules = array(
                'album',
                'blog',
                'classified',
                'event',
                'forum',
                'group',
                'music',
                'poll',
                'video'
            );
            $modules = Engine_Api::_()->getDbtable('modules', 'core')->getEnabledModuleNames();
            $finalModules = array_intersect($APIModules, $modules);
            foreach ($finalModules as $module) {
                $this->_enabledModules[$module] = Engine_Api::_()->getDbTable('integrated', 'seaocore')->getModuleTitle($module);
            }

            if ($tab == 1) {
                $this->tabOneForm($package);
            } else if ($tab == 2) {
                $this->tabTwoForm($subTab);
            } else if ($tab == 3) {
                $this->tabThreeForm();
            } else if ($tab == 4) {
                $this->tabFourForm();
            } else if ($tab == 5) {
                $this->tabFiveForm();
            } else if ($tab == 6) {
                $this->tabSixForm();
            } else if ($tab == 7) {
                $this->tabSevenForm();
            }
        }
    }

    protected function validateMessengerSubscription() {
        $apiURL = 'http://channelize.io/rest/V1/api/hasMobileApps';
        $website = str_replace('www.', '', strtolower($_SERVER['HTTP_HOST']));

        $apiKey = Engine_Api::_()->getApi('settings', 'core')->getSetting('primemessenger.apikey', '');
    
        if (empty($apiKey))
            return false;

        $tempAdminMenuPost = array(
            'key' => base64_encode($apiKey)
        );

        $ch = curl_init();
        curl_setopt($ch, CURLOPT_URL, $apiURL);
        curl_setopt($ch, CURLOPT_CONNECTTIMEOUT, 0);
        curl_setopt($ch, CURLOPT_POST, true);
        curl_setopt($ch, CURLOPT_SSL_VERIFYPEER, false);
        curl_setopt($ch, CURLOPT_POSTFIELDS, $tempAdminMenuPost);
        ob_start();
        curl_exec($ch);
        curl_close($ch);
        $getCurlResponse = ob_get_contents();
        ob_end_clean();

        if (strstr($getCurlResponse, 'error::'))
            return false;

        return $getCurlResponse;
    }
    protected function tabOneForm($package) {
        $view = Zend_Registry::isRegistered('Zend_View') ? Zend_Registry::get('Zend_View') : null;

        if (($package === 'pro')) {
            $this->addElement('Dummy', 'google_play_details', array(
                'label' => Zend_Registry::get('Zend_Translate')->_('<h3 onclick="onBlockClick(event)" id="google_play_details" class="siteandroidapp_form_heading">Google Play Developer Credentials and Access</h3>'),
                'attribs' => array('class' => 'level1-1'),
            ));
            $this->google_play_details->getDecorator('Label')->setOptions(array('escape' => false));
            $this->google_play_details->getDecorator('Description')->setOptions(array('escape' => false));

            $this->addElement('Radio', 'publish_app', array(
                'label' => 'Submitting App to Google Play Store',
                'description' => "How do you want your Android App to be submitted to the Google Play Store?",
                'multiOptions' => array(
                    1 => 'I want the SocialApps.tech Support Team to submit my app.',
                    0 => 'I want my app’s “.apk” file to be sent to me, and I will myself submit the app.'
                ),
                'value' => 1,
                'onchange' => 'gmailAppSubmission()'
            ));
            $this->publish_app->getDecorator('Description')->setOptions(array('placement' => 'PREPEND', 'escape' => false));

            $this->addElement('Radio', 'provide_google_play_account_details', array(
                'label' => 'Google Play Developer Credentials / Access',
                'escape' => false,
                'multiOptions' => array(
                    1 => 'I will provide my Google Play Developer Account Details for app submission.',
                    0 => 'I will give permission to <a href="javascript:void(0)" target="_blank"> socialengineaddons@gmail.com</a> email address, to access my Google Play Developer Console.'
                ),
                'value' => 1,
                'onchange' => 'gmailPlayStorePermission()'
            ));

            $this->addElement('Text', 'gmail_permission_done', array(
                'decorators' => array(array('ViewScript', array(
                            'viewScript' => '_gmailPermission.tpl',
                            'class' => 'form element'
                        )))
            ));

            $this->addElement('Dummy', 'google_play_login', array(
                'label' => 'Google Play Account Details',
                'description' => '<span style="font-weight:bold;">Turned Off "2-Step Verification" for your Google Developer / Gmail Account. Follow this <a href="https://youtu.be/G8DtPEn1FpI" target="_blank"> video</a> to turn it off.</span>',
                'validators' => array(array('EmailAddress', 1)),
                'filters' => array('StringTrim')
            ));
            $this->google_play_login->getDecorator('Description')->setOptions(array('placement' => 'PREPEND', 'escape' => false));


            $this->addElement('Text', 'google_play_login_email', array(
                'placeholder' => 'Email Address',
                'validators' => array(array('EmailAddress', 1)),
                'filters' => array('StringTrim')
            ));
            $this->google_play_login_email->getDecorator('Description')->setOptions(array('placement' => 'PREPEND', 'escape' => false));

            $this->addElement('Text', 'google_play_login_password', array(
                'placeholder' => 'Password',
            ));
        }

        $this->addElement('Dummy', 'app_details', array(
            'label' => Zend_Registry::get('Zend_Translate')->_('<h3 onclick="onBlockClick(event)" id="app_details" class="siteandroidapp_form_heading">App Submission Details</h3>'),
        ));
        $this->app_details->getDecorator('Label')->setOptions(array('escape' => false));

        $this->addElement('Text', 'package_name', array(
            'label' => 'App Package Name',
            'description' => "Package Name is the URL component of your App in the Google Play Store and should be unique on it. Ideally it should be com.domain.app (domain is your website domain name). Suggested Package name for your app is mentioned in the field below, but you can change it if required. <b>Package name should be three words only</b>",
            'onblur' => 'PackageUrlBlur();',
            'value' => Engine_Api::_()->getApi('core', 'siteandroidapp')->getPackageNameFile(1)
        ));
        $this->package_name->getDecorator('Description')->setOptions(array('placement' => 'PREPEND', 'escape' => false));

        $this->addElement('Text', 'title', array(
            'label' => 'App Title',
            'description' => 'Character limit is 0 to 30.<a target="_blank" class="mleft5" title="View Screenshot" href="application/modules/Siteandroidapp/externals/images/Title.png" target="_blank"><img src="application/modules/Siteandroidapp/externals/images/eye.png" /></a>',
            'required' => true,
            'allowEmpty' => false,
            'maxlength' => 30,
            'validators' => array(
                array('stringLength', false, array(0, 30))
            )
        ));
        $this->title->getDecorator('Description')->setOptions(array('placement' => 'PREPEND', 'escape' => false));

        $this->addElement('Textarea', 'short_description', array(
            'label' => 'App Short Description',
            'description' => 'Character limit is 0 to 80.<a target="_blank" class="mleft5" title="View Screenshot" href="application/modules/Siteandroidapp/externals/images/Description.png" target="_blank"><img src="application/modules/Siteandroidapp/externals/images/eye.png" /></a>',
            'required' => true,
            'allowEmpty' => false,
            'validators' => array(
                array('stringLength', false, array(0, 80))
            )
        ));
        $this->short_description->getDecorator('Description')->setOptions(array('placement' => 'PREPEND', 'escape' => false));

        $this->addElement('Textarea', 'description', array(
            'label' => 'App Description',
            'description' => 'Character limit is 0 to 4000. <a target="_blank" class="mleft5" title="View Screenshot" href="application/modules/Siteandroidapp/externals/images/rating.png" target="_blank"><img src="application/modules/Siteandroidapp/externals/images/eye.png" /></a><a href="https://play.google.com/about/developer-content-policy" target="_blank"> See tips </a>for creating policy compliant description.',
            'required' => true,
            'allowEmpty' => false,
            'validators' => array(
                array('stringLength', false, array(0, 4000))
            )
        ));
        $this->description->getDecorator('Description')->setOptions(array('placement' => 'PREPEND', 'escape' => false));

        $this->addElement('Text', 'default_language', array(
            'label' => 'Default Language',
            'description' => 'Language that we need to choose while submitting your App on Play Store. We will not be doing any translations.',
            'required' => true,
            'allowEmpty' => false
        ));

        $this->addElement('Select', 'category', array(
            'label' => 'App Category',
            'description' => 'Your App Category that will display at Play Store. (For ex. choose Sports category for Bikes based community). <a target="_blank" class="mleft5" title="View Screenshot" href="application/modules/Siteandroidapp/externals/images/Description.png" target="_blank"><img src="application/modules/Siteandroidapp/externals/images/eye.png" /></a>',
            'required' => true,
            'allowEmpty' => false,
            'multiOptions' => array(
                'book_&_reference' => 'Books & Reference',
                'business' => 'Business',
                'comics' => 'Comics',
                'communication' => 'Communication',
                'education' => 'Education',
                'entertainment' => 'Entertainment',
                'finance' => 'Finance',
                'health_&_fitness' => 'Health & Fitness',
                'libraries_&_demo' => 'Libraries & Demo',
                'lifestyle' => 'Lifestyle',
                'media_&_video' => 'Media & Video',
                'medical' => 'Medical',
                'music_&_audio' => 'Music & Audio',
                'news_&_magazines' => 'News & Magazines',
                'personalization' => 'Personalization',
                'photography' => 'Photography',
                'productivity' => 'Productivity',
                'shopping' => 'Shopping',
                'social' => 'Social',
                'sports' => 'Sports',
                'tools' => 'Tools',
                'transportation' => 'Transportation',
                'traval_&_local' => 'Travel & Local',
                'weather' => 'Weather'
            ),
        ));
        $this->category->getDecorator('Description')->setOptions(array('placement' => 'PREPEND', 'escape' => false));

        $this->addElement('Select', 'content_rating', array(
            'label' => 'Content Rating',
            'description' => '<div class="tooltip_main">Select content rating of your app. <a target="_blank" class="mleft5" title="View Screenshot" href="application/modules/Siteandroidapp/externals/images/rating.png" target="_blank"><img src="application/modules/Siteandroidapp/externals/images/eye.png" /></a><span class="tooltip"><span class="tooltiptext">As per Google Play content rating policy, the Content Rating of your app cannot be one of the other 2 options: Low Maturity and Everyone as it will enable communication between users, and hence requires Medium Maturity or higher content rating. <a href=\'https://support.google.com/googleplay/android-developer/answer/188189#ugc\' target="_blank" title= "">Read More.</a></span><a class="admin help" href="" target="_blank" title= ""></a></span></div>',
            'required' => true,
            'allowEmpty' => false,
            'multiOptions' => array(
                '' => '',
                'high_maturity' => 'High Maturity',
                'medium_maturity' => 'Medium Maturity'
            ),
        ));
        $this->content_rating->getDecorator('Description')->setOptions(array('placement' => 'PREPEND', 'escape' => false));

        $this->addElement('File', 'firebase_google_services', array(
            'label' => 'Google Services File',
            'description' => "This file is required for Push Notifications. Upload the file that you've downloaded while following <a href='https://youtu.be/0PNvUN9YfZY' target='_blank'>video</a> for Project Number.",
        ));
        $this->firebase_google_services->getDecorator('Description')->setOptions(array('placement' => 'PREPEND', 'escape' => false));

        $this->addElement('Dummy', 'contact_details', array(
            'label' => Zend_Registry::get('Zend_Translate')->_('<h3 onclick="onBlockClick(event)" id="contact_details" class="siteandroidapp_form_heading">Contact Details</h3>'),
            'description' => 'This information will be displayed at your app’s listing on Play Store. <a target="_blank" class="mleft5" title="View Screenshot" href="application/modules/Siteandroidapp/externals/images/website.png" target="_blank"><img src="application/modules/Siteandroidapp/externals/images/eye.png" /></a>'));
        $this->contact_details->getDecorator('Label')->setOptions(array('escape' => false));
        $this->contact_details->getDecorator('Description')->setOptions(array('escape' => false));

        $this->addElement('Text', 'website_contact_details', array(
            'label' => 'Website',
            'required' => true,
            'allowEmpty' => false,
        ));

        $this->addElement('Text', 'email_contact_details', array(
            'label' => 'Email',
            'required' => true,
            'allowEmpty' => false,
            'validators' => array(array('EmailAddress', 1)),
            'filters' => array('StringTrim')
        ));

        // Deepak add URI validator here.
        $this->addElement('Text', 'policy_url', array(
            'label' => 'Privacy Policy URL',
            'required' => true,
            'allowEmpty' => false,
        ));

        $this->addElement('Dummy', 'app_default_settings', array(
            'label' => Zend_Registry::get('Zend_Translate')->_('<h3 onclick="onBlockClick(event)" id="app_default_settings" class="siteandroidapp_form_heading">Default App Settings</h3>'),
        ));
        $this->app_default_settings->getDecorator('Label')->setOptions(array('escape' => false));

        $consumerCalling = $view->url(array('module' => 'siteapi', 'controller' => 'consumers', 'action' => 'manage'), 'admin_default', true);
        $this->addElement('Dummy', 'api_key', array(
            'label' => 'API Keys',
            'description' => '<a href="' . $consumerCalling . '" target="_blank">Create</a> and Enter API Consumer key and Consumer Secret. This is required for communication between your server and mobile apps.<span class="tooltip">',
            'required' => true,
            'allowEmpty' => false
        ));
        $this->api_key->getDecorator('Description')->setOptions(array('placement' => 'PREPEND', 'escape' => false));

        $this->addElement('Text', 'api_consumer_key', array(
            'placeholder' => 'API Consumer Key',
            'required' => true,
            'allowEmpty' => false
        ));
        $this->api_consumer_key->getDecorator('Description')->setOptions(array('placement' => 'PREPEND', 'escape' => false));

        $this->addElement('Text', 'api_consumer_secret', array(
            'placeholder' => 'API Consumer Secret',
            'required' => true,
            'allowEmpty' => false
        ));
        $this->api_consumer_secret->getDecorator('Description')->setOptions(array('placement' => 'PREPEND', 'escape' => false));


        $mapGuidelines = $view->url(array('module' => 'seaocore', 'controller' => 'settings', 'action' => 'map-guidelines'), 'admin_default', true);
        $this->addElement('Text', 'map_key', array(
            'label' => 'Google Places API Key',
            'description' => '<div class="tooltip_main">This is used for location features like Check-in etc. Visit the <a href="' . $mapGuidelines . '" target="_blank">Guidelines</a> to configure this key.<span class="tooltip"><span class="tooltiptext">We recommend you to enable the billing feature for this API calling as google allow free usage only up to a certain limit, after which it does not give the required response resulting in blank pages. <a href="https://support.google.com/cloud/answer/6158867" target="_blank"> Read More..</a></span><a class="admin help" href="void(0)"></a></span></div>',
            'value' => Engine_Api::_()->getApi('settings', 'core')->getSetting('seaocore.google.map.key')
        ));
        $this->map_key->getDecorator('Description')->setOptions(array('placement' => 'PREPEND', 'escape' => false));

        // Giphy integration api key work
        $this->addElement('Text', "giphy_api_key", array(
            'label' => 'GIPHY API Key',
            'description' => "Enter the GIPHY API key. [Note: You can create GIPHY API Key from <a target='_blank' href='https://developers.giphy.com/dashboard/?create=true'>here</a>. If you already have the key, then simply get it from <a target='_blank' href='https://developers.giphy.com/dashboard'>here</a>.]",
            'allowEmpty' => false,
            'required' => true,
            'value' => Engine_Api::_()->getApi('settings', 'core')->getSetting('sitegifplayer.giphy.apikey', ''),
        ));

        $this->giphy_api_key->getDecorator('Description')->setOptions(array('placement' => 'PREPEND', 'escape' => false));

        $this->addElement('Hidden', 'commit_chat_package', array(
            'label' => 'CometChat Package Name',
            'description' => '<div class="tooltip_main">Enter the package name of your CometChat.<span class="tooltip"><span class="tooltiptext">If you are not having it then please contact to the CometChat team. To integrate your CometChat app with your SocialEngine app, you should have your CometChat app already built and published on Google Play Store.</span><a class="admin help" href=""></a></span></div>'
        ));

        $url = $view->url(array('module' => 'siteapi', 'controller' => 'settings'), 'admin_default', true);
        $this->addElement('Radio', 'siteapi_validate_ssl', array(
            'label' => 'Protocol Selection',
            'description' => '<div class="tooltip_main">It is suggested to run your website on https.<span class="tooltip"><span class="tooltiptext">If you are still working to run your website on https then you should wait to send us mobile application request until site run on https.<a href="' . $url . '#siteapi_ssl_verification" target="_blank"> Read More..</a></span><a class="admin help" href="void(0)" target="_blank"></a></span></div>',
            'multiOptions' => array(
                0 => 'I do not want to run my website on https',
                1 => 'I am running my website on https'
            ),
            'required' => true,
            'allowEmpty' => false
        ));
        $this->siteapi_validate_ssl->getDecorator('Description')->setOptions(array('placement' => 'PREPEND', 'escape' => false));

        if (isset($this->_enabledModules) && !empty($this->_enabledModules)) {
            $this->addElement('Multiselect', 'enabledModules', array(
                'label' => 'Modules in App',
                'description' => 'Choose Core Modules from your website that you want to be available in your Android App. All plugins from SocialApps.tech installed on your website will be available automatically in the app.',
                'multiOptions' => $this->_enabledModules,
                'value' => array_keys($this->_enabledModules)
            ));
            $this->enabledModules->getDecorator('Description')->setOptions(array('placement' => 'PREPEND', 'escape' => false));
        }

        $chrome = "<a target='_blank' class='mleft5' title='View Screenshot' href='application/modules/Siteandroidapp/externals/images/Chrome.png' target='_blank'><img src='application/modules/Siteandroidapp/externals/images/eye.png' /></a>";
        $self = "<a target='_blank' class='mleft5' title='View Screenshot' href='application/modules/Siteandroidapp/externals/images/In-app.png' target='_blank'><img src='application/modules/Siteandroidapp/externals/images/eye.png' /></a>";
        $this->addElement('Radio', 'app_webview', array(
            'label' => 'WebView Type',
            'escape' => false,
            'description' => "Webview is used to access non-integrated modules in the app. Recommended webview type is “Chrome-extension” as it’s comparatively faster than the “Self-designed in-app” webview.",
            'multiOptions' => array(
                0 => 'Self-Designed In-App Webview ' . $chrome,
                1 => 'Chrome Extension for Webview ' . $self
            ),
            'value' => 0
        ));
        $this->app_webview->getDecorator('Description')->setOptions(array('placement' => 'PREPEND', 'escape' => false));

        $onlySearch = '<a target="_blank" class="mleft5" title="View Screenshot" href="application/modules/Siteandroidapp/externals/images/App_Header_with_Search_only.png" target="_blank"><img src="application/modules/Siteandroidapp/externals/images/eye.png" /></a>';
        $withSearch = '<a target="_blank" class="mleft5" title="View Screenshot" href="application/modules/Siteandroidapp/externals/images/App_Header_with_Title.png" target="_blank"><img src="application/modules/Siteandroidapp/externals/images/eye.png" /></a>';

        $this->addElement('Radio', 'isshow_app_name', array(
            'label' => 'Header UI in app',
            'description' => 'Select the header type you want to display in the app.',
            'escape' => false,
            'multiOptions' => array(
                0 => 'Only the Search Bar in complete App Header ' . $onlySearch,
                1 => 'App Name and Search Icon in the App Header ' . $withSearch
            ),
            'value' => 0
        ));
        $this->getElement('isshow_app_name')->getDecorator('Description')->setEscape(false);

        if (Engine_Api::_()->getDbtable('modules', 'core')->isModuleEnabled('primemessenger')) {
            $validateMessengerSubscription = $this->validateMessengerSubscription();
            if ($validateMessengerSubscription) {
                $this->addElement('Radio', 'enable_primemessenger', array(
                    'description' => 'Enable Prime Messenger for the App?',
                    'label' => 'Display Messenger',
                    'multiOptions' => array(
                        1 => "Yes",
                        0 => "No"
                    ),
                    'value' => 1
                ));
                $this->enable_primemessenger->getDecorator('Description')->setOptions(array('placement' => 'PREPEND', 'escape' => false));

                $this->addElement('Radio', 'channelize_version', array(
                    'description' => 'Do you want to create the app from which version?',
                    'label' => 'Channelize Version',
                    'multiOptions' => array(
                        0 => "v1",
                        1 => "v2"
                    ),
                    'value' => 1
                ));
                $this->channelize_version->getDecorator('Description')->setOptions(array('placement' => 'PREPEND', 'escape' => false));
            }
        }

        $this->addElement('Radio', 'showcase_app', array(
            'label' => 'Allow Showcasing Apps',
            'description' => "Showcase your app on our SocialApps.tech website, blog posts and newsletters?",
            'multiOptions' => array(
                0 => "No",
                1 => "Yes"
            ),
            'value' => 0
        ));
        $this->showcase_app->getDecorator('Description')->setOptions(array('placement' => 'PREPEND', 'escape' => false));

        if (Engine_Api::_()->getDbtable('modules', 'core')->isModuleEnabled('sitestore')) {
            $this->addElement('Radio', 'header_cart_display', array(
                'description' => 'Display Cart Icon in App Header on Home Page.<a target="_blank" class="mleft5" title="View Screenshot" href="application/modules/Siteandroidapp/externals/images/Header.png" target="_blank"><img src="application/modules/Siteandroidapp/externals/images/eye.png" /></a>',
                'label' => 'Display Cart Icon',
                'multiOptions' => array(
                    0 => "No",
                    1 => "Yes"
                ),
                'value' => 1
            ));
            $this->header_cart_display->getDecorator('Description')->setOptions(array('placement' => 'PREPEND', 'escape' => false));
        }


        $this->addElement('Radio', 'rate_us', array(
            'description' => 'Enabling this feature will display a Rate Us pop-up to app users at appropriate instances.',
            'multiOptions' => array(
                0 => "No",
                1 => "Yes"
            ),
            'value' => 0,
            'label' => "Enable Rate Us feature ?",
        ));
        $this->rate_us->getDecorator('Description')->setOptions(array('placement' => 'PREPEND', 'escape' => false));

        $this->addElement('Dummy', 'social_website_details', array(
            'label' => Zend_Registry::get('Zend_Translate')->_('<h3 onclick="onBlockClick(event)" id="social_website_details" class="siteandroidapp_form_heading">Social Login and Share</h3>'),
        ));
        $this->social_website_details->getDecorator('Label')->setOptions(array('escape' => false));

        $view = Zend_Registry::isRegistered('Zend_View') ? Zend_Registry::get('Zend_View') : null;
        $facebook = $view->url(array('module' => 'user', 'controller' => 'settings', 'action' => 'facebook'), 'admin_default', true);
        $twitter = $view->url(array('module' => 'user', 'controller' => 'settings', 'action' => 'twitter'), 'admin_default', true);

        $description = "Allow your app users to login via below Social Platforms. Social Login the app will work only if ";

        if (Engine_Api::_()->getDbtable('modules', 'core')->isModuleEnabled('sitelogin')) {
            $google = $view->url(array('module' => 'sitelogin', 'controller' => 'settings', 'action' => 'google'), 'admin_default', true);
            $description .= "<a href=" . $facebook . " >Facebook</a>, <a href=" . $twitter . " >Twitter</a> and <a href=" . $google . " >Google</a>";
        } else {
            $description .= "<a href=" . $facebook . " >Facebook</a> and <a href=" . $twitter . " >Twitter</a>";
        }

        $description .= " Login is enabled on your website. <a target='_blank' class='mleft5' title='View Screenshot' href='application/modules/Siteandroidapp/externals/images/social.png' target='_blank'><img src='application/modules/Siteandroidapp/externals/images/eye.png' /></a>";

        $this->addElement('Dummy', 'social_login', array(
            'label' => Zend_Registry::get('Zend_Translate')->_('Social Login'),
            'description' => Zend_Registry::get('Zend_Translate')->_($description),
        ));

        $this->social_login->getDecorator('Description')->setOptions(array('placement' => 'PREPEND', 'escape' => false));

        $this->addElement('Text', 'twitter_app_id', array(
            'decorators' => array(array('ViewScript', array(
                        'viewScript' => '_twitterLogin.tpl',
                        'class' => 'form element',
                    )))
        ));


        $this->addElement('Text', 'facebook_app_id', array(
            'decorators' => array(array('ViewScript', array(
                        'viewScript' => '_facebookLogin.tpl',
                        'class' => 'form element'
                    )))
        ));

        $isSocialLoginEnabled = Engine_Api::_()->getDbtable('modules', 'core')->isModuleEnabled('sitelogin');
        if ($isSocialLoginEnabled) {
            $this->addElement('Text', 'google_app_id', array(
                'decorators' => array(array('ViewScript', array(
                            'viewScript' => '_googleLogin.tpl',
                            'class' => 'form element'
                        )))
            ));
        }

        $this->addElement('Text', 'facebook_access_permission', array(
            'decorators' => array(array('ViewScript', array(
                        'viewScript' => '_facebookAccessPermission.tpl',
                        'class' => 'form element'
                    )))
        ));

        $this->addElement('Dummy', 'social_share', array(
            'label' => Zend_Registry::get('Zend_Translate')->_('Social Share'),
            'description' => Zend_Registry::get('Zend_Translate')->_("Enable Content sharing from Status Box to below Social Platforms."),
        ));
        $this->social_share->getDecorator('Description')->setOptions(array('placement' => 'APPEND', 'escape' => false));

        $this->addElement('Checkbox', 'twitter_post', array(
            'label' => 'Twitter',
        ));

        $this->addElement('Checkbox', 'facebook_post', array(
            'label' => '<span class="tooltip_main">Facebook<span class="tooltip"><span class="tooltiptext">Content sharing from Status Box to Facebook will work only if you have configured "Publish to Facebook" setting (from Admin > Settings > Facebook Integration) on your website. To enable this functionality in app, you need to get "Publish_actions" permission approved from Facebook. Please click<a href="https://www.socialengineaddons.com/page/facebook-permission-ios-android-mobile-app" target="_blank"> here </a>for the steps of permission approval.</span><a class="admin help" href="void(0)" target="_blank"></a></span></span>',
            'onchange' => 'facebookPermission()'
        ));
        $this->facebook_post->getDecorator('Label')->setOptions(array('placement' => 'APPEND', 'escape' => false));
        
        
    $enableLivestreamingModule = Engine_Api::_()->getDbtable('modules', 'core')->isModuleEnabled('livestreamingvideo');
       if($enableLivestreamingModule)
       {
            $this->addElement('Dummy', 'live_broadcast_settings', array(
                'label' => Zend_Registry::get('Zend_Translate')->_('<h3 onclick="onBlockClick(event)" id="live_broadcast_settings" class="siteandroidapp_form_heading">Live Broadcast Settings</h3>'),
            ));
            $this->live_broadcast_settings->getDecorator('Label')->setOptions(array('escape' => false));

            $this->addElement('Radio', 'enable_broadcast', array(
                'description' => 'Do you want to integrate live broadcasting?',
                'multiOptions' => array(
                    "1" => "Yes",
                    "0" => "No"
                ),
                'value' => 0,
                'label' => "Integrate Live Broadcasting?",
                 'onchange' => 'liveBroadcast()'
            ));

            $view = Zend_Registry::isRegistered('Zend_View') ? Zend_Registry::get('Zend_View') : null;
            $URL = $view->url(array('module' => 'livestreamingvideo', 'controller' => 'settings', 'action' => 'index'), 'admin_default', true);
            $description = sprintf(Zend_Registry::get('Zend_Translate')->_('Please enter the agora id at %1sGlobal Settings%2s of Live Broadcasting Plugin.'), "<a href='" . $URL . "' target='_blank'>", "</a>");
            
            $this->addElement('Text', 'agora_app_id', array(
                'label' => "Enter Agora Project ID?",
                'description' =>  $description,
                'attribs'    => array('readonly' => true)
            ));
            
            $this->getElement('agora_app_id')->getDecorator('Description')->setEscape(false);

            $url_description = sprintf(Zend_Registry::get('Zend_Translate')->_('Please enter the agora server url at %1sGlobal Settings%2s of Live Broadcasting Plugin.'), "<a href='" . $URL . "' target='_blank'>", "</a>");

            $this->addElement('Text', 'live_stream_url', array(
                'label' => "Agora Server URL?",
                'description' => $url_description,
                'attribs'    => array('readonly' => true)
            ));

            $this->live_stream_url->getDecorator('Description')->setOption('escape', false);
       }
         

        $this->addElement('Button', 'submit', array(
            'label' => 'Save Changes and Continue',
            'type' => 'submit',
            'ignore' => true,
        ));
    }

    protected function tabTwoForm($subTab) {
        if ($subTab == 1) {
            $this->addElement('Dummy', 'app_color_code', array(
                'label' => Zend_Registry::get('Zend_Translate')->_('<h3>App Branding Colors</h3>'),
            ));
            $this->app_color_code->getDecorator('Label')->setOptions(array('escape' => false));

            $this->addElement('Text', 'app_header_color_primary', array(
                'decorators' => array(array('ViewScript', array(
                            'viewScript' => '_themeHeaderColorPrimary.tpl',
                            'class' => 'form element'
                        )))
            ));

            $this->addElement('Text', 'app_header_color_dark', array(
                'decorators' => array(array('ViewScript', array(
                            'viewScript' => '_themeHeaderColorDark.tpl',
                            'class' => 'form element'
                        )))
            ));

            $this->addElement('Text', 'app_header_text_color', array(
                'decorators' => array(array('ViewScript', array(
                            'viewScript' => '_themeHeaderTextColor.tpl',
                            'class' => 'form element'
                        )))
            ));

            $this->addElement('Text', 'app_header_color_accent', array(
                'decorators' => array(array('ViewScript', array(
                            'viewScript' => '_themeHeaderColorAccent.tpl',
                            'class' => 'form element'
                        )))
            ));

            $this->addElement('Text', 'app_button_color', array(
                'decorators' => array(array('ViewScript', array(
                            'viewScript' => '_appButtonColor.tpl',
                            'class' => 'form element'
                        )))
            ));

            $this->addElement('Select', 'font', array(
                'label' => 'App Font Style',
                'description' => 'Select the font style for your App with below dropdown. <a target="_blank" class="mleft5" title="View Screenshot" href="application/modules/Siteandroidapp/externals/images/fonts-preview.png" target="_blank"><img src="application/modules/Siteandroidapp/externals/images/eye.png" /></a>',
                'required' => true,
                'allowEmpty' => false,
                'multiOptions' => array(
                    'Roboto-Regular' => 'Roboto Regular (Default)',
                    'Abel-Regular' => 'Abel Regular',
                    'Amaranth-Regular' => 'Amaranth Regular',
                    'Audiowide-Regular' => 'Audiowide Regular',
                    'Bellerose' => 'Bellerose Light',
                    'CLOSCP__' => 'Closecall PM',
                    'Comfortaa-Regular' => 'Comfortaa Regular',
                    'Dosis-Regular' => 'Dosis Book',
                    'Exo-Regular' => 'Exo Regular',
                    'FortuneCity' => 'FortuneCity Regular',
                    'HappyMonkey-Regular' => 'Happy Monkey Regular',
                    'Joyful Juliana' => 'Joyful Juliana Regular',
                    'Lato-Regular' => 'Lato Regular',
                    'Oxygen-Regular' => 'Oxygen Regular',
                    'Philosopher-Regular' => 'Philosopher Regular',
                    'Playball-Regular' => 'Playball Regular',
                    'Play-Regular' => 'Play Regular',
                    'PT_Sans-Narrow-Web-Regular' => 'PT Sans Narrow Regular',
                    'Sansation_Regular' => 'Sansation Regular',
                    'Walkway rounded' => 'Walkway Rounded Regular',
                    'Walkway UltraBold' => 'Walkway UltraBond Regular',
                    'KGAlwaysAGoodTime' => 'KG Always A Good Time',
                    'MavenPro-Regular' => 'MavenPro'
                ),
                'value' => 'Roboto-Regular'
            ));
            $this->font->getDecorator('Description')->setOptions(array('placement' => 'PREPEND', 'escape' => false));

            $this->addElement('Radio', 'image_upload_type', array(
                'label' => 'Graphics Upload and Resizing Process:',
                'description' => 'This setting is useful for the next steps in the form. “Automatic” option is suggested where you need to upload just few images of maximum size and system will resize them to required sizes and upload in the form.',
                'multiOptions' => array(
                    1 => 'Automatic',
                    0 => 'Manual'
                ),
                'value' => 1,
            ));
            $this->image_upload_type->getDecorator('Description')->setOptions(array('placement' => 'PREPEND', 'escape' => false));
        } elseif ($subTab == 2) {
            $this->addElement('Dummy', 'graphic_assets', array(
                'label' => Zend_Registry::get('Zend_Translate')->_('<h3>Graphic Assets</h3><br />You can download sample Graphic Assets for your reference from <a href="http://www.socialengineaddons.com/sites/default/files/Sample_Graphics_Assets_Android_App.tar">here</a>. If you would like us to build the required graphic assets for your iOS and Android apps, then please order our service: "<a href="http://www.socialengineaddons.com/services/building-graphic-assets-ios-android-mobile-apps" target="_blank">Building Graphic Assets for Mobile Apps</a>".'),
            ));
            $this->graphic_assets->getDecorator('Label')->setOptions(array('escape' => false));

            $this->addElement('Dummy', 'app_icon', array(
                'label' => Zend_Registry::get('Zend_Translate')->_('<h3 onclick="onBlockClick(event)" id="app_icon" class="siteandroidapp_form_heading">App Icons</h3>'),
            ));
            $this->app_icon->getDecorator('Label')->setOptions(array('escape' => false));
            if (isset($this->_appBuilderParams['image_upload_type']) && empty($this->_appBuilderParams['image_upload_type'])) {
                $this->addElement('File', 'app_icon_2', array(
                    'label' => 'PNG in 48 x 48 px',
                    'validators' => array(
                        array('Extension', false, 'png')
                    )
                ));

                $this->addElement('File', 'app_icon_3', array(
                    'label' => 'PNG in 72 x 72 px',
                    'validators' => array(
                        array('Extension', false, 'png')
                    )
                ));

                $this->addElement('File', 'app_icon_4', array(
                    'label' => 'PNG in 96 x 96 px',
                    'validators' => array(
                        array('Extension', false, 'png')
                    )
                ));

                $this->addElement('File', 'app_icon_5', array(
                    'label' => 'PNG in 180 x 180 px',
                    'validators' => array(
                    )
                ));
            }

            $this->addElement('File', 'notification_icon', array(
                'label' => 'Notification PNG in 48 x 48 px',
                'description' => 'Icon should be of white color with transparent background.',
                'validators' => array(
                    array('Extension', false, 'png')
                )
            ));

            $this->addElement('File', 'notification_icon_large', array(
                'label' => 'Notification PNG in 512 x 512 px (Transparent)',
                'description' => 'Icon should be of white color with transparent background.',
                'validators' => array(
                    array('Extension', false, 'png')
                )
            ));

            $this->addElement('File', 'hi_res_icon', array(
                'label' => Zend_Registry::get('Zend_Translate')->_('App Icon PNG in 512 x 512 px'),
                'description' => '512 x 512 pixels, 32-bit PNG (with alpha)',
                'validators' => array(
                    array('Extension', false, 'png')
                )
            ));

            $this->addElement('File', 'feature_graphics', array(
                'label' => Zend_Registry::get('Zend_Translate')->_('Feature Graphic PNG in 1024 x 500 px'),
                'description' => 'This image is displayed as main photo for your app Play Store <a target="_blank" class="mleft5" title="View Screenshot" href="application/modules/Siteandroidapp/externals/images/Splash.PNG" target="_blank"><img src="application/modules/Siteandroidapp/externals/images/eye.png" /></a>',
                'validators' => array(
                    array('Extension', false, 'png')
                )
            ));
            $this->feature_graphics->getDecorator('Description')->setOptions(array('placement' => 'PREPEND', 'escape' => false));

            $this->addElement('Dummy', 'splash_screen', array(
                'label' => Zend_Registry::get('Zend_Translate')->_('<h3 onclick="onBlockClick(event)" id="splash_screen" class="siteandroidapp_form_heading">Splash Screen Images</h3>'),));
            $this->splash_screen->getDecorator('Label')->setOptions(array('escape' => false));

            $png = ' <a target="_blank" class="mleft5" title="View Screenshot" href="application/modules/Siteandroidapp/externals/images/feature.png" target="_blank"><img src="application/modules/Siteandroidapp/externals/images/eye.png" /></a>';
            $gif = '<a target="_blank" class="mleft5" title="View Screenshot" href="application/modules/Siteandroidapp/externals/images/Splash.gif" target="_blank"><img src="application/modules/Siteandroidapp/externals/images/eye.png" /></a>';
            $this->addElement('Radio', 'welcome_image_type', array(
                'label' => 'Splash Screen Image Type',
                'escape' => false,
                'description' => ' Choose the type of image you want to show in your app on App Launch.',
                'multiOptions' => array(
                    1 => 'PNG ' . $png,
                    0 => 'GIF ' . $gif
                ),
                'value' => 1,
                'onchange' => 'welcomeImageTypeChange()'
            ));
            $this->welcome_image_type->getDecorator('Description')->setOptions(array('placement' => 'PREPEND', 'escape' => false));

            $this->addElement('Text', 'animation_time', array(
                'label' => 'Animation Time of GIF (in Seconds)',
                'description' => 'Enter the GIF Image Animation Time. Suggested time for animation is "4-5 seconds"',
                'value' => 4,
            ));

            $this->addElement('Dummy', 'splash_screen_portrait', array(
                'label' => Zend_Registry::get('Zend_Translate')->_('<h3 onclick="onBlockClick(event)" id="splash_screen_portrait" class="siteandroidapp_form_heading">Splash Screen Images - Portrait</h3>'),
                'description' => Zend_Registry::get('Zend_Translate')->_('This image is displayed as a first screen on the app launch.'),
            ));
            $this->splash_screen_portrait->getDecorator('Label')->setOptions(array('escape' => false));
            $this->splash_screen_portrait->getDecorator('Description')->setOptions(array('escape' => false));

            $this->addElement('File', 'splash_portrait_1', array(
                'label' => ' in 200 x 320 px',
                'validators' => array(
                    array('Extension', false, 'png')
                )
            ));


            $this->addElement('File', 'splash_portrait_2', array(
                'label' => ' in 320 x 480 px',
                'validators' => array(
                    array('Extension', false, 'png')
                )
            ));

            $this->addElement('File', 'splash_portrait_3', array(
                'label' => ' in 480 x 800 px',
                'validators' => array(
                    array('Extension', false, 'png')
                )
            ));

            $this->addElement('File', 'splash_portrait_4', array(
                'label' => ' in 720 x 1280 px',
                'validators' => array(
                    array('Extension', false, 'png')
                )
            ));
        } elseif ($subTab == 3) {
            $this->tabThreeForm();
        }


        $this->addElement('Button', 'submit', array(
            'label' => 'Save Changes and Continue',
            'type' => 'submit',
            'ignore' => true,
        ));
    }

    protected function tabThreeForm() {
        $background = '<a target="_blank" class="mleft5" title="View Screenshot" href="application/modules/Siteandroidapp/externals/images/social.png" target="_blank"><img src="application/modules/Siteandroidapp/externals/images/eye.png" /></a>';
        $plain = '<a target="_blank" class="mleft5" title="View Screenshot" href="application/modules/Siteandroidapp/externals/images/slideshow_type.png" target="_blank"><img src="application/modules/Siteandroidapp/externals/images/eye.png" /></a>';
        $this->addElement('Radio', 'slide_show_type', array(
            'label' => 'Slideshow Type',
            'multiOptions' => array(
                1 => 'With Background Images ' . $background,
                0 => 'With Plain Background ' . $plain,
            ),
            'escape' => false,
            'value' => 1,
            'onchange' => 'slideshowType()'
        ));
        $this->slide_show_type->getDecorator('Description')->setOptions(array('placement' => 'PREPEND', 'escape' => false));

        $this->addElement('Dummy', 'slideshow_first_plain_slide', array(
            'label' => Zend_Registry::get('Zend_Translate')->_('<h3 onclick="onBlockClick(event)" id="slideshow_first_plain_slide" class="siteandroidapp_form_heading">Introductory Slideshow Details - First Slide</h3>'),
        ));
        $this->slideshow_first_plain_slide->getDecorator('Label')->setOptions(array('escape' => false));

        $this->addElement('Text', 'slideshow_color_background_1', array(
            'decorators' => array(array('ViewScript', array(
                        'viewScript' => '_slideshow_color_background_1.tpl',
                        'class' => 'form element'
                    )))
        ));

        $this->addElement('Text', 'slideshow_color_text_1', array(
            'decorators' => array(array('ViewScript', array(
                        'viewScript' => '_slideshow_color_text_1.tpl',
                        'class' => 'form element'
                    )))
        ));

        $this->addElement('Text', 'slideshow_slide_plain_1_title', array(
            'label' => 'Title',
        ));

        $this->addElement('Textarea', 'slideshow_slide_plain_1_description', array(
            'label' => 'Description',
        ));

        $this->addElement('File', 'slideshow_slide_plain_image_1_1', array(
            'label' => 'PNG in 512 x 512 px (Transparent Background)',
            'validators' => array(
                array('Extension', false, 'png')
            )
        ));

        $this->addElement('Dummy', 'slideshow_second_plain_slide', array(
            'label' => Zend_Registry::get('Zend_Translate')->_('<h3 onclick="onBlockClick(event)" id="slideshow_second_plain_slide" class="siteandroidapp_form_heading">Introductory Slideshow Details - Second Slide</h3>'),
        ));
        $this->slideshow_second_plain_slide->getDecorator('Label')->setOptions(array('escape' => false));

        $this->addElement('Text', 'slideshow_color_background_2', array(
            'decorators' => array(array('ViewScript', array(
                        'viewScript' => '_slideshow_color_background_2.tpl',
                        'class' => 'form element'
                    )))
        ));

        $this->addElement('Text', 'slideshow_color_text_2', array(
            'decorators' => array(array('ViewScript', array(
                        'viewScript' => '_slideshow_color_text_2.tpl',
                        'class' => 'form element'
                    )))
        ));

        $this->addElement('Text', 'slideshow_slide_plain_2_title', array(
            'label' => 'Title',
        ));

        $this->addElement('Textarea', 'slideshow_slide_plain_2_description', array(
            'label' => 'Description',
        ));

        $this->addElement('File', 'slideshow_slide_plain_image_1_2', array(
            'label' => 'PNG in 512 x 512 px (Transparent Background)',
            'validators' => array(
                array('Extension', false, 'png')
            )
        ));

        $this->addElement('Dummy', 'slideshow_third_plain_slide', array(
            'label' => Zend_Registry::get('Zend_Translate')->_('<h3 onclick="onBlockClick(event)" id="slideshow_third_plain_slide" class="siteandroidapp_form_heading">Introductory Slideshow Details - Third Slide</h3>'),
        ));
        $this->slideshow_third_plain_slide->getDecorator('Label')->setOptions(array('escape' => false));

        $this->addElement('Text', 'slideshow_color_background_3', array(
            'decorators' => array(array('ViewScript', array(
                        'viewScript' => '_slideshow_color_background_3.tpl',
                        'class' => 'form element'
                    )))
        ));

        $this->addElement('Text', 'slideshow_color_text_3', array(
            'decorators' => array(array('ViewScript', array(
                        'viewScript' => '_slideshow_color_text_3.tpl',
                        'class' => 'form element'
                    )))
        ));

        $this->addElement('Text', 'slideshow_slide_plain_3_title', array(
            'label' => 'Title',
        ));

        $this->addElement('Textarea', 'slideshow_slide_plain_3_description', array(
            'label' => 'Description',
        ));

        $this->addElement('File', 'slideshow_slide_plain_image_1_3', array(
            'label' => 'PNG in 512 x 512 px (Transparent Background)',
            'validators' => array(
                array('Extension', false, 'png')
            )
        ));

        $this->addElement('Dummy', 'slideshow_four_plain_slide', array(
            'label' => Zend_Registry::get('Zend_Translate')->_('<h3 onclick="onBlockClick(event)" id="slideshow_four_plain_slide" class="siteandroidapp_form_heading">Introductory Slideshow Details - Fourth Slide</h3>'),
        ));
        $this->slideshow_four_plain_slide->getDecorator('Label')->setOptions(array('escape' => false));

        $this->addElement('Text', 'slideshow_color_background_4', array(
            'decorators' => array(array('ViewScript', array(
                        'viewScript' => '_slideshow_color_background_4.tpl',
                        'class' => 'form element'
                    )))
        ));

        $this->addElement('Text', 'slideshow_color_text_4', array(
            'decorators' => array(array('ViewScript', array(
                        'viewScript' => '_slideshow_color_text_4.tpl',
                        'class' => 'form element'
                    )))
        ));

        $this->addElement('Text', 'slideshow_slide_plain_4_title', array(
            'label' => 'Title',
        ));

        $this->addElement('Textarea', 'slideshow_slide_plain_4_description', array(
            'label' => 'Description',
        ));

        $this->addElement('File', 'slideshow_slide_plain_image_1_4', array(
            'label' => 'PNG in 512 x 512 px (Transparent Background)',
            'validators' => array(
                array('Extension', false, 'png')
            )
        ));

        $this->addElement('Dummy', 'slideshow_five_plain_slide', array(
            'label' => Zend_Registry::get('Zend_Translate')->_('<h3 onclick="onBlockClick(event)" id="slideshow_five_plain_slide" class="siteandroidapp_form_heading">Introductory Slideshow Details - Fifth Slide</h3>'),
        ));
        $this->slideshow_five_plain_slide->getDecorator('Label')->setOptions(array('escape' => false));

        $this->addElement('Text', 'slideshow_color_background_5', array(
            'decorators' => array(array('ViewScript', array(
                        'viewScript' => '_slideshow_color_background_5.tpl',
                        'class' => 'form element'
                    )))
        ));

        $this->addElement('Text', 'slideshow_color_text_5', array(
            'decorators' => array(array('ViewScript', array(
                        'viewScript' => '_slideshow_color_text_5.tpl',
                        'class' => 'form element'
                    )))
        ));

        $this->addElement('Text', 'slideshow_slide_plain_5_title', array(
            'label' => 'Title',
        ));

        $this->addElement('Textarea', 'slideshow_slide_plain_5_description', array(
            'label' => 'Description',
        ));

        $this->addElement('File', 'slideshow_slide_plain_image_1_5', array(
            'label' => 'PNG in 512 x 512 px (Transparent Background)',
            'validators' => array(
                array('Extension', false, 'png')
            )
        ));

        $this->addElement('Dummy', 'slideshow_six_plain_slide', array(
            'label' => Zend_Registry::get('Zend_Translate')->_('<h3 onclick="onBlockClick(event)" id="slideshow_six_plain_slide" class="siteandroidapp_form_heading">Introductory Slideshow Details - Sixth Slide</h3>'),
        ));
        $this->slideshow_six_plain_slide->getDecorator('Label')->setOptions(array('escape' => false));

        $this->addElement('Text', 'slideshow_color_background_6', array(
            'decorators' => array(array('ViewScript', array(
                        'viewScript' => '_slideshow_color_background_6.tpl',
                        'class' => 'form element'
                    )))
        ));

        $this->addElement('Text', 'slideshow_color_text_6', array(
            'decorators' => array(array('ViewScript', array(
                        'viewScript' => '_slideshow_color_text_6.tpl',
                        'class' => 'form element'
                    )))
        ));

        $this->addElement('Text', 'slideshow_slide_plain_6_title', array(
            'label' => 'Title',
        ));

        $this->addElement('Textarea', 'slideshow_slide_plain_6_description', array(
            'label' => 'Description',
        ));

        $this->addElement('File', 'slideshow_slide_plain_image_1_6', array(
            'label' => 'PNG in 512 x 512 px (Transparent Background)',
            'validators' => array(
                array('Extension', false, 'png')
            )
        ));

        $this->addElement('Dummy', 'slideshow_seven_plain_slide', array(
            'label' => Zend_Registry::get('Zend_Translate')->_('<h3 onclick="onBlockClick(event)" id="slideshow_seven_plain_slide" class="siteandroidapp_form_heading">Introductory Slideshow Details - Seventh Slide</h3>')));
        $this->slideshow_seven_plain_slide->getDecorator('Label')->setOptions(array('escape' => false));

        $this->addElement('Text', 'slideshow_color_background_7', array(
            'decorators' => array(array('ViewScript', array(
                        'viewScript' => '_slideshow_color_background_7.tpl',
                        'class' => 'form element'
                    )))
        ));

        $this->addElement('Text', 'slideshow_color_text_7', array(
            'decorators' => array(array('ViewScript', array(
                        'viewScript' => '_slideshow_color_text_7.tpl',
                        'class' => 'form element'
                    )))
        ));

        $this->addElement('Text', 'slideshow_slide_plain_7_title', array(
            'label' => 'Title',
        ));

        $this->addElement('Textarea', 'slideshow_slide_plain_7_description', array(
            'label' => 'Description',
        ));

        $this->addElement('File', 'slideshow_slide_plain_image_1_7', array(
            'label' => 'PNG in 512 x 512 px (Transparent Background)',
            'validators' => array(
                array('Extension', false, 'png')
            )
        ));

        $this->addElement('Dummy', 'slideshow_first_slide', array(
            'label' => Zend_Registry::get('Zend_Translate')->_('<h3 onclick="onBlockClick(event)" id="slideshow_first_slide" class="siteandroidapp_form_heading">Introductory Slideshow Details - First Slide</h3>'),
            'description' => Zend_Registry::get('Zend_Translate')->_('These images display on the welcome screen. At least one slideshow image is mandatory. <a target="_blank" class="mleft5" title="View Screenshot" href="application/modules/Siteandroidapp/externals/images/welcome.png" target="_blank"><img src="application/modules/Siteandroidapp/externals/images/eye.png" /></a> ')
        ));
        $this->slideshow_first_slide->getDecorator('Label')->setOptions(array('escape' => false));
        $this->slideshow_first_slide->getDecorator('Description')->setOptions(array('escape' => false));

        $this->addElement('Text', 'slideshow_slide_1_title', array(
            'label' => 'Title',
        ));

        $this->addElement('Textarea', 'slideshow_slide_1_description', array(
            'label' => 'Description',
        ));

        if (isset($this->_appBuilderParams['image_upload_type']) && empty($this->_appBuilderParams['image_upload_type']))
            $this->addElement('File', 'slideshow_slide_image_1_1', array(
                'label' => 'PNG in 480 x 800 px',
                'validators' => array(
                    array('Extension', false, 'png')
                )
            ));

        $this->addElement('File', 'slideshow_slide_image_1_2', array(
            'label' => 'PNG in 720 x 1280 px',
            'validators' => array(
                array('Extension', false, 'png')
            )
        ));


        $this->addElement('Dummy', 'slideshow_second_slide', array(
            'label' => Zend_Registry::get('Zend_Translate')->_('<h3 onclick="onBlockClick(event)" id="slideshow_second_slide" class="siteandroidapp_form_heading">Introductory Slideshow Details - Second Slide</h3>'),
        ));
        $this->slideshow_second_slide->getDecorator('Label')->setOptions(array('escape' => false));

        $this->addElement('Text', 'slideshow_slide_2_title', array(
            'label' => 'Title',
        ));

        $this->addElement('Textarea', 'slideshow_slide_2_description', array(
            'label' => 'Description',
        ));

        if (isset($this->_appBuilderParams['image_upload_type']) && empty($this->_appBuilderParams['image_upload_type']))
            $this->addElement('File', 'slideshow_slide_image_2_1', array(
                'label' => 'PNG in 480 x 800 px',
                'validators' => array(
                    array('Extension', false, 'png')
                )
            ));

        $this->addElement('File', 'slideshow_slide_image_2_2', array(
            'label' => 'PNG in 720 x 1280 px',
            'validators' => array(
                array('Extension', false, 'png')
            )
        ));

        $this->addElement('Dummy', 'slideshow_third_slide', array(
            'label' => Zend_Registry::get('Zend_Translate')->_('<h3 onclick="onBlockClick(event)" id="slideshow_third_slide" class="siteandroidapp_form_heading">Introductory Slideshow Details - Third Slide</h3>'),
        ));
        $this->slideshow_third_slide->getDecorator('Label')->setOptions(array('escape' => false));

        $this->addElement('Text', 'slideshow_slide_3_title', array(
            'label' => 'Title',
        ));

        $this->addElement('Textarea', 'slideshow_slide_3_description', array(
            'label' => 'Description',
        ));

        if (isset($this->_appBuilderParams['image_upload_type']) && empty($this->_appBuilderParams['image_upload_type']))
            $this->addElement('File', 'slideshow_slide_image_3_1', array(
                'label' => 'PNG in 480 x 800 px',
                'validators' => array(
                    array('Extension', false, 'png')
                )
            ));

        $this->addElement('File', 'slideshow_slide_image_3_2', array(
            'label' => 'PNG in 720 x 1280 px',
            'validators' => array(
                array('Extension', false, 'png')
            )
        ));

        $this->addElement('Button', 'submit', array(
            'label' => 'Save Changes and Continue',
            'type' => 'submit',
            'ignore' => true,
        ));
    }

    protected function tabFourForm() {

        // Language File Upload Options
        $this->addElement('Dummy', 'language_assets', array(
            'Label' => Zend_Registry::get('Zend_Translate')->_('<h3>Language Assets [Optional]</h3><br />This section is useful for you only if you want your app to be multi-lingual (in multiple languages), or if you want to change any existing English phrases in your app.<br />You can download sample "Language File" for your reference from here: "<a href="http://mobiledemo.socialengineaddons.com/public/admin/Sample_Android_English_Language.csv">http://mobiledemo.socialengineaddons.com/public/admin/Sample_Android_English_Language.csv</a>". Below, you can upload the language files.<br /><br />'
                    . 'You need to add your changes at right side phrases of CSV file. For example if you want to change "Browse as a Guest" of French csv file then do changes at right side of ";" <br /><br /> '
                    . '<span style="font-weight:bold;">Text before your changes</span><br />'
                    . '&nbsp;&nbsp;&nbsp;"browse_as_guest";"Browse as a Guest"<br /><br />'
                    . '<span style="font-weight:bold;">Text after your changes in French</span><br />'
                    . '&nbsp;&nbsp;&nbsp;"browse_as_guest";"Parcourir en tant qu\'invité"'
                    . '<br /><br /> Note:<br>
1.Default language of your app will be the default language of your website (the one you set from Language Manager). <br>
2. To add a new language in the app, please add required language pack from Language Manager. Once you add there, same language pack will display here in this section.
<br>'),
        ));
        $this->language_assets->getDecorator('Label')->setOptions(array('escape' => false));

        $getLanguages = Engine_Api::_()->getApi('Core', 'siteapi')->getLanguages(true);
        if (isset($getLanguages)) {

            foreach ($getLanguages as $key => $label) {

                $this->addElement('File', $key, array(
                    'label' => 'Upload Language File For: [' . $label . ']',
                    'validators' => array(
                        array('Extension', false, 'csv')
                    )
                ));
            }
        }
        // Language work end

        $this->addElement('Button', 'submit', array(
            'label' => 'Save Changes and Continue',
            'type' => 'submit',
            'ignore' => true,
        ));
    }

    protected function tabFiveForm() {
        $communityPluginEnabled = Engine_Api::_()->getDbtable('modules', 'core')->isModuleEnabled('communityad');
        if ($communityPluginEnabled)
            $description = "Please select the type of advertisment you want to enable for your app.In addition to the above selected Ad Type, you will also be able to choose to show “Community Ads” and “Sponsered Stories” in the Ad Placement areas.<a target='_blank' class='mleft5' title='View Screenshot' href='application/modules/Siteandroidapp/externals/images/Ads.png' target='_blank'><img src='application/modules/Siteandroidapp/externals/images/eye.png' /></a>";
        else
            $description = "Please select the type of advertisment you want to enable for your app. <a target='_blank' class='mleft5' title='View Screenshot' href='application/modules/Siteandroidapp/externals/images/Ads.png' target='_blank'><img src='application/modules/Siteandroidapp/externals/images/eye.png' /></a>";
        $this->addElement('Radio', 'adv_type', array(
            'label' => 'Advertisment Type',
            'description' => $description,
            'multiOptions' => array(
                1 => 'Facebook Ads',
            ),
            'value' => 1,
            'onchange' => 'advertismentType()'
        ));
        $this->addElement('Text', 'google_ad_placement_id', array(
            'decorators' => array(array('ViewScript', array(
                        'viewScript' => '_advertismentType.tpl',
                        'class' => 'form element',
                    )))
        ));
        $this->adv_type->getDecorator('description')->setOptions(array('placement' => 'PREPEND', 'escape' => false));

        $this->addElement('Text', 'ad_placement_id', array(
            'label' => 'Placement ID',
            'description' => 'Display Facebook Ads in Activity Feeds and Content Browse Pages at desired position in your app and earn revenue from your app.<a href = "https://youtu.be/Y31ZwKIvkNE" target = "_blank"> Create </a>and Enter "Placement ID" from “Add Network” section of your Facebook Developer <a href="https://developers.facebook.com/" target="_blank">account </a>.'
        ));
        $this->ad_placement_id->getDecorator('description')->setOptions(array('placement' => 'PREPEND', 'escape' => false));


        $this->addElement('Button', 'submit', array(
            'label' => 'Save Changes and Continue',
            'type' => 'submit',
            'ignore' => true,
        ));
    }

    protected function tabSixForm() {
        $this->removeElement('required_fields');

        if (!empty($this->_doWeHaveLatestVersion)) {
            // Language File Upload Options
            $this->addElement('Dummy', 'download_text', array(
                'Label' => Zend_Registry::get('Zend_Translate')->_('<div class="seaocore_tip"><span><p>You do not have the latest version of the above listed plugins, Please upgrade all listed modules to the latest version to enable its integration with Android Mobile Application.</p></span></div><br />'),
            ));
            $this->download_text->getDecorator('Label')->setOptions(array('escape' => false));
        } else {
            // Language File Upload Options
            $this->addElement('Dummy', 'download_text', array(
                'Label' => Zend_Registry::get('Zend_Translate')->_('<h3>Download Tar File</h3><p>
                Before downloading this file, please ensure that you have filled all the App Submission Details correctly. This tar file contains all the details required for building your Android App.
            </p><br />'),
            ));
            $this->download_text->getDecorator('Label')->setOptions(array('escape' => false));
        }

        $getWebsiteName = str_replace('www.', '', strtolower($_SERVER['HTTP_HOST']));
        $websiteStr = str_replace(".", "-", $getWebsiteName);
        if (empty($this->_doWeHaveLatestVersion) && (is_dir(APPLICATION_PATH . DIRECTORY_SEPARATOR . 'public/' . 'android-' . $websiteStr . '-app-builder'))) {
            // Element: Download TAR
            $this->addElement('Cancel', 'download_tar', array(
                'label' => 'Download tar',
                'type' => 'cancel',
                'ignore' => true,
                'onclick' => 'Smoothbox.open("' . Zend_Controller_Front::getInstance()->getRouter()->assemble(array('action' => 'download')) . '")',
                'decorators' => array('ViewHelper'),
            ));
        }
    }

    protected function tabSevenForm() {
        $this->addElement('Dummy', 'people_suggestion', array(
            'label' => Zend_Registry::get('Zend_Translate')->_('<h3>People You May Know Suggestions</h3>'),
        ));
        $this->people_suggestion->getDecorator('Label')->setOptions(array('escape' => false));

//        $this->addElement('Radio', 'display_story', array(
//            'label' => 'Display stories',
//            'description' => "Do you want to show stories in your android app?",
//            'multiOptions' => array(
//                1 => 'Yes',
//                0 => 'No'
//            ),
//            'value' => 1,
//        ));
//        $this->display_story->getDecorator('Description')->setOptions(array('placement' => 'PREPEND', 'escape' => false));

        $this->addElement('Radio', 'display_suggestion', array(
            'label' => 'Friends Suggestions',
            'description' => "Do you want to display ‘People You May Know’ suggestions in activity feed? <a target='_blank' class='mleft5' title='View Screenshot' href='application/modules/Siteandroidapp/externals/images/PeopleSuggestion.png' target='_blank'><img src='application/modules/Siteandroidapp/externals/images/eye.png' /></a>",
            'multiOptions' => array(
                1 => 'Yes',
                0 => 'No'
            ),
            'value' => 1,
        ));
        $this->display_suggestion->getDecorator('Description')->setOptions(array('placement' => 'PREPEND', 'escape' => false));

        $this->addElement('Text', 'suggestion_placement', array(
            'label' => 'Placement of Suggestions Block',
            'description' => "After how many feeds you want to show people you may know suggestion ? <div class='tooltip'><span class='tooltiptext'>Note: This Placement count and Advertisement Placement should not be same, otherwise only one of them will be visible in Activity Feed. Make sure that its not N, as you have set this position for ads as well.</span></div>",
            'value' => 5,
        ));
        $this->suggestion_placement->getDecorator('Description')->setOptions(array('placement' => 'PREPEND', 'escape' => false));

        $this->addElement('Text', 'suggestion_count', array(
            'label' => 'Number of Suggestions',
            'description' => "How many suggestions you want to display in Activity Feed in the suggestions block?",
            'value' => 3,
        ));
        $this->suggestion_count->getDecorator('Description')->setOptions(array('placement' => 'PREPEND', 'escape' => false));

        $this->addElement('Button', 'submit', array(
            'label' => 'Save Changes and Continue',
            'type' => 'submit',
            'ignore' => true,
        ));
    }
      
}
