<?php

/**
 * SocialEngine
 *
 * @category   Application_Extensions
 * @package    Siteautoaction
 * @copyright  Copyright 2014-2015 BigStep Technologies Pvt. Ltd.
 * @license    http://www.socialengineaddons.com/license/
 * @version    $Id: Core.php 2014-08-06 00:00:00 SocialEngineAddOns $
 * @author     SocialEngineAddOns
 */
class Siteautoaction_Api_Core extends Core_Api_Abstract {

    /**
     * Get users listing according to requirement
     *
     * @param Siteautoaction_Model_Action $action
     * @param array $values
     *
     * @return Engine_Db_Table_Rowset|null
     */
    public function getUsers($action, $values) {
        $table = Engine_Api::_()->getItemTable('user');
        $userTableName = $table->info('name');
        $fieldTable = Engine_Api::_()->fields()->getTable('user', 'values');
        $fieldTableName = $fieldTable->info('name');
        $select = $table->select()
            ->from($userTableName, array('user_id', new Zend_Db_Expr('COUNT(*) as match_count')));
        
        if (!empty($values)){
            $select->setIntegrityCheck(false)
                ->joinRight($fieldTableName, "`{$fieldTableName}`.`item_id` = `{$userTableName}`.`user_id`", ['field_id', 'value']);

            $or = '';
            $where = '(';
            foreach ($values as $k => $v) {
                $where .= " $or ({$fieldTableName}.field_id = '$k' and {$fieldTableName}.value = '$v')";
                $or = 'or';
            }

            $select->where($where . ')');
        }

        $select->where("{$userTableName}.level_id IN(?)", $action->level_id);
        $select->group('user_id');

        return $select->getTable()->fetchAll($select);
    }

    /**
     * Perform actions as per $actions
     *
     * @param Core_Model_Item_Abstract $resource
     * @param User_Model_User $user
     * @param User_Model_User $actions
     *
     * @return void
     */
    public function performActions($resource, $user, $actions, $actionrow) {
        if (in_array('like', $actions)) {
            $this->likeContent($resource, $user);
        }
        if (in_array('follow', $actions)) {
                $this->followContent($resource, $user);
        }

        // $joinActionSetting = Engine_Api::_()->getApi('settings', 'core')->getSetting('siteautoaction.join',1);
        if (in_array('join', $actions) &&
            method_exists(Engine_Api::_()->getItemClass($resource->getType()), 'membership')
             // && $actionrow->action_join == 1
        ) {
            $this->joinContent($resource, $user, $actionrow);
        }
        if (in_array('bookmark', $actions) && Engine_Api::_()->hasModuleBootstrap('siteshortcut')) {
            $this->bookmarkContent($resource, $user);
        }
        if (in_array('subscribe', $actions)) {
            Engine_Api::_()->getDbtable('subscriptions', 'blog')
                ->createSubscription($resource->getOwner('user'), $user);
        }
        // if (in_array('custom', $actions) && method_exists(Engine_Api::_()->getItemClass($resource->getType()), 'customAutoAction')) {
        //     Engine_Api::_()->getItemClass($resource->getType())->customAutoAction($user);
        // }

        Engine_Hooks_Dispatcher::getInstance()->callEvent('onAutoActionPerformed', array(
          'user' => $user,
          'resource' => $resource,
          'actions' => $actions
        ));
    }

    /**
     * Get resource type array
     *
     * @param array $availableTypes
     *
     * @return $resourceTypes
     */
    public function getResourceTypes($availableTypes) {
        $resourceTypes = array();
        if (is_array($availableTypes) && count($availableTypes) > 0) {
            foreach ($availableTypes as $type) {
                if (strpos($type, 'sitereview_listing') !== false) {
                    $resourceTypes[$type] = $this->addListingTypes($resourceTypes)[$type];
                    continue;
                }
                $resourceTypes[$type] = strtoupper('ITEM_TYPE_' . $type);
            }
            if (in_array('sitereview_listing', $availableTypes)) {
                $resourceTypes = $this->addListingTypes($resourceTypes);
            }
        }
        return $resourceTypes;
    }

    private function followContent($resource, $user) {
        try {
            if (Engine_Api::_()->getDbTable('follows', 'seaocore')->isFollow($resource, $user)) {
                return;
            }
            Engine_Api::_()->getDbTable('follows', 'seaocore')->addFollow($resource, $user);
        } catch (Exception $ex) {

        }
    }

    private function joinContent($resource, $user, $actionrow) {
        try {
            if ($resource->membership()->isMember($user)) {
                return;
            }

            if ($user->getType() == $resource->getType() && $user->getIdentity() == $resource->getIdentity())
                return; 
            
            if ($actionrow->action_join == 1)
                $resource->membership()->addMember($user)->setUserApproved($user)->setResourceApproved($user);
            else 
                $this->joinCustom($resource, $user);
            $row = $resource->membership()->getRow($user);

            if (isset($row->rsvp)) {
                $row->rsvp = 2;
            }
            $row->save();

            $resource->member_count = $resource->membership()->getMemberCount();
            $resource->save();
        } catch (Exception $ex) {

        }
    }

    /**
     * Perform actions for sending manual join/friend request from user to resource
     *
     * @param Core_Model_Item_Abstract $resource
     * @param User_Model_User $user
     *
     * @return
    */

    private function joinCustom($resource, $user) {

        switch ($resource->getType()) {
            case 'user':
                $this->sendFriendRequest($user,$resource);
                break;
            case 'event':
                $this->sendEventJoinRequest($user,$resource);
                break;
            case 'siteevent_event':
                $this->sendAdvancedEventJoinRequest($user,$resource);
                break;
            case 'group':
                $this->sendGroupJoinRequest($user,$resource);
                break;
            case 'sitegroup_group':
                $this->sendAdvancedGroupJoinRequest($user,$resource);
                break;
            case 'sitepage_page':
                $this->sendPagesJoinRequest($user,$resource);
                break;
            default :
                return;
        }
    }

    /**
     * Perform actions for sending join request for events
     *
     * @param Core_Model_Item_Abstract $viewer
     * @param User_Model_User $user
     *
     * @return
    */

    public function sendEventJoinRequest($viewer, $user) {

        $db = Engine_Api::_()->getDbtable('membership', 'event')->getAdapter();
        $db->beginTransaction();
        try
        {
            $user->membership()->addMember($viewer)->setUserApproved($viewer);
            $row = $user->membership()->getRow($viewer);
            $row->resource_approved  = 0;
            $row->active  = 0;
            $row->save(); 
            // Add notification
            $notifyApi = Engine_Api::_()->getDbtable('notifications', 'activity');
            $notifyApi->addNotification($user->getOwner(), $viewer, $user, 'event_approve');
            $db->commit();
        }
        catch( Exception $e )
        {
            $db->rollBack();
            throw $e;
        }
    }

    /**
     * Perform actions for sending friend request from users to resource
     *
     * @param Core_Model_Item_Abstract $viewer
     * @param User_Model_User $user
     *
     * @return
    */

    public function sendFriendRequest($viewer, $user) {
        // Process
        $db = Engine_Api::_()->getDbtable('membership', 'user')->getAdapter();
        $db->beginTransaction();

        try {          
          // send request
          $user->membership()->addMember($viewer)->setUserApproved($viewer);      
          if( !$viewer->membership()->isUserApprovalRequired() && !$viewer->membership()->isReciprocal() ) {
            // if one way friendship and verification not required
            // Add activity
            Engine_Api::_()->getDbtable('actions', 'activity')
                ->addActivity($viewer, $user, 'friends_follow', '{item:$subject} is now following {item:$object}.');
            // Add notification
            Engine_Api::_()->getDbtable('notifications', 'activity')
                ->addNotification($user, $viewer, $viewer, 'friend_follow');        
          } else if( !$viewer->membership()->isUserApprovalRequired() && $viewer->membership()->isReciprocal() ){
            // if two way friendship and verification not require
            // Add activity
            Engine_Api::_()->getDbtable('actions', 'activity')
                ->addActivity($user, $viewer, 'friends', '{item:$object} is now friends with {item:$subject}.');
            Engine_Api::_()->getDbtable('actions', 'activity')
                ->addActivity($viewer, $user, 'friends', '{item:$object} is now friends with {item:$subject}.');
            // Add notification
            Engine_Api::_()->getDbtable('notifications', 'activity')
                ->addNotification($user, $viewer, $user, 'friend_accepted');        
          } else if( !$user->membership()->isReciprocal() ) {
            // if one way friendship and verification required
            // Add notification
            Engine_Api::_()->getDbtable('notifications', 'activity')
                ->addNotification($user, $viewer, $user, 'friend_follow_request');        
          } else if( $user->membership()->isReciprocal() ) {
            // if two way friendship and verification required
            // Add notification
            Engine_Api::_()->getDbtable('notifications', 'activity')
                ->addNotification($user, $viewer, $user, 'friend_request');
          }

          $db->commit();
        }catch( Exception $e ) {
          $db->rollBack();
        }
    }

    /**
     * Perform actions for sending join request for groups
     *
     * @param Core_Model_Item_Abstract $viewer
     * @param User_Model_User $user
     *
     * @return
    */

    public function sendGroupJoinRequest($viewer, $user) {
        // Process
        $db = Engine_Api::_()->getDbtable('membership', 'group')->getAdapter();
        $db->beginTransaction();
        try
        {
            $user->membership()->addMember($viewer)->setUserApproved($viewer);
            $row = $user->membership()->getRow($viewer);
            $row->resource_approved  = 0;
            $row->active  = 0;
            $row->save(); 
            Engine_Api::_()->getDbtable('notifications', 'activity')->addNotification($user->getOwner(), $viewer, $user, 'group_approve');
            $db->commit();
        }
        catch( Exception $e )
        {
            $db->rollBack();
            throw $e;
        }
    }

    /**
     * Perform actions for sending join request for pages
     *
     * @param Core_Model_Item_Abstract $viewer
     * @param User_Model_User $user
     *
     * @return
    */

    public function sendPagesJoinRequest($viewer, $user) {

        $db = Engine_Api::_()->getDbtable('membership', 'sitepage')->getAdapter();
        $db->beginTransaction();
        try
        {
            $user->membership()->addMember($viewer);
            $row = $user->membership()->getRow($viewer);
            $row->page_id = $row->resource_id;
            $row->resource_approved  = 0;
            $row->active  = 0;
            $row->save(); 
            Engine_Api::_()->getDbtable('notifications', 'activity')->addNotification($user->getOwner(), $viewer, $user, 'sitepagemember_approve');
            $db->commit();
        }
        catch( Exception $e )
        {
            $db->rollBack();
            throw $e;
        }
    }

    /**
     * Perform actions for sending join request for Advanced groups
     *
     * @param Core_Model_Item_Abstract $viewer
     * @param User_Model_User $user
     *
     * @return
    */

    public function sendAdvancedGroupJoinRequest($viewer, $user) {
        // Process
        $db = Engine_Api::_()->getDbtable('membership', 'sitegroup')->getAdapter();
        $db->beginTransaction();
        try
        {
            $user->membership()->addMember($viewer);
            $row = $user->membership()->getRow($viewer);
            $row->group_id = $row->resource_id;
            $row->resource_approved  = 0;
            $row->active  = 0;
            $row->save();
            Engine_Api::_()->getDbtable('notifications', 'activity')->addNotification($user->getOwner(), $viewer, $user, 'sitegroupmember_approve');
            $db->commit();
        }
        catch( Exception $e )
        {
            $db->rollBack();
            throw $e;
        } 
    }

    /**
     * Perform actions for sending join request for Advanced events
     *
     * @param Core_Model_Item_Abstract $viewer
     * @param User_Model_User $user
     *
     * @return
    */

    public function sendAdvancedEventJoinRequest($viewer, $user) {

        $db = Engine_Api::_()->getDbtable('membership', 'siteevent')->getAdapter();
        $db->beginTransaction();
        try
        {
            $user->membership()->addMember($viewer)->setUserApproved($viewer);
            $row = $user->membership()->getRow($viewer);
            $row->resource_approved  = 0;
            $row->active  = 0;
            $row->save();
            // Add notification
            $notifyApi = Engine_Api::_()->getDbtable('notifications', 'activity');
            $notifyApi->addNotification($user->getOwner(), $viewer, $user, 'siteevent_approve');
            $db->commit();
        }
        catch( Exception $e )
        {
            $db->rollBack();
            throw $e;
        }
    }

    private function likeContent($resource, $user) {
        try {
            if ($resource->likes()->isLike($user)) {
                return;
            }
            Engine_Api::_()->getItemTable('core_like')->addLike($resource, $user);
            if (Engine_Api::_()->getDbtable('modules', 'core')->isModuleEnabled('sitelike')) {
                Engine_Api::_()->sitelike()->setLikeFeed($user, $resource);
            }
        } catch (Exception $ex) {

        }
    }

    private function bookmarkContent($resource, $user) {
        try {
            Engine_Api::_()->getDbTable('shortcuts', 'siteshortcut')->addToShortcut(array(
                'resource_type' => $resource->getType(),
                'resource_id' => $resource->getIdentity(),
                'user_id' => $user->getIdentity()
            ));
        } catch (Exception $ex) {

        }
    }

    private function addListingTypes($availableTypes) {
        unset($availableTypes['sitereview_listing']);
        $listingType = Engine_Api::_()->getDbTable('listingtypes', 'sitereview')->getListingTypesArray();

        return array_merge($availableTypes, array_combine(array_map(function ($key) {
            return 'sitereview_listing_' . $key;
        }, array_keys($listingType)), $listingType));
    }


    public function getFollowItems() {
        return array('siteevent_event','sitegroup_group','sitestore_store','sitepage_page');
    }

}
