<?php
/**
 * SocialEngine
 *
 * @category   Application_Extensions
 * @package    Siteautoaction
 * @copyright  Copyright 2014-2015 BigStep Technologies Pvt. Ltd.
 * @license    http://www.socialengineaddons.com/license/
 * @version    $Id: Actions.php 2014-08-06 00:00:00 SocialEngineAddOns $
 * @author     SocialEngineAddOns
 */
class Siteautoaction_Model_DbTable_Actions extends Core_Model_Item_DbTable_Abstract
{
    protected $_serializedColumns = array('action_type', 'level_id', 'apply_to');

    public function getResourceIds($params = array())
    {
        $resourceIds = array();
        if (empty($params['search']) || empty($params['resource_type'])) {
            return $resourceIds;
        }

        $isSitereview = strpos($params['resource_type'], 'sitereview_listing') !== false;
        $resourceType = $isSitereview ? 'sitereview_listing' : $params['resource_type'];

//        $select = Engine_Api::_()->getApi('search', 'core')->getSelect(
//            $params['search'],
//            $resourceType
//        );

         $select = $this->getSelect(
                 $params['search'],
                 $resourceType
             );
        $select = isset($params['limit']) ? $select->limit($params['limit']) : $select;
        $searchResults = $select->getTable()->fetchAll($select);

        foreach ($searchResults as $result) {
            // In case of sitereview get Ids for selected listing type only
            if ( $isSitereview && Engine_Api::_()->getDbtable('listings', 'sitereview')
                ->getListingTypeId($result->id) !== (int) array_pop(explode('_', $params['resource_type']))) {
                    continue;
                }
            $resourceIds[$result->id] = $result->title;
        }

        return $resourceIds;
    }

    public function getSelect($text, $type = null) {
        // Build base query
        $table = Engine_Api::_()->getDbtable('search', 'core');
        $select = $table->select()
  	                ->setIntegrityCheck(false)
  	                ->from($table->info('name'), array('type', 'id', 'description', 'keywords', 'title'));
  	        $select->where("(`title` LIKE  ? )","%$text%");

        // Filter by item types
        $availableTypes = Engine_Api::_()->getItemTypes();
        if( $type && in_array($type, $availableTypes) ) {
          $select->where('type = ?', $type);
        } else {
          $select->where('type IN(?)', $availableTypes);
        }
        
        return $select;
    }

    public function getActions($params = array())
    {
        $select = $this->select();
        $tableName = $this->info('name');
        $resourceType = $params['resource_type'];
        if (strpos($params['resource_type'], 'sitereview_listing') !== false) {
            $resourceType = 'sitereview_listing';
            $listingsTable = Engine_Api::_()->getDbTable('listings','sitereview');
            $listingsTableName = $listingsTable->info('name');
            $select
                ->from($tableName)
                ->setIntegrityCheck(false)
                ->joinLeft($listingsTableName,
                    "`$listingsTableName`.`listing_id` = `{$tableName}`.`resource_id`", ['listingtype_id'])
                ->where("`{$listingsTableName}`.`listingtype_id` = ?",
                    (int) array_pop(explode('_', $params['resource_type'])));
        }
        if (empty($resourceType)) {
            return;
        }
        $select->where("`{$tableName}`.`resource_type` = ?", $resourceType);
        if (!empty($params['search'])) {
            $resourceIds = $this->getResourceIds([
                'search' => $params['search'],
                'resource_type' => $params['resource_type']
            ]);
            if (empty($resourceIds)) {
                return;
            }
            $select->where("`{$tableName}`.`resource_id` IN(?) ", array_keys($resourceIds));
        }

        if (isset($params['order']) && !empty($params['order'])) {
            $select->order($params['order']);
        }

        return Zend_Paginator::factory($select);
    }
}
