<?php

/**
 * SocialEngine
 *
 * @category   Application_Extensions
 * @package    Sitebanner
 * @copyright  Copyright 2015-2018 BigStep Technologies Pvt. Ltd.
 * @license    http://www.socialengineaddons.com/license/
 * @version    $Id: Layout.php 2018-04-05 00:00:00Z SocialEngineAddOns $
 * @author     SocialEngineAddOns
 */
class Sitebanner_Form_Admin_Settings_Header extends Engine_Form {

	public function init() {
		$this->setTitle("Manage Header Inside Banner");
		$this->setDescription("You have the option to show the header of your site inside banners. Here, you can manage the settings related to the header of your site in case you want to show it inside the banner. The settings applied here will apply only when you choose to show the header inside a banner. You can choose whether to show the header inside or outside a banner by editing the widget “Ultimate Banner Slideshow” from the Layout Editor.");

		$coreSettings = Engine_Api::_()->getApi('settings', 'core');
		$imgOptions = Engine_Api::_()->sitebanner()->getImages(array('' => 'Text-only (No logo)'));
		$imageExtensions = array('gif', 'jpg', 'jpeg', 'png');
		$files = new DirectoryIterator(APPLICATION_PATH . '/public/admin/');
		foreach ($files as $file) {
			if ($file->isDot() || !$file->isFile()) {
				continue;
			}

			$basename = basename($file->getFilename());
			if (!($pos = strrpos($basename, '.'))) {
				continue;
			}

			$ext = strtolower(ltrim(substr($basename, $pos), '.'));
			if (!in_array($ext, $imageExtensions)) {
				continue;
			}

			$imgOptions['public/admin/' . $basename] = $basename;
		}

		$this->addElement('Select', 'sitebanner_header_logo_image', array(
			'label' => 'Select Logo',
			'description' => 'Select the logo for your website. [Note: Logo must be uploaded prior from Admin Panel → Appearance → File & Media Manager.]',
			'multiOptions' => $imgOptions,
			'value' => $coreSettings->getSetting('sitebanner.header.logo.image', ''),
		));

		$headerOptions = array(
			'logo' => 'Site Logo',
			'mini_menu' => 'Mini Menu',
			'main_menu' => 'Main Menu ',
			'search_box' => 'Search Box',
		);

		$deafultHeaderOptions = array(
			'logo',
			'mini_menu',
			'main_menu',
			'search_box',
		);

		$this->addElement('MultiCheckbox', 'sitebanner_header_loggedin_widgets', array(
			'label' => 'Header Elements for Logged In Members',
			'description' => 'Select the elements you want to display in header section for logged in members.',
			'multiOptions' => $headerOptions,
			'value' => $coreSettings->getSetting('sitebanner.header.loggedin.widgets', $deafultHeaderOptions),
		));

		$this->addElement('MultiCheckbox', 'sitebanner_header_loggedout_widgets', array(
			'label' => 'Header Elements for Non-Logged In Members',
			'description' => 'Select the options you want to display in header section for non-logged in / guest members.',
			'multiOptions' => $headerOptions,
			'value' => $coreSettings->getSetting('sitebanner.header.loggedout.widgets', $deafultHeaderOptions),
		));
		$options = array(
			'1' => 'Yes, fix the header.',
			'0' => 'Don\'t fix the header.',
		);

		$this->addElement('Radio', 'sitebanner_header_menu_fixed', array(
			'label' => 'Fix Header',
			'description' => 'How do you want Header to behave on scroll?',
			'multiOptions' => $options,
			'value' => $coreSettings->getSetting('sitebanner.header.menu.fixed', 0),
		));

		$this->addElement('Text', 'sitebanner_header_desktop_totalmenuwith_dots', array(
			'label' => 'Menu Count with 3 Dots',
			'description' => 'How many menu items do you want to show? (Note: Other menu items will go under 3 dots section.)',
			'value' => $coreSettings->getSetting('sitebanner.header.desktop.totalmenuwith.dots', 4),
		));

		$this->addElement('Button', 'submit', array(
			'label' => 'Save Changes',
			'type' => 'submit',
			'ignore' => true,
		));
	}

}