<?php

/**
 * SocialEngine
 *
 * @category   Application_Extensions
 * @package    Sitebusiness
 * @copyright  Copyright 2013-2014 BigStep Technologies Pvt. Ltd.
 * @license    http://www.socialengineaddons.com/license/
 * @version    $Id: Global.php 6590 2014-01-02 00:00:00Z SocialEngineAddOns $
 * @author     SocialEngineAddOns
 */
class Sitebusiness_Form_Admin_CreateEdit extends Engine_Form {

    public function init() {

        $this->setTitle('Miscellaneous Settings')
                ->setDescription('The below settings govern various properties for businesses on your website. By choosing fewer fields for business creation, you can make creating businesses quicker on your website (Remaining fields can be configured from Business Dashboard).')
                ->setName('sitebusiness_global');

        $coreSettings = Engine_Api::_()->getApi('settings', 'core');

        $this->addElement('Radio', 'sitebusiness_description_allow', array(
            'label' => 'Allow Description',
            'description' => 'Do you want to allow business owners to write description for their businesses?',
            'multiOptions' => array(
                1 => 'Yes',
                0 => 'No'
            ),
            'value' => $coreSettings->getSetting('sitebusiness.description.allow', 1),
            'onclick' => 'showDescription(this.value)'
        ));

        //VALUE FOR DESCRIPTION
        $this->addElement('Radio', 'sitebusiness_requried_description', array(
            'label' => 'Description Required',
            'description' => 'Do you want to make Description a mandatory field for directory items / businesses?',
            'multiOptions' => array(
                1 => 'Yes',
                0 => 'No'
            ),
            'value' => $coreSettings->getSetting('sitebusiness.requried.description', 1),
        ));

        //VALUE FOR CAPTCHA
        $this->addElement('Radio', 'sitebusiness_requried_photo', array(
            'label' => 'Profile Photo Required',
            'description' => 'Do you want to make Profile Photo a mandatory field for directory items / businesses?',
            'multiOptions' => array(
                1 => 'Yes',
                0 => 'No'
            ),
            'value' => $coreSettings->getSetting('sitebusiness.requried.photo', 0),
        ));
        $this->addElement('Radio', 'sitebusiness_status_show', array(
            'label' => 'Open / Closed status in Search',
            'description' => 'Do you want the Status field (Open / Closed) in the search form widget? (This widget appears on the "Businesses Home", "My Businesses" and "Browse Businesses" businesses, and enables users to search and filter businesses.)',
            'multiOptions' => array(
                1 => 'Yes',
                0 => 'No'
            ),
            'value' => $coreSettings->getSetting('sitebusiness.status.show', 1),
        ));

        $this->addElement('Radio', 'sitebusiness_profile_fields', array(
            'label' => 'Profile Information Fields',
            'description' => 'Do you want to display Profile Information Fields associated with the selected category while creation of directory items / businesses?',
            'multiOptions' => array(
                1 => 'Yes',
                0 => 'No'
            ),
            'value' => $coreSettings->getSetting('sitebusiness.profile.fields', 1),
        ));

        //VALUE FOR ENABLE /DISABLE PRICE FIELD
        $this->addElement('Radio', 'sitebusiness_price_field', array(
            'label' => 'Price Field',
            'description' => 'Do you want the Price field to be enabled for directory items / businesses?',
            'multiOptions' => array(
                1 => 'Yes',
                0 => 'No'
            ),
            'value' => $coreSettings->getSetting('sitebusiness.price.field', 1),
        ));

        $createFormFields = array(
            'location' => 'Location',
            'tags' => 'Tags',
            'photo' => 'Photo [Note: This setting will only work if photo is not required.]',
            'description' => 'Description [Note: This setting will only work if description is not required.]',
            'price' => 'Price',
            'viewPrivacy' => 'View Privacy',
            'commentPrivacy' => 'Comment Privacy',
            'allPostPrivacy' => 'Post Updates'
        );

        if (Engine_Api::_()->getDbtable('modules', 'core')->isModuleEnabled('sitebusinessdiscussion')) {
            $createFormFields = array_merge($createFormFields, array('discussionPrivacy' => 'Discussion Privacy'));
        }

        if (Engine_Api::_()->getDbtable('modules', 'core')->isModuleEnabled('sitebusinessalbum')) {
            $createFormFields = array_merge($createFormFields, array('photoPrivacy' => 'Photo Privacy'));
        }

        if (Engine_Api::_()->getDbtable('modules', 'core')->isModuleEnabled('sitebusinessvideo')) {
            $createFormFields = array_merge($createFormFields, array('videoPrivacy' => 'Video Privacy'));
        }

        if (Engine_Api::_()->getDbtable('modules', 'core')->isModuleEnabled('sitebusinessdocument')) {
            $createFormFields = array_merge($createFormFields, array('documentPrivacy' => 'Document Privacy'));
        }

        if (Engine_Api::_()->getDbtable('modules', 'core')->isModuleEnabled('sitebusinesspoll')) {
            $createFormFields = array_merge($createFormFields, array('pollPrivacy' => 'Poll Privacy'));
        }

        if (Engine_Api::_()->getDbtable('modules', 'core')->isModuleEnabled('sitebusinessnote')) {
            $createFormFields = array_merge($createFormFields, array('notePrivacy' => 'Note Privacy'));
        }

        if ((Engine_Api::_()->hasModuleBootstrap('siteevent') && Engine_Api::_()->getDbtable('modules', 'siteevent')->getIntegratedModules(array('enabled' => 1, 'item_type' => 'sitebusiness_business', 'item_module' => 'sitebusiness')))) {
            $createFormFields = array_merge($createFormFields, array('eventPrivacy' => 'Event Privacy'));
        } elseif (Engine_Api::_()->getDbtable('modules', 'core')->isModuleEnabled('sitebusinessevent')) {
            $createFormFields = array_merge($createFormFields, array('eventPrivacy' => 'Event Privacy'));
        }

        if (Engine_Api::_()->getDbtable('modules', 'core')->isModuleEnabled('sitebusinessmusic')) {
            $createFormFields = array_merge($createFormFields, array('musicPrivacy' => 'Music Privacy'));
        }
        
        if (Engine_Api::_()->getDbtable('modules', 'core')->isModuleEnabled('sitebusinessmember')) {
            $createFormFields = array_merge($createFormFields, array('memberTitle' => 'What will members be called setting?'));
            $createFormFields = array_merge($createFormFields, array('memberInvite' => 'Invite member'));
            $createFormFields = array_merge($createFormFields, array('memberApproval' => 'Approve members?'));
        }
        
        $createFormFields = array_merge($createFormFields, array(
            'subBusinessPrivacy' => 'Sub Business Creation Privacy',
            'claimThisBusiness' => 'Claim this Business',
            'status' => 'Status',
            'search' => 'Show this business on browse business and in various blocks',
            'showHideAdvancedOptions' => 'Advanced Show / Hide Options'
        ));

        $this->addElement('MultiCheckbox', 'sitebusiness_createFormFields', array(
            'label' => 'Business Creation Fields',
            'description' => 'Choose the fields that you want to be available on the Business Creation business. Choosing less fields here could mean quicker business creation. Other fields that are enabled for businesses but not chosen here will appear in Business Dashboard.',
            'multiOptions' => $createFormFields,
            'value' => $coreSettings->getSetting('sitebusiness.createFormFields', array_keys($createFormFields)),
        ));

        $this->addElement('Hidden', 'is_remove_note', array('value' => 0, 'order' => 999));

        $this->addElement('Button', 'save', array(
            'label' => 'Save Changes',
            'type' => 'submit',
            'ignore' => true
        ));
    }

}