<?php

/**
 * SocialEngine
 *
 * @category   Application_Extensions
 * @package    Sitebusiness
 * @copyright  Copyright 2010-2011 BigStep Technologies Pvt. Ltd.
 * @license    http://www.socialengineaddons.com/license/
 * @version    $Id: Level.php 2011-05-05 9:40:21Z SocialEngineAddOns $
 * @author     SocialEngineAddOns
 */
class Sitebusiness_Form_Admin_Settings_Level extends Authorization_Form_Admin_Level_Abstract
{

  public function init()
  {
    parent::init();

    // My stuff
    $this
      ->setTitle('Member Level Settings')
      ->setDescription("These settings are applied on a per member level basis. Start by selecting the member level you want to modify, then adjust the settings for that level below. (Note: If packages are enabled from global settings, then some member level settings will not be available as those feature settings for businesses will now depend on packages.)");

    $isEnabledPackage = Engine_Api::_()->sitebusiness()->hasPackageEnable();

    // Element: view
    $this->addElement('Radio', 'view', array(
      'label' => 'Allow Viewing of Businesses?',
      'description' => 'Do you want to let members view businesses? If set to no, some other settings on this business may not apply.',
      'multiOptions' => array(
        2 => 'Yes, allow viewing of all businesses, even private ones.',
        1 => 'Yes, allow viewing of businesses.',
        0 => 'No, do not allow businesses to be viewed.',
      ),
      'value' => ( $this->isModerator() ? 2 : 1 ),
    ));
    if( !$this->isModerator() ) {
      unset($this->view->options[2]);
    }

    if( !$this->isPublic() ) {
      // Element: create
      $this->addElement('Radio', 'create', array(
        'label' => 'Allow Creation of Businesses?',
        'description' => 'Do you want to let members create businesses? If set to no, some other settings on this business may not apply. This is useful if you want members to be able to view businesses, but only certain levels to be able to create businesses.',
        'multiOptions' => array(
          1 => 'Yes, allow creation of businesses.',
          0 => 'No, do not allow businesses to be created.'
        ),
        'value' => 1,
      ));


      // Element: edit
      $this->addElement('Radio', 'edit', array(
        'label' => 'Allow Editing of Businesses?',
        'description' => 'Do you want to let members edit businesses? If set to no, some other settings on this business may not apply.',
        'multiOptions' => array(
          2 => 'Yes, allow members to edit all businesses.',
          1 => 'Yes, allow members to edit their own businesses.',
          0 => 'No, do not allow members to edit their businesses.',
        ),
        'value' => ( $this->isModerator() ? 2 : 1 ),
      ));
      if( !$this->isModerator() ) {
        unset($this->edit->options[2]);
      }

      // Element: delete
      $this->addElement('Radio', 'delete', array(
        'label' => 'Allow Deletion of Businesses?',
        'description' => 'Do you want to let members delete businesses? If set to no, some other settings on this business may not apply.',
        'multiOptions' => array(
          2 => 'Yes, allow members to delete all businesses.',
          1 => 'Yes, allow members to delete their own businesses.',
          0 => 'No, do not allow members to delete their businesses.',
        ),
        'value' => ( $this->isModerator() ? 2 : 1 ),
      ));
      if( !$this->isModerator() ) {
        unset($this->delete->options[2]);
      }

      // Element: comment
      $this->addElement('Radio', 'comment', array(
        'label' => 'Allow Commenting on Businesses?',
        'description' => 'Do you want to let members of this level comment on businesses?',
        'multiOptions' => array(
          2 => 'Yes, allow members to comment on all businesses, including private ones.',
          1 => 'Yes, allow members to comment on businesses.',
          0 => 'No, do not allow members to comment on businesses.',
        ),
        'value' => ( $this->isModerator() ? 2 : 1 ),
      ));
      if( !$this->isModerator() ) {
        unset($this->comment->options[2]);
      }

      if( Engine_Api::_()->getApi('settings', 'core')->getSetting('sitebusiness.manageadmin', 1) ) {
        $ownerTitle = "Business Admins";
      } else {
        $ownerTitle = "Just Me";
      }

      $privacyArray = array(
        'everyone' => 'Everyone',
        'registered' => 'All Registered Members',
        'owner_network' => 'Friends and Networks',
        'owner_member_member' => 'Friends of Friends',
        'owner_member' => 'Friends Only',
        //	'owner' => $ownerTitle,
      );
      $privacyValueArray = array('everyone', 'owner_network', 'owner_member_member', 'owner_member');
      $sitebusinessmemberEnabled = Engine_Api::_()->getDbtable('modules', 'core')->isModuleEnabled('sitebusinessmember');
      if( $sitebusinessmemberEnabled ) {
        $privacyArray['member'] = 'Business Members Only';
        $privacyValueArray[] = 'member';
      }
      $privacyArray['owner'] = $ownerTitle;
      $privacyValueArray[] = 'owner';

      //START SUBBUSINESS WORK.
      // Element:sub create
      $this->addElement('Radio', 'sspcreate', array(
        'label' => 'Allow Creation of Sub Businesses?',
        'description' => 'Do you want to let members create sub businesses? If set to no, some other settings on this business may not apply. This is useful if you want members to be able to create sub businesses, but only certain levels to be able to create sub businesses.',
        'multiOptions' => array(
          1 => 'Yes, allow creation of sub businesses.',
          0 => 'No, do not allow sub businesses to be created.'
        ),
        'value' => 1,
      ));

      $privacy_array = array(
        'registered' => 'All Registered Members',
        'owner_network' => 'Friends and Networks',
        'owner_member_member' => 'Friends of Friends',
        'owner_member' => 'Friends Only',
        //	'owner' => $ownerTitle,
      );
      $privacy_value_array = array('everyone', 'owner_network', 'owner_member_member', 'owner_member');
      $sitebusinessmemberEnabled = Engine_Api::_()->getDbtable('modules', 'core')->isModuleEnabled('sitebusinessmember');
      if( $sitebusinessmemberEnabled ) {
        $privacy_array['member'] = 'Business Members Only';
        $privacy_value_array[] = 'member';
      }
      $privacy_array['like_member'] = 'Who Liked This Business';
      $privacy_value_array[] = 'like_member';

      $privacy_array['owner'] = $ownerTitle;
      $privacy_value_array[] = 'owner';

      // Element: auth_subbusiness create
      $this->addElement('MultiCheckbox', 'auth_sspcreate', array(
        'label' => 'Sub-Business Creation Options',
        'description' => 'Your users can choose from any of the options checked below when they decide who can create the sub-businesses in their businesses. If you do not check any options, everyone will be allowed to create sub-businesses.',
        'multiOptions' => $privacy_array
      ));
      //Element: subbusiness
      // Element: auth_view
      $this->addElement('MultiCheckbox', 'auth_view', array(
        'label' => 'Business Privacy',
        'description' => 'Your members can choose from any of the options checked below when they decide who can see their businesses. These options appear on your members\' "Create New Business" and "Edit Business" businesses. If you do not check any options, everyone will be allowed to view businesses.',
        'multiOptions' => $privacyArray,
        'value' => $privacyValueArray
      ));

      // Element: auth_comment
      $this->addElement('MultiCheckbox', 'auth_comment', array(
        'label' => 'Business Comment Options',
        'description' => 'Your members can choose from any of the options checked below when they decide who can post comments on their businesses. These options appear on your members\' "Create New Business" and "Edit Business" businesses. If you do not check any options, everyone will be allowed to post comments on businesses.',
        'multiOptions' => $privacyArray,
        'value' => $privacyValueArray
      ));
    }

    if( !$this->isPublic() && empty($isEnabledPackage) ) {

      $privacy_array = array(
        'registered' => 'All Registered Members',
        'owner_network' => 'Friends and Networks',
        'owner_member_member' => 'Friends of Friends',
        'owner_member' => 'Friends Only',
        //	'owner' => $ownerTitle,
      );
      $privacy_value_array = array('everyone', 'owner_network', 'owner_member_member', 'owner_member');
      $sitebusinessmemberEnabled = Engine_Api::_()->getDbtable('modules', 'core')->isModuleEnabled('sitebusinessmember');
      if( $sitebusinessmemberEnabled ) {
        $privacy_array['member'] = 'Business Members Only';
        $privacy_value_array[] = 'member';
      }
      $privacy_array['like_member'] = 'Who Liked This Business';
      $privacy_value_array[] = 'like_member';

      $privacy_array['owner'] = $ownerTitle;
      $privacy_value_array[] = 'owner';


      //Element: approved
      $this->addElement('Radio', 'approved', array(
        'label' => 'Business Approval Moderation',
        'description' => 'Do you want new business to be automatically approved?',
        'multiOptions' => array(
          1 => 'Yes, automatically approve business.',
          0 => 'No, site admin approval will be required for all businesses.'
        ),
        'value' => 1,
      ));

      //Element: sponsored
      $this->addElement('Radio', 'sponsored', array(
        'label' => 'Business Sponsored Moderation',
        'description' => 'Do you want new business to be automatically made sponsored?',
        'multiOptions' => array(
          1 => 'Yes, automatically make business sponsored.',
          0 => 'No, site admin will be making business sponsored.'
        ),
        'value' => 0,
      ));

      //Element: featured
      $this->addElement('Radio', 'featured', array(
        'label' => 'Business Featured Moderation',
        'description' => 'Do you want new business to be automatically made featured?',
        'multiOptions' => array(
          1 => 'Yes, automatically make business featured.',
          0 => 'No, site admin will be making business featured.'
        ),
        'value' => 0,
      ));

      $this->addElement('Radio', 'tfriend', array(
        'label' => 'Tell a friend',
        'description' => 'Do you want to show "Tell a friend" link on the Profile Business of businesses created by members of this level? (Using this feature, viewers will be able to email the business to their friends.)',
        'multiOptions' => array(
          1 => 'Yes',
          0 => 'No'
        ),
        'value' => 1,
      ));

      $this->addElement('Radio', 'print', array(
        'label' => 'Print',
        'description' => 'Do you want to show "Print Business" link on the Profile Business of businesses created by members of this level? (If set to no, viewers will not to be able to print information of the businesses.)',
        'multiOptions' => array(
          1 => 'Yes',
          0 => 'No'
        ),
        'value' => 1,
      ));


      $this->addElement('Radio', 'overview', array(
        'label' => 'Overview',
        'description' => 'Do you want to enable Overview for businesses created by members of this level? (If set to no, neither the overview widget will be shown on the Business Profile nor members will be able to compose or edit the overview of their businesses.)',
        'multiOptions' => array(
          //2 => 'Yes, show overview of the businesses, including private ones.',
          1 => 'Yes',
          0 => 'No'
        ),
        //'value' => ( $this->isModerator() ? 2 : 1 ),
        'value' => 1,
      ));

      $this->addElement('Radio', 'map', array(
        'label' => 'Location Map',
        'description' => 'Do you want to enable Location Map for businesses created by members of this level? (If set to no, neither the map widget will be shown on the Business Profile nor members will be able to specify location of their businesses to be shown in the map.)',
        'multiOptions' => array(
          //2 => 'Yes show map of the businesses, including private ones.',
          1 => 'Yes',
          0 => 'No'
        ),
        //'value' => ( $this->isModerator() ? 2 : 1 ),
        'value' => 1,
      ));


      $this->addElement('Radio', 'insight', array(
        'label' => 'Insights',
        'description' => 'Do you want to allow members of this level to view insights of their businesses? (Insights for businesses show graphical statistics and other metrics such as views, likes, comments, active users, etc over different durations and time summaries. If set to no, neither insights will be shown nor the periodic, auto-generated emails containing Business insights will be send to the business admins who belong to this level.)',
        'multiOptions' => array(
          //2 => 'Yes, allow them to view the insights of the businesses, including private ones.',
          1 => 'Yes',
          0 => 'No'
        ),
        //'value' => ( $this->isModerator() ? 2 : 1 ),
        'value' => 1,
      ));


      $this->addElement('Radio', 'contact', array(
        'label' => 'Contact Details',
        'description' => 'Do you want to enable Contact Details for the businesses created by members of this level? (If set to no, neither the contact details will be shown on the info and browse businesses nor members will be able to mention them for their businesses\' entity.)',
        'multiOptions' => array(
          //2 => 'Yes, enable contact details for the businesses, including private ones.',
          1 => 'Yes',
          0 => 'No'
        ),
        'onclick' => 'contactoption(this.value)',
        //'value' => ( $this->isModerator() ? 2 : 1 ),
        'value' => 1,
      ));


      $this->addElement('MultiCheckbox', 'contact_detail', array(
        'label' => 'Specific Contact Details',
        'description' => 'Which of the following contact details you want to be specified by members of this level in the "Contact Details" section of the Business Dashboard?',
        'multiOptions' => array(
          'phone' => 'Phone',
          'website' => 'Website',
          'email' => 'Email',
        ),
        'value' => array('phone', 'website', 'email')
      ));

//      $this->addElement('Radio', 'foursquare', array(
//          'label' => 'Save To Foursquare Button',
//          'description' => "Do you want to enable 'Save to foursquare' buttons for the businesses created by members of this level? (Using this, 'Save to foursquare' buttons will be shown on profiles of businesses having location information. These buttons will enable business visitors to add the business's place or tip to their foursquare To-Do List. Business Admins will get this option in the \"Marketing\" section of their Dashboard.)",
//          'multiOptions' => array(
//              1 => 'Yes',
//              0 => 'No'
//          ),
//          'value' => 1,
//      ));
      // Element:Twitter
      $sitebusinesstwitterEnabled = Engine_Api::_()->getDbtable('modules', 'core')->isModuleEnabled('sitebusinesstwitter');
      if( $sitebusinesstwitterEnabled ) {
        $this->addElement('Radio', 'twitter', array(
          'label' => 'Display Twitter Updates',
          'description' => "Enable displaying of Twitter Updates for businesses of this package. (Using this, business admins will be able to display their Twitter Updates on their Business profile. Business Admins will get the option for entering their Twitter username in the \"Marketing\" section of their Dashboard. From the Layout Editor, you can choose to place the Twitter Updates widget either in the Tabs container or in the sidebar on Business Profile.)",
          'multiOptions' => array(
            1 => 'Yes',
            0 => 'No'
          ),
          'value' => 1,
        ));
      }

      $this->addElement('Radio', 'sendupdate', array(
        'label' => 'Send an Update',
        'description' => "Do you want to enable 'Send an Update' for the businesses created by members of this level? (Using this, business admins will be able to send an update for their businesses' entity. Business Admins will get this option in the \"Marketing\" section of their Dashboard.)",
        'multiOptions' => array(
          1 => 'Yes',
          0 => 'No'
        ),
        'value' => 1,
      ));
      $sitebusinessFormEnabled = Engine_Api::_()->getDbtable('modules', 'core')->isModuleEnabled('sitebusinesslikebox');
      if( $sitebusinessFormEnabled ) {
        $this->addElement('Radio', 'likebox', array(
          'label' => 'External Embeddable Badge / Like Box',
          'description' => "Do you want business admins to be able to generate code for Embeddable Badges / Like Boxes for businesses created by a member of this level? (If enabled, business admins of such businesses will be able to generate code to embed their external business badges in other websites / blogs to promote their business from Marketing section of business dashboard. Business Admins will also have to belong to this member level to generate code.)",
          'multiOptions' => array(
            1 => 'Yes',
            0 => 'No'
          ),
          'value' => 1,
        ));
      }
      //START SITEBUSINESSBADGES PLUGIN WORK
      $sitebusinessFormEnabled = Engine_Api::_()->getDbtable('modules', 'core')->isModuleEnabled('sitebusinessbadge');
      if( $sitebusinessFormEnabled ) {
        $this->addElement('Radio', 'badge', array(
          'label' => 'Badge Requesting',
          'description' => 'Do you want business admins to be able to request a badge for their business created by a member of this level? (If enabled, business admins of such businesses will be able to request a badge from their business dashboard. You will be able to manage badge requests and assign badges from the admin panel of Badges Extension. Business Admins will also have to belong to this member level to request a badge.)',
          'multiOptions' => array(
            //2 => 'Yes, Private ones also',
            1 => 'Yes',
            0 => 'No'
          ),
          //'value' => ( $this->isModerator() ? 2 : 1 ),
          'value' => 1,
        ));
      }

      //START SITEBUSINESSDOCUMENT PLUGIN WORK
      $sitebusinessDocumentEnabled = Engine_Api::_()->getDbtable('modules', 'core')->isModuleEnabled('sitebusinessdocument');
      if( $sitebusinessDocumentEnabled || (Engine_Api::_()->hasModuleBootstrap('document') && Engine_Api::_()->getDbtable('modules', 'document')->getIntegratedModules(array('enabled' => 1, 'item_type' => 'sitebusiness_business', 'item_module' => 'sitebusiness'))) ) {
        $this->addElement('Radio', 'sdcreate', array(
          'label' => 'Documents in Businesses',
          'description' => 'Do you want Documents to be available to Businesses created by members of this level? This setting will also apply to ability of users of this level to create Documents in Businesses.',
          'multiOptions' => array(
            //2 => 'Yes, allow members to create documents in all businesses, including private ones.',
            1 => 'Yes',
            0 => 'No',
          ),
          //'value' => ( $this->isModerator() ? 2 : 1 ),
          'value' => 1,
        ));

        $this->addElement('MultiCheckbox', 'auth_sdcreate', array(
          'label' => 'Document Creation Options',
          'description' => 'Your users can choose from any of the options checked below when they decide who can create the documents in their business. If you do not check any options, everyone will be allowed to create.',
          'multiOptions' => $privacy_array,
          'value' => $privacy_value_array
//                 array(
//                         'registered' => 'All Registered Members',
//                         'owner_network' => 'Friends and Networks',
//                         'owner_member_member' => 'Friends of Friends',
//                         'owner_member' => 'Friends Only',
//                         'owner' => $ownerTitle,
//                         'member' => $memberTitle,
//                 )
        ));
      }
      //END SITEBUSINESSDOCUMENT PLUGIN WORK
      //START SITEBUSINESSEVENT PLUGIN WORK
      $sitebusinesseventEnabled = Engine_Api::_()->getDbtable('modules', 'core')->isModuleEnabled('sitebusinessevent');
      if( $sitebusinesseventEnabled || (Engine_Api::_()->hasModuleBootstrap('siteevent') && Engine_Api::_()->getDbtable('modules', 'siteevent')->getIntegratedModules(array('enabled' => 1, 'item_type' => 'sitebusiness_business', 'item_module' => 'sitebusiness'))) ) {
        $this->addElement('Radio', 'secreate', array(
          'label' => 'Events in Businesses',
          'description' => 'Do you want Events to be available to Businesses created by members of this level? This setting will also apply to ability of users of this level to create Events in Businesses.',
          'multiOptions' => array(
            //2 => 'Yes, allow members to create events in all businesses, including private ones.',
            1 => 'Yes',
            0 => 'No',
          ),
          //'value' => ( $this->isModerator() ? 2 : 1 ),
          'value' => 1,
        ));

        //START SITEBUSINESSEVENT PLUGIN WORK
        $this->addElement('MultiCheckbox', 'auth_secreate', array(
          'label' => 'Event Creation Options',
          'description' => 'Your users can choose from any of the options checked below when they decide who can create the events in their business. If you do not check any options, everyone will be allowed to create.',
          'multiOptions' => $privacy_array
//                 array(
//                         'registered' => 'All Registered Members',
//                         'owner_network' => 'Friends and Networks',
//                         'owner_member_member' => 'Friends of Friends',
//                         'owner_member' => 'Friends Only',
//                         'owner' => $ownerTitle,
//                         'member' => $memberTitle
//                 )
        ));
      }
      //END SITEBUSINESSEVENT PLUGIN WORK
      //START SITEBUSINESSOFFER PLUGIN WORK
      $sitebusinessFormEnabled = Engine_Api::_()->getDbtable('modules', 'core')->isModuleEnabled('sitebusinessform');
      if( $sitebusinessFormEnabled ) {
        $this->addElement('Radio', 'form', array(
          'label' => 'Form',
          'description' => 'Do you want Forms to be available to Businesses created by members of this level? (The Form on a Business will contain questions added by business admins. If set to No, neither the form widget will be shown on the Business Profile nor the business admins will be able to add questions to the Form from Business Dashboard. Business Admins will also have to belong to this member level to manage form.)',
          'multiOptions' => array(
            //2 => 'Yes, Private ones also',
            1 => 'Yes',
            0 => 'No'
          ),
          //'value' => ( $this->isModerator() ? 2 : 1 ),
          'value' => 1,
        ));
      }
      //END SITEBUSINESSOFFER PLUGIN WORK
      //START SITEBUSINESSINVITE PLUGIN WORK
      $sitebusinessInviteEnabled = Engine_Api::_()->getDbtable('modules', 'core')->isModuleEnabled('sitebusinessinvite');
      if( $sitebusinessInviteEnabled ) {
        $this->addElement('Radio', 'invite', array(
          'label' => 'Invite & Promote',
          'description' => 'Do you want members of this level to be able to invite their friends to the businesses? (If set to no, "Invite your Friends" link will not appear on the Business Profile of their businesses.)',
          'multiOptions' => array(
            1 => 'Yes',
            0 => 'No'
          ),
          'value' => 1,
        ));
      }
      //END SITEBUSINESSINVITE PLUGIN WORK
      //START SITEBUSINESSNOTE PLUGIN WORK
      $sitebusinessNoteEnabled = Engine_Api::_()->getDbtable('modules', 'core')->isModuleEnabled('sitebusinessnote');
      if( $sitebusinessNoteEnabled ) {
        $this->addElement('Radio', 'sncreate', array(
          'label' => 'Notes in Businesses',
          'description' => 'Do you want Notes to be available to Businesses created by members of this level? This setting will also apply to ability of users of this level to create Notes in Businesses.',
          'multiOptions' => array(
            //2 => 'Yes, allow members to create notes in all businesses, including private ones.',
            1 => 'Yes',
            0 => 'No',
          ),
          //'value' => ( $this->isModerator() ? 2 : 1 ),
          'value' => 1,
        ));


        $this->addElement('MultiCheckbox', 'auth_sncreate', array(
          'label' => 'Note Creation Options',
          'description' => 'Your users can choose from any of the options checked below when they decide who can create the notes in their business. If you do not check any options, everyone will be allowed to create.',
          'multiOptions' => $privacy_array
//                 array(
//                         'registered' => 'All Registered Members',
//                         'owner_network' => 'Friends and Networks',
//                         'owner_member_member' => 'Friends of Friends',
//                         'owner_member' => 'Friends Only',
//                         'owner' => $ownerTitle,
//                         'member' => $memberTitle,
//                 )
        ));
      }
      //END SITEBUSINESSNOTE PLUGIN WORK
      //START SITEBUSINESSOFFER PLUGIN WORK
      $sitebusinessOfferEnabled = Engine_Api::_()->getDbtable('modules', 'core')->isModuleEnabled('sitebusinessoffer');
      if( $sitebusinessOfferEnabled ) {
        $this->addElement('Radio', 'offer', array(
          'label' => 'Offer',
          'description' => 'Do you want to let members of this level to show offers for their businesses? (If set to no, neither the offer widget will be shown on their Business Profiles nor they will be able to create them for their businesses.)',
          'multiOptions' => array(
            //2 => 'Yes, allow them to create offers in the businesses, including private ones.',
            1 => 'Yes',
            0 => 'No'
          ),
          //'value' => ( $this->isModerator() ? 2 : 1 ),
          'value' => 1,
        ));
      }
      //END SITEBUSINESSOFFER PLUGIN WORK
      //START DISCUSSION PRIVACY WORK
      $sitebusinessDiscussionEnabled = Engine_Api::_()->getDbtable('modules', 'core')->isModuleEnabled('sitebusinessdiscussion');
      if( $sitebusinessDiscussionEnabled ) {
        $this->addElement('Radio', 'sdicreate', array(
          'label' => 'Discussion Topics in Businesses',
          'description' => 'Do you want Discussion Topics to be available to Businesses created by members of this level? This setting will also apply to ability of users of this level to post discussion topics in Businesses.',
          'multiOptions' => array(
            //2 => 'Yes, allow photo uploading to all businesses, including private ones.',
            1 => 'Yes',
            0 => 'No'
          ),
          //'value' => ( $this->isModerator() ? 2 : 1 ),
          'value' => 1,
        ));

        $this->addElement('MultiCheckbox', 'auth_sdicreate', array(
          'label' => 'Discussion Topics Post Options',
          'description' => 'Your users can choose from any of the options checked below when they decide who can post the discussion topics in their business. If you do not check any options, everyone will be allowed to post.',
          'multiOptions' => $privacy_array
//                 array(
//                         'registered' => 'All Registered Members',
//                         'owner_network' => 'Friends and Networks',
//                         'owner_member_member' => 'Friends of Friends',
//                         'owner_member' => 'Friends Only',
//                         'owner' => $ownerTitle,
//                         'member' => $memberTitle,
//                 )
        ));
      }
      //END DISCUSSION PRIVACY WORK
      //START PHOTO PRIVACY WORK
      $sitebusinessAlbumEnabled = Engine_Api::_()->getDbtable('modules', 'core')->isModuleEnabled('sitebusinessalbum');
      if( $sitebusinessAlbumEnabled ) {
        $this->addElement('Radio', 'spcreate', array(
          'label' => 'Photos in Businesses',
          'description' => 'Do you want Photos to be available to Businesses created by members of this level? This setting will also apply to ability of users of this level to upload Photos in Businesses.',
          'multiOptions' => array(
            //2 => 'Yes, allow photo uploading to all businesses, including private ones.',
            1 => 'Yes',
            0 => 'No'
          ),
          //'value' => ( $this->isModerator() ? 2 : 1 ),
          'value' => 1,
        ));


        $this->addElement('MultiCheckbox', 'auth_spcreate', array(
          'label' => 'Photo Upload Options',
          'description' => 'Your users can choose from any of the options checked below when they decide who can upload the photos in their business. If you do not check any options, everyone will be allowed to create.',
          'multiOptions' => $privacy_array
//                 array(
//                         'registered' => 'All Registered Members',
//                         'owner_network' => 'Friends and Networks',
//                         'owner_member_member' => 'Friends of Friends',
//                         'owner_member' => 'Friends Only',
//                         'owner' => $ownerTitle,
//                         'member' => $memberTitle,
//                 )
        ));
      }
      //END PHOTO PRIVACY WORK
      //START SITEBUSINESSPOLL PLUGIN WORK
      $sitebusinessPollEnabled = Engine_Api::_()->getDbtable('modules', 'core')->isModuleEnabled('sitebusinesspoll');
      if( $sitebusinessPollEnabled ) {
        $this->addElement('Radio', 'splcreate', array(
          'label' => 'Polls in Businesses',
          'description' => 'Do you want Polls to be available to Businesses created by members of this level? This setting will also apply to ability of users of this level to create Polls in Businesses.',
          'multiOptions' => array(
            //2 => 'Yes, allow members to create polls in all businesses, including private ones.',
            1 => 'Yes',
            0 => 'No',
          ),
          //'value' => ( $this->isModerator() ? 2 : 1 ),
          'value' => 1,
        ));

        $this->addElement('MultiCheckbox', 'auth_splcreate', array(
          'label' => 'Poll Creation Options',
          'description' => 'Your users can choose from any of the options checked below when they decide who can create the polls in their business. If you do not check any options, everyone will be allowed to create.',
          'multiOptions' => $privacy_array
//                 array(
//                         'registered' => 'All Registered Members',
//                         'owner_network' => 'Friends and Networks',
//                         'owner_member_member' => 'Friends of Friends',
//                         'owner_member' => 'Friends Only',
//                         'owner' => $ownerTitle,
//                         'member' => $memberTitle,
//                 )
        ));
      }
      //END SITEBUSINESSPOLL PLUGIN WORK
      //START SITEBUSINESSVIDEO PLUGIN WORK
      $sitebusinessVideoEnabled = Engine_Api::_()->getDbtable('modules', 'core')->isModuleEnabled('sitebusinessvideo');
      if( $sitebusinessVideoEnabled || (Engine_Api::_()->hasModuleBootstrap('sitevideo') && Engine_Api::_()->getDbtable('modules', 'sitevideo')->getIntegratedModules(array('enabled' => 1, 'item_type' => 'sitebusiness_business', 'item_module' => 'sitebusiness'))) ) {
        $this->addElement('Radio', 'svcreate', array(
          'label' => 'Videos in Businesses',
          'description' => 'Do you want Videos to be available to Businesses created by members of this level? This setting will also apply to ability of users of this level to create Videos in Businesses.',
          'multiOptions' => array(
            //2 => 'Yes, allow members to create videos in all businesses, including private ones.',
            1 => 'Yes',
            0 => 'No',
          ),
          //'value' => ( $this->isModerator() ? 2 : 1 ),
          'value' => 1,
        ));

        $this->addElement('MultiCheckbox', 'auth_svcreate', array(
          'label' => 'Video Creation Options',
          'description' => 'Your users can choose from any of the options checked below when they decide who can create the videos in their business. If you do not check any options, everyone will be allowed to create.',
          'multiOptions' => $privacy_array
//                 array(
//                         'registered' => 'All Registered Members',
//                         'owner_network' => 'Friends and Networks',
//                         'owner_member_member' => 'Friends of Friends',
//                         'owner_member' => 'Friends Only',
//                         'owner' => $ownerTitle,
//                         'member' => $memberTitle,
//                 )
        ));
      }
      //END SITEBUSINESSVIDEO PLUGIN WORK
      // Element : profile
      $this->addElement('Radio', 'profile', array(
        'label' => 'Profile Creation',
        'description' => 'Do you want members of this level to create profiles for their businesses? (Using this feature, members will be able to create a profile for their Business and fill the corresponding details which will be displayed on info businesses. If set to no, "Profile Types" link will not be shown on the Business Dashboard.)',
        'multiOptions' => array(
          '1' => 'Allow profile creation with all custom Fields.',
          '2' => 'Allow profile creation with only below selected custom Fields.',
          '0' => 'Do not allow the custom profile creation.',
        ),
        'value' => 1,
        'onclick' => 'showprofileOption(this.value)',
      ));

      //Add Dummy element for using the tables
      $this->addElement('Dummy', 'profilefield', array(
        'ignore' => true,
        'decorators' => array(array('ViewScript', array(
              'viewScript' => '_profilefield.tpl',
              'class' => 'form element'
            )))
      ));


      //START SITEBUSINESSMUSIC PLUGIN WORK
      $sitebusinessMusicEnabled = Engine_Api::_()->getDbtable('modules', 'core')->isModuleEnabled('sitebusinessmusic');
      if( $sitebusinessMusicEnabled ) {
        $this->addElement('Radio', 'smcreate', array(
          'label' => 'Music in Businesses',
          'description' => 'Do you want Music to be available to Businesses created by members of this level? This setting will also apply to ability of users of this level to create Music in Businesses.',
          'multiOptions' => array(
            //2 => 'Yes, allow members to create notes in all businesses, including private ones.',
            1 => 'Yes',
            0 => 'No',
          ),
          //'value' => ( $this->isModerator() ? 2 : 1 ),
          'value' => 1,
        ));


        $this->addElement('MultiCheckbox', 'auth_smcreate', array(
          'label' => 'Music Creation Options',
          'description' => 'Your users can choose from any of the options checked below when they decide who can create the music in their business. If you do not check any options, everyone will be allowed to create.',
          'multiOptions' => $privacy_array
//                 array(
//                         'registered' => 'All Registered Members',
//                         'owner_network' => 'Friends and Networks',
//                         'owner_member_member' => 'Friends of Friends',
//                         'owner_member' => 'Friends Only',
//                         'owner' => $ownerTitle,
//                         'member' => $memberTitle,
//                 )
        ));
      }
      //END SITEBUSINESSMUSIC PLUGIN WORK
      //START SITEBUSINESSINTREGRATION PLUGIN WORK//
      if( Engine_Api::_()->getDbtable('modules', 'core')->isModuleEnabled('sitebusinessintegration') ) {
        $mixSettingsResults = Engine_Api::_()->getDbtable('mixsettings', 'sitebusinessintegration')->getIntegrationItems();
        foreach( $mixSettingsResults as $modNameValue ) {

          $Params = Engine_Api::_()->sitebusinessintegration()->integrationParams($modNameValue['resource_type'], $modNameValue['listingtype_id'], '', $modNameValue['item_title']);

          $title = $Params['level_setting_title'];
          $singular = $Params['singular'];
          $plugin_name = $Params['plugin_name'];

          $description = 'Do you want to let members of this level to add ' . $singular . ' from "' . $plugin_name . '" to Directory Items / Businesses? (If set to Yes, then business admins will get this option in the “Apps” section of their dashboard.)';

          $description = Zend_Registry::get('Zend_Translate')->_($description);

          $this->addElement('Radio', $modNameValue['resource_type'] . '_' . $modNameValue['listingtype_id'], array(
            'label' => $title,
            'description' => $description,
            'multiOptions' => array(
              1 => 'Yes',
              0 => 'No',
            ),
            'value' => 1,
          ));
        }
      }

      //START SITECROWDFUNDING PLUGIN WORK
      $sitecrowdfundingEnabled = Engine_Api::_()->getDbtable('modules', 'core')->isModuleEnabled('sitecrowdfunding');
      if( $sitecrowdfundingEnabled && (Engine_Api::_()->hasModuleBootstrap('sitecrowdfundingintegration') && Engine_Api::_()->getDbtable('modules', 'sitecrowdfunding')->getIntegratedModules(array('enabled' => 1, 'item_type' => 'sitebusiness_business', 'item_module' => 'sitebusiness'))) ) {
        $this->addElement('Radio', 'sprcreate', array(
          'label' => 'Allow Creation of Projects',
          'description' => 'Do you want Crowdfunding projects to be available to Businesses created by members of this level? This setting will also apply to ability of users of this level to create Projects in Businesses.',
          'multiOptions' => array(
            1 => 'Yes',
            0 => 'No',
          ),
          'value' => 1,
        ));

        $this->addElement('MultiCheckbox', 'auth_sprcreate', array(
          'label' => 'Crowdfunding Project Creation Options',
          'description' => 'Your users can choose from any of the options checked below when they decide who can create the projects in their Businesses. If you do not check any options, everyone will be allowed to create.',
          'multiOptions' => $privacy_array
        ));

        //END SITECROWDFUNDING PLUGIN WORK
      }

             //START SITEMUSIC PLUGIN WORK
      $sitemusicEnabled = Engine_Api::_()->getDbtable('modules', 'core')->isModuleEnabled('sitemusic');
      if ($sitemusicEnabled && (Engine_Api::_()->hasModuleBootstrap('sitemusic') && Engine_Api::_()->getDbtable('modules', 'sitemusic')->getIntegratedModules(array('enabled' => 1, 'item_type' => 'sitegroup_group', 'item_module' => 'sitegroup')))) {
        $this->addElement('Radio', 'samcreate', array(
            'label' => 'Allow Creation of Music Album',
            'description' => 'Do you want Music Album to be available to Groups created by members of this level? This setting will also apply to ability of users of this level to create Music Album in Groups.',
            'multiOptions' => array(
                1 => 'Yes',
                0 => 'No',
            ),
            'value' => 1,
        ));

        $this->addElement('MultiCheckbox', 'auth_samcreate', array(
            'label' => 'Music Album Creation Options',
            'description' => 'Your users can choose from any of the options checked below when they decide who can create the music album in their groups. If you do not check any options, everyone will be allowed to create.',
            'multiOptions' => $privacy_array
        ));
      }
        //END SITEMUSIC PLUGIN WORK


      //END SITEBUSINESSINTREGRATION PLUGIN WORK//
      //START SITEBUSINESSMEMBER PLUGIN WORK
      $sitebusinessMemberEnabled = Engine_Api::_()->getDbtable('modules', 'core')->isModuleEnabled('sitebusinessmember');
      if( $sitebusinessMemberEnabled ) {
        $this->addElement('Radio', 'smecreate', array(
          'label' => 'Member in Businesses',
          'description' => 'Do you want Member to be available to Businesses join by members of this level? This setting will also apply to ability of users of this level to join Member in Businesses.',
          'multiOptions' => array(
            1 => 'Yes',
            0 => 'No',
          ),
          'value' => 1,
        ));
      }
      //START SITEBUSINESSMEMBER PLUGIN WORK
    }


    if( !$this->isPublic() ) {
      // Element: style
      $this->addElement('Radio', 'style', array(
        'label' => 'Allow Custom CSS Styles?',
        'description' => 'If you enable this feature, your members will be able to customize the colors and fonts of their businesses by altering their CSS styles.',
        'multiOptions' => array(
          1 => 'Yes, enable custom CSS styles.',
          0 => 'No, disable custom CSS styles.',
        ),
        'value' => 1,
      ));
    }
    // Element: claim
    $this->addElement('Radio', 'claim', array(
      'label' => 'Claim Businesses',
      'description' => 'Do you want members of this level to be able to claim businesses? (This will also depend on other settings for claiming like in global settings, manage claims, setting while creation of business, etc.)',
      'multiOptions' => array(
        1 => 'Yes',
        0 => 'No'
      ),
      'value' => 1,
    ));
    if( !$this->isPublic() ) {
      // Element: max
      $this->addElement('Text', 'max', array(
        'label' => 'Maximum Allowed Businesses',
        'description' => 'Enter the maximum number of directory items / businesses that members of this level can create. This field must contain an integer; use zero for unlimited.',
        'validators' => array(
          array('Int', true),
          new Engine_Validate_AtLeast(0),
        ),
      ));
    }
  }

}

?>