<?php

/**
 * SocialEngine
 *
 * @category   Application_Extensions
 * @package    Sitebusiness
 * @copyright  Copyright 2010-2011 BigStep Technologies Pvt. Ltd.
 * @license    http://www.socialengineaddons.com/license/
 * @version    $Id: Menus.php 2011-05-05 9:40:21Z SocialEngineAddOns $
 * @author     SocialEngineAddOns
 */
class Sitebusiness_Plugin_Menus {

    public function canCreateSitebusinesses() {

        // Must be logged in
        $viewer = Engine_Api::_()->user()->getViewer();
        if (!$viewer || !$viewer->getIdentity()) {
            return false;
        }

        // Must be able to view Sitebusinesses
        if (!Engine_Api::_()->authorization()->isAllowed('sitebusiness_business', $viewer, 'view')) {
            return false;
        }

        // Must be able to create Sitebusinesses
        if (!Engine_Api::_()->authorization()->isAllowed('sitebusiness_business', $viewer, 'create')) {
            return false;
        }
        return true;
    }

    public function onMenuInitialize_SitebusinessSubbusinessGutterCreate($row) {

        // Must be logged in
        $viewer = Engine_Api::_()->user()->getViewer();
        if (!$viewer || !$viewer->getIdentity()) {
            return false;
        }
        $subject = Engine_Api::_()->core()->getSubject();
        if ($subject->getType() !== 'sitebusiness_business') {
            return false;
        }

        if (!empty($subject->subbusiness)) {
            return false;
        }

        // Must be able to view Sitebusinesses
        if (!Engine_Api::_()->authorization()->isAllowed('sitebusiness_business', $viewer, 'view')) {
            return false;
        }

        $subbusinessCreate = Engine_Api::_()->sitebusiness()->isManageAdmin($subject, 'sspcreate');
        if (empty($subbusinessCreate)) {
            return false;
        }

        $isBusinessOwnerAllow = Engine_Api::_()->sitebusiness()->isBusinessOwnerAllow($subject, 'sspcreate');
        if (empty($isBusinessOwnerAllow)) {
            return false;
        }

        if (Engine_Api::_()->sitebusiness()->hasPackageEnable()) {
            return array(
                'label' => $row->label,
                'route' => 'sitebusiness_packages',
                'action' => 'index',
                'class' => 'buttonlink item_icon_sitebusiness',
                'params' => array(
                    'parent_id' => $subject->getIdentity()
                ),
            );
        } else {
            return array(
                'label' => $row->label,
                'route' => 'sitebusiness_general',
                'action' => 'create',
                'class' => 'buttonlink item_icon_sitebusiness',
                'params' => array(
                    'parent_id' => $subject->getIdentity()
                ),
            );
        }
    }

    public function canViewSitebusinesses($row) {

        $viewer = Engine_Api::_()->user()->getViewer();

        // Must be able to view Sitebusinesses
        if (!Engine_Api::_()->authorization()->isAllowed('sitebusiness_business', $viewer, 'view')) {
            return false;
        }

//     $enableLocation = Engine_Api::_()->getApi('settings', 'core')->getSetting('sitebusiness.locationfield', 1);
//     if (empty($enableLocation)) { 
// 			return false;
// 	  }
        //Business location work for navigation show.
//     if ($row->params['route'] == 'sitebusiness_general' && $row->params['action'] == 'map') {
// 			$results = Engine_Api::_()->getDbtable('business', 'sitebusiness')->getLocationCount();
// 			if (empty($results)) {
// 				return false;
// 			}
// 	  }
        //End Business location work.

        return true;
    }

    // SHOWING LINK ON "USER HOME BUSINESS".
    public function onMenuInitialize_CoreMainSitebusiness($row) {

        $viewer = Engine_Api::_()->user()->getViewer()->getIdentity();
        $view = Zend_Registry::isRegistered('Zend_View') ? Zend_Registry::get('Zend_View') : null;
        if (!empty($viewer)) {
            return array(
                'label' => $row->label,
                'icon' => $view->layout()->staticBaseUrl . 'application/modules/Sitebusiness/externals/images/sitebusiness.png',
                'route' => 'sitebusiness_general',
            );
        }
        return false;
    }

    public function onMenuInitialize_SitebusinessGutterShare() {
        $viewer = Engine_Api::_()->user()->getViewer();
        $subject = Engine_Api::_()->core()->getSubject();
        if ($subject->getType() !== 'sitebusiness_business') {
            return false;
        }

        $moduleEnabled = Engine_Api::_()->getDbtable('modules', 'core')->isModuleEnabled('sitebusinessmember');
        if (Engine_Api::_()->seaocore()->isSitemobileApp() && !$moduleEnabled) {
            return false;
        }
        // Check share is enable/disable
        $can_share = (int) Engine_Api::_()->getApi('settings', 'core')->getSetting('sitebusiness.share', 1);

        if (!$viewer->getIdentity() || empty($can_share)) {
            return false;
        }

        return array(
            'class' => 'smoothbox icon_sitebusinesses_share buttonlink',
            'route' => 'default',
            'params' => array(
                'module' => 'activity',
                'controller' => 'index',
                'action' => 'share',
                'type' => $subject->getType(),
                'id' => $subject->getIdentity(),
                'format' => 'smoothbox',
            ),
        );
    }

    public function onMenuInitialize_SitebusinessGutterDelete() {
        $viewer = Engine_Api::_()->user()->getViewer();
        $subject = Engine_Api::_()->core()->getSubject();
        if ($subject->getType() !== 'sitebusiness_business') {
            return false;
        }

        $isManageAdmin = Engine_Api::_()->sitebusiness()->isManageAdmin($subject, 'delete');
        if (empty($isManageAdmin)) {
            $can_delete = 0;
        } else {
            $can_delete = 1;
        }

        if (!$viewer->getIdentity() || empty($can_delete)) {
            return false;
        }

        return array(
            'class' => 'buttonlink icon_sitebusinesses_delete',
            'route' => 'sitebusiness_delete',
            'params' => array(
                'business_id' => $subject->getIdentity(),
            ),
        );
    }

    public function onMenuInitialize_SitebusinessGutterPublish() {
        $viewer = Engine_Api::_()->user()->getViewer();
        $subject = Engine_Api::_()->core()->getSubject();
        if ($subject->getType() !== 'sitebusiness_business') {
            return false;
        }

        $isManageAdmin = Engine_Api::_()->sitebusiness()->isManageAdmin($subject, 'edit');
        if (empty($isManageAdmin)) {
            $can_edit = 0;
        } else {
            $can_edit = 1;
        }

        if (!$viewer->getIdentity() || empty($can_edit) || $subject->draft == 1) {
            return false;
        }

        return array(
            'class' => 'buttonlink smoothbox icon_sitebusiness_publish',
            'route' => 'sitebusiness_publish',
            'params' => array(
                'business_id' => $subject->getIdentity(),
            ),
        );
    }

    public function onMenuInitialize_SitebusinessGutterPrint() {
        $subject = Engine_Api::_()->core()->getSubject();
        if ($subject->getType() !== 'sitebusiness_business') {
            return false;
        }

        $isManageAdmin = Engine_Api::_()->sitebusiness()->isManageAdmin($subject, 'print');
        if (empty($isManageAdmin)) {
            $can_print = 0;
        } else {
            $can_print = 1;
        }

        if (empty($can_print)) {
            return false;
        }

        return array(
            'class' => 'buttonlink icon_sitebusinesses_print',
            'target' => '_blank',
            'route' => 'sitebusiness_profilebusiness',
            'params' => array(
                'action' => 'print',
                'id' => $subject->getIdentity(),
            ),
        );
    }

    public function onMenuInitialize_SitebusinessGutterTfriend() {
        $subject = Engine_Api::_()->core()->getSubject();
        if ($subject->getType() !== 'sitebusiness_business') {
            return false;
        }

        $isManageAdmin = Engine_Api::_()->sitebusiness()->isManageAdmin($subject, 'tfriend');
        if (empty($isManageAdmin)) {
            $can_tellfriend = 0;
        } else {
            $can_tellfriend = 1;
        }

        if (empty($can_tellfriend)) {
            return false;
        }

        $class = 'smoothbox buttonlink icon_sitebusinesses_tellafriend';
        $sitemobile = Engine_Api::_()->getDbtable('modules', 'core')->isModuleEnabled('sitemobile');
        if ($sitemobile && Engine_Api::_()->sitemobile()->checkMode('mobile-mode'))
            $class = 'buttonlink icon_sitebusinesses_tellafriend';
        return array(
            'class' => $class,
            'route' => 'sitebusiness_profilebusiness',
            'params' => array(
                'action' => 'tell-a-friend',
                'id' => $subject->getIdentity(),
            ),
        );
    }

    public function onMenuInitialize_SitebusinessGutterClaim() {
        $viewer = Engine_Api::_()->user()->getViewer();

//     if (!Engine_Api::_()->authorization()->isAllowed('sitebusiness_business', $viewer, 'view')) {
//       return false;
//     }
        $viewer_id = $viewer->getIdentity();

        if (!empty($viewer_id)) {
            $level_id = $viewer->level_id;
        } else {
            $authorizationTable = Engine_Api::_()->getItemTable('authorization_level');
            $authorization = $authorizationTable->fetchRow(array('type = ?' => 'public', 'flag = ?' => 'public'));
            if (!empty($authorization))
                $level_id = $authorization->level_id;
        }

        $allow_claim = Engine_Api::_()->authorization()->getPermission($level_id, 'sitebusiness_business', 'claim');
        if (empty($allow_claim)) {
            return false;
        }
        $subject = Engine_Api::_()->core()->getSubject();
        if ($subject->getType() !== 'sitebusiness_business') {
            return false;
        }

        if (!Engine_Api::_()->getApi('settings', 'core')->getSetting('sitebusiness.claimlink', 1)) {
            return false;
        }

        $listmemberclaimsTable = Engine_Api::_()->getDbtable('listmemberclaims', 'sitebusiness');
        $listmemberclaimsTablename = $listmemberclaimsTable->info('name');
        $select = $listmemberclaimsTable->select()->from($listmemberclaimsTablename, array('count(*) as total_count'))
                ->where('user_id = ?', $subject->owner_id);
        $row = $listmemberclaimsTable->fetchAll($select);

        if (!empty($row[0]['total_count'])) {
            $total_count = 1;
        }

        if (empty($total_count) || $subject->owner_id == $viewer_id || empty($subject->userclaim) || empty($allow_claim)) {
            return false;
        }

        if ($viewer_id) {
            return array(
                'class' => 'smoothbox buttonlink icon_sitebusinesses_claim',
                'route' => 'sitebusiness_claimbusinesses',
                'params' => array(
                    'action' => 'claim-business',
                    'business_id' => $subject->getIdentity(),
                ),
            );
        } else {
            return array(
                'class' => 'buttonlink icon_sitebusinesses_claim',
                'route' => 'user_login',
                'params' => array(
                    'return_url' => '64-' . base64_encode($subject->getHref()),
                ),
            );
        }
    }

    public function onMenuInitialize_SitebusinessGutterMessageowner() {
        $viewer = Engine_Api::_()->user()->getViewer();
        $viewer_id = $viewer->getIdentity();

        $moduleEnabled = Engine_Api::_()->getDbtable('modules', 'core')->isModuleEnabled('sitebusinessmember');

        if (Engine_Api::_()->seaocore()->isSitemobileApp() && !$moduleEnabled) {
            return false;
        }
        $subject = Engine_Api::_()->core()->getSubject();
        if ($subject->getType() !== 'sitebusiness_business') {
            return false;
        }

        if ($subject->owner_id == $viewer_id || empty($viewer_id)) {
            return false;
        }

        $showMessageOwner = Engine_Api::_()->authorization()->getPermission($viewer->level_id, 'messages', 'auth');
        if ($showMessageOwner == 'none') {
            return false;
        }

        return array(
            'class' => 'buttonlink smoothbox icon_sitebusinesses_invite',
            'route' => 'sitebusiness_profilebusiness',
            'params' => array(
                'action' => 'message-owner',
                'business_id' => $subject->getIdentity(),
            ),
        );
    }

    public function onMenuInitialize_SitebusinessGutterOpen() {
        $viewer = Engine_Api::_()->user()->getViewer();
        $subject = Engine_Api::_()->core()->getSubject();
        if ($subject->getType() !== 'sitebusiness_business') {
            return false;
        }

        $isManageAdmin = Engine_Api::_()->sitebusiness()->isManageAdmin($subject, 'edit');
        if (empty($isManageAdmin)) {
            $can_edit = 0;
        } else {
            $can_edit = 1;
        }

        if (!$viewer->getIdentity() || $subject->closed != 1 || empty($can_edit)) {
            return false;
        }

        return array(
            'class' => 'buttonlink icon_sitebusinesses_open',
            'route' => 'sitebusiness_close',
            'params' => array(
                'business_id' => $subject->getIdentity(),
                'closed' => 0,
            ),
        );
    }

    public function onMenuInitialize_SitebusinessGutterClose() {
        $viewer = Engine_Api::_()->user()->getViewer();
        $subject = Engine_Api::_()->core()->getSubject();
        if ($subject->getType() !== 'sitebusiness_business') {
            return false;
        }

        $isManageAdmin = Engine_Api::_()->sitebusiness()->isManageAdmin($subject, 'edit');
        if (empty($isManageAdmin)) {
            $can_edit = 0;
        } else {
            $can_edit = 1;
        }

        if (!$viewer->getIdentity() || $subject->closed != 0 || empty($can_edit)) {
            return false;
        }

        return array(
            'class' => 'buttonlink icon_sitebusinesses_close',
            'route' => 'sitebusiness_close',
            'params' => array(
                'business_id' => $subject->getIdentity(),
                'closed' => 1,
            ),
        );
    }

    public function onMenuInitialize_SitebusinessGutterReport() {
        $viewer = Engine_Api::_()->user()->getViewer();
        $subject = Engine_Api::_()->core()->getSubject();
        if ($subject->getType() !== 'sitebusiness_business') {
            return false;
        }

        $report = (int) Engine_Api::_()->getApi('settings', 'core')->getSetting('sitebusiness.report', 1);

        if (!$viewer->getIdentity() || empty($report)) {
            return false;
        }

        return array(
            'class' => 'smoothbox icon_sitebusinesses_report buttonlink',
            'route' => 'default',
            'params' => array(
                'module' => 'core',
                'controller' => 'report',
                'action' => 'create',
                'subject' => $subject->getGuid(),
                'format' => 'smoothbox',
            ),
        );
    }

    public function onMenuInitialize_SitebusinessGutterEditdetail($row) {
        if (!Engine_Api::_()->core()->hasSubject()) {
            return false;
        }

        $sitebusiness = Engine_Api::_()->core()->getSubject('sitebusiness_business');

        //START MANAGE-ADMIN CHECK
        $isManageAdmin = Engine_Api::_()->sitebusiness()->isManageAdmin($sitebusiness, 'edit');
        if (empty($isManageAdmin)) {
            return false;
        }
        //END MANAGE-ADMIN CHECK
        // Modify params
        $params = $row->params;
        $params['params']['business_id'] = $sitebusiness->getIdentity();
        return $params;
    }

    public function onMenuInitialize_SitebusinessGutterEditoverview($row) {
        if (!Engine_Api::_()->core()->hasSubject()) {
            return false;
        }

        $sitebusiness = Engine_Api::_()->core()->getSubject('sitebusiness_business');

        //START MANAGE-ADMIN CHECK
        $isManageAdmin = Engine_Api::_()->sitebusiness()->isManageAdmin($sitebusiness, 'edit');
        if (empty($isManageAdmin)) {
            return false;
        }

        $isManageAdmin = Engine_Api::_()->sitebusiness()->isManageAdmin($sitebusiness, 'overview');
        if (empty($isManageAdmin)) {
            return false;
        }
        //END MANAGE-ADMIN CHECK
        // Modify params
        $params = $row->params;
        $params['params']['business_id'] = $sitebusiness->getIdentity();
        return $params;
    }

    public function onMenuInitialize_SitebusinessGutterEditstyle($row) {

        if (!Engine_Api::_()->core()->hasSubject()) {
            return false;
        }
        $sitebusiness = Engine_Api::_()->core()->getSubject('sitebusiness_business');

        //START MANAGE-ADMIN CHECK
        $isManageAdmin = Engine_Api::_()->sitebusiness()->isManageAdmin($sitebusiness, 'edit');
        if (empty($isManageAdmin)) {
            return false;
        }
        //END MANAGE-ADMIN CHECK
        // Modify params
        $params = $row->params;
        $params['params']['business_id'] = $sitebusiness->getIdentity();
        return $params;
    }

    public function onMenuInitialize_SitebusinessGutterEditlayout($row) {
        $viewer = Engine_Api::_()->user()->getViewer();
        if (!$viewer || !$viewer->getIdentity()) {
            return false;
        }
        if (!Engine_Api::_()->core()->hasSubject()) {
            return false;
        }

        $viewer = Engine_Api::_()->user()->getViewer();
        $sitebusiness = Engine_Api::_()->core()->getSubject('sitebusiness_business');

        //START MANAGE-ADMIN CHECK
        $isManageAdmin = Engine_Api::_()->sitebusiness()->isManageAdmin($sitebusiness, 'edit');
        if (empty($isManageAdmin)) {
            return false;
        }
        //END MANAGE-ADMIN CHECK

        $check = Engine_Api::_()->getApi('settings', 'core')->getSetting('sitebusiness.layoutcreate', 0);

        // Modify params
        $params = $row->params;
        $params['params']['business_id'] = $sitebusiness->getIdentity();

        if (!empty($check)) {
            return $params;
        }
    }

    public function onMenuInitialize_SitebusinessMainClaim($row) {
        // Modify params
        $params = $row->params;
        return $params;
    }

    public function canViewClaims() {
        $viewer = Engine_Api::_()->user()->getViewer();
        //Must be able to view Sitebusinesses
        if (!Engine_Api::_()->authorization()->isAllowed('sitebusiness_business', $viewer, 'view')) {
            return false;
        }


        $viewer_id = $viewer->getIdentity();
        if (!empty($viewer_id)) {
            $level_id = $viewer->level_id;
        } else {
            $authorizationTable = Engine_Api::_()->getItemTable('authorization_level');
            $authorization = $authorizationTable->fetchRow(array('type = ?' => 'public', 'flag = ?' => 'public'));
            if (!empty($authorization))
                $level_id = $authorization->level_id;
        }

        $allow_claim = Engine_Api::_()->authorization()->getPermission($level_id, 'sitebusiness_business', 'claim');

        if (!Engine_Api::_()->getApi('settings', 'core')->sitebusiness_claimlink || empty($allow_claim)) {
            return false;
        }

        $table = Engine_Api::_()->getDbtable('business', 'sitebusiness');
        $tablename = $table->info('name');
        $select = $table->select()->from($tablename, array('count(*) as count'))->where($tablename . '.closed = ?', '0')
                ->where($tablename . '.approved = ?', '1')
                ->where($tablename . '.declined = ?', '0')
                ->where($tablename . '.draft = ?', '1');
        if (Engine_Api::_()->sitebusiness()->hasPackageEnable())
            $select->where($tablename . '.expiration_date  > ?', date("Y-m-d H:i:s"));
        $results = $table->fetchAll($select);
        if (!$results[0]['count']) {
            return false;
        }
        return true;
    }

    // START FOR PROMOTE WITH AN AD LINK
    public function onMenuInitialize_SitebusinessGutterPromotead($row) {

        if (!Engine_Api::_()->core()->hasSubject()) {
            return false;
        }

        // check if Communityad Plugin is enabled
        $sitebusinesscommunityadEnabled = Engine_Api::_()->getDbtable('modules', 'core')->isModuleEnabled('communityad');
        if (!$sitebusinesscommunityadEnabled) {
            return false;
        }

        // check if it is upgraded version
        $communityadmodulemodule = Engine_Api::_()->getDbtable('modules', 'core')->getModule('communityad');
        $adversion = $communityadmodulemodule->version;
        if (!empty(Engine_Api::_()->seaocore()->checkVersion($adversion, '4.1.5'))) {
            return;
        }

        $sitebusiness = Engine_Api::_()->core()->getSubject();
        $ismoduleads_enabled = Engine_Api::_()->getDbtable('modules', 'communityad')->ismoduleads_enabled('sitebusiness');
        if (!$ismoduleads_enabled) {
            return false;
        }

        $useradsTable = Engine_Api::_()->getDbtable('userads', 'communityad');
        $useradsName = $useradsTable->info('name');

        $select = $useradsTable->select();
        $select
                ->from($useradsName, array('userad_id'))
                ->where('resource_type = ?', 'sitebusiness')
                ->where('resource_id = ?', $sitebusiness->business_id)
                ->limit(1);
        $ad_exist = $useradsTable->fetchRow($select);
        if (!empty($ad_exist)) {
            return false;
        }

        //START OWNER CHECK
        $isOwner = Engine_Api::_()->sitebusiness()->isBusinessOwner($sitebusiness);
        if (!$isOwner) {
            return false;
        }
        //END OWNER CHECK
        // Modify params
        $params = $row->params;
        $params['params']['type'] = 'sitebusiness';
        $params['params']['type_id'] = $sitebusiness->getIdentity();
        return $params;
    }

    // START FOR ADD fAVOURITE
    public function onMenuInitialize_SitebusinessGutterFavourite($row) {

        $viewer = Engine_Api::_()->user()->getViewer();
        $viewer_id = $viewer->getIdentity();

        if (!$viewer || !$viewer->getIdentity()) {
            return false;
        }

        //FOR SHOW ADD FAVOURITE LINK ON THE BUSINESS PROFILE BUSINESS
        $show_link = Engine_Api::_()->getApi('settings', 'core')->getSetting('sitebusiness.addfavourite.show', 0);
        if (empty($show_link)) {
            return false;
        }

        if (!Engine_Api::_()->core()->hasSubject()) {
            return false;
        }

        $sitebusiness = Engine_Api::_()->core()->getSubject();
        $business_id = $sitebusiness->business_id;
        $table = Engine_Api::_()->getDbtable('business', 'sitebusiness');
        $tablename = $table->info('name');

        $select = $table->select()->from($tablename, array('count(*) as count'))
                ->where('owner_id = ?', $viewer_id)
                ->where($tablename . '.business_id <> ?', $business_id)
                //->where($tablename . '.owner_id  <> ?', $viewer_id)
                ->where($tablename . '.approved = 1')
                ->where($tablename . '.draft = ?', '1')
                //->group($tablename . '.owner_id')
                ->where($tablename . '.closed = ?', '0');
        $results = $table->fetchRow($select);
        $count = $results->count;

        if ($count < 1) {
            return false;
        }

        $check = Engine_Api::_()->getDbtable('favourites', 'sitebusiness')->isShow($sitebusiness->getIdentity());
        $table_favourites = Engine_Api::_()->getDbtable('favourites', 'sitebusiness');
        $tablename = $table->info('name');

        $select_content = $table_favourites->select()->where('owner_id = ?', $viewer_id);
        $content = $select_content->query()->fetchAll();

        if (!empty($content)) {
            //Started the select query
            $select = $table->select()
                    ->from($tablename, 'business_id')
                    ->where($tablename . '.business_id <> ?', $business_id)
                    ->where($tablename . '.owner_id  =?', $viewer_id)
                    ->where($tablename . '.approved = 1')
                    ->where($tablename . '.draft = ?', '1')
                    ->where($tablename . '.closed = ?', '0')
                    ->where('NOT EXISTS (SELECT `business_id` FROM `engine4_sitebusiness_favourites` WHERE `business_id_for`=' . $business_id . ' AND `business_id` = ' . $tablename . '.`business_id`) ');
            $content_result = $select->query()->fetchAll();
            $count_result1 = count($content_result);

            if (($count_result1 == 0)) {
                return false;
            }
        }

        // Modify params
        $params = $row->params;
        $params['params']['business_id'] = $sitebusiness->getIdentity();

        if (!empty($check)) {
            return $params;
        } else {
            return $params;
        }
    }

    // END FOR ADD fAVOURITE
    // START FOR DELETE fAVOURITE
    public function onMenuInitialize_SitebusinessGutterFavouritedelete($row) {

        $viewer = Engine_Api::_()->user()->getViewer();
        if (!$viewer || !$viewer->getIdentity()) {
            return false;
        }

        if (!Engine_Api::_()->core()->hasSubject()) {
            return false;
        }
        $viewer_id = $viewer->getIdentity();


        $viewer = Engine_Api::_()->user()->getViewer();
        $sitebusiness = Engine_Api::_()->core()->getSubject('sitebusiness_business');

        $check = Engine_Api::_()->getDbtable('favourites', 'sitebusiness')->isnotShow($sitebusiness->getIdentity());

        // Modify params
        $params = $row->params;
        $params['params']['business_id'] = $sitebusiness->getIdentity();

        if (!empty($check)) {
            return $params;
        }
    }

    // END FOR DELETE fAVOURITE
    //ADD TO WISHLIST LINK
    public function onMenuInitialize_SitebusinessGutterWishlist($row) {

        //GET VIEWER DETAIL
        $viewer = Engine_Api::_()->user()->getViewer();
        $viewer_id = $viewer->getIdentity();

        if (empty($viewer_id)) {
            return false;
        }

        $canView = Engine_Api::_()->authorization()->getPermission($viewer->level_id, 'sitebusinesswishlist_wishlist', 'view');
        if (empty($canView)) {
            return false;
        }

        //RETURN FALSE IF SUBJECT IS NOT SET
        $subject = Engine_Api::_()->core()->getSubject();
        if ($subject->getType() !== 'sitebusiness_business') {
            return false;
        }

        //SHOW ADD TO WISHLIST LINK IF SITEPAGWISHLIST MODULES IS ENABLED
        $sitebusinessWishlistEnabled = Engine_Api::_()->getDbtable('modules', 'core')->isModuleEnabled('sitebusinesswishlist');
        if (!$viewer->getIdentity() || empty($sitebusinessWishlistEnabled)) {
            return false;
        }

        return array(
            'class' => 'icon_sitebusinesswishlist_add buttonlink',
            'route' => 'default',
            'params' => array(
                'module' => 'sitebusinesswishlist',
                'controller' => 'index',
                'action' => 'add',
                'business_id' => $subject->getIdentity(),
            ),
        );
    }

    public function onMenuInitialize_SitebusinessSitegroupGutterCreate($row) {

        if (!Engine_Api::_()->core()->hasSubject()) {
            return false;
        }

        $moduleEnabled = Engine_Api::_()->getDbtable('modules', 'core')->isModuleEnabled('sitebusinessintegration');
        $sitegroupmoduleEnabled = Engine_Api::_()->getDbtable('modules', 'core')->isModuleEnabled('sitegroup');
        if (empty($moduleEnabled) || empty($sitegroupmoduleEnabled)) {
            return false;
        }

        $viewer = Engine_Api::_()->user()->getViewer();
        $sitebusiness = Engine_Api::_()->core()->getSubject('sitebusiness_business');

        $item_enabled = Engine_Api::_()->getDbtable('mixsettings', 'sitebusinessintegration')->getItemsEnabled('sitegroup_group', 0);
        if (empty($item_enabled)) {
            return false;
        }

        if (Engine_Api::_()->sitebusiness()->hasPackageEnable()) {
            if (!Engine_Api::_()->sitebusiness()->allowPackageContent($sitebusiness->package_id, "modules", "sitegroup_group_0")) {
                return false;
            }
        } else {
            $isBusinessOwnerAllow = Engine_Api::_()->sitebusiness()->isBusinessOwnerAllow($sitebusiness, 'sitegroup_group_0');
            if (empty($isBusinessOwnerAllow)) {
                return false;
            }
        }

        //START MANAGE-ADMIN CHECK
        $isManageAdmin = Engine_Api::_()->sitebusiness()->isManageAdmin($sitebusiness, 'edit');
        if (empty($isManageAdmin)) {
            return false;
        }

        if (!Engine_Api::_()->authorization()->isAllowed('sitegroup_group', $viewer, 'create')) {
            return false;
        }

        if (Engine_Api::_()->sitegroup()->hasPackageEnable()) {
            return array(
                'label' => $row->label,
                'route' => 'sitegroup_packages',
                'action' => 'index',
                'class' => 'buttonlink item_icon_sitegroup',
                'params' => array(
                    'business_id' => $sitebusiness->business_id
                ),
            );
        } else {
            return array(
                'label' => $row->label,
                'route' => 'sitegroup_general',
                'action' => 'create',
                'class' => 'buttonlink item_icon_sitegroup',
                'params' => array(
                    'business_id' => $sitebusiness->business_id
                ),
            );
        }
    }

    public function onMenuInitialize_SitebusinessDocumentGutterCreate($row) {

        if (!Engine_Api::_()->core()->hasSubject()) {
            return false;
        }
        $viewer = Engine_Api::_()->user()->getViewer();
        $sitebusiness = Engine_Api::_()->core()->getSubject('sitebusiness_business');
        $moduleEnabled = Engine_Api::_()->getDbtable('modules', 'core')->isModuleEnabled('sitebusinessintegration');
        $listmoduleEnabled = Engine_Api::_()->getDbtable('modules', 'core')->isModuleEnabled('document');
        if (empty($moduleEnabled) || empty($listmoduleEnabled)) {
            return false;
        }

        $item_enabled = Engine_Api::_()->getDbtable('mixsettings', 'sitebusinessintegration')->getItemsEnabled('document', 0);
        if (empty($item_enabled)) {
            return false;
        }
        if (Engine_Api::_()->sitebusiness()->hasPackageEnable()) {
            if (!Engine_Api::_()->sitebusiness()->allowPackageContent($sitebusiness->package_id, "modules", "document_0")) {
                return false;
            }
        } else {
            $isBusinessOwnerAllow = Engine_Api::_()->sitebusiness()->isBusinessOwnerAllow($sitebusiness, 'document_0');
            if (empty($isBusinessOwnerAllow)) {
                return false;
            }
        }
        //START MANAGE-ADMIN CHECK
        $isManageAdmin = Engine_Api::_()->sitebusiness()->isManageAdmin($sitebusiness, 'edit');
        if (empty($isManageAdmin)) {
            return false;
        }

        if (!Engine_Api::_()->authorization()->isAllowed('document', $viewer, 'create')) {
            return false;
        }

        // Modify params
        $params = $row->params;
        $params['params']['business_id'] = $sitebusiness->getIdentity();
        return $params;
    }

    public function onMenuInitialize_SitebusinessSitepageGutterCreate($row) {

        if (!Engine_Api::_()->core()->hasSubject()) {
            return false;
        }

        $moduleEnabled = Engine_Api::_()->getDbtable('modules', 'core')->isModuleEnabled('sitebusinessintegration');
        $sitepagemoduleEnabled = Engine_Api::_()->getDbtable('modules', 'core')->isModuleEnabled('sitepage');
        if (empty($moduleEnabled) || empty($sitepagemoduleEnabled)) {
            return false;
        }

        $viewer = Engine_Api::_()->user()->getViewer();
        $sitebusiness = Engine_Api::_()->core()->getSubject('sitebusiness_business');

        $item_enabled = Engine_Api::_()->getDbtable('mixsettings', 'sitebusinessintegration')->getItemsEnabled('sitepage_page', 0);
        if (empty($item_enabled)) {
            return false;
        }
        if (Engine_Api::_()->sitebusiness()->hasPackageEnable()) {
            if (!Engine_Api::_()->sitebusiness()->allowPackageContent($sitebusiness->package_id, "modules", "sitepage_page_0")) {
                return false;
            }
        } else {
            $isBusinessOwnerAllow = Engine_Api::_()->sitebusiness()->isBusinessOwnerAllow($sitebusiness, 'sitepage_page_0');
            if (empty($isBusinessOwnerAllow)) {
                return false;
            }
        }
        //START MANAGE-ADMIN CHECK
        $isManageAdmin = Engine_Api::_()->sitebusiness()->isManageAdmin($sitebusiness, 'edit');
        if (empty($isManageAdmin)) {
            return false;
        }

        if (!Engine_Api::_()->authorization()->isAllowed('sitepage_page', $viewer, 'create')) {
            return false;
        }

        if (Engine_Api::_()->sitepage()->hasPackageEnable()) {
            return array(
                'label' => $row->label,
                'route' => 'sitepage_packages',
                'action' => 'index',
                'class' => 'buttonlink item_icon_sitepage',
                'params' => array(
                    'business_id' => $sitebusiness->business_id
                ),
            );
        } else {
            return array(
                'label' => $row->label,
                'route' => 'sitepage_general',
                'action' => 'create',
                'class' => 'buttonlink item_icon_sitepage',
                'params' => array(
                    'business_id' => $sitebusiness->business_id
                ),
            );
        }
    }

    public function onMenuInitialize_SitebusinessFolderGutterCreate($row) {

        if (!Engine_Api::_()->core()->hasSubject()) {
            return false;
        }
        $viewer = Engine_Api::_()->user()->getViewer();
        $sitebusiness = Engine_Api::_()->core()->getSubject('sitebusiness_business');
        $moduleEnabled = Engine_Api::_()->getDbtable('modules', 'core')->isModuleEnabled('sitebusinessintegration');
        $listmoduleEnabled = Engine_Api::_()->getDbtable('modules', 'core')->isModuleEnabled('folder');
        if (empty($moduleEnabled) || empty($listmoduleEnabled)) {
            return false;
        }

        $item_enabled = Engine_Api::_()->getDbtable('mixsettings', 'sitebusinessintegration')->getItemsEnabled('folder', 0);
        if (empty($item_enabled)) {
            return false;
        }
        if (Engine_Api::_()->sitebusiness()->hasPackageEnable()) {
            if (!Engine_Api::_()->sitebusiness()->allowPackageContent($sitebusiness->package_id, "modules", "folder_0")) {
                return false;
            }
        } else {
            $isBusinessOwnerAllow = Engine_Api::_()->sitebusiness()->isBusinessOwnerAllow($sitebusiness, 'folder_0');
            if (empty($isBusinessOwnerAllow)) {
                return false;
            }
        }
        //START MANAGE-ADMIN CHECK
        $isManageAdmin = Engine_Api::_()->sitebusiness()->isManageAdmin($sitebusiness, 'edit');
        if (empty($isManageAdmin)) {
            return false;
        }

        if (!Engine_Api::_()->authorization()->isAllowed('folder', $viewer, 'create')) {
            return false;
        }

        // Modify params
        $params = $row->params;
        $params['params']['business_id'] = $sitebusiness->getIdentity();
        return $params;
    }

    public function onMenuInitialize_SitebusinessQuizGutterCreate($row) {

        if (!Engine_Api::_()->core()->hasSubject()) {
            return false;
        }
        $viewer = Engine_Api::_()->user()->getViewer();
        $sitebusiness = Engine_Api::_()->core()->getSubject('sitebusiness_business');
        $moduleEnabled = Engine_Api::_()->getDbtable('modules', 'core')->isModuleEnabled('sitebusinessintegration');
        $listmoduleEnabled = Engine_Api::_()->getDbtable('modules', 'core')->isModuleEnabled('quiz');
        if (empty($moduleEnabled) || empty($listmoduleEnabled)) {
            return false;
        }

        $item_enabled = Engine_Api::_()->getDbtable('mixsettings', 'sitebusinessintegration')->getItemsEnabled('quiz', 0);
        if (empty($item_enabled)) {
            return false;
        }
        if (Engine_Api::_()->sitebusiness()->hasPackageEnable()) {
            if (!Engine_Api::_()->sitebusiness()->allowPackageContent($sitebusiness->package_id, "modules", "quiz_0")) {
                return false;
            }
        } else {
            $isBusinessOwnerAllow = Engine_Api::_()->sitebusiness()->isBusinessOwnerAllow($sitebusiness, 'quiz_0');
            if (empty($isBusinessOwnerAllow)) {
                return false;
            }
        }
        //START MANAGE-ADMIN CHECK
        $isManageAdmin = Engine_Api::_()->sitebusiness()->isManageAdmin($sitebusiness, 'edit');
        if (empty($isManageAdmin)) {
            return false;
        }

        if (!Engine_Api::_()->authorization()->isAllowed('quiz', $viewer, 'create')) {
            return false;
        }

        // Modify params
        $params = $row->params;
        $params['params']['business_id'] = $sitebusiness->getIdentity();
        return $params;
    }

    public function onMenuInitialize_SitebusinessListGutterCreate($row) {

        if (!Engine_Api::_()->core()->hasSubject()) {
            return false;
        }
        $viewer = Engine_Api::_()->user()->getViewer();
        $sitebusiness = Engine_Api::_()->core()->getSubject('sitebusiness_business');
        $moduleEnabled = Engine_Api::_()->getDbtable('modules', 'core')->isModuleEnabled('sitebusinessintegration');
        $listmoduleEnabled = Engine_Api::_()->getDbtable('modules', 'core')->isModuleEnabled('list');
        if (empty($moduleEnabled) || empty($listmoduleEnabled)) {
            return false;
        }

        //START MANAGE-ADMIN CHECK
        $isManageAdmin = Engine_Api::_()->sitebusiness()->isManageAdmin($sitebusiness, 'edit');
        if (empty($isManageAdmin)) {
            return false;
        }
        if (Engine_Api::_()->sitebusiness()->hasPackageEnable()) {
            if (!Engine_Api::_()->sitebusiness()->allowPackageContent($sitebusiness->package_id, "modules", "list_listing_0")) {
                return false;
            }
        } else {
            $isBusinessOwnerAllow = Engine_Api::_()->sitebusiness()->isBusinessOwnerAllow($sitebusiness, 'list_listing_0');
            if (empty($isBusinessOwnerAllow)) {
                return false;
            }
        }
        if (!Engine_Api::_()->authorization()->isAllowed('list_listing', $viewer, 'create')) {
            return false;
        }

        // Modify params
        $params = $row->params;
        $params['params']['business_id'] = $sitebusiness->getIdentity();
        return $params;
    }

    public function sitebusinesssitereviewGutterCreate($row) {

        if (!Engine_Api::_()->core()->hasSubject()) {
            return false;
        }

        $viewer = Engine_Api::_()->user()->getViewer();
        $sitebusiness = Engine_Api::_()->core()->getSubject('sitebusiness_business');
        $moduleEnabled = Engine_Api::_()->getDbtable('modules', 'core')->isModuleEnabled('sitebusinessintegration');
        $sitereviewmoduleEnabled = Engine_Api::_()->getDbtable('modules', 'core')->isModuleEnabled('sitereview');
        if (empty($moduleEnabled) || empty($sitereviewmoduleEnabled)) {
            return false;
        }

        //START MANAGE-ADMIN CHECK
        $isManageAdmin = Engine_Api::_()->sitebusiness()->isManageAdmin($sitebusiness, 'edit');
        if (empty($isManageAdmin)) {
            return false;
        }

        //GET LISTING TYPE ID
        $listingtype_id = $row->params['listing_id'];
        $listingType = Engine_Api::_()->getItem('sitereview_listingtype', $listingtype_id);
        $titleSinUc = ucfirst($listingType->title_singular);
        if (Engine_Api::_()->sitebusiness()->hasPackageEnable()) {
            if (!Engine_Api::_()->sitebusiness()->allowPackageContent($sitebusiness->package_id, "modules", "sitereview_listing_$listingtype_id")) {
                return false;
            }
        } else {
            $isBusinessOwnerAllow = Engine_Api::_()->sitebusiness()->isBusinessOwnerAllow($sitebusiness, "sitereview_listing_$listingtype_id");
            if (empty($isBusinessOwnerAllow)) {
                return false;
            }
        }

        $item_enabled = Engine_Api::_()->getDbtable('mixsettings', 'sitebusinessintegration')->getItemsEnabled('sitereview_listing', $listingtype_id);
        if (empty($item_enabled)) {
            return false;
        }

        //MUST BE ABLE TO VIEW LISTINGS
        if (!Engine_Api::_()->authorization()->isAllowed('sitereview_listing', $viewer, "view_listtype_$listingtype_id")) {
            return false;
        }

        //MUST BE ABLE TO CRETE LISTINGS
        if (!Engine_Api::_()->authorization()->isAllowed('sitereview_listing', $viewer, "create_listtype_$listingtype_id")) {
            return false;
        }

        $sitereviewpaidlistingEnabled = Engine_Api::_()->getDbtable('modules', 'core')->isModuleEnabled('sitereviewpaidlisting');
        if ($sitereviewpaidlistingEnabled) {
            $total_packages = Engine_Api::_()->getDbtable('packages', 'sitereviewpaidlisting')->getTotalPackage($listingtype_id, 1);
        }
        
        $translate = Zend_Registry::get('Zend_Translate');

        if ($sitereviewpaidlistingEnabled && $listingType->package && $total_packages == 1) {
            $package = Engine_Api::_()->getDbTable('packages', 'sitereviewpaidlisting')->getEnabledPackage($listingtype_id);
            return array(
//                'label' => "Post New $titleSinUc Listings",
                'label' => $translate->translate(rtrim($row->label)),
                'route' => "sitereview_general_listtype_$listingtype_id",
                'action' => 'create',
                'class' => $row->params['class'],
                'params' => array(
                    'id' => $package->package_id,
                    'business_id' => $sitebusiness->business_id,
                ),
            );
        } elseif ($sitereviewpaidlistingEnabled && $listingType->package && $total_packages > 1) {
            return array(
//                'label' => "Post New $titleSinUc Listings",
                'label' => $translate->translate(rtrim($row->label)),
                'route' => "sitereview_all_package_listtype_$listingtype_id",
                'action' => 'index',
                'class' => $row->params['class'],
                'params' => array(
                    'business_id' => $sitebusiness->business_id,
                ),
            );
        } else {
            return array(
//                'label' => "Post New $titleSinUc Listings",
                'label' => $translate->translate(rtrim($row->label)),
                'route' => "sitereview_general_listtype_$listingtype_id",
                'action' => 'create',
                'class' => $row->params['class'],
                'params' => array(
                    'business_id' => $sitebusiness->business_id,
                ),
            );
        }
    }

    public function onMenuInitialize_SitebusinessTutorialGutterCreate($row) {

        if (!Engine_Api::_()->core()->hasSubject()) {
            return false;
        }
        $viewer = Engine_Api::_()->user()->getViewer();
        $sitebusiness = Engine_Api::_()->core()->getSubject('sitebusiness_business');
        $moduleEnabled = Engine_Api::_()->getDbtable('modules', 'core')->isModuleEnabled('sitebusinessintegration');
        $sitetutorialmoduleEnabled = Engine_Api::_()->getDbtable('modules', 'core')->isModuleEnabled('sitetutorial');
        if (empty($moduleEnabled) || empty($sitetutorialmoduleEnabled)) {
            return false;
        }

        $item_enabled = Engine_Api::_()->getDbtable('mixsettings', 'sitebusinessintegration')->getItemsEnabled('sitetutorial_tutorial', 0);
        if (empty($item_enabled)) {
            return false;
        }

        //START MANAGE-ADMIN CHECK
        $isManageAdmin = Engine_Api::_()->sitebusiness()->isManageAdmin($sitebusiness, 'edit');
        if (empty($isManageAdmin)) {
            return false;
        }
        if (Engine_Api::_()->sitebusiness()->hasPackageEnable()) {
            if (!Engine_Api::_()->sitebusiness()->allowPackageContent($sitebusiness->package_id, "modules", "sitetutorial_tutorial_0")) {
                return false;
            }
        } else {
            $isBusinessOwnerAllow = Engine_Api::_()->sitebusiness()->isBusinessOwnerAllow($sitebusiness, 'sitetutorial_tutorial_0');
            if (empty($isBusinessOwnerAllow)) {
                return false;
            }
        }

        if (!Engine_Api::_()->authorization()->isAllowed('sitetutorial_tutorial', $viewer, 'create')) {
            return false;
        }

        // Modify params
        $params = $row->params;
        $params['params']['business_id'] = $sitebusiness->getIdentity();
        return $params;
    }

    public function onMenuInitialize_SitebusinessFaqGutterCreate($row) {

        if (!Engine_Api::_()->core()->hasSubject()) {
            return false;
        }
        $viewer = Engine_Api::_()->user()->getViewer();
        $sitebusiness = Engine_Api::_()->core()->getSubject('sitebusiness_business');
        $moduleEnabled = Engine_Api::_()->getDbtable('modules', 'core')->isModuleEnabled('sitebusinessintegration');
        $sitefaqmoduleEnabled = Engine_Api::_()->getDbtable('modules', 'core')->isModuleEnabled('sitefaq');
        if (empty($moduleEnabled) || empty($sitefaqmoduleEnabled)) {
            return false;
        }

        $item_enabled = Engine_Api::_()->getDbtable('mixsettings', 'sitebusinessintegration')->getItemsEnabled('sitefaq_faq', 0);
        if (empty($item_enabled)) {
            return false;
        }

        //START MANAGE-ADMIN CHECK
        $isManageAdmin = Engine_Api::_()->sitebusiness()->isManageAdmin($sitebusiness, 'edit');
        if (empty($isManageAdmin)) {
            return false;
        }
        if (Engine_Api::_()->sitebusiness()->hasPackageEnable()) {
            if (!Engine_Api::_()->sitebusiness()->allowPackageContent($sitebusiness->package_id, "modules", "sitefaq_faq_0")) {
                return false;
            }
        } else {
            $isBusinessOwnerAllow = Engine_Api::_()->sitebusiness()->isBusinessOwnerAllow($sitebusiness, 'sitefaq_faq_0');
            if (empty($isBusinessOwnerAllow)) {
                return false;
            }
        }

        if (!Engine_Api::_()->authorization()->isAllowed('sitefaq_faq', $viewer, 'create')) {
            return false;
        }

        // Modify params
        $params = $row->params;
        $params['params']['business_id'] = $sitebusiness->getIdentity();
        return $params;
    }

    public function onMenuInitialize_SitebusinessSitestoreproductGutterCreate($row) {

        if (!Engine_Api::_()->core()->hasSubject()) {
            return false;
        }

        $moduleEnabled = Engine_Api::_()->getDbtable('modules', 'core')->isModuleEnabled('sitebusinessintegration');
        $sitestoreproductmoduleEnabled = Engine_Api::_()->getDbtable('modules', 'core')->isModuleEnabled('sitestoreproduct');
        if (empty($moduleEnabled) || empty($sitestoreproductmoduleEnabled)) {
            return false;
        }

        $viewer = Engine_Api::_()->user()->getViewer();
        $sitebusiness = Engine_Api::_()->core()->getSubject('sitebusiness_business');

        $item_enabled = Engine_Api::_()->getDbtable('mixsettings', 'sitebusinessintegration')->getItemsEnabled('sitestoreproduct_product', 0);
        if (empty($item_enabled)) {
            return false;
        }

        //START MANAGE-ADMIN CHECK
        $isManageAdmin = Engine_Api::_()->sitebusiness()->isManageAdmin($sitebusiness, 'edit');
        if (empty($isManageAdmin)) {
            return false;
        }

        if (Engine_Api::_()->sitebusiness()->hasPackageEnable()) {
            if (!Engine_Api::_()->sitebusiness()->allowPackageContent($sitebusiness->package_id, "modules", "sitestoreproduct_product_0")) {
                return false;
            }
        } else {
            $isBusinessOwnerAllow = Engine_Api::_()->sitebusiness()->isBusinessOwnerAllow($sitebusiness, 'sitestoreproduct_product_0');
            if (empty($isBusinessOwnerAllow)) {
                return false;
            }
        }

        if (!Engine_Api::_()->authorization()->isAllowed('sitestoreproduct_product', $viewer, 'create')) {
            return false;
        }

        if (!empty($sitebusiness->owner_id)) {
            $store = Engine_Api::_()->getDbtable('stores', 'sitestore')->getStoreId($sitebusiness->owner_id);
        }

        if (count($store) == 0) {
            return false;
        }

        if ($sitestoreproductmoduleEnabled) {
            $authValue = Engine_Api::_()->sitestoreproduct()->isStoreAdmin($store[0]['store_id']);
            if (empty($authValue)) {
                return false;
            }
        }

        if (count($store) == 1) {
            $store_id = $store[0]['store_id'];
            return array(
                'label' => $row->label,
                'route' => 'sitestoreproduct_general',
                'action' => 'create',
                'class' => 'buttonlink seaocore_icon_add',
                'params' => array(
                    'business_id' => $sitebusiness->business_id,
                    'store_id' => $store_id
                ),
            );
        } else {
            return array(
                'label' => $row->label,
                'route' => 'default',
                'module' => 'sitebusinessintegration',
                'controller' => 'index',
                'action' => 'storeintegration',
                'class' => 'buttonlink seaocore_icon_add smoothbox',
                'params' => array(
                    'resource_id' => $sitebusiness->business_id
                ),
            );
        }
    }

}
