<?php

/**
 * SocialEngine
 *
 * @category   Application_Extensions
 * @package    Sitebusiness
 * @copyright  Copyright 2010-2011 BigStep Technologies Pvt. Ltd.
 * @license    http://www.socialengineaddons.com/license/
 * @version    $Id: IndexController.php 2011-05-05 9:40:21Z SocialEngineAddOns $
 * @author     SocialEngineAddOns
 */
class Sitebusiness_ClaimController extends Core_Controller_Action_Standard {

  protected $_navigation;

  //ACTION FOR CLAIMING THE BUSINESS
  public function indexAction() {

    //CHECK USER VALIDATION
    if (!$this->_helper->requireUser()->isValid())
      return;

    //GET LOGGED IN USER INFORMATION
    $viewer = Engine_Api::_()->user()->getViewer();
    $viewer_id = $viewer->getIdentity();

    //GET LEVEL ID
    $level_id = 0;
    if (!empty($viewer_id)) {
      $level_id = $viewer->level_id;
    } else {
      $authorizationTable = Engine_Api::_()->getItemTable('authorization_level');
      $authorization = $authorizationTable->fetchRow(array('type = ?' => 'public', 'flag = ?' => 'public'));
      if (!empty($authorization))
        $level_id = $authorization->level_id;
    }

    //CHECK USER HAVE TO ALLOW CLAIM OR NOT
    $allow_claim = Engine_Api::_()->authorization()->getPermission($level_id, 'sitebusiness_business', 'claim');
    $getPackageClaim = Engine_Api::_()->sitebusiness()->getPackageAuthInfo('sitebusiness');
    if (empty(Engine_Api::_()->getApi('settings', 'core')->sitebusiness_claimlink) || empty($allow_claim)) {
      return $this->_forward('requireauth', 'error', 'core');
    }

    //FETCH
    $params = array();
    $params['viewer_id'] = $viewer_id;
    $params['limit'] = $this->_getParam('limit', 40);
    $usersitebusinesses = Engine_Api::_()->getDbtable('business', 'sitebusiness')->getSuggestClaimBusiness($params);

    //IF THERE IS NO BUSINESSS THEN SHOWING THE TIP THERE IS NO BUSINESSS
    if (!empty($usersitebusinesses)) {
      $usersitebusiness = $usersitebusinesses->toarray();
      if (empty($usersitebusiness))
        $this->view->showtip = 1;
    }

    //GET NAVIGATION
    $this->view->navigation = Engine_Api::_()->getApi('menus', 'core')->getNavigation('sitebusiness_main');

    //BUSINESS ID
    $business_id = $this->_getParam('business_id', null);

    //FORM
    $this->view->form = $form = new Sitebusiness_Form_Claim();

    //POPULATE FORM
    if (!empty($viewer_id)) {
      $value['email'] = $viewer->email;
      $value['nickname'] = $viewer->displayname;
      $form->populate($value);
    }

    //CHECK FORM VALIDAION
    if ($this->getRequest()->isPost() && $form->isValid($this->getRequest()->getPost())) {
      if ($business_id == 0) {
        $error = $this->view->translate('This is an invalid business name. Please select a valid business name from the autosuggest given below.');
        $this->view->status = false;
        $error = Zend_Registry::get('Zend_Translate')->_($error);
        $form->getDecorator('errors')->setOption('escape', false);
        $form->addError($error);
        return;
      }
      $values = $form->getValues();

      //GET SITEBUSINESS ITEM
      $sitebusiness = Engine_Api::_()->getItem('sitebusiness_business', $business_id);
      if (!empty($sitebusiness)) {
        $items = array();
        $items['business_id'] = $business_id;
        $items['viewer_id'] = $viewer_id;
        $claimbusinesses = Engine_Api::_()->getDbtable('claims', 'sitebusiness')->getClaimStatus($items);
        if (!empty($claimbusinesses)) {
          if ($claimbusinesses->status == 3 || $claimbusinesses->status == 4) {
            $error = $this->view->translate("You have already filed a claim for the business: \"%s\", which is either on hold or is awaiting action by administration.", $sitebusiness->title);
            $this->view->status = false;
            $form->getElement("business_id")->setValue("0");
            $error = Zend_Registry::get('Zend_Translate')->_($error);
            $form->getDecorator('errors')->setOption('escape', false);
            $form->addError($error);
            return;
          } elseif ($claimbusinesses->status == 2) {
            $error = $this->view->translate("You have already filed a claim for the business: \"%s\", which has been declined by the site admin.", $sitebusiness->title);
            $this->view->status = false;
            $error = Zend_Registry::get('Zend_Translate')->_($error);
            $form->getDecorator('errors')->setOption('escape', false);
            $form->getElement("business_id")->setValue("0");
            $form->addError($error);
            return;
          }
        }
      }
      //GET EMAIl
      $email = $values['email'];

      //CHECK EMAIL VALIDATION
      $validator = new Zend_Validate_EmailAddress();
      $validator->getHostnameValidator()->setValidateTld(false);
      if (!$validator->isValid($email)) {
        $form->addError(Zend_Registry::get('Zend_Translate')->_('Please enter a valid email address.'));
        return;
      }
      
			$coreApiSettings = Engine_Api::_()->getApi('settings', 'core');
		  $adminEmail = $coreApiSettings->getSetting('core.mail.contact', $coreApiSettings->getSetting('core.mail.from', "email@domain.com"));
			if(!$adminEmail) $adminEmail = $coreApiSettings->getSetting('core.mail.from', "email@domain.com");

      //GET CLAIM TABLE
      $tableClaim = Engine_Api::_()->getDbTable('claims', 'sitebusiness');
      $db = Engine_Db_Table::getDefaultAdapter();
      $db->beginTransaction();
      try {
        //SAVE VALUES
        if (!empty($getPackageClaim)) {
          //GET SITEBUSINESS ITEM
          $sitebusiness = Engine_Api::_()->getItem('sitebusiness_business', $business_id);

          //GET BUSINESS URL
          $business_url = Engine_Api::_()->sitebusiness()->getBusinessUrl($business_id);

          //SEND SITEBUSINESS TITLE TO THE TPL
          $business_title = $sitebusiness->title;

          //SEND CLAIM OWNER EMAIL
          if(Engine_Api::_()->getApi('settings', 'core')->getSetting('sitebusiness.claim.email', 1) && Engine_Api::_()->getApi('settings', 'core')->getSetting('sitebusiness_claimlink', 1) ) {
						Engine_Api::_()->getApi('mail', 'core')->sendSystem($adminEmail, 'SITEBUSINESS_CLAIMOWNER_EMAIL', array(
								'business_title' => $business_title,
								'business_title_with_link' => '<a href="' . 'http://' . $_SERVER['HTTP_HOST'] .
								Zend_Controller_Front::getInstance()->getRouter()->assemble(array('business_url' => $business_url), 'sitebusiness_entry_view', true) . '"  >' . $business_title . ' </a>',
								'object_link' => 'http://' . $_SERVER['HTTP_HOST'] .
								Zend_Controller_Front::getInstance()->getRouter()->assemble(array('business_url' => $business_url), 'sitebusiness_entry_view', true),
								'email' => $coreApiSettings->getSetting('core.mail.from', "email@domain.com"),
								'queue' => true
						));
					}

          $row = $tableClaim->createRow();
          $row->business_id = $business_id;
          $row->user_id = $viewer_id;
          $row->about = $values['about'];
          $row->nickname = $values['nickname'];
          $row->email = $email;
          $row->contactno = $values['contactno'];
          $row->usercomments = $values['usercomments'];
          $row->status = 3;
          $row->save();
        }
        $db->commit();
      } catch (Exception $e) {
        $db->rollBack();
        throw $e;
      }
      $this->view->successmessage = 1;
    }
  }

  //ACTION FOR SHOW BUSINESSS ON WHICH I HAVE CLAIMED
  public function myBusinessesAction() {

    //CHECK USER VALIDATION
    if (!$this->_helper->requireUser()->isValid())
      return;

    //CHECK CLAIM IS ENABLED OR NOT
    $claimEnabled = Engine_Api::_()->getApi('settings', 'core')->getSetting('sitebusiness.claimlink', 1);
    if (empty($claimEnabled)) {
      return $this->_forward('requireauth', 'error', 'core');
    }

    //GET LOGGED IN USER INFORMATION
    $viewer = Engine_Api::_()->user()->getViewer();
    $this->view->viewer_id = $viewer_id = $viewer->getIdentity();

    //CHECK THAT MEMBER HAS ALLOED FOR CLAIM OR NOT
    $canClaim = Engine_Api::_()->authorization()->getPermission($viewer->level_id, 'sitebusiness_business', 'claim');
    if (empty($canClaim)) {
      return $this->_forward('requireauth', 'error', 'core');
    }

    //GET NAVIGATION
    $this->view->navigation = Engine_Api::_()->getApi('menus', 'core')->getNavigation('sitebusiness_main', array(), 'sitebusiness_main_manage');

    //MAKE PAGINATOR
    $this->view->paginator = $paginator = Engine_Api::_()->getDbtable('claims', 'sitebusiness')->getMyClaimBusinesses($viewer_id);

    //GET PAGINATOR
    $items_count = (int) Engine_Api::_()->getApi('settings', 'core')->getSetting('sitebusiness.business', 10);
    $paginator->setItemCountPerPage($items_count);
    $this->view->paginator = $paginator->setCurrentPageNumber($values['business']);
  }

  //ACTION FOR CLAIM A BUSINESS FROM THE BUSINESS PROFILE BUSINESS
  public function claimBusinessAction() {

    //CHECK USER VALIDATION
    if (!$this->_helper->requireUser()->isValid())
      return;

    //GET LOGGED IN USER INFORMATION
    $viewer = Engine_Api::_()->user()->getViewer();
    $viewer_id = $viewer->getIdentity();

    //GET LEVEL ID
    if (!empty($viewer_id)) {
      $level_id = $viewer->level_id;
    } else {
      $authorizationTable = Engine_Api::_()->getItemTable('authorization_level');
      $authorization = $authorizationTable->fetchRow(array('type = ?' => 'public', 'flag = ?' => 'public'));
      if (!empty($authorization))
        $level_id = $authorization->level_id;
    }

    $getPackageClaim = Engine_Api::_()->sitebusiness()->getPackageAuthInfo('sitebusiness');
    $this->_helper->layout->setLayout('default-simple');

    //GET BUSINESS ID
    $business_id = $this->_getParam('business_id', null);

    //SET PARAMS
    $paramss = array();
    $paramss['business_id'] = $business_id;
    $paramss['viewer_id'] = $viewer_id;
    $inforow = Engine_Api::_()->getDbtable('claims', 'sitebusiness')->getClaimStatus($paramss);

		$this->view->status = 0;
    if (!empty($inforow)) {
      $this->view->status = $inforow->status;
		}

		$coreApiSettings = Engine_Api::_()->getApi('settings', 'core');
		$adminEmail = $coreApiSettings->getSetting('core.mail.contact', $coreApiSettings->getSetting('core.mail.from', "email@domain.com"));
		if(!$adminEmail) $adminEmail = $coreApiSettings->getSetting('core.mail.from', "email@domain.com");
		

    //CHECK STATUS
    if ($this->view->status == 2) {
      echo '<div class="global_form" style="margin:15px 0 0 15px;"><div><div><h3>' . $this->view->translate("Alert!") . '</h3>';
      echo '<div class="form-elements" style="margin-top:10px;"><div class="form-wrapper" style="margin-bottom:10px;">' . $this->view->translate("You have already send a request to claim for this business which has been declined by the site admin.") . '</div>';
      echo '<div class="form-wrapper"><button onclick="parent.Smoothbox.close()">' . $this->view->translate("Close") . '</button></div></div></div></div></div>';
    }

    $this->view->claimoption = $claimoption = Engine_Api::_()->authorization()->getPermission($level_id, 'sitebusiness_business', 'claim');

    //FETCH
    $paramss = array();
    $this->view->userclaim = $userclaim = 0;
    $paramss['business_id'] = $business_id;
    $paramss['limit'] = 1;
    $businessclaiminfo = Engine_Api::_()->getDbtable('business', 'sitebusiness')->getSuggestClaimBusiness($paramss);

    if (!$claimoption || !$businessclaiminfo[0]['userclaim'] || !Engine_Api::_()->getApi('settings', 'core')->getSetting('sitebusiness.claimlink', 1)) {
      return $this->_forward('requireauth', 'error', 'core');
    }

    if (isset($businessclaiminfo[0]['userclaim'])) {
      $this->view->userclaim = $userclaim = $businessclaiminfo[0]['userclaim'];
    }

    if ($inforow['status'] == 3 || $inforow['status'] == 4) {
      echo '<div class="global_form" style="margin:15px 0 0 15px;"><div><div><h3>' . $this->view->translate("Alert!") . '</h3>';
      echo '<div class="form-elements" style="margin-top:10px;"><div class="form-wrapper" style="margin-bottom:10px;">' . $this->view->translate("You have already filed a claim for this business: \"%s\", which is either on hold or is awaiting action by administration.", Engine_Api::_()->getItem('sitebusiness_business', $business_id)->title) . '</div>';
      echo '<div class="form-wrapper"><button onclick="parent.Smoothbox.close()">' . $this->view->translate("Close") . '</button></div></div></div></div></div>';
    }

    if (!$inforow['status'] && $claimoption && $userclaim) {
      //GET FORM
      $this->view->form = $form = new Sitebusiness_Form_Claimbusiness();

      //POPULATE FORM
      if (!empty($viewer_id)) {
        $value['email'] = $viewer->email;
        $value['nickname'] = $viewer->displayname;
        $form->populate($value);
      }

      if ($this->getRequest()->isPost() && $form->isValid($this->getRequest()->getPost())) {
        //GET FORM VALUES
        $values = $form->getValues();

        //GET EMAIL
        $email = $values['email'];

        //CHECK EMAIL VALIDATION
        $validator = new Zend_Validate_EmailAddress();
        if (!$validator->isValid($email)) {
          $form->addError(Zend_Registry::get('Zend_Translate')->_('Please enter a valid email address.'));
          return;
        }

        //GET CLAIM TABLE
        $tableClaim = Engine_Api::_()->getDbTable('claims', 'sitebusiness');
        $db = Engine_Db_Table::getDefaultAdapter();
        $db->beginTransaction();
        try {
          //SAVE VALUES
          if (!empty($getPackageClaim)) {

            //GET SITEBUSINESS ITEM
            $sitebusiness = Engine_Api::_()->getItem('sitebusiness_business', $business_id);

            //GET BUSINESS URL
            $business_url = Engine_Api::_()->sitebusiness()->getBusinessUrl($business_id);

            //SEND SITEBUSINESS TITLE TO THE TPL
            $business_title = $sitebusiness->title;

           //SEND CHANGE OWNER EMAIL
						if(Engine_Api::_()->getApi('settings', 'core')->getSetting('sitebusiness.claim.email', 1) && Engine_Api::_()->getApi('settings', 'core')->getSetting('sitebusiness.claimlink', 1)) {
							Engine_Api::_()->getApi('mail', 'core')->sendSystem($adminEmail, 'SITEBUSINESS_CLAIMOWNER_EMAIL', array(
									'business_title' => $business_title,
									'business_title_with_link' => '<a href="' . 'http://' . $_SERVER['HTTP_HOST'] .
									Zend_Controller_Front::getInstance()->getRouter()->assemble(array('business_url' => $business_url), 'sitebusiness_entry_view', true) . '"  >' . $business_title . ' </a>',
									'object_link' => 'http://' . $_SERVER['HTTP_HOST'] .
									Zend_Controller_Front::getInstance()->getRouter()->assemble(array('business_url' => $business_url), 'sitebusiness_entry_view', true),
									'email' => $coreApiSettings->getSetting('core.mail.from', "email@domain.com"),
									'queue' => true
							));
						}

            $row = $tableClaim->createRow();
            $row->business_id = $business_id;
            $row->user_id = $viewer_id;
            $row->about = $values['about'];
            $row->nickname = $values['nickname'];
            $row->email = $email;
            $row->contactno = $values['contactno'];
            $row->usercomments = $values['usercomments'];
            $row->status = 3;
            $row->save();
          }
          $db->commit();
        } catch (Exception $e) {
          $db->rollBack();
          throw $e;
        }
        $this->_forward('success', 'utility', 'core', array(
            'smoothboxClose' => true,
            'parentRefreshTime' => '60',
            'parentRefresh' => 'true',
            'format' => 'smoothbox',
            'messages' => array(Zend_Registry::get('Zend_Translate')->_('Your request has been send successfully. You will now receive an email confirming Admin approval of your request.'))
        ));
      }
    }
  }

  //ACTION FOR GETTING BUSINESSS ON WHICH USER CAN CLAIM
  public function getBusinessesAction() {

    //FETCH
    $paramss = array();
    $paramss['title'] = $this->_getParam('text');
    $paramss['viewer_id'] = Engine_Api::_()->user()->getViewer()->getIdentity();
    $paramss['limit'] = $this->_getParam('limit', 40);
    $paramss['orderby'] = 'title ASC';
    $usersitebusinesses = Engine_Api::_()->getDbtable('business', 'sitebusiness')->getSuggestClaimBusiness($paramss);
    $data = array();
    $mode = $this->_getParam('struct');
    if ($mode == 'text') {
      foreach ($usersitebusinesses as $usersitebusiness) {
        $content_photo = $this->view->itemPhoto($usersitebusiness, 'thumb.icon');
        $data[] = array(
            'id' => $usersitebusiness->business_id,
            'label' => $usersitebusiness->title,
            'photo' => $content_photo
        );
      }
    } else {
      foreach ($usersitebusinesses as $usersitebusiness) {
        $content_photo = $this->view->itemPhoto($usersitebusiness, 'thumb.icon');
        $data[] = array(
            'id' => $usersitebusiness->business_id,
            'label' => $usersitebusiness->title,
            'photo' => $content_photo
        );
      }
    }
    return $this->_helper->json($data);
  }

  //ACTION FOR DELETING THE CLAIM REQUEST
  public function deleteAction() {

  	//CHECK USER VALIDATION
    if (!$this->_helper->requireUser()->isValid())
      return;

    //SET LAYOUT
    $this->_helper->layout->setLayout('default-simple');

    //GET CLAIM ID
    $claim_id = $this->_getParam('claim_id', 'null');

    //GET CLAIM ITEM
    $claim = Engine_Api::_()->getItem('sitebusiness_claim', $claim_id);
    if ($claim->user_id != Engine_Api::_()->user()->getViewer()->getIdentity()) {
      return $this->_forward('requireauth', 'error', 'core');
    }

    //GET FORM
    $this->view->form = $form = new Sitebusiness_Form_Deleteclaim();

    //CHECK FORM VALIDATION
    if ($this->getRequest()->isPost() && $form->isValid($this->getRequest()->getPost())) {
      //GET CLAIM TABLE
      Engine_Api::_()->getDbtable('claims', 'sitebusiness')->delete(array('claim_id=?' => $claim_id));
      $this->_forward('success', 'utility', 'core', array(
          'smoothboxClose' => true,
          'parentRefresh' => true,
          'format' => 'smoothbox',
          'messages' => array(Zend_Registry::get('Zend_Translate')->_('You have successfully deleted your claim request.'))
      ));
    }
  }

  //ACTION FOR SHOWING THE TREM OF THE CLAIM
  public function termsAction() {

    $this->_helper->layout->setLayout('default-simple');
  }
}

?>