<?php

/**
 * SocialEngine
 *
 * @category   Application_Extensions
 * @package    Sitebusiness
 * @copyright  Copyright 2010-2011 BigStep Technologies Pvt. Ltd.
 * @license    http://www.socialengineaddons.com/license/
 * @version    $Id: LayoutController.php 2011-05-05 9:40:21Z SocialEngineAddOns $
 * @author     SocialEngineAddOns
 */
class Sitebusiness_LayoutController extends Core_Controller_Action_Standard {

    //SET THE VALUE FOR ALL ACTION DEFAULT
    public function init() {

        $ajaxContext = $this->_helper->getHelper('AjaxContext');
        $ajaxContext
                ->addActionContext('rate', 'json')
                ->addActionContext('validation', 'html')
                ->initContext();

        $id = $this->_getParam('business_id', $this->_getParam('id', null));
        if ($id) {
            $sitebusiness = Engine_Api::_()->getItem('sitebusiness_business', $id);
            if ($sitebusiness) {
                Engine_Api::_()->core()->setSubject($sitebusiness);
                //START MANAGE-ADMIN CHECK
                $isManageAdmin = Engine_Api::_()->sitebusiness()->isManageAdmin($sitebusiness, 'edit');

                if (empty($isManageAdmin)) {
                    return $this->_forward('requireauth', 'error', 'core');
                }
                //END MANAGE-ADMIN CHECK
            }
        }
    }

    public function layoutAction() {

        if (!Engine_Api::_()->core()->hasSubject('sitebusiness_business')) {
            return false;
        }

        $edit_layout_setting = Engine_Api::_()->getApi('settings', 'core')->getSetting('sitebusiness.layoutcreate', 0);
        if (empty($edit_layout_setting)) {
            $this->_helper->redirector->gotoRoute(array('action' => 'home'), 'user_general', true);
        }

        $viewer_id = Engine_Api::_()->user()->getViewer()->getIdentity();
        $this->view->sitebusiness = $sitebusiness = Engine_Api::_()->core()->getSubject('sitebusiness_business');

        //GET NAVIGATION
        $this->view->navigation = $navigation = Engine_Api::_()->getApi('menus', 'core')->getNavigation('sitebusiness_main');

        //FINDING THE LAYOUT ID OF THIS BUSINESS
        $contentTable = Engine_Api::_()->getDbtable('content', 'sitebusiness');
        $contentTableName = $contentTable->info('name');
        $contentBusinessTable = Engine_Api::_()->getDbtable('contentbusinesses', 'sitebusiness');
        $contentBusinessTableName = $contentBusinessTable->info('name');
        $contentbusiness_id = $contentBusinessTable->select()
                ->from($contentBusinessTableName, array('contentbusiness_id'))
                ->where('business_id =?', $sitebusiness->business_id)
                ->query()
                ->fetchColumn();
        //GET BUSINESS PARAM
        $business = $contentbusiness_id;
        $contentTable = Engine_Api::_()->getDbtable('content', 'sitebusiness');
        $this->view->adminDriven = 0;
        if (empty($business)) {
            $corebusinessinfo = Engine_Api::_()->sitebusiness()->getWidgetizedBusiness();
            $coreBusinessesTable = Engine_Api::_()->getDbtable('pages', 'core');
            $coreBusinessesTableName = $coreBusinessesTable->info('name');
            $contentCoreTable = Engine_Api::_()->getDbtable('content', 'core');
            $contentCoreTableName = $contentCoreTable->info('name');
            $adminContentTable = Engine_Api::_()->getDbtable('admincontent', 'sitebusiness');
            $adminContentTableName = $adminContentTable->info('name');
            $contentbusiness_id = $adminContentTable->select()
                    ->from($adminContentTableName, array('business_id'))
                    ->where('business_id =?', $corebusinessinfo->page_id)
                    ->query()
                    ->fetchColumn();
            //GET CURRENT BUSINESS
            $this->view->businessObject = $businessObject = $coreBusinessesTable->fetchRow($coreBusinessesTable->select()->where('name = ?', 'sitebusiness_index_view')->orWhere('page_id = ?', $contentbusiness_id));
            if (null === $businessObject) {
                $business = 'core_index_index';
                $businessObject = $coreBusinessesTable->fetchRow($coreBusinessesTable->select()->where('name = ?', 'core_index_index'));
            }

            //GET REGISTERED CONTENT AREAS
            if (!empty($businessObject)) {
                $contentRowset = $adminContentTable->fetchAll($adminContentTable->select()->where('business_id = ?', $businessObject->page_id)->order('order ASC'));
                $contentStructure = $adminContentTable->prepareContentArea($contentRowset);
            }
            $this->view->adminDriven = 1;
        } else {
            //GET CURRENT BUSINESS
            $this->view->businessObject = $businessObject = $contentBusinessTable->fetchRow($contentBusinessTable->select()->where('user_id = ?', $viewer_id)->where('name = ?', $business)->orWhere('contentbusiness_id = ?', $business));
            if (null === $businessObject) {
                $business = 'core_index_index';
                $businessObject = $businessTable->fetchRow($contentBusinessTable->select()->where('name = ?', $business)->where('user_id = ?', $viewer_id));
            }
            //GET REGISTERED CONTENT AREAS
            if (!empty($businessObject)) {
                $contentRowset = $contentTable->fetchAll($contentTable->select()->where('contentbusiness_id = ?', $businessObject->contentbusiness_id)->order('order ASC'));
                $contentStructure = $contentBusinessTable->prepareContentArea($contentRowset);
            }
        }
        $this->view->business = $business;
        $this->view->businessObject = $businessObject;

        //GET AVAILABLE CONTENT BLOCKS
        $this->view->contentAreas = $contentAreas = $this->buildCategorizedContentAreas($this->getContentAreas());

        $rows = Engine_Api::_()->getDbtable('hideprofilewidgets', 'sitebusiness')->hideWidgets();
        $hideWidgets = array();
        foreach ($rows as $value)
            $hideWidgets[] = $value->widgetname;
        $this->view->hideWidgets = $hideWidgets;
        $contentByName = array();
        foreach ($contentAreas as $category => $categoryAreas) {
            foreach ($categoryAreas as $info) {
                $contentByName[$info['name']] = $info;
            }
        }
        $this->view->contentByName = $contentByName;

        //MAKE BUSINESS FORM
        $this->view->businessForm = $businessForm = new Sitebusiness_Form_Layout_Content_Business();
        if (!empty($businessObject)) {
            $businessForm->populate($businessObject->toArray());
        } else {
            //return;
        }

        //VALIDATE STRUCTURE
        //NOTE: DO NOT VALIDATE FOR HEADER OR FOOTER
        $error = false;
        if ($businessObject->name !== 'header' && $businessObject->name !== 'footer') {
            foreach ($contentStructure as &$info1) {
                if (!in_array($info1['name'], array('top', 'bottom', 'main')) || $info1['type'] != 'container') {
                    $error = true;
                    break;
                }
                foreach ($info1['elements'] as &$info2) {
                    if (!in_array($info2['name'], array('left', 'middle', 'right')) || $info1['type'] != 'container') {
                        $error = true;
                        break;
                    }
                }
                //RE ORDER SECOND-LEVEL ELEMENTS
                usort($info1['elements'], array($this, '_reorderContentStructure'));
            }
        }

        if ($error) {
            $error_msg = Zend_Registry::get('Zend_Translate')->_('business failed validation check');
            throw new Exception($error_msg);
        }

        $this->view->showeditinwidget = array('seaocore.feed', 'activity.feed', 'sitebusiness.info-sitebusiness', 'sitebusiness.overview-sitebusiness', 'sitebusiness.location-sitebusiness', 'core.profile-links', 'sitebusiness.discussion-sitebusiness', 'sitebusinesspoll.profile-sitebusinesspolls', 'sitebusinessevent.profile-sitebusinessevents', 'sitebusinessoffer.profile-sitebusinessoffers', 'sitebusinessdocument.profile-sitebusinessdocuments', 'sitebusinessform.sitebusiness-viewform', 'sitebusinessreview.profile-sitebusinessreviews', 'sitebusinessnote.profile-sitebusinessnotes', 'sitebusinessvideo.profile-sitebusinessvideos', 'sitebusiness.photos-sitebusiness', 'sitebusinessmusic.profile-sitebusinessmusic', 'sitebusinessintegration.profile-items', 'sitebusinesstwitter.feeds-sitebusinesstwitter', 'advancedactivity.home-feeds', 'sitebusinessmember.profile-sitebusinessmembers', 'siteevent.contenttype-events', 'sitevideo.contenttype-videos','sitecrowdfunding.contenttype-projects','sitemusic.contenttype-music');

        //ASSIGN STRUCTURE
        $this->view->contentRowset = $contentRowset;
        $this->view->contentStructure = $contentStructure;

        $isSupport = null;
        $coreVersion = Engine_Api::_()->getDbtable('modules', 'core')->getModule('core');
        /*
          return < 0 : when running version is lessthen 4.2.1
          return 0 : If running version is equal to 4.2.1
          return > 0 : when running version is greaterthen 4.2.1
         */
        if (!empty($coreVersion)) {
            $coreVersion = $coreVersion->version;
            if (!empty(Engine_Api::_()->seaocore()->checkVersion($coreVersion, '4.2.1'))) {
                $isSupport = 1;
            }
        }
        if (!empty($isSupport)) {
            $this->renderScript('layout/layout.tpl');
        } else {
            $this->renderScript('layout/layout_default.tpl');
        }
    }

    public function updateAction() {

        $businessTable = Engine_Api::_()->getDbtable('contentbusinesses', 'sitebusiness');
        $contentTable = Engine_Api::_()->getDbtable('content', 'sitebusiness');
        $db = $businessTable->getAdapter();
        $db->beginTransaction();

        try {
            //GET BUSINESS
            $business = $this->_getParam('business');
            $businessObject = $businessTable->fetchRow($businessTable->select()->where('name = ?', $business)->orWhere('contentbusiness_id = ?', $business));
            if (null === $businessObject) {
                $message1 = Zend_Registry::get('Zend_Translate')->_('Business is missing');
                throw new Engine_Exception($message1);
            }

            //UPDATE LAYOUT
            if (null !== ($newLayout = $this->_getParam('layout'))) {
                $businessObject->layout = $newLayout;
                $businessObject->save();
            }

            //GET REGISTERED CONTENT AREAS
            $contentRowset = $contentTable->fetchAll($contentTable->select()->where('contentbusiness_id = ?', $businessObject->contentbusiness_id));

            //GET STRUCTURE
            $paramStructure = $this->_getParam('structure');
            $structure = !empty($paramStructure) ? Zend_Json::decode( $paramStructure ) : array();

            //DIFF
            $orderIndex = 1;
            $newRowsByTmpId = array();
            $existingRowsByContentId = array();

            foreach ($structure as $element) {
                //GET INFO
                $content_id = @$element['identity'];
                $tmp_content_id = @$element['tmp_identity'];
                $parent_id = @$element['parent_identity'];
                $tmp_parent_id = @$element['parent_tmp_identity'];

                $newOrder = $orderIndex++;

                //SANITY
                if (empty($content_id) && empty($tmp_content_id)) {
                    $message2 = Zend_Registry::get('Zend_Translate')->_('content id and tmp content id both empty');
                    throw new Exception($message2);
                }

                //GET EXISTING CONTENT ROW (IF ANY)
                $contentRow = null;
                if (!empty($content_id)) {
                    $contentRow = $contentRowset->getRowMatching('content_id', $content_id);
                    if (null === $contentRow) {
                        $message3 = Zend_Registry::get('Zend_Translate')->_('content row missing');
                        throw new Exception($message3);
                    }
                }

                //GET EXISTING PARENT ROW (IF ANY)
                $parentContentRow = null;
                if (!empty($parent_id)) {
                    $parentContentRow = $contentRowset->getRowMatching('content_id', $parent_id);
                } else if (!empty($tmp_parent_id)) {
                    $parentContentRow = @$newRowsByTmpId[$tmp_parent_id];
                }

                //EXISTING ROW
                if (!empty($contentRow) && is_object($contentRow)) {
                    $existingRowsByContentId[$content_id] = $contentRow;

                    //UPDATE ROW
                    if (!empty($parentContentRow)) {
                        $contentRow->parent_content_id = $parentContentRow->content_id;
                    }
                    if (empty($contentRow->parent_content_id)) {
                        $contentRow->parent_content_id = new Zend_Db_Expr('NULL');
                    }
                    $session = new Zend_Session_Namespace();

                    //SET PARAMS
                    if (isset($session->setSomething) && in_array($element['name'], $session->setSomething)) {
                        $contentRow->params = json_encode($element['params']);
                        $contentRow->widget_admin = 0;
                    }
                    if ($contentRow->type == 'container') {
                        $newOrder = array_search($contentRow->name, array('top', 'main', 'bottom', 'left', 'right', 'middle')) + 1;
                    }

                    $contentRow->order = $newOrder;
                    $contentRow->save();
                }
                //NEW ROW
                else {
                    if (empty($element['type']) || empty($element['name'])) {
                        $message4 = Zend_Registry::get('Zend_Translate')->_('missing name and/or type info');
                        throw new Exception($message4);
                    }

                    if ($element['type'] == 'container') {
                        $newOrder = array_search($element['name'], array('top', 'main', 'bottom', 'left', 'right', 'middle')) + 1;
                    }

                    $contentRow = $contentTable->createRow();
                    $contentRow->contentbusiness_id = $businessObject->contentbusiness_id;
                    $contentRow->order = $newOrder;
                    $contentRow->type = $element['type'];
                    $contentRow->name = $element['name'];
                    $contentRow->widget_admin = 0;

                    //SET PARENT CONTENT
                    if (!empty($parentContentRow)) {
                        $contentRow->parent_content_id = $parentContentRow->content_id;
                    }
                    if (empty($contentRow->parent_content_id)) {
                        $contentRow->parent_content_id = new Zend_Db_Expr('NULL');
                    }

                    $contentRow->params = json_encode($element['params']);
                    $contentRow->save();
                    $newRowsByTmpId[$tmp_content_id] = $contentRow;
                }
            }
            //DELETE ROWS THAT WERE NOT PRESENT IN DATA SENT BACK
            $deletedRowIds = array();
            foreach ($contentRowset as $contentRow) {
                if (empty($existingRowsByContentId[$contentRow->content_id])) {
                    $deletedRowIds[] = $contentRow->content_id;
                    $contentRow->delete();
                }
            }
            $this->view->deleted = $deletedRowIds;

            //SEND BACK NEW CONTENT INFO
            $newData = array();
            foreach ($newRowsByTmpId as $tmp_id => $newRow) {
                $newData[$tmp_id] = $businessTable->createElementParams($newRow);
            }
            $this->view->newIds = $newData;

            $this->view->status = true;
            $this->view->error = false;

            $db->commit();
        } catch (Exception $e) {
            $db->rollBack();
            $this->view->status = false;
            $this->view->error = true;
        }
        if (isset($session->setSomething))
            unset($session->setSomething);
    }

    public function createAction() {

        //GET BUSINESS PARAM
        $business = $this->_getParam('business');
        $businessTable = Engine_Api::_()->getDbtable('contentbusinesses', 'sitebusiness');
        $contentTable = Engine_Api::_()->getDbtable('content', 'sitebusiness');

        //MAKE NEW BUSINESS
        if (($business == 'new' || $business === null) && $this->getRequest()->isPost()) {
            $businessObject = $businessTable->createRow();
            $businessObject->displayname = ( null !== ($name = $this->_getParam('name')) ? $name : 'Untitled' );
            $businessObject->save();

            //CREATE A CONTENT ROW FOR THIS BUSINESS
            $contentRow = $contentTable->createRow();
            $contentRow->type = 'container';
            $contentRow->name = 'main';
            $contentRow->contentbusiness_id = $businessObject->contentbusiness_id;
            $contentRow->save();

            $contentRow2 = $contentTable->createRow();
            $contentRow2->type = 'container';
            $contentRow2->name = 'middle';
            $contentRow2->contentbusiness_id = $businessObject->contentbusiness_id;
            $contentRow2->parent_content_id = $contentRow->content_id;
            $contentRow2->save();
        }

        if ($businessObject) {
            return $this->_redirectCustom($this->view->url(array('action' => 'index')) . '?business=' . $businessObject->contentbusiness_id);
        } else {
            return $this->_redirectCustom($this->view->url(array('action' => 'index')));
        }
    }

    public function saveAction() {

        $form = new Sitebusiness_Form_Layout_Content_Business();
        if ($this->getRequest()->isPost() && $form->isValid($this->getRequest()->getPost())) {
            $values = $form->getValues();
            $business_id = $values['contentbusiness_id'];
            unset($values['contentbusiness_id']);

            if (empty($values['url'])) {
                $values['url'] = new Zend_Db_Expr('NULL');
            }

            $businessTable = Engine_Api::_()->getDbtable('contentbusinesses', 'sitebusiness');
            $businessObject = $businessTable->fetchRow($businessTable->select()->where('name = ?', $business_id)->orWhere('contentbusiness_id = ?', $business_id));
            $businessObject->setFromArray($values)->save();
            $form->addNotice($this->view->translate('Your changes have been saved.'));
        }

        $this->getResponse()->setBody($form->render($this->view));
        $this->_helper->layout->disableLayout(true);
        $this->_helper->viewRenderer->setNoRender(true);
        return;
    }

    public function deleteAction() {

        $business_id = $this->_getParam('business');
        if (!$this->getRequest()->isPost()) {
            $this->view->status = false;
            $this->view->error = Zend_Registry::get('Zend_Translate')->_('Invalid method');
            return;
        }

        $business = Engine_Api::_()->getDbtable('contentbusinesses', 'sitebusiness')->find($business_id)->current();
        if (null === $business) {
            $this->view->status = false;
            $this->view->error = Zend_Registry::get('Zend_Translate')->_('Business not found');
            return;
        }

        if (!$business->custom) {
            $this->view->status = false;
            $this->view->error = Zend_Registry::get('Zend_Translate')->_('Cannot delete non-custom businesses');
            return;
        }

        $businessTable->deleteBusiness($business);
        $this->view->status = true;
    }

    public function widgetAction() {

        $business_id = $this->_getParam('business_id');
        $mod = $this->_getParam('mod');
        //RENDER BY WIDGET NAME
        $name = $this->_getParam('name');
        if (null === $name) {
            $message5 = Zend_Registry::get('Zend_Translate')->_('no widget found with name:');
            throw new Exception($message5 . $name);
        }
        if (null !== $mod) {
            $name = $mod . '.' . $name;
        }

        $contentInfoRaw = $this->getContentAreas();
        $contentInfo = array();
        foreach ($contentInfoRaw as $info) {
            $contentInfo[$info['name']] = $info;
        }

        //IT HAS A FORM SPECIFIED IN CONTENT MANIFEST
        if (!empty($contentInfo[$name]['adminForm'])) {
            if (is_string($contentInfo[$name]['adminForm'])) {
                $formClass = $contentInfo[$name]['adminForm'];
                Engine_Loader::loadClass($formClass);
                $this->view->form = $form = new $formClass();
            } else if (is_array($contentInfo[$name]['adminForm'])) {
                $this->view->form = $form = new Engine_Form($contentInfo[$name]['adminForm']);
            } else {
                throw new Core_Model_Exception('Unable to load admin form class');
            }

            //TRY TO SET TITLE IF MISSING
            if (!$form->getTitle()) {
                $form->setTitle('Editing: ' . $contentInfo[$name]['title']);
            }

            //TRY TO SET DESCRIPTION IF MISSING
            if (!$form->getDescription()) {
                $form->setDescription('placeholder');
            }

            $form->setAttrib('class', 'global_form_popup ' . $form->getAttrib('class'));

            //ADD TITLE ELEMENT
            if (!$form->getElement('title')) {
                $form->addElement('Text', 'title', array(
                    'label' => 'Title',
                    'order' => -100,
                ));
            }
            //ADD SUBMIT BUTTON
            if (!$form->getElement('submit') && !$form->getElement('execute')) {
                $form->addElement('Button', 'execute', array(
                    'label' => 'Save Changes',
                    'type' => 'submit',
                    'ignore' => true,
                    'decorators' => array(
                        'ViewHelper',
                    ),
                ));
            }

            //ADD NAME
            $form->addElement('Hidden', 'name', array(
                'value' => $name
            ));

            if (!$form->getElement('cancel')) {
                $form->addElement('Cancel', 'cancel', array(
                    'label' => 'cancel',
                    'link' => true,
                    'prependText' => ' or ',
                    'onclick' => 'parent.Smoothbox.close();',
                    'ignore' => true,
                    'decorators' => array(
                        'ViewHelper',
                    ),
                ));
            }

            if (!$form->getDisplayGroup('buttons')) {
                $submitName = ( $form->getElement('execute') ? 'execute' : 'submit' );
                $form->addDisplayGroup(array(
                    $submitName,
                    'cancel',
                        ), 'buttons', array(
                ));
            }

            //FORCE METHOD AND ACTION
            $form->setMethod('post')
                    ->setAction($_SERVER['REQUEST_URI']);

            if ($this->getRequest()->isPost() && $form->isValid($this->getRequest()->getPost())) {
                $this->view->values = $form->getValues();
                $this->view->form = null;
                $session = new Zend_Session_Namespace();
                if (isset($session->setSomething))
                    unset($session->setSomething);

                $session = new Zend_Session_Namespace();
                $session->setSomething[] = $name;
            }

            return;
        }

        //TRY TO RENDER ADMIN BUSINESS
        if (!empty($contentInfo[$name])) {
            try {
                $structure = array(
                    'type' => 'widget',
                    'name' => $name,
                    'request' => $this->getRequest(),
                    'action' => 'admin',
                    'throwExceptions' => true,
                );

                //CREATE ELEMENT (WITH STRUCTURE)
                $element = new Engine_Content_Element_Container(array(
                    'elements' => array($structure),
                    'decorators' => array(
                        'Children'
                    )
                ));

                $content = $element->render();
                $this->getResponse()->setBody($content);
                $this->_helper->viewRenderer->setNoRender(true);
                return;
            } catch (Exception $e) {

            }
        }

        //JUST RENDER DEFAULT EDITING FORM
        $this->view->form = $form = new Engine_Form(array(
            'title' => $contentInfo[$name]['title'],
            'description' => 'placeholder',
            'method' => 'post',
            'action' => $_SERVER['REQUEST_URI'],
            'class' => 'global_form_popup',
            'elements' => array(
                array(
                    'Text',
                    'title',
                    array(
                        'label' => 'Title',
                    )
                ),
                array(
                    'Button',
                    'submit',
                    array(
                        'label' => 'Save',
                        'type' => 'submit',
                        'decorators' => array('ViewHelper'),
                        'ignore' => true,
                        'order' => 1501,
                    )
                ),
                array(
                    'Hidden',
                    'name',
                    array(
                        'value' => $name,
                    )
                ),
                array(
                    'Cancel',
                    'cancel',
                    array(
                        'label' => 'cancel',
                        'link' => true,
                        'prependText' => ' or ',
                        'onclick' => 'parent.Smoothbox.close();',
                        'ignore' => true,
                        'decorators' => array('ViewHelper'),
                        'order' => 1502,
                    )
                )
            ),
            'displaygroups' => array(
                'buttons' => array(
                    'name' => 'buttons',
                    'elements' => array(
                        'submit',
                        'cancel',
                    ),
                    'options' => array(
                        'order' => 1500,
                    )
                )
            )
        ));

        if (!empty($contentInfo[$name]['isPaginated'])) {
            $form->addElement('Text', 'itemCountPerBusiness', array(
                'label' => 'Count',
                'description' => 'Number of items to show.',
                'validators' => array(
                    array('Int', true),
                    array('GreaterThan', true, array(0)),
                ),
                'order' => 1000000 - 1,
            ));
        }

        if ($this->getRequest()->isPost() && $form->isValid($this->getRequest()->getPost())) {
            $this->view->values = $form->getValues();
            $this->view->form = null;
            $session = new Zend_Session_Namespace();
            if (isset($session->setSomething))
                unset($session->setSomething);
            $session->setSomething[] = $name;
        } else {
            $form->populate($this->_getAllParams());
        }
    }

    public function getContentAreas() {

        $contentAreas = array();
        $levelModules = array("offer" => "sitebusinessoffer", "form" => "sitebusinessform", "invite" => "sitebusinessinvite", "sdcreate" => "sitebusinessdocument", "sncreate" => "sitebusinessnote", "splcreate" => "sitebusinesspoll", "secreate" => "sitebusinessevent", "svcreate" => "sitebusinessvideo", "spcreate" => "sitebusinessalbum", "sdicreate" => "sitebusinessdiscussion", "smcreate" => "sitebusinessmusic", "smecreate" => "sitebusinessmusic", "twitter" => "sitebusinesstwitter");
        //$sitebusinessintegrationEnabled = Engine_Api::_()->getDbtable('modules', 'core')->isModuleEnabled('sitebusinessintegration');
        //FROM MODULES
        $modules = Zend_Controller_Front::getInstance()->getControllerDirectory();
        $flag = 0;
        $integrated_module = '';
        foreach ($modules as $module => $path) {
            if ($module == 'sitebusiness' || $module == 'core' || $module == 'sitebusinessnote' || $module == 'activity' || $module == 'sitebusinessdocument' || $module == 'sitebusinessevent' || $module == 'sitebusinessreview' || $module == 'sitebusinesspoll' || $module == 'sitebusinessvideo' || $module == 'sitebusinessform' || $module == 'sitebusinessdiscussion' || $module == 'sitebusinessalbum' || $module == 'sitebusinessoffer' || $module == 'sitebusinessbadge' || $module == 'facebookse' || $module == 'sitelike' || $module == 'suggestion' || $module == 'sitebusinessmusic' || $flag || $module == 'sitebusinesstwitter' || $module == 'sitebusinessmember' || $module == 'sitecontentcoverphoto' || $module == 'siteusercoverphoto' || $module == 'siteevent' || $module == 'sitevideo'  || $module == 'sitecrowdfunding'|| $module == 'sitemusic') {
                if ($module == 'activity' || $module == 'core' || $module == 'facebookse' || $module == 'sitelike' || $module == 'suggestion' || $module == 'sitecontentcoverphoto' || $module == 'siteusercoverphoto') {
                    $contentManifestFile = dirname($path) . '/settings/content.php';
                } else {
                    $addFile = true;
                    $subject = Engine_Api::_()->core()->getSubject('sitebusiness_business');

                    if ($flag == 0) {
                        if ($module != 'sitebusiness' && $module != 'sitebusinessreview' && $module != 'sitebusinessbadge' && $module != 'sitebusinesstwitter') {

                            if ($module == 'siteevent') {
                                $module = 'sitebusinessevent';
                            } else if ($module == 'sitevideo') {
                                $module = 'sitebusinessvideo';
                            } else if ($module == 'document') {
                                $module = 'sitebusinessdocument';
                            }

                            //PACKAGE BASE PRIYACY START
                            if (Engine_Api::_()->sitebusiness()->hasPackageEnable()) {
                                if (!Engine_Api::_()->sitebusiness()->allowPackageContent($subject->package_id, "modules", $module)) {
                                    $addFile = false;
                                }
                            } else {
                                //non sub modules
                                $search_Key = array_search($module, $levelModules);
                                if (!empty($search_Key))
                                    $isBusinessOwnerAllow = Engine_Api::_()->sitebusiness()->isBusinessOwnerAllow($subject, $search_Key);
                                if (empty($isBusinessOwnerAllow)) {
                                    $addFile = false;
                                }
                            }
                            //PACKAGE BASE PRIYACY END
                        }
                    } elseif ($module == 'sitebusinesstwitter') {
                        $isManageAdmin = Engine_Api::_()->sitebusiness()->isManageAdmin($subject, 'twitter');
                        if (empty($isManageAdmin)) {
                            $addFile = false;
                        }
                    }

                    $contentManifestFile = '';
                    if ($addFile)
                        $contentManifestFile = dirname($path) . '/settings/content_user.php';
                }
                if (!file_exists($contentManifestFile))
                    continue;
                $ret = include $contentManifestFile;
                $contentAreas = array_merge($contentAreas, (array) $ret);
            }
        }
        $businesslayout = Engine_Api::_()->getApi('settings', 'core')->getSetting('sitebusiness.layout.setting', 1);
        //$layoutBlockTable = Engine_Api::_()->getDbtable('layoutblocks', 'sitebusiness');
        foreach ($contentAreas as $key => $item) {
            if ($businesslayout) {
                if ($item['name'] == 'core.content' || $item['name'] == 'core.theme-choose' || $item['name'] == 'core.menu-footer' || $item['name'] == 'core.menu-generic' || $item['name'] == 'core.menu-main' || $item['name'] == 'core.menu-mini' || $item['name'] == 'core.menu-logo' || $item['name'] == 'core.statistics' || $item['name'] == 'activity.list-requests' || $item['name'] == 'sitebusinessevent.profile-photo' || $item['name'] == 'sitebusinessevent.profile-options' || $item['name'] == 'sitebusinessevent.profile-info' || $item['name'] == 'sitebusinessevent.profile-rsvp' || $item['name'] == 'sitebusinessevent.profile-members' || $item['name'] == 'sitebusinessevent.profile-status' || $item['name'] == 'Facebookse.facebookse-recommendation' || $item['name'] == 'Facebookse.facebookse-activity' || $item['name'] == 'Facebookse.facebookse-facepile' || $item['name'] == 'Facebookse.facebookse-likebox' || $item['name'] == 'Facebookse.facebookse-websitelike' || $item['name'] == 'Facebookse.facebookse-groupprofilelike' ||
                        $item['name'] == '
Facebookse.facebookse-eventprofilelike' || $item['name'] == 'Facebookse.facebookse-userprofilelike' || $item['name'] == 'Facebookse.facebookse-listprofilelike' || $item['name'] == 'Facebookse.facebookse-sitebusinesseventprofilelike' || $item['name'] == 'Suggestion.suggestion-classified' || $item['name'] == 'Suggestion.explore-friend' || $item['name'] == 'Suggestion.suggestion-album' || $item['name'] == 'Suggestion.suggestion-blog' || $item['name'] == 'Suggestion.suggestion-document' || $item['name'] == 'Suggestion.suggestion-event' || $item['name'] == 'Suggestion.suggestion-forum' || $item['name'] == 'Suggestion.suggestion-friend' || $item['name'] == 'Suggestion.suggestion-mix' || $item['name'] == 'Suggestion.suggestion-list' || $item['name'] == 'Suggestion.suggestion-music' || $item['name'] == 'Suggestion.suggestion-poll' || $item['name'] == 'Suggestion.suggestion-video' || $item['name'] == 'Suggestion.suggestion-group' || $item['name'] == 'sitelike.event-friend-like' || $item['name'] == 'sitelike.event-like' || $item['name'] == 'sitelike.event-like-button' || $item['name'] == 'sitelike.group-friend-like' || $item['name'] == 'sitelike.group-like' || $item['name'] == 'sitelike.group-like-button' || $item['name'] == '
sitelike.list-browse-mixlikes' || $item['name'] == 'sitelike.list-friend-like' || $item['name'] == 'sitelike.list-like' || $item['name'] == 'sitelike.list-like-album' || $item['name'] == 'sitelike.list-like-albumphoto' || $item['name'] == 'sitelike.list-like-blogs' || $item['name'] == 'sitelike.list-like-eventphotos' || $item['name'] == 'sitelike.list-like-events' || $item['name'] == 'sitelike.list-like-forum' || $item['name'] == 'sitelike.list-like-groupphotos' || $item['name'] == 'sitelike.list-like-groups' || $item['name'] == 'sitelike.list-like-listings' || $item['name'] == 'sitelike.list-like-members' || $item['name'] == 'sitelike.list-like-musics' || $item['name'] == 'sitelike.list-like-businesses' || $item['name'] == 'sitelike.list-like-button' || $item['name'] == 'sitelike.list-like-classifieds' || $item['name'] == 'sitelike.list-like-document' || $item['name'] == 'sitelike.list-like-videos' || $item['name'] == 'sitelike.member-friend-like' || $item['name'] == 'sitelike.member-like' || $item['name'] == '
sitelike.mix-like' || $item['name'] == 'sitelike.navigation-like' || $item['name'] == 'sitelike.business-like' || $item['name'] == 'sitelike.profile-like-button' || $item['name'] == 'sitelike.profile-user-likes' || $item['name'] == 'sitelike.list-like-businessalbumphotos' || $item['name'] == 'sitelike.list-like-businessalbums' || $item['name'] == 'sitelike.list-like-businessdocuments' || $item['name'] == 'sitelike.list-like-businessevent' || $item['name'] == 'sitelike.list-like-businessnotes' || $item['name'] == 'sitelike.list-like-businesspolls' || $item['name'] == 'sitelike.list-like-businessreviews' || $item['name'] == 'sitelike.list-like-businessvideos' || $item['name'] == 'sitelike.list-like-recipe' || $item['name'] == 'sitelike.businessevent-friend-like' || $item['name'] == 'sitelike.businessevent-like' || $item['name'] == 'sitelike.businessevent-like-button' || $item['name'] == 'sitelike.recipe-friend-like' || $item['name'] == 'sitelike.recipe-like' || $item['name'] == 'sitelike.recipe-like-button' ||
                        $item['name'] == 'sitelike.sitebusinessevent-like-
button' || $item['name'] == 'sitelike.list-like-polls' || $item['name'] == 'Facebookse.facebookse-comments' || $item['name'] == 'Facebookse.facebookse-commonlike'
                ) {
                    unset($contentAreas[$key]);
                }
            } else {
                if ($item['name'] == 'Suggestion.common-suggestion' || $item['name'] == 'core.content' || $item['name'] == 'core.theme-choose' || $item['name'] == 'core.menu-footer' || $item['name'] == 'core.menu-generic' || $item['name'] == 'core.menu-main' || $item['name'] == 'core.menu-mini' || $item['name'] == 'core.menu-logo' || $item['name'] == 'core.statistics' || $item['name'] == 'activity.list-requests' || $item['name'] == 'sitebusinessevent.profile-photo' || $item['name'] == 'sitebusinessevent.profile-options' || $item['name'] == 'sitebusinessevent.profile-info' || $item['name'] == 'sitebusinessevent.profile-rsvp' || $item['name'] == 'sitebusinessevent.profile-members' || $item['name'] == 'sitebusinessevent.profile-status' || $item['name'] == 'core.container-tabs' || $item['name'] == 'Facebookse.facebookse-recommendation' || $item['name'] == 'Facebookse.facebookse-activity' || $item['name'] == 'Facebookse.facebookse-facepile' || $item['name'] == 'Facebookse.facebookse-likebox' || $item['name'] == '
Facebookse.facebookse-
websitelike' || $item['name'] == 'Facebookse.facebookse-groupprofilelike' || $item['name'] == 'Facebookse.facebookse-eventprofilelike' || $item['name'] == 'Facebookse.facebookse-userprofilelike' || $item['name'] == 'Facebookse.facebookse-listprofilelike' || $item['name'] == 'Facebookse.facebookse-sitebusinesseventprofilelike' || $item['name'] == 'Suggestion.suggestion-classified' || $item['name'] == 'Suggestion.explore-friend' || $item['name'] == 'Suggestion.suggestion-album' || $item['name'] == 'Suggestion.suggestion-blog' || $item['name'] == 'Suggestion.suggestion-document' || $item['name'] == 'Suggestion.suggestion-event' || $item['name'] == 'Suggestion.suggestion-forum' || $item['name'] == 'Suggestion.suggestion-friend' || $item['name'] == 'Suggestion.suggestion-mix' || $item['name'] == 'Suggestion.suggestion-list' || $item['name'] == 'Suggestion.suggestion-music' || $item['name'] == 'Suggestion.suggestion-poll' || $item['name'] == 'Suggestion.suggestion-video' || $item['name'] == 'Suggestion.suggestion-
group' || $item['name'] == 'sitelike.event-friend-like' || $item['name'] == 'sitelike.event-like' || $item['name'] == 'sitelike.event-like-button' || $item['name'] == 'sitelike.group-friend-like' || $item['name'] == 'sitelike.group-like' || $item['name'] == 'sitelike.group-like-button' || $item['name'] == 'sitelike.list-browse-mixlikes' || $item['name'] == 'sitelike.list-friend-like' || $item['name'] == 'sitelike.list-like' || $item['name'] == 'sitelike.list-like-album' || $item['name'] == 'sitelike.list-like-albumphoto' || $item['name'] == 'sitelike.list-like-blogs' || $item['name'] == 'sitelike.list-like-eventphotos' || $item['name'] == 'sitelike.list-like-events' || $item['name'] == 'sitelike.list-like-forum' || $item['name'] == 'sitelike.list-like-groupphotos' || $item['name'] == 'sitelike.list-like-groups' || $item['name'] == 'sitelike.list-like-listings' || $item['name'] == 'sitelike.list-like-members' || $item['name'] == 'sitelike.list-like-musics' || $item['name'] == 'sitelike.list-like-businesses' ||
                        $item['name'] == 'sitelike.list-like-button' || $item['name'] == 'sitelike.list-like-classifieds' || $item['name'] == 'sitelike.list-like-document' || $item['name'] == 'sitelike.list-like-videos' || $item['name'] == 'sitelike.member-friend-like' || $item['name'] == 'sitelike.member-like' || $item['name'] == 'sitelike.mix-like' || $item['name'] == 'sitelike.navigation-like' || $item['name'] == 'sitelike.business-like' || $item['name'] == 'sitelike.profile-like-button' || $item['name'] == 'sitelike.profile-user-likes' || $item['name'] == 'sitelike.list-like-businessalbumphotos' || $item['name'] == 'sitelike.list-like-businessalbums' || $item['name'] == 'sitelike.list-like-businessdocuments' || $item['name'] == 'sitelike.list-like-businessevent' || $item['name'] == 'sitelike.list-like-businessnotes' || $item['name'] == 'sitelike.list-like-businesspolls' || $item['name'] == 'sitelike.list-like-businessreviews' || $item['name'] == 'sitelike.list-like-businessvideos' || $item['name'] == 'sitelike.list-like-recipe' || $item['name'] == 'sitelike.
businessevent-friend-like' || $item['name'] == 'sitelike.businessevent-like' || $item['name'] == 'sitelike.businessevent-like-button' || $item['name'] == 'sitelike.recipe-friend-like' || $item['name'] == 'sitelike.recipe-like' || $item['name'] == 'sitelike.recipe-like-button' || $item['name'] == 'sitelike.sitebusinessevent-like-button' || $item['name'] == 'sitelike.list-like-polls'
                ) {
                    unset($contentAreas[$key]);
                }
            }
        }

        // From widgets
        $it = new DirectoryIterator(APPLICATION_PATH . '/application/widgets');
        foreach ($it as $dir) {
            if (!$dir->isDir() || $dir->isDot())
                continue;
            $path = $dir->getPathname();
            $contentManifestFile = $path . '/' . 'manifest.php';
            if (!file_exists($contentManifestFile))
                continue;
            $ret = include $contentManifestFile;
            if (!is_array($ret))
                continue;
            foreach ($ret as $key => $value) {
                if ((isset($value['name']) && $value['name'] == 'rss')) {
                    array_push($contentAreas, $ret);
                }
            }
        }

        return $contentAreas;
    }

    public function buildCategorizedContentAreas($contentAreas) {

        $categorized = array();
        foreach ($contentAreas as $config) {
            //CHECK SOME STUFF
            if (!empty($config['requireItemType'])) {
                if (is_string($config['requireItemType']) && !Engine_Api::_()->hasItemType($config['requireItemType'])) {
                    $config['disabled'] = true;
                } else if (is_array($config['requireItemType'])) {
                    $tmp = array_map(array(Engine_Api::_(), 'hasItemType'), $config['requireItemType']);
                    $config['disabled'] = !(array_sum($tmp) == count($config['requireItemType']));
                }
            }

            //ADD TO CATEGORY
            $category = ( isset($config['category']) ? $config['category'] : 'Uncategorized' );
            $categorized[$category][] = $config;
        }

        //SORT CATEGORIES
        uksort($categorized, array($this, '_sortCategories'));

        //SORT ITEMS IN CATEGORIES
        foreach ($categorized as $category => &$items) {
            usort($items, array($this, '_sortCategoryItems'));
        }

        return $categorized;
    }

    protected function _sortCategories($a, $b) {

        if ($a == 'Core')
            return -1;
        if ($b == 'Core')
            return 1;
        return strcmp($a, $b);
    }

    protected function _sortCategoryItems($a, $b) {

        if (!empty($a['special']))
            return -1;
        if (!empty($b['special']))
            return 1;
        return strcmp($a['title'], $b['title']);
    }

    protected function _reorderContentStructure($a, $b) {

        $sample = array('left', 'middle', 'right');
        $av = $a['name'];
        $bv = $b['name'];
        $ai = array_search($av, $sample);
        $bi = array_search($bv, $sample);
        if ($ai === false && $bi === false)
            return 0;
        if ($ai === false)
            return -1;
        if ($bi === false)
            return 1;
        $r = ( $ai == $bi ? 0 : ($ai < $bi ? -1 : 1) );
        return $r;
    }

    public function setUserDrivenLayoutAction() {
        $this->view->business_id = $this->_getParam('business_id', null);
        $this->_helper->layout->setLayout('default-simple');
    }

    public function saveUserDrivenLayoutAction() {
        $business_id = $this->_getParam('business_id', null);
        $viewer_id = Engine_Api::_()->user()->getViewer()->getIdentity();
        //EXTRACTING CURRENT ADMIN SETTINGS FOR THIS VIEW BUSINESS.
        $businessAdminTable = Engine_Api::_()->getDbtable('pages', 'core');
        $businessAdminTableName = $businessAdminTable->info('name');
        $selectBusinessAdmin = $businessAdminTable->select()
                ->setIntegrityCheck(false)
                ->from($businessAdminTableName)
                ->where('name = ?', 'sitebusiness_index_view');
        $businessAdminresult = $businessAdminTable->fetchRow($selectBusinessAdmin);
        $sitebusiness = Engine_Api::_()->getItem('sitebusiness_business', $business_id);
        //NOW INSERTING THE ROW IN BUSINESS TABLE
        $businessTable = Engine_Api::_()->getDbtable('contentbusinesses', 'sitebusiness');

        //CREATE NEW BUSINESS
        $businessObject = $businessTable->createRow();
        $businessObject->displayname = $sitebusiness->title;
        $businessObject->title = $sitebusiness->title;
        $businessObject->description = $sitebusiness->body;
        $businessObject->name = "sitebusiness_index_view";
        $businessObject->url = $businessAdminresult->url;
        $businessObject->custom = $businessAdminresult->custom;
        $businessObject->fragment = $businessAdminresult->fragment;
        $businessObject->keywords = $businessAdminresult->keywords;
        $businessObject->layout = $businessAdminresult->layout;
        $businessObject->view_count = $businessAdminresult->view_count;
        $businessObject->user_id = $viewer_id;
        $businessObject->business_id = $business_id;
        $contentBusinessId = $businessObject->save();

        //NOW FETCHING BUSINESS CONTENT DEFAULT SETTING INFORMATION FROM CORE CONTENT TABLE FOR THIS BUSINESS.
        //NOW INSERTING DEFAULT BUSINESS CONTENT SETTINGS IN OUR CONTENT TABLE
        $layout = Engine_Api::_()->getApi('settings', 'core')->getSetting('sitebusiness.layoutcreate', 0);
        $sitebusiness_layout_cover_photo = Engine_Api::_()->getApi('settings', 'core')->getSetting('sitebusiness.layout.cover.photo', 1);
        if (!$layout) {
            Engine_Api::_()->getDbtable('content', 'sitebusiness')->setContentDefault($contentBusinessId, $sitebusiness_layout_cover_photo);
        } else {
            Engine_Api::_()->getApi('layoutcore', 'sitebusiness')->setContentDefaultLayout($contentBusinessId, $sitebusiness_layout_cover_photo);
        }

        $this->_forward('success', 'utility', 'core', array(
            'smoothboxClose' => true,
            'parentRefreshTime' => '60',
            'parentRefresh' => 'true',
            'format' => 'smoothbox',
            'messages' => array(Zend_Registry::get('Zend_Translate')->_('Layout for this business has been changed successfully.'))
        ));
    }

}

?>