<?php

/**
 * SocialEngine
 *
 * @category   Application_Extensions
 * @package    Sitebusinessnote
 * @copyright  Copyright 2010-2011 BigStep Technologies Pvt. Ltd.
 * @license    http://www.socialengineaddons.com/license/
 * @version    $Id: Menus.php 2011-05-05 9:40:21Z SocialEngineAddOns $
 * @author     SocialEngineAddOns
 */
class Sitebusinessnote_Plugin_Menus {

  public function canViewNotes() {

    if (!Engine_Api::_()->getApi('settings', 'core')->getSetting('sitebusinessnote.note.show.menu', 1)) {
      return false;
    }

    $table = Engine_Api::_()->getDbTable('notes', 'sitebusinessnote');
    $rName = $table->info('name');
    $table_businesses = Engine_Api::_()->getDbtable('business', 'sitebusiness');
    $rName_businesses = $table_businesses->info('name');
    $select = $table->select()
                    ->setIntegrityCheck(false)
                    ->from($rName_businesses, array('photo_id', 'title as sitebusiness_title'))
                    ->join($rName, $rName . '.business_id = ' . $rName_businesses . '.business_id');

    $select = $select
                    ->where($rName_businesses . '.closed = ?', '0')
                    ->where($rName_businesses . '.approved = ?', '1')
                    ->where($rName_businesses . '.search = ?', '1')
                    ->where($rName_businesses . '.declined = ?', '0')
                    ->where($rName_businesses . '.draft = ?', '1');
    if (Engine_Api::_()->sitebusiness()->hasPackageEnable()) {
      $select->where($rName_businesses . '.expiration_date  > ?', date("Y-m-d H:i:s"));
    }
    $row = $table->fetchAll($select);
    $count = count($row);
    if (empty($count)) {
      return false;
    }
    return true;
  }


  //SITEMOBILE BUSINESS NOTE MENUS
  public function onMenuInitialize_SitebusinessnoteWrite($row) {

    $subject = Engine_Api::_()->core()->getSubject();

    $sitebusinessnote = $this->getSitebusinessNoteObject();

    if (empty($sitebusinessnote)) {
      return false;
    }
    //BUSINESS ID
    $business_id = $sitebusinessnote->business_id;

    $sitebusiness = Engine_Api::_()->getItem('sitebusiness_business', $business_id);
    //START MANAGE-ADMIN CHECK
    $isManageAdmin = Engine_Api::_()->sitebusiness()->isManageAdmin($sitebusiness, 'sncreate');
    if (empty($isManageAdmin)) {
      $can_create = 0;
    } else {
      $can_create = 1;
    }

    //CHECKS FOR WRITE
    if (empty($can_create)) {
      return false;
    }

    return array(
        'label' => 'Write a Note',
        'route' => 'sitebusinessnote_create',
        'class' => 'ui-btn-action',
        'params' => array(
            'business_id' => $business_id,
            'tab' => Zend_Controller_Front::getInstance()->getRequest()->getParam('tab')
        )
    );
  }

  public function onMenuInitialize_SitebusinessnotePublish($row) {
    $subject = Engine_Api::_()->core()->getSubject();

    $check = $this->commonChecks();

    if (empty($check)) {
      return false;
    }
    $sitebusinessnote = $this->getSitebusinessNoteObject();

    if (empty($sitebusinessnote)) {
      return false;
    }
    if ($sitebusinessnote->draft != 1) {
      return false;
    }
    return array(
        'label' => 'Publish Note',
        'route' => 'sitebusinessnote_publish',
        'class' => 'ui-btn-action smoothbox',
        'params' => array(
            'note_id' => $subject->getIdentity(),
            'tab' => Zend_Controller_Front::getInstance()->getRequest()->getParam('tab')
        )
    );
  }

  public function onMenuInitialize_SitebusinessnoteEdit($row) {
    $subject = Engine_Api::_()->core()->getSubject();
    $sitebusinessnote = $this->getSitebusinessNoteObject();

    if (empty($sitebusinessnote)) {
      return false;
    }
    //BUSINESS ID
    $business_id = $sitebusinessnote->business_id;

    $check = $this->commonChecks();

    if (empty($check)) {
      return false;
    }

    return array(
        'label' => 'Edit Note',
        'route' => 'sitebusinessnote_edit',
        'class' => 'ui-btn-action',
        'params' => array(
            'note_id' => $subject->getIdentity(),
            'business_id' => $business_id,
            'tab' => Zend_Controller_Front::getInstance()->getRequest()->getParam('tab')
        )
    );
  }

  public function onMenuInitialize_SitebusinessnoteDelete($row) {
    $subject = Engine_Api::_()->core()->getSubject();
    $sitebusinessnote = $this->getSitebusinessNoteObject();

    if (empty($sitebusinessnote)) {
      return false;
    }
    //BUSINESS ID
    $business_id = $sitebusinessnote->business_id;

    $check = $this->commonChecks();

    if (empty($check)) {
      return false;
    }

    return array(
        'label' => 'Delete Note',
        'route' => 'sitebusinessnote_delete',
        'class' => 'ui-btn-danger',
        'params' => array(
            'note_id' => $subject->getIdentity(),
            'business_id' => $business_id,
            'tab' => Zend_Controller_Front::getInstance()->getRequest()->getParam('tab')
        )
    );
  }

  public function onMenuInitialize_SitebusinessnoteAdd($row) {
    $viewer = Engine_Api::_()->user()->getViewer();
    $subject = Engine_Api::_()->core()->getSubject();

    $sitebusinessnote = $this->getSitebusinessNoteObject();

    if (empty($sitebusinessnote)) {
      return false;
    }
    //BUSINESS ID
    $business_id = $sitebusinessnote->business_id;

    $owner_id = $sitebusinessnote->owner_id;

    $viewer_id = $viewer->getIdentity();

    $allow_image = Engine_Api::_()->getApi('settings', 'core')->sitebusinessnote_allow_image;

    //CHECKS FOR ADD PHOTOS
    if ($owner_id != $viewer_id || empty($allow_image)) {
      return false;
    }

    if (Engine_API::_()->seaocore()->checkSitemobileMode('fullsite-mode')) {
			return array(
					'label' => 'Add Photos',
					'route' => 'sitebusinessnote_photoupload',
					'class' => 'ui-btn-action',
					'params' => array(
							'note_id' => $subject->getIdentity(),
							'business_id' => $business_id,
              'tab' => Zend_Controller_Front::getInstance()->getRequest()->getParam('tab')
					)
			);
    } else {
			return array(
					'label' => 'Add Photos',
					'route' => 'sitebusinessnote_sitemobilephotoupload',
					'class' => 'ui-btn-action',
					'params' => array(
							'note_id' => $subject->getIdentity(),
							'business_id' => $business_id,
              'tab' => Zend_Controller_Front::getInstance()->getRequest()->getParam('tab')
					)
			);
    }
  }

  //PHOTO VIEW BUSINESS OPTIONS
  public function onMenuInitialize_SitebusinessnotePhotoEdit($row) {

     //GET VIEWER ID
    $viewer_id = Engine_Api::_()->user()->getViewer()->getIdentity();

    $subject = Engine_Api::_()->core()->getSubject();
    //GET ALBUM ID
    $note_id = $subject->note_id;
    
    $sitebusinessnote = Engine_Api::_()->getItem('sitebusinessnote_note', $note_id);
    
    //GET BUSINESS ID
    $business_id = $sitebusinessnote->business_id;

    $sitebusiness = Engine_Api::_()->getItem('sitebusiness_business', $business_id);
    
    //START MANAGE-ADMIN CHECK
    $isManageAdmin = Engine_Api::_()->sitebusiness()->isManageAdmin($sitebusiness, 'edit');
    if (empty($isManageAdmin)) {
      $can_edit = 0;
    } else {
      $can_edit = 1;
    }
    
    //PHOTO OWNER, BUSINESS OWNER AND SUPER-ADMIN CAN EDIT PHOTO
    if ($viewer_id != $sitebusinessnote->owner_id && $can_edit != 1) {
      return false;
    }


    return array(
        'label' => 'Edit',
        'route' => 'sitebusinessnote_photoedit',
        'class' => 'ui-btn-action smoothbox',
        'params' => array(
           'action' => 'photoedit',
            'photo_id' => $subject->photo_id,
            'note_id' => $note_id,
            'business_id' => $business_id,
             'tab' => Zend_Controller_Front::getInstance()->getRequest()->getParam('tab')
        )
    );
  }

  public function onMenuInitialize_SitebusinessnotePhotoDelete($row) {


     //GET VIEWER ID
    $viewer_id = Engine_Api::_()->user()->getViewer()->getIdentity();

    $subject = Engine_Api::_()->core()->getSubject();
    //GET ALBUM ID
    $note_id = $subject->note_id;
    
    $sitebusinessnote = Engine_Api::_()->getItem('sitebusinessnote_note', $note_id);
    
    //GET BUSINESS ID
    $business_id = $sitebusinessnote->business_id;

    $sitebusiness = Engine_Api::_()->getItem('sitebusiness_business', $business_id);
    
    //START MANAGE-ADMIN CHECK
    $isManageAdmin = Engine_Api::_()->sitebusiness()->isManageAdmin($sitebusiness, 'edit');
    if (empty($isManageAdmin)) {
      $can_edit = 0;
    } else {
      $can_edit = 1;
    }
    
    //PHOTO OWNER, BUSINESS OWNER AND SUPER-ADMIN CAN EDIT PHOTO
    if ($viewer_id != $sitebusinessnote->owner_id && $can_edit != 1) {
      return false;
    }

    return array(
        'label' => 'Delete',
        'route' => 'sitebusinessnote_removeimage',
        'class' => 'ui-btn-danger',
        'params' => array(
            'action' => 'remove',
            'photo_id' => $subject->photo_id,
            'note_id' => $note_id,
            'business_id' => $business_id,
            'owner_id' => $subject->user_id,
            'tab' => Zend_Controller_Front::getInstance()->getRequest()->getParam('tab')
        )
    );
  }

  public function onMenuInitialize_SitebusinessnotePhotoShare($row) {
    $subject = Engine_Api::_()->core()->getSubject();
    //GET VIEWER ID
    $viewer_id = Engine_Api::_()->user()->getViewer()->getIdentity();
    
    if(!$viewer_id){
      return false;
    }
    if (!SEA_PHOTOLIGHTBOX_SHARE) {
      return false;
    }
    return array(
        'label' => 'Share',
        'class' => 'ui-btn-action smoothbox',
        'route' => 'default',
        'params' => array(
            'module' => 'activity',
            'action' => 'share',
            'type' => $subject->getType(),
            'id' => $subject->getIdentity(),
        )
    );
  }

  public function onMenuInitialize_SitebusinessnotePhotoReport($row) {
    $subject = Engine_Api::_()->core()->getSubject();
    //GET VIEWER ID
    $viewer_id = Engine_Api::_()->user()->getViewer()->getIdentity();
    
    if(!$viewer_id){
      return false;
    }
    if (!SEA_PHOTOLIGHTBOX_REPORT) {
      return false;
    }
    return array(
        'label' => 'Report',
        'class' => 'ui-btn-action smoothbox',
        'route' => 'default',
        'params' => array(
            'module' => 'core',
            'controller' => 'report',
            'action' => 'create',
            'subject' => $subject->getGuid(),
        )
    );
  }

   //COMMON FUNCTION
  public function commonChecks() {
    $viewer = Engine_Api::_()->user()->getViewer();
    $subject = Engine_Api::_()->core()->getSubject();

    $sitebusinessnote = $this->getSitebusinessNoteObject();

    if (empty($sitebusinessnote)) {
      return false;
    }
    //BUSINESS ID
    $business_id = $sitebusinessnote->business_id;
    $owner_id = $sitebusinessnote->owner_id;

    $sitebusiness = Engine_Api::_()->getItem('sitebusiness_business', $business_id);

    $viewer_id = $viewer->getIdentity();

    //EDIT
    $isManageAdmin = Engine_Api::_()->sitebusiness()->isManageAdmin($sitebusiness, 'edit');
    if (empty($isManageAdmin)) {
      $can_edit = 0;
    } else {
      $can_edit = 1;
    }

    //CHECKS FOR DELETE
    if ($owner_id != $viewer_id && empty($can_edit)) {
      return false;
    } else {
      return true;
    }
  }

  public function getSitebusinessNoteObject() {
    $subject = Engine_Api::_()->core()->getSubject();
    //GET NOTE ID
    $note_id = $subject->getIdentity();
    //GET NOTE ITEM
    $sitebusinessnote = Engine_Api::_()->getItem('sitebusinessnote_note', $note_id);
    //ASK
    if (empty($sitebusinessnote)) {
      return false;
    }
    return $sitebusinessnote;
  }

}
?>