<?php
/**
 * SocialEngine
 *
 * @category   Application_Extensions
 * @package    Sitecontest
 * @copyright  Copyright 2019-2020 BigStep Technologies Pvt. Ltd.
 * @license    http://www.socialengineaddons.com/license/
 * @version    2019-08-10 9:40:21Z SocialEngineAddOns $
 * @author     SocialEngineAddOns
 */
class Sitecontest_Form_Admin_Global extends Engine_Form {
  
  public function init(){
    $this->setTitle('Global Settings')
        ->setDescription('These settings affect all members in your community.')
        ->setName('review_global');

    $coreSettings = Engine_Api::_()->getApi('settings', 'core');

    $this->addElement('Text', 'sitecontest_titlesingular', array(
      'label' => 'Singular Contest Title',
      'description' => 'Please enter Singular Title for contest. This text will come in places like feeds generated, widgets etc.',
      'allowEmpty' => false,
      'required' => true,
      'validators' => array(
          array('NotEmpty', true),
          array('StringLength', true, array(3, 32)),
          array('Regex', true, array('/^[a-zA-Z0-9-_\s]+$/')),
      ),
      'value' => $coreSettings->getSetting('sitecontest.titlesingular', 'Contest'),
      'filters' => array(
          'StripTags',
          new Engine_Filter_Censor(),
    )));

    $this->addElement('Text', 'sitecontest_titleplural', array(
      'label' => 'Plural Contest Title',
      'description' => 'Please enter Plural Title for contests. This text will come in places like Main Navigation Menu, Contest Main Navigation Menu, widgets etc.',
      'allowEmpty' => false,
      'required' => true,
      'validators' => array(
          array('NotEmpty', true),
          array('StringLength', true, array(3, 32)),
          array('Regex', true, array('/^[a-zA-Z0-9-_\s]+$/')),
      ),
      'value' => $coreSettings->getSetting('sitecontest.titleplural', 'Contests'),
      'filters' => array(
          'StripTags',
          new Engine_Filter_Censor(),
    )));

    $this->addElement('Text', 'sitecontest_slugsingular', array(
      'label' => 'Contests URL Alternate Text for "contest"',
      'description' => 'Please enter the text below which you want to display in place of "contest" in the URLs of this plugin.',
      'allowEmpty' => false,
      'required' => true,
      'validators' => array(
          array('NotEmpty', true),
          array('StringLength', true, array(3, 16)),
          array('Regex', true, array('/^[a-zA-Z0-9-_]+$/')),
      ),
      'value' => $coreSettings->getSetting('sitecontest.slugsingular', 'contest'),
    ));

    $this->addElement('Text', 'sitecontest_slugplural', array(
      'label' => 'Contests URL Alternate Text for "contests"',
      'description' => 'Please enter the text below which you want to display in place of "contests" in the URLs of this plugin.',
      'allowEmpty' => false,
      'required' => true,
      'validators' => array(
          array('NotEmpty', true),
          array('StringLength', true, array(3, 16)),
          array('Regex', true, array('/^[a-zA-Z0-9-_]+$/')),
      ),
      'value' => $coreSettings->getSetting('sitecontest.slugplural', 'contests'),
    ));

    $this->addElement('Radio', 'sitecontest_redirection', array(
      'label' => 'Default Redirection of Contests Link',
      'description' => 'Please select the redirection page for Contests, when user click on "Contests" link at Main Navigation Menu.',
      "multiOptions" => array(
          'index' => 'Contests Home Page',
          'browse' => 'Browse Contests Page'
      ),
      'value' => $coreSettings->getSetting('sitecontest.redirection', 'index'),
    ));

    $this->addElement('Radio', 'sitecontest_integrate_buttons', array(
      'label' => 'Allow Voting via Like or Vote',
      'description' => 'Do you want to enable voting on entries via likes or votes ? ',
      "multiOptions" => array(
          1 => 'Likes',
          0 => 'Votes'
      ),
      'value' => $coreSettings->getSetting('sitecontest.integrate.buttons', 1),
    )); 

    $this->addElement('Radio', 'sitecontest_user_vote', array(
      'label' => 'Who Can Vote On Entries',
      'description' => 'Select "Only Jury Members" if you do not want other normal users to be able to vote.',
      "multiOptions" => array(
          1 => 'All Login Users',
          0 => 'Only Jury Members'
      ),
      'value' => $coreSettings->getSetting('sitecontest.user.vote', 1),
    ));

    $this->addElement('Radio', 'sitecontest_share_popup_enabled', array(
      'label' => 'Community Sharing',
      'description' => "Do you want to allow members to share contests within your community? (This popup will be visible after contest creation.)",
      'multiOptions' => array(
          1 => 'Yes',
          0 => 'No'
      ),
      'escape' => false,
      'value' => $coreSettings->getSetting('sitecontest.share.popup.enabled', 1)
    ));

    $this->addElement('Button', 'save', array(
      'label' => 'Save Changes',
      'type' => 'submit',
      'ignore' => true
    ));
  }
}
?>