<?php
/**
 * SocialEngine
 *
 * @category   Application_Extensions
 * @package    Sitecontest
 * @copyright  Copyright 2019-2020 BigStep Technologies Pvt. Ltd.
 * @license    http://www.socialengineaddons.com/license/
 * @version    2019-08-10 9:40:21Z SocialEngineAddOns $
 * @author     SocialEngineAddOns
 */
class Sitecontest_Form_Admin_Settings_Level extends Authorization_Form_Admin_Level_Abstract
{
	public function init() {
    parent::init();

    // My stuff
    $this
      ->setTitle('Member Level Settings for Contest')
      ->setDescription(" These settings are applied on a per member level basis. Start by selecting the member level you want to modify, then adjust the settings for that level below");

    // Element: view
    $this->addElement('Radio', 'view', array(
      'label' => 'Allow Viewing of Contests?',
      'description' => 'Do you want to let members view contests? If set to no, some other settings on this page may not apply.',
      'multiOptions' => array(
        2 => 'Yes, allow viewing of all contests, even private ones.',
        1 => 'Yes, allow viewing of contests.',
        0 => 'No, do not allow contests to be viewed.',
      ),
      'value' => ( $this->isModerator() ? 2 : 1 ),
    ));
    if( !$this->isModerator() ) {
      unset($this->view->options[2]);
    }

    if( !$this->isPublic() ) {

      // Element: create
      $this->addElement('Radio', 'create', array(
        'label' => 'Allow Creation of Contests?',
        'description' => 'Do you want to let members create contests? If set to no, some other settings on this page may not apply. This is useful if you want members to be able to view contests, but only want certain levels to be able to create contests.',
        'multiOptions' => array(
          1 => 'Yes, allow creation of contests.',
          0 => 'No, do not allow contests to be created.'
        ),
        'value' => 1,
      ));

      // Element: edit
      $this->addElement('Radio', 'edit', array(
        'label' => 'Allow Editing of Contests?',
        'description' => 'Do you want to let members edit contests? If set to no, some other settings on this page may not apply.',
        'multiOptions' => array(
          2 => 'Yes, allow members to edit all contests.',
          1 => 'Yes, allow members to edit their own contests.',
          0 => 'No, do not allow members to edit their contests.',
        ),
        'value' => ( $this->isModerator() ? 2 : 1 ),
      ));
      if( !$this->isModerator() ) {
        unset($this->edit->options[2]);
      }

      // Element: delete
      $this->addElement('Radio', 'delete', array(
        'label' => 'Allow Deletion of Contests?',
        'description' => 'Do you want to let members delete contests? If set to no, some other settings on this page may not apply.',
        'multiOptions' => array(
          2 => 'Yes, allow members to delete all contests.',
          1 => 'Yes, allow members to delete their own contests.',
          0 => 'No, do not allow members to delete their contests.',
        ),
        'value' => ( $this->isModerator() ? 2 : 1 ),
      ));
      if( !$this->isModerator() ) {
        unset($this->delete->options[2]);
      }

      // Element: comment
      $this->addElement('Radio', 'comment', array(
        'label' => 'Allow Commenting on Contests?',
        'description' => 'Do you want to let members of this level comment on contests?',
        'multiOptions' => array(
          2 => 'Yes, allow members to comment on all contests, including private ones.',
          1 => 'Yes, allow members to comment on contests.',
          0 => 'No, do not allow members to comment on contests.',
        ),
        'value' => ( $this->isModerator() ? 2 : 1 ),
      ));
      if( !$this->isModerator() ) {
        unset($this->comment->options[2]);
      }

      // Element: auth_view
      $this->addElement('MultiCheckbox', 'auth_view', array(
        'label' => 'Contest View Privacy',
        'required' => true,
        'description' => 'Your members can choose from any of the options checked below when they decide who can see their contests. These options appear on your members \' "Create Contest" and "Edit Contest" pages. If you select only one option, members of this level will not have a choice.',
        'multiOptions' => array(
          'everyone'            => 'Everyone',
          'registered'          => 'All Registered Members',
          'owner_network'       => 'Friends and Networks',
          'owner_member_member' => 'Friends of Friends',
          'owner_member'        => 'Friends Only',
          'owner'               => 'Just Me'
        ),
        'value' => array('everyone', 'owner_network', 'owner_member_member', 'owner_member', 'owner'),
      ));

      // Element: auth_comment
      $this->addElement('MultiCheckbox', 'auth_comment', array(
        'label' => 'Contest Comment Options',
        'required' => true,
        'description' => 'Your members can choose from any of the options checked below when they decide who can post comments on their contest. If you select only one option, members of this level will not have a choice.',
        'multiOptions' => array(
          'everyone'            => 'Everyone',
          'registered'          => 'All Registered Members',
          'owner_network'       => 'Friends and Networks',
          'owner_member_member' => 'Friends of Friends',
          'owner_member'        => 'Friends Only',
          'owner'               => 'Just Me'
        ),
        'value' => array('everyone', 'owner_network', 'owner_member_member', 'owner_member', 'owner'),
      ));
      // Element: media_type
      $this->addElement('MultiCheckbox', 'media_type', array(
        'label' => 'Contest Media Type Options',
        'required' => true,
        'description' => 'Your members can choose any of the options checked below that which type of media contest they want to post. If you select only one option, members of this level will not have a choice.',
        'multiOptions' => array(
          'text'            => 'Text',
          'photo'          => 'Photo',
          'music'       => 'Music',
          'video' => 'Video',
        ),
        'value' => array('text', 'photo', 'music', 'video'),
      ));


      $this->addElement('Select', 'prize', array(
      'label' => 'No. of Awards in Contest',
      'multiOptions' => array("1"=>"1", "2"=>"2","3"=>"3", "4"=>"4","5"=>"5"),
      'description' => 'How many awards in a contest can be added ?'
    	));
    	// $this->prize->getDecorator('Description')->setOption('placement', 'append');

      $this->addElement('Radio', 'approve', array(
        'label' => 'Auto Approve of Contests',
        'description' => 'Do you want new contest to be automatically approved?',
        'multiOptions' => array(
          1 => 'Yes, automatically approve contests.',
          0 => 'No, site admin approval will be required for all contests.'
        ),
        'value' => 1,
      ));

      $this->addElement('Radio', 'feature', array(
        'label' => 'Automatically Mark Contest as Featured',
        'description' => 'Do you want new contest to be automatically made featured?',
        'multiOptions' => array(
          1 => 'Yes, automatically make contest featured.',
          0 => 'No, site admin will be making contest featured.'
        ),
        'value' => 1,
      ));

      $this->addElement('Radio', 'sponsored', array(
        'label' => 'Automatically Mark Contest as Sponsored',
        'description' => 'Do you want new contest to be automatically made sponsored?',
        'multiOptions' => array(
          1 => 'Yes, automatically make contest sponsored.',
          0 => 'No, site admin will be making contest sponsored.'
        ),
        'value' => 1,
      ));

      $this->addElement('Radio', 'verified', array(
        'label' => 'Automatically Mark Contest as Verified',
        'description' => 'Do you want new contest to be automatically made verified?',
        'multiOptions' => array(
          1 => 'Yes, automatically make contest verified.',
          0 => 'No, site admin will be making contest verified.'
        ),
        'value' => 1,
      ));

      $this->addElement('Radio', 'hot', array(
        'label' => 'Automatically Mark Contest as Trending',
        'description' => 'Do you want new contest to be automatically made trending?',
        'multiOptions' => array(
          1 => 'Yes, automatically make contest trending.',
          0 => 'No, site admin will be making contest trending.'
        ),
        'value' => 1,
      ));


      // Element: max
      $this->addElement('Text', 'max', array(
          'label' => 'Maximum Allowed Contests',
          'description' => 'Enter the maximum number of contests that members of this level can create. The field must contain an integer, use zero for unlimited.',
          'validators' => array(
              array('Int', true),
              new Engine_Validate_AtLeast(0),
          ),
          'value' => 0,
      ));
    }
  }
}

?>