<?php
/**
 * SocialEngine
 *
 * @category   Application_Extensions
 * @package    Sitecontest
 * @copyright  Copyright 2019-2020 BigStep Technologies Pvt. Ltd.
 * @license    http://www.socialengineaddons.com/license/
 * @version    2019-08-10 9:40:21Z SocialEngineAddOns $
 * @author     SocialEngineAddOns
 */
class Sitecontest_Model_DbTable_Contests extends Core_Model_Item_DbTable_Abstract
{	
	protected $_name = 'sitecontest_contests';
	protected $_rowClass = "Sitecontest_Model_Contest";
	public function getCategoryList($category_id, $categoryType) {
		//RETURN IF CATEGORY ID IS NULL
		if (empty($category_id)) {
				return null;
		}
		//MAKE QUERY
		$select = $this->select()
						->from($this->info('name'), 'contest_id')
						->where("$categoryType = ?", $category_id);
		//GET DATA
		return $this->fetchAll($select);
	}
	public function getDayItems($title, $limit = 10, $category_id = null) {
		//MAKE QUERY
		$select = $this->select()
						->from($this->info('name'), array('contest_id', 'owner_id', 'title', 'photo_id'));

		if (!empty($category_id)) {
			$select->where('category_id = ?', $category_id);
		}

		$select->where($this->info('name') . ".title LIKE ? " , '%' . $title . '%')
						->where('approved = ?',  1)
						->where('draft = ?',0)
						->order('title ASC')
						->limit($limit);

		//FETCH RESULTS
		return $this->fetchAll($select);
	}
	public function getItemOfDay() {

		$sitecontestTableName = $this->info('name');
		$itemofthedaytable = Engine_Api::_()->getDbtable('itemofthedays', 'sitecontest');
		$itemofthedayName = $itemofthedaytable->info('name');
		$select = $this->select();
		$select = $select->setIntegrityCheck(false)
						->from($sitecontestTableName, array('contest_id', 'title', 'photo_id', 'contest_url', 'owner_id'))
						->join($itemofthedayName, $sitecontestTableName . ".contest_id = " . $itemofthedayName . '.resource_id', array('start_date'))
						->where($itemofthedayName . '.resource_type=?', 'sitecontest_cont')
						->where($itemofthedayName . '.start_date <=?', date('Y-m-d'))
						->where($itemofthedayName . '.end_date >=?', date('Y-m-d'))
						->order('RAND()');
		return $this->fetchRow($select);
	}
	public function getListings($params = array()) {
		$limit =2;
		$rName = $this->info('name');

		$select = $this->select()
						->setIntegrityCheck(false)
						->from($rName, '*')
						->where($rName . ".approved = ?", 1)
						->where($rName . ".search = ?", 1);

				$select = $select->where($rName . '.entry_count <> ?', '0');
				if (isset($params['featured']) && ($params['featured'] == '1')) {
						$select = $select->where($rName . '.	featured =?', '0');
				} elseif (isset($params['featured']) && ($params['featured'] == '2')) {
						$select = $select->where($rName . '.	featured =?', '1');
				}
				if (isset($params['hot']) && ($params['hot'] == '1')) {
						$select = $select->where($rName . '.	hot =?', '0');
				} elseif (isset($params['hot']) && ($params['hot'] == '2')) {
						$select = $select->where($rName . '.	hot =?', '1');
				}
				if (isset($params['sponsored']) && ($params['sponsored'] == '1')) {
						$select = $select->where($rName . '.	sponsored =?', '0');
				} elseif (isset($params['sponsored']) && ($params['sponsored'] == '2')) {
						$select = $select->where($rName . '.	sponsored =?', '1');
				}
			 
				$select->order($rName . '.entry_count DESC');

				if (isset($params['totalpages'])) {
						$limit = (int) $params['totalpages'];
				}
			 $select = $select->limit($limit);

		return $this->fetchALL($select);
	}
	public function getContestsSelect($params = array())
	{
		$viewer = Engine_Api::_()->user()->getViewer();
		$current_date = date('Y-m-d H:i:s');
		$table = Engine_Api::_()->getDbtable('contests', 'sitecontest');
		$rName = $table->info('name');

		$tmTable = Engine_Api::_()->getDbtable('TagMaps', 'core');
		$tmName = $tmTable->info('name');

		$select = $table->select()
			->order( !empty($params['orderby']) ? $params['orderby'].' DESC' : $rName.'.creation_date DESC' );

		if( !empty($params['user_id']) && is_numeric($params['user_id']) )
		{
			$owner = Engine_Api::_()->getItem('user', $params['user_id']);
			$select = $this->getProfileItemsSelect($owner, $select);
		} elseif( !empty($params['user']) && $params['user'] instanceof User_Model_User ) {
			$owner = $params['user'];
			$select = $this->getProfileItemsSelect($owner, $select);
		} elseif( isset($params['users']) ) {
			$str = (string) ( is_array($params['users']) ? "'" . join("', '", $params['users']) . "'" : $params['users'] );
			$select->where($rName.'.owner_id in (?)', new Zend_Db_Expr($str));
			if( !in_array($viewer->level_id, $this->_excludedLevels) ) {
				$select->where("view_privacy != ? ", 'owner');
			}
		} else {
			$param = array();
			$select = $this->getItemsSelect($param, $select);
		}

		if( !empty($params['sort'])) {
			if( $params['sort'] == 'featured' ) {
				$select->where($rName . '.featured = ?', 1);
			}

			if( $params['sort'] == 'sponsored' ) {
				$select->where($rName . '.sponsored = ?', 1);
			}

			if( $params['sort'] == 'verified' ) {
				$select->where($rName . '.verified = ?', 1);
			}

			if( $params['sort'] == 'hot' ) {
				$select->where($rName . '.hot = ?', 1);
			}

			if( $params['sort'] == 'most_joined') {
				$select->order($rName . '.entry_count DESC');
			}

			if( $params['sort'] == 'follow_count') {
				$select->order($rName . '.follow_count DESC');
			}

			if( $params['sort'] == 'view_count') {
				$select->order($rName . '.view_count DESC');
			}

			if( $params['sort'] == 'comment_count') {
				$select->order($rName . '.comment_count DESC');
			}

			if( $params['sort'] == 'like_count') {
				$select->order($rName . '.like_count DESC');
			}

			if( $params['sort'] == 'coming_soon' ) {
				$select->where("start_datetime >= ?",  $current_date);
			}

			if( $params['sort'] == 'active' ) {
				$select->where("start_datetime <= ?",  $current_date);
				$select->where("end_datetime >= ?",  $current_date);
			}

			if( $params['sort'] == 'ended' ) {
				$select->where("end_datetime <= ?",  $current_date);
			}
		}
		if( !empty($params['tag']) )
		{
			$select
				->setIntegrityCheck(false)
				->from($rName)
				->joinLeft($tmName, "$tmName.resource_id = $rName.contest_id")
				->where($tmName.'.resource_type = ?', 'contest')
				->where($tmName.'.tag_id = ?', $params['tag']);
		}

		if( !empty($params['category_id']) )
		{
			$select->where($rName.'.category_id = ?', $params['category_id']);
		}

		if( isset($params['draft']) )
		{
			$select->where($rName.'.draft = ?', $params['draft']);
		}

		// Could we use the search indexer for this?
		if( !empty($params['search']) )
		{
			$select->where($rName.".title LIKE ? OR ".$rName.".body LIKE ?", '%'.$params['search'].'%');
		}

		if( !empty($params['start_date']) )
		{
			$select->where($rName.".creation_date > ?", date('Y-m-d', $params['start_date']));
		}

		if( !empty($params['end_date']) )
		{
			$select->where($rName.".creation_date < ?", date('Y-m-d', $params['end_date']));
		}

		if( !empty($params['visible']) )
		{
			$select->where($rName.".search = ?", $params['visible']);
		}
		$select->where("contest_id IN(?)", $this->getOnlyViewableContestsId());

		if( !empty($owner) ) {
			return $select;
		}
		return $this->getAuthorisedSelect($select);
	}

	public function getContestsPaginator($params = array())
	{
		$paginator = Zend_Paginator::factory($this->getContestsSelect($params));
		if( !empty($params['page']) )
		{
			$paginator->setCurrentPageNumber($params['page']);
		}
		if( !empty($params['limit']) )
		{
			$paginator->setItemCountPerPage($params['limit']);
		}
		return $paginator;
	}

	public function getContestsCount($id, $column_name, $foruser = null) {
		//MAKE QUERY
		$select = $this->select()
						->from($this->info('name'), array('COUNT(*) AS count'));
		if (!empty($foruser)) {
				$select->where('approved = ?', 1)
								->where('draft = ?', 0)
								->where('search = ?', 1);
		}
		if (!empty($column_name) && !empty($id)) {
				$select->where("$column_name = ?", $id);
		}
		$totalContests = $select->query()->fetchColumn();
		//RETURN CONTESTS COUNT
		return $totalContests;
	}

	public function getMappedSitecontest($category_id) {
		//RETURN IF CATEGORY ID IS NULL
		if (empty($category_id)) {
				return null;
		}
		//MAKE QUERY
		$select = $this->select()
						->from($this->info('name'), 'contest_id')
						->where("category_id = $category_id OR subcategory_id = $category_id OR subsubcategory_id = $category_id");
		//GET DATA
		$categoryData = $this->fetchAll($select);
		if (!empty($categoryData)) {
				return $categoryData->toArray();
		}
		return null;
	}   
	//* popular tag widget
	public function getTagCloud($limit = 100, $count_only = 0,$params=array()) {

		$tableTagmaps = 'engine4_core_tagmaps';
		$tableTags = 'engine4_core_tags';

		$tableSitecontests = $this->info('name');
		$select = $this->select()
						->setIntegrityCheck(false)
						->from($tableSitecontests, array(''))
						->joinInner($tableTagmaps, "$tableSitecontests.contest_id = $tableTagmaps.resource_id", array('COUNT(engine4_core_tagmaps.resource_id) AS Frequency'))
						->joinInner($tableTags, "$tableTags.tag_id = $tableTagmaps.tag_id", array('text', 'tag_id'))
						->where($tableSitecontests . '.approved = ?', "1")
						->where($tableSitecontests . '.draft = ?', "0");
		$select = $select
						->where($tableTagmaps . '.resource_type = ?', 'sitecontest_cont')
						->group("$tableTags.text");

		if (isset($params['orderingType']) && !empty($params['orderingType']))
			$select->order("$tableTags.text");
		else
			$select->order("Frequency DESC");
						
		if (!empty($count_only)) {
			$total_results = $select->query()->fetchAll(Zend_Db::FETCH_COLUMN);
			return Count($total_results);
		}

		$select = $select->limit($limit);
		return $select->query()->fetchAll();
	}
	public function recentlyViewed($params = array()) {
		//GET VIEWER ID
		$viewer_id = $params['viewer_id'];
		//GET VIEWER TABLE
		$viewTable = Engine_Api::_()->getDbtable('vieweds', 'sitecontest');
		$viewTableName = $viewTable->info('name');
		//GET Sitecontest TABLE NAME
		$sitecontestTableName = $this->info('name');
		//MAKE QUERY
		$select = $this->select()
						->setIntegrityCheck(false)
						->from($sitecontestTableName)
						->joinInner($viewTableName, "$sitecontestTableName . contest_id = $viewTableName . resource_id", array(''));
		$select->where($viewTableName . '.viewer_id = ?', $viewer_id); 
		$select->order('date DESC');
		$select->where($sitecontestTableName . '.draft = ?', '0')
						->where($sitecontestTableName . ".search = ?", '1');
		if (isset($params['limit']) && !empty($params['limit'])) {
			$select->limit($params['limit']);
		}
		//RETURN RESULTS
		return $this->fetchAll($select);
	}
	public function updateContestState() {

		$contestTableName = $this->info('name');
		$select = $this->select()->from($contestTableName, '*')
						->where('draft=?', 0);
		$contests = $this->fetchAll($select);
		foreach ($contests as $contest) {
				if($contest->notification < 2) {
					//Entry Submission start Notofication To CONTEST FOLLOWERS
					if($contest->notification < 1) {    
						if ($contest->isContestSucceeded($contest->entry_start_datetime,$contest->entry_end_datetime)) {
								$owner = $contest->getOwner('user');
								$followers = $this->getFollowers($contest);
								foreach ($followers as $follower) {
									$user = Engine_Api::_()->getItem('user',$follower->poster_id);
									Engine_Api::_()->getDbtable('notifications', 'activity')->addNotification($user, $owner, $contest, 'sitecontest_entry_submisstion_start');
								}
								$contest->notification = 1;
								$contest->save();
							}
						}
						//Voting Started Notofication To CONTEST FOLLOWERS and Jury Members
						if($contest->notification < 2) {
							if ($contest->isContestSucceeded($contest->vote_start_datetime,$contest->vote_end_datetime)) {
									//TO Followers
									$owner = $contest->getOwner('user');
									$juries = Engine_Api::_()->getDbtable('juries', 'sitecontest')->fetchAll();
									$followers = $this->getFollowers($contest);
									
									$user_ids = array();
									foreach ($followers as $follower) {
											$user = Engine_Api::_()->getItem('user',$follower->poster_id);
											$user_ids[] =  $follower->poster_id;
											Engine_Api::_()->getDbtable('notifications', 'activity')->addNotification($user, $owner, $contest, 'sitecontest_vote_start');
									}

									//TO Jury Members
									foreach ($juries as $jury) {
											if(!in_array($jury->user_id, $user_ids)) {
													$user = Engine_Api::_()->getItem('user',$jury->user_id);
													Engine_Api::_()->getDbtable('notifications', 'activity')->addNotification($user, $owner, $contest, 'sitecontest_vote_start'); 
											}
									}
								$contest->notification = 2; 
								$contest->save();
							}
						}
				}
			}
	}
	public function UpdateContestWinner() {

		$contestTableName = $this->info('name');
		$select = $this->select()->from($contestTableName, '*')
						->where('result_datetime<=?', date('Y-m-d H:i:s'))
						->where('status=?','active')
						->where('draft=?', 0);
		$contests = $this->fetchAll($select);
		foreach ($contests as $contest) {
			$value = Engine_Api::_()->authorization()->getPermission($contest->getOwner()->level_id, 'sitecontest_cont', "prize");
			$entryTable = Engine_Api::_()->getDbtable('entries', 'sitecontest');
			$entryTableName = $entryTable->info('name');
			$select = $entryTable->select()->from($entryTableName, '*')
			->where('contest_id=?', $contest->contest_id)
			->order('vote_count DESC')
			->limit($value);
			$entries = $entryTable->fetchAll($select);

			$allselect = $entryTable->select()->from($entryTableName, '*')
			->where('contest_id=?', $contest->contest_id)
			->order('vote_count DESC');
			$allentries = $entryTable->fetchAll($allselect);

			$owner = $contest->getOwner('user');
			$i =1;
			$tie = 0;
			$votes = array();

			$contest->status = 'expired';
			//Cheak any tie condition
			foreach ($entries as $entry) {
					if(in_array($entry->vote_count, $votes)) {
									$tie = 1; 
									// MAIL of Tie to SuperAdmin
									$users = Engine_Api::_()->user()->getSuperAdmins();
									foreach ($users as $user) {
									$this->sendTieMail($user,$contest);
							}
					}
					$votes[] = $entry->vote_count;
			}
			if(empty($tie)) {
				foreach ($entries as $entry) {
					if (empty($entry->winner)) {
						$entry->winner = $i;
						//Genrate Activity feed of Contest Winner
						$viewer = Engine_Api::_()->getItem('user', $entry->user_id);
						$action = Engine_Api::_()->getDbtable('actions', 'activity')->addActivity($viewer, $contest, 'sitecontest_winner',null,array('rank' => $i));
						if( $action ) {
							Engine_Api::_()->getDbtable('actions', 'activity')->attachActivity($action, $entry);
						}

						//START DEFAULT EMAIL TO SUPERADMIN WHEN ANYONE CREATE PAGES.
						$awardTable = Engine_Api::_()->getDbtable('awards', 'sitecontest');
						$awardTableName = $awardTable->info('name');
						$select = $awardTable->select()->from($awardTableName, '*')
						->where('contest_id=?', $contest->contest_id);
						$awards = $awardTable->fetchRow($select);
						if ($i == 1) {
								$entry->award = $awards->first_award_prize;
								Engine_Api::_()->sitecontest()->congratesEmail($entry,$awards->first_award_message,$i);
								//MAil to contest Owner
								Engine_Api::_()->sitecontest()->resultdeclareEmail($contest);
						}elseif ($i == 2) {
								$entry->award = $awards->second_award_prize;
								Engine_Api::_()->sitecontest()->congratesEmail($entry,$awards->second_award_message,$i);
						}elseif ($i == 3) {
								$entry->award = $awards->third_award_prize;
								Engine_Api::_()->sitecontest()->congratesEmail($entry,$awards->third_award_message,$i);
						}elseif ($i == 4) {
								$entry->award = $awards->forth_award_prize;
								Engine_Api::_()->sitecontest()->congratesEmail($entry,$awards->forth_award_message,$i);
						}else{
								$entry->award = $awards->fifth_award_prize;
								Engine_Api::_()->sitecontest()->congratesEmail($entry,$awards->fifth_award_message,$i);
						}
						$i++;
						$entry->save();
					}
				}
				$followids = array();
				foreach ($allentries as $entry) {
					$followids[] = $entry->user_id;
					//Winner Declare Notification to ALl Entry Submitor
					$users = Engine_Api::_()->getItem('user',$entry->user_id);
					Engine_Api::_()->getDbtable('notifications', 'activity')->addNotification($users, $owner, $contest, 'sitecontest_Winner_declare');
				}

				//Winner Declare Notification to follower
				$followers = $this->getFollowers($contest);
				foreach ($followers as $follower) {
						if(!in_array($follower->poster_id,$followids)) {
						$user = Engine_Api::_()->getItem('user',$follower->poster_id);
						Engine_Api::_()->getDbtable('notifications', 'activity')->addNotification($user, $owner, $contest, 'sitecontest_Winner_declare');
						}
				}
			}
			$contest->save();  
		}
	} 
	public function getOnlyViewableContestsId() {
		$viewer = Engine_Api::_()->user()->getViewer();
		set_time_limit(0);
		$table = Engine_Api::_()->getItemTable('sitecontest_contest');
		$contest_select = $table->select()
						->order('contest_id DESC');

		$i = 0;
		$contest_ids = array();
		foreach ($contest_select->getTable()->fetchAll($contest_select) as $contest) {
				if ($contest->isOwner($viewer) || Engine_Api::_()->authorization()->isAllowed($contest, $viewer, 'view')) {
						$contest_ids[$i++] = $contest->contest_id;
				}
		}
		if (empty($contest_ids))
				$contest_ids = array(0);
		return $contest_ids;
	}

	public function sendTieMail($user,$object){
		$mailParams = array(
				'host' => $_SERVER['HTTP_HOST'],
				'date' => time(),
				'sender_email' => $user->email,
				'sender_title' => $user->getTitle(),
				'sender_link' => $user->getHref(),
				'sender_photo' => $user->getPhotoUrl('thumb.icon'),
				'object_link' => $object->getHref(),
				'title' => $object->getTitle(),
		);
		Engine_Api::_()->getApi('mail', 'core')->sendSystem($user->email, 'MAIL_ADMIN_TIE_DECLARE',$mailParams);
	}

	public function getFollowers($object) {
		$followTable = Engine_Api::_()->getDbtable('follows', 'seaocore');
		$followName = $followTable->info('name');
		$select = $followTable->select()
				->from($followName)
				->where($followName . '.resource_id = ?', $object->getIdentity())
				->where($followName . '.resource_type = ?', $object->getType());
		return $followTable->fetchAll($select);
	}
}