<?php
/**
* SocialEngine
*
* @category Application_Extensions
* @package Sitecontest
* @copyright Copyright 2019-2020 BigStep Technologies Pvt. Ltd.
* @license http://www.socialengineaddons.com/license/
* @version 2019-08-10 9:40:21Z SocialEngineAddOns $
* @author SocialEngineAddOns
*/
?>
<?php
class Sitecontest_AdminEntryItemsController extends Core_Controller_Action_Admin {

    //ACTION FOR PAGE OF THE DAY
    public function dayAction() {

        //GET NAVIGATION
        $this->view->navigation = Engine_Api::_()->getApi('menus', 'core')
                ->getNavigation('sitecontest_admin_main', array(), 'sitecontest_admin_main_entryofday');

        //FORM GENERATION
        $this->view->formFilter = $formFilter = new Sitecontest_Form_Admin_Filter();
        $page = $this->_getParam('page', 1); 

        $values = array(); 
        if ($formFilter->isValid($this->_getAllParams())) {
            $values = $formFilter->getValues();
        }
        foreach ($values as $key => $value) {
            if (null == $value) {
                unset($values[$key]);
            }
        }
        $values = array_merge(array(
                'order' => 'start_date',
                'order_direction' => 'DESC',
        ), $values);

        $this->view->assign($values);

        //FETCH DATA
        $this->view->paginator = $paginator = Engine_Api::_()->getDbtable('entryitemofthedays', 'sitecontest')->getItemOfDayList($values, 'entry_id', 'sitecontest_entry');
        $this->view->paginator->setItemCountPerPage(50);
        $this->view->paginator = $paginator->setCurrentPageNumber($page);
    }

    //ACTION FOR ADDING ENTRY OF THE DAY
    public function addItemAction() {

    //SET LAYOUT
    $this->_helper->layout->setLayout('admin-simple');
    $viewer = Engine_Api::_()->user()->getViewer();
    //FORM GENERATION
    $form = $this->view->form = new Sitecontest_Form_Admin_Entryitem();

    //CHECK POST
    if ($this->getRequest()->isPost() && $form->isValid($this->getRequest()->getPost())) {

        //GET FORM VALUES
        $values = $form->getValues();

        //BEGIN TRANSACTION
        $db = Engine_Db_Table::getDefaultAdapter();
        $db->beginTransaction();
        try {
            $table = Engine_Api::_()->getDbtable('entryitemofthedays', 'sitecontest');
            $select = $table->select()->where('resource_id = ?', $values["resource_id"])->where('resource_type = ?', 'sitecontest_enty');
            $row = $table->fetchRow($select);

            if (empty($row)) {
                $row = $table->createRow();
                $row->resource_id = $values["resource_id"];
            }

            // $oldTz = date_default_timezone_get();
            // date_default_timezone_set($viewer->timezone);
            $start = strtotime($values['starttime']);
            $end = strtotime($values['endtime']);
            // date_default_timezone_set($oldTz);
            if( $start > $end ) {
              $form->starttime->setErrors(array('Start Date should be before End Date.'));
              return;
            }
            $values['starttime'] = date('Y-m-d', $start);
            $values['endtime'] = date('Y-m-d', $end);
    
            $row->start_date = $values["starttime"];
            $row->end_date = $values["endtime"];
            $row->resource_type = 'sitecontest_enty';
            $row->save();

            $db->commit();
        } catch (Exception $e) {
            $db->rollBack();
            throw $e;
        }
        $this->_forward('success', 'utility', 'core', array(
            'smoothboxClose' => 10,
            'parentRefresh' => 10,
            'messages' => array(Zend_Registry::get('Zend_Translate')->_('The Contest of the Day has been added successfully.'))
        ));
    }
    }

    //ACTION FOR PAGE SUGGESTION DROP-DOWN
    public function getitemAction() {

            
        $search_text = $this->_getParam('text', null);
        $limit = $this->_getParam('limit', 40);
        
        $data = array();

        $moduleContents = Engine_Api::_()->getItemTable('sitecontest_entry')->getDayItems($search_text, $limit=10);
        foreach ($moduleContents as $moduleContent) {
            $content_photo = $this->view->itemPhoto($moduleContent, 'thumb.icon');
            $data[] = array(
                'id' => $moduleContent->entry_id,
                'label' => $moduleContent->title,
                'photo' => $content_photo
            );
        }
        return $this->_helper->json($data);
    }

    //ACTION FOR PAGE DELETE ENTRY
    public function deleteItemAction() {
        if ($this->getRequest()->isPost()) {
            $db = Engine_Db_Table::getDefaultAdapter();
            $db->beginTransaction();
            try {
                $entryitemofthedaysTable = Engine_Api::_()->getDbtable('entryitemofthedays', 'sitecontest')->delete(array('entryitemoftheday_id =?' => $this->_getParam('id')));
                $db->commit();
            } catch (Exception $e) {
                $db->rollBack();
                throw $e;
            }
            $this->_forward('success', 'utility', 'core', array(
                'smoothboxClose' => 10,
                'parentRefresh' => 10,
                'messages' => array(Zend_Registry::get('Zend_Translate')->_(''))
            ));
        }
        $this->renderScript('admin-entry-items/delete.tpl');
    }

    //ACTION FOR MULTI DELETE PAGE ENTRIES
    public function multiDeleteAction() {

        if ($this->getRequest()->isPost()) {
            $values = $this->getRequest()->getPost();
            foreach ($values as $key => $value) {
                if ($key == 'delete_' . $value) {
                    $sitecontestentryitemofthedays = Engine_Api::_()->getItem('sitecontest_entryitemofthedays', (int) $value);
                    if (!empty($sitecontestentryitemofthedays)) {
                        $sitecontestentryitemofthedays->delete();
                    }
                }
            }
        }
        return $this->_helper->redirector->gotoRoute(array('action' => 'day'));
    }
}
?>