<?php
/**
* SocialEngine
*
* @category Application_Extensions
* @package Sitecontest
* @copyright Copyright 2019-2020 BigStep Technologies Pvt. Ltd.
* @license http://www.socialengineaddons.com/license/
* @version 2019-08-10 9:40:21Z SocialEngineAddOns $
* @author SocialEngineAddOns
*/
?>
<?php
/**
 * 
 */
class Sitecontest_AdminProfileMapsController extends Core_Controller_Action_Admin
{
	
	public function manageAction() {
		//GET NAVIGATION
		$this->view->navigation = Engine_Api::_()->getApi('menus', 'core')
				->getNavigation('sitecontest_admin_main', array(), 'sitecontest_admin_main_profilemaps');




		//GET FIELD OPTION TABLE NAME
		$tableFieldOptions = Engine_Api::_()->getDbtable('options', 'sitecontest');

		//GET TOTAL PROFILES
		$topStructure = Engine_Api::_()->fields()->getFieldStructureTop('sitecontest_cont');
		$this->view->totalProfileTypes = 1;
		if (count($topStructure) == 1 && $topStructure[0]->getChild()->type == 'profile_type') {
			$profileTypeField = $topStructure[0]->getChild();
			$options = $profileTypeField->getOptions();
			$this->view->totalProfileTypes = Count($options);
		}

		$tableCategory = Engine_Api::_()->getDbtable('categories', 'sitecontest');
		$sub_cat_array = array();
		$categories = array();
		$category_info = $tableCategory->getCategories(array('category_id', 'category_name', 'cat_order', 'profile_type'), null, 0, 0, 1);
		foreach ($category_info as $value) {

			$cat_profile_type_label = '---';
			if (!empty($value->profile_type)) {
				$cat_profile_type_label = $tableFieldOptions->getProfileTypeLabel($value->profile_type);
			}

			$categories[] = $category_array = array(
				'category_id' => $value->category_id,
				'category_name' => $value->category_name,
				'order' => $value->cat_order,
				'sub_categories' => $sub_cat_array,
				'cat_profile_type_id' => $value->profile_type,
				'cat_profile_type_label' => $cat_profile_type_label,
			);
		}
		$this->view->categories = $categories;
	}

	public function mapAction() {

		//DEFAULT LAYOUT
		$this->_helper->layout->setLayout('admin-simple');

		//GET CATEGORY ID
		$this->view->category_id = $category_id = $this->_getParam('category_id');

		//GENERATE THE FORM
		$this->view->form = $form = new Sitecontest_Form_Admin_Profilemaps_Map();

		//GET MAPPING ITEM
		$category = Engine_Api::_()->getItem('sitecontest_category', $category_id);

		//POST DATA
		if ($this->getRequest()->isPost() && $form->isValid($this->getRequest()->getPost())) {

			// $tempCatFlag = false;
			//GET DATA
			$values = $form->getValues();

			//GET CONTEST TABLE
			$contestTable = Engine_Api::_()->getDbTable('contests', 'sitecontest');

			//BEGIN TRANSCATION
			$db = Engine_Db_Table::getDefaultAdapter();
			$db->beginTransaction();

			try {

				$category->profile_type = $values['profile_type'];
				$category->save();
			   
				//IF YES BUTTON IS CLICKED THEN CHANGE MAPPING OF ALL CONTESTS
				if (isset($_POST['yes_button'])) {

					
					//SELECT CONTESTS WHICH HAVE THIS CATEGORY AND THIS PROFILE TYPE
					$contestsIds = $contestTable->getMappedSitecontest($category_id);
					

					if (!empty($contestsIds)) {
						foreach ($contestsIds as $contest) {
							$contest_id = $contest['contest_id'];

							//GET FIELD VALUE TABLE
							$fieldvalueTable = Engine_Api::_()->fields()->getTable('sitecontest_cont', 'values');

							//DELETE ALL MAPPING VALUES FROM FIELD TABLES
							Engine_Api::_()->fields()->getTable('sitecontest_cont', 'values')->delete(array('item_id = ?' => $contest_id));
							Engine_Api::_()->fields()->getTable('sitecontest_cont', 'search')->delete(array('item_id = ?' => $contest_id));

							//PUT NEW PROFILE TYPE
							$fieldvalueTable->insert(array(
								'item_id' => $contest_id,
								'field_id' => Engine_Api::_()->getDbTable('metas', 'sitecontest')->defaultProfileId(),
								'index' => 0,
								'value' => $category->profile_type,
							));

							$contestTable->update(array('profile_type' => $category->profile_type), array('contest_id = ?' => $contest_id));
						}
					}
				}
				$db->commit();
			} catch (Exception $e) {
				$db->rollBack();
				throw $e;
			}

			$this->_forward('success', 'utility', 'core', array(
				'smoothboxClose' => 10,
				'parentRefresh' => 10,
				'messages' => array(Zend_Registry::get('Zend_Translate')->_('Mapping has been done successfully.'))
			));
		}
		$this->renderScript('admin-profilemaps/map.tpl');
	}   


	public function editAction() {

		//DEFAULT LAYOUT
		$this->_helper->layout->setLayout('admin-simple');

		//GET CATEGORY ID
		$this->view->category_id = $category_id = $this->_getParam('category_id');

		//GET PROFILE TYPE
		$old_profile_type_id = $this->_getParam('profile_type');

		$topStructure = Engine_Api::_()->fields()->getFieldStructureTop('sitecontest_cont');
		$this->view->totalProfileTypes = 1;
		

		//GENERATE THE FORM
		$this->view->form = $form = new Sitecontest_Form_Admin_Profilemaps_Edit();

		//POST DATA
		if ($this->getRequest()->isPost() && $form->isValid($this->getRequest()->getPost())) {

			//GET DATA
			$values = $form->getValues();
			$new_profile_type_id = $values['profile_type'];

			if ($old_profile_type_id != $new_profile_type_id) {

				//BEGIN TRANSCATION
				$db = Engine_Db_Table::getDefaultAdapter();
				$db->beginTransaction();

				try {

					//GET MAPPING ITEM
					$category = Engine_Api::_()->getItem('sitecontest_category', $category_id);

					//GET CONTEST TABLE
					$sitecontestTable = Engine_Api::_()->getDbTable('contests', 'sitecontest');

					//FOR CATEGORY
					if ($category->cat_dependency == 0 && $category->subcat_dependency == 0) {
						$select = $sitecontestTable->select()
								->from($sitecontestTable->info('name'), array('contest_id'))
								->where('category_id = ?', $category->category_id)
								->where('subcategory_id = ?', 0)
						;
					}
					

					$category->profile_type = $new_profile_type_id;
					$category->save();

					$db->commit();
				} catch (Exception $e) {
					$db->rollBack();
					throw $e;
				}
			}

			$this->_forward('success', 'utility', 'core', array(
				'smoothboxClose' => 10,
				'parentRefresh' => 10,
				'messages' => array(Zend_Registry::get('Zend_Translate')->_('Mapping has been edited successfully.'))
			));
		}
	}


	public function removeAction() {

		//DEFAULT LAYOUT
		$this->_helper->layout->setLayout('admin-simple');

		//GET MAPPING ID
		$this->view->category_id = $category_id = $this->_getParam('category_id');

		//GET CHILD CATEGORIES
		$categoryTable = Engine_Api::_()->getDbTable('categories', 'sitecontest');
		

		//GET MAPPING ITEM
		$this->view->category = $category = Engine_Api::_()->getItem('sitecontest_category', $category_id);

		//POST DATA
		if ($this->getRequest()->isPost()) {

			//BEGIN TRANSCATION
			$db = Engine_Db_Table::getDefaultAdapter();
			$db->beginTransaction();
			try {

				//GET CONTEST TABLE
				$sitecontestTable = Engine_Api::_()->getDbTable('contests', 'sitecontest');

				if (!isset($_POST['import_profile'])) {

					//SELECT CONTESTS WHICH HAVE THIS CATEGORY
					$sitecontests = $sitecontestTable->getMappedSitecontest($category_id);
				} else {

					foreach ($getChilds as $getChild) {
						$child = Engine_Api::_()->getItem('sitecontest_category', $getChild->category_id);
						$child->profile_type = $category->profile_type;
						$child->save();
					}

					//FOR CATEGORY
					if ($category->cat_dependency == 0 && $category->subcat_dependency == 0) {
						$select = $sitecontestTable->select()
								->from($sitecontestTable->info('name'), array('contest_id'))
								->where('category_id = ?', $category->category_id)
								->where('subcategory_id = ?', 0)
						;
					}
					//FOR SUBCATEGORY
					elseif ($category->cat_dependency != 0 && $category->subcat_dependency == 0) {
						$select = $sitecontestTable->select()
								->from($sitecontestTable->info('name'), array('contest_id'))
								->where('subcategory_id = ?', $category->category_id)
								->where('subsubcategory_id = ?', 0)
						;
					}

					$sitecontests = $sitecontestTable->fetchAll($select);

					if (!empty($sitecontests)) {
						$sitecontests = $sitecontests->toArray();
					}
				}

				foreach ($sitecontests as $sitecontest) {

					//GET CONTEST ID
					$contest_id = $sitecontest['contest_id'];

					//DELETE ALL MAPPING VALUES FROM FIELD TABLES
					Engine_Api::_()->fields()->getTable('sitecontest_cont', 'values')->delete(array('item_id = ?' => $contest_id));
					Engine_Api::_()->fields()->getTable('sitecontest_cont', 'search')->delete(array('item_id = ?' => $contest_id));

					//UPDATE THE PROFILE TYPE OF ALREADY CREATED CONTESTS
					$sitecontestTable->update(array('profile_type' => 0), array('contest_id = ?' => $contest_id));
				}

				
				//DELETE MAPPING
				$category->profile_type = 0;
				$category->save();


				$db->commit();
			} catch (Exception $e) {
				$db->rollBack();
				throw $e;
			}
			$this->_forward('success', 'utility', 'core', array(
				'smoothboxClose' => 10,
				'parentRefresh' => 10,
				'messages' => array(Zend_Registry::get('Zend_Translate')->_('Mapping has been deleted successfully!'))
			));
		}
		$this->renderScript('admin-profilemaps/remove.tpl');
	}
}
?>