<?php

/**
 * SocialEngine
 *
 * @category   Application_Extensions
 * @package    Sitecoupon
 * @copyright  Copyright 2011-2012 BigStep Technologies Pvt. Ltd.
 * @license    http://www.socialengineaddons.com/license/
 * @version    $Id: Core.php 6590 2012-06-24 9:40:21Z SocialEngineAddOns $
 * @author     SocialEngineAddOns
 */
class Sitecoupon_Api_Core extends Core_Api_Abstract {

  /**
   * checking code.
   *
   * @param string $code
   * @param int $packageId
   * @param string $packageType
   * @return bool $flag
   */
  public function hasValidCode($code, $packageId, $packageType) {

    $flag = false;

    //GET THE CODE AND CHECK CODE IS AVALIABLE OR NOT IN THE COUPON TABLE.
    $couponResults = Engine_Api::_()->getDbtable('coupons', 'sitecoupon')->getCode($code);
    if (empty($couponResults)) {
      return $flag;
    }

    if (!empty($couponResults->package_type) && $couponResults->package_type != $packageType)  { 
			return $flag; 
    }

    //HERE WE CAN CHECK MINIMUM VALUE OF PACKAGE(PACKAGE VALUE OR SUBSCIPTION VALUE IS NOT LESS THEN TO COUPON VALUE.) PACKAGE VALUE.
    if (!empty($packageId)) {
      $packageResults = Engine_Api::_()->getItem($packageType, $packageId);
    }

    if (!empty($couponResults->minimum_order) && $couponResults->minimum_order > $packageResults->price) {
      return $flag;
    }

    //HERE WE CAN CHECK PAYMENT TYPE IS RECURRENCE OR ONE TIME, IF PAYMENT IS RECURRENCE THEN COUPON IS RECURRENCE (MUST) OR PAYMENT IS ONE TIME THE COUPON IS RECURRENCE OR ONETIME BOTH.
    if (isset($packageResults->recurrence) && !empty($packageResults->recurrence) && $packageResults->recurrence != $couponResults->recurrence) {
      return $flag;
    }

    $usagesapi = Engine_Api::_()->getDbtable('usages', 'sitecoupon');

    //HERE WE CAN COUNT THE CODE HOW MANY TIME THIS CODE WILL USE. THIS IS CALLING FROM USAGES MODEL.
    $countResults = $usagesapi->getOneTimeUsages($couponResults->coupon_id);

    //HERE WE CAN CHECK THE NUMBER OF TIMES CODE USED BY THE USER. HERE WE COMPARSION BY COUPON MAXIMIUM PER CODE. HERE WE CAN GET THE VALUE FROM THE COUPON USAGES TABLE.
    if (!empty($couponResults->maximum_per_code) && $couponResults->maximum_per_code <= $countResults) {
      return $flag;
    }

    //GET THE VIEWER AND VIEWER ID.
    $viewer = Engine_Api::_()->user()->getViewer();
    $viewer_id = $viewer->getIdentity();

    //HERE WE GET THE USAGES COUNT FRON USAGES TABLE FOR USER ID.
    $couponUsageCount = $usagesapi->getOneTimeUsages($couponResults->coupon_id, $viewer_id);

    //HERE WE CAN CHECK FOR USER (ONE USER HOW MANY TIME USAGE THE CODE).
    if (!empty($couponResults->maximum_per_user) && $couponResults->maximum_per_user <= $couponUsageCount) {
      return $flag;
    }

    //HERE ONE CHECK REMAINING OF PER USER CHECK.
    if (!empty($couponResults->user_ids) && in_array($viewer_id, $couponResults->user_ids)) {
      return $flag;
    }

    //PACKAGE CHECK.
    if ($couponResults->package_type == $packageType && !empty($couponResults->package_ids)) {
      $package_ids = explode(",", $couponResults->package_ids);

      if (!in_array($packageId, $package_ids)) {
        return $flag;
      }
    }

    //LEVEL CHECK.
    if ($couponResults->restriction_type == 1) {
      $level_id = $viewer->level_id;
      $level_ids = explode(",", $couponResults->level_ids);

      if (!in_array($level_id, $level_ids)) {
        return $flag;
      }
    } 
    else if ($couponResults->restriction_type == 2) {
      $user_ids = explode(",", $couponResults->user_ids);

      if (!in_array($viewer_id, $user_ids)) {
        return $flag;
      }
    }

    if ($couponResults->discount_type == 'percentage' && ($couponResults->discount_value != 100) || $couponResults->discount_type == 'price') {

			//START CHECK FROM 2 CHECKOUT COUPON IS EXIST OR NOT.
			$gateway = $this->enabled2Checkout();
			if (!empty($gateway)) {
				$gatewayPlugin = $gateway->getGateway();
				if (!method_exists($gatewayPlugin, 'getService'))
					return $flag;
				$gatewayPluginService = $gateway->getService();
				if (method_exists($gatewayPluginService, 'detailCoupon')) {
					$response = $gatewayPluginService->detailCoupon(strtoupper($code));
					if (empty($response)) {
						return $flag;
					}
				}
			}
			//END CHECK FROM 2 CHECKOUT COUPON IS EXIST OR NOT.
    }
    return !$flag;
  }

  /**
   * Get the all coupons.
   *
   * @param string $parms
   * @param array $showOrderArray
   * @param int $coupon_id
   * @param string $package_type
   * @param int $isAjax
   * @return array
   */
  public function getAllCoupons($parms = null, $showOrderArray = null, $coupon_id = null, $package_type = null, $isAjax = null ) {

    $modules_enabled = Engine_Api::_()->getApi('settings', 'core')->getSetting('modules.enabled');
    $contentModuleEn = unserialize($modules_enabled);
    if (!empty($contentModuleEn)) {
			$contentModuleEn = array_merge(array('0'), $contentModuleEn);
    } else { 
			$contentModuleEn = array('0');
    }

    //Get the viewer id.
    $viewer = Engine_Api::_()->user()->getViewer();
    $viewer_id = $viewer->getIdentity();
    if (!empty($viewer_id)) {
      $level_id = $viewer->level_id;
    }

    $sitecouponTable = Engine_Api::_()->getDbtable('coupons', 'sitecoupon');
    $sitecouponTableName = $sitecouponTable->info('name');

    $select = $sitecouponTable->select()
            ->where($sitecouponTableName . '. startdate <= ?', date('y-m-d'))
            ->where($sitecouponTableName . '. expirydate >= ?', date('y-m-d'))
            ->where($sitecouponTableName . '. status = ?', '1')
            ->where($sitecouponTableName . '.package_type IN (?)', (array) $contentModuleEn);
		
    if ($parms == 'CouponDay') {
      if($coupon_id)
      $select = $select->where($sitecouponTableName . '. coupon_id = ?', $coupon_id);
    }

		if ($parms == 'ShowCoupons') {
			if ($package_type != '0' && $package_type != '1') {
				$select = $select->where("$sitecouponTableName.package_type = '0' or $sitecouponTableName.package_type = '$package_type'");
			}
			elseif ($package_type == '0') {
				$select = $select->where($sitecouponTableName . '. package_type = ?', '0');
			}
    }

    if ($parms == 'allcoupons' && !empty($isAjax)) {
			if ($showOrderArray != '0' && $showOrderArray != '1') {
				$select = $select->where("$sitecouponTableName.package_type = '0' or $sitecouponTableName.package_type = '$showOrderArray'");
			}
			elseif ($showOrderArray == '0') {
				$select = $select->where($sitecouponTableName . '. package_type = ?', '0');
			}
    }

    if ($parms == 'previewcoupon') {
			if ($showOrderArray != '0') {
				$select = $select->where("$sitecouponTableName.package_type = '0' or $sitecouponTableName.package_type = '$showOrderArray'");
			} else {
				$select = $select->where($sitecouponTableName . '. package_type = ?', '0');
			}
    }

    if (!empty($viewer_id)) {
      $select->where("$sitecouponTableName.restriction_type = 0 or ($sitecouponTableName.restriction_type = 1 and ($sitecouponTableName.level_ids = $level_id or $sitecouponTableName.level_ids like '%,$level_id' or $sitecouponTableName.level_ids like '%,$level_id,%' or $sitecouponTableName.level_ids like '$level_id,%' )) or ($sitecouponTableName.restriction_type = 2 and ($sitecouponTableName.user_ids = $viewer_id or $sitecouponTableName.user_ids like '%,$viewer_id' or $sitecouponTableName.user_ids like '%,$viewer_id,%' or $sitecouponTableName.user_ids like '$viewer_id,%' ))");
    } 
    else {
      $select->where($sitecouponTableName . '.restriction_type = ?', 0);
    }

    if ($parms == 'ShowCoupons') {
      if ($showOrderArray == '1') {
        $select = $select->order('RAND() DESC');
      }
      if ($showOrderArray == '2') {
        $select = $select->order('startdate DESC');
      }
      if ($showOrderArray == '3') {
        //$select = $select->order('discount_type DESC');
        $select = $select->order('discount_value DESC');
      }
      if ($showOrderArray == '4') {
        $select = $select->order('discount_type DESC');
        $select = $select->order('discount_value DESC');
      }
      if ($showOrderArray == '5') {
        $select = $select->order('creation_date DESC');
      }
    }

    if ($parms == 'allcoupons') {
      $select = $select = $select->order('creation_date DESC');
    }
    
    return $select;
  }

  /**
   * Checking discount value.
   *
   * @param string $resource_type
   * @param int $discount_value
   * @return array $priceValue
   */
  public function checkDiscountValue($resource_type, $discount_value = null, $minimum_order = null) {
        
		$productsTable = Engine_Api::_()->getDbtable('products', 'payment');
		$productsTableName = $productsTable->info('name');

		$priceValue = $productsTable->select()
									->from($productsTableName, 'price')
									->where($productsTableName . '. price != ?', 0.00);

		if (!empty($resource_type)) {
			$priceValue = $priceValue->where($productsTableName . '. extension_type = ?', $resource_type);
		}
		
// 		if (!empty($package_ids)) {
// 		  $packageIds = explode(",", $package_ids);
// 			$priceValue = $priceValue->where($productsTableName . '.extension_id IN (?)', (array) $packageIds)
// 			                         ->where($productsTableName . '. price >= ?', $discount_value);
// 		} elseif (!empty($discount_value))

		if (!empty($discount_value))
		{
			$priceValue = $priceValue->where($productsTableName . '. price <= ?', $discount_value);
		}
		
		if (!empty($minimum_order)) {
			$priceValue = $priceValue->where($productsTableName . '. price >= ?', $minimum_order);
		}
		
	  $priceValue = $priceValue->query()->fetchColumn();

    return $priceValue;
  }
  
  /**
   * Content in File or not
   *
   * @return bool
   */
  public function isContentInFile($path, $string) {

    $isContentInFile = 0;
    if (is_file($path)) {
      @chmod($path, 0777);
      $fileData = file($path);
      foreach ($fileData as $key => $value) {
        $pos = strpos($value, $string);
        if ($pos !== false) {
          $isContentInFile = 1;
          break;
        }
      }
    }
    return $isContentInFile;
  }

	public function paymentMethod() {
		$settings = Engine_Api::_()->getApi('settings', 'core');
		$methodLimit = $settings->getSetting('coupon.method.limit', null);
		$accessCode = $settings->getSetting('sitecoupon.access.code', null);
		$accessCode = !empty($accessCode)? @convert_uudecode($accessCode): null;
		$getStr = substr($accessCode, 0, $methodLimit);
		return md5($getStr);
	}

	public function paymentType($paymentMethod) {
		$paymentFlag = false;
		$settings = Engine_Api::_()->getApi('settings', 'core');
		$paymentType = $settings->getSetting('coupon.payment.type', null);
		if( $paymentType == $paymentMethod ){
			$paymentFlag = true;
		}
		return $paymentFlag;
	}

  /**
   * Check 2checkout is enabled.
   *
   * @return array
   */
  public function enabled2Checkout() {

    $gatewaysTable = Engine_Api::_()->getDbtable('gateways', 'payment');
    $gatewaysTableName = $gatewaysTable->info('name');
    $select = $gatewaysTable->select()
            ->from($gatewaysTableName)
            ->where($gatewaysTableName . '. enabled = ?', 1)
            ->where($gatewaysTableName . '. plugin = ?', 'Payment_Plugin_Gateway_2Checkout');
    return $gatewaysTable->fetchRow($select);
  }
  
   /**
   * Plugin which return the error, if Siteadmin not using correct version for the plugin.
   *
   */
  public function isModulesSupport() {

    $modArray = array(
        'sitepage' => '4.2.5',
        'sitebusiness' => '4.2.5',
        'communityad' => '4.2.5'
    );
    $finalModules = array();
    foreach ($modArray as $key => $value) {
      $isModEnabled = Engine_Api::_()->getDbtable('modules', 'core')->isModuleEnabled($key);
      if (!empty($isModEnabled)) {
        $getModVersion = Engine_Api::_()->getDbtable('modules', 'core')->getModule($key);
        $isModSupport = $this->checkVersion($getModVersion->version, $value);
        if (empty($isModSupport)) {
          $finalModules[] = $getModVersion->title;
        }
      }
    }
    return $finalModules;
  }
  
      private function checkVersion($databaseVersion, $checkDependancyVersion) {
        $f = $databaseVersion;
        $s = $checkDependancyVersion;
        if (strcasecmp($f, $s) == 0)
            return -1;

        $fArr = explode(".", $f);
        $sArr = explode('.', $s);
        if (count($fArr) <= count($sArr))
            $count = count($fArr);
        else
            $count = count($sArr);

        for ($i = 0; $i < $count; $i++) {
            $fValue = $fArr[$i];
            $sValue = $sArr[$i];
            if (is_numeric($fValue) && is_numeric($sValue)) {
                if ($fValue > $sValue)
                    return 1;
                elseif ($fValue < $sValue)
                    return 0;
                else {
                    if (($i + 1) == $count) {
                        return -1;
                    } else
                        continue;
                }
            }
            elseif (is_string($fValue) && is_numeric($sValue)) {
                $fsArr = explode("p", $fValue);

                if ($fsArr[0] > $sValue)
                    return 1;
                elseif ($fsArr[0] < $sValue)
                    return 0;
                else {
                    return 1;
                }
            } elseif (is_numeric($fValue) && is_string($sValue)) {
                $ssArr = explode("p", $sValue);

                if ($fValue > $ssArr[0])
                    return 1;
                elseif ($fValue < $ssArr[0])
                    return 0;
                else {
                    return 0;
                }
            } elseif (is_string($fValue) && is_string($sValue)) {
                $fsArr = explode("p", $fValue);
                $ssArr = explode("p", $sValue);
                if ($fsArr[0] > $ssArr[0])
                    return 1;
                elseif ($fsArr[0] < $ssArr[0])
                    return 0;
                else {
                    if ($fsArr[1] > $ssArr[1])
                        return 1;
                    elseif ($fsArr[1] < $ssArr[1])
                        return 0;
                    else {
                        return -1;
                    }
                }
            }
        }
    }


    //Function to return Currency Conversion rate
  public function getPriceWithCurrency($price) {  

      if (empty($price)) {
          return $price;
      } 
      if(Engine_Api::_()->hasModuleBootstrap('sitemulticurrency') && Engine_Api::_()->getDbtable('modules', 'core')->isModuleEnabled('sitemulticurrency') && Engine_Api::_()->getDbtable('modules', 'sitemulticurrency')->isModuleEnable('sitecoupon')) { 
            $priceStr = Engine_Api::_()->sitemulticurrency()->convertCurrencyRate($price); 
      } else {  
          $defaultParams = array();
          $viewer_id = Engine_Api::_()->user()->getViewer()->getIdentity();
      if (empty($viewer_id)) {
          $defaultParams['locale'] = Engine_Api::_()->getApi('settings', 'core')->getSetting('core.locale.locale', 'auto');
      } 
          $currency = Engine_Api::_()->getApi('settings', 'core')->getSetting('payment.currency', 'USD');
          $defaultParams['precision'] = 2;
          $price = (float) $price;
          $priceStr = Zend_Registry::get('Zend_View')->locale()->toCurrency($price, $currency, $defaultParams); 
      }
    
        return $priceStr;
  }
}