<?php

/**
 * SocialEngine
 *
 * @category   Application_Extensions
 * @package    Sitecoupon
 * @copyright  Copyright 2011-2012 BigStep Technologies Pvt. Ltd.
 * @license    http://www.socialengineaddons.com/license/
 * @version    $Id: Coupon.php 6590 2012-06-24 9:40:21Z SocialEngineAddOns $
 * @author     SocialEngineAddOns
 */
class Sitecoupon_Form_Admin_Coupon extends Engine_Form {

  public function init() {

    $this->setTitle('Create New Coupon')
      ->setDescription('Create a new coupon over here. Below, you can configure various settings for this coupon like coupon code, expiry date, discount type, discount value, etc. Please note that the parameters (Coupon Code, Discount Type, Discount Value, Restrictions, Ordered Item) cannot be edited once the coupon is used. If you wish to change these, you will have to create a new coupon with new coupon code and disable the existing one.');

    //ELEMENT PACKAGE TITLE
    $this->addElement('Text', 'name', array(
			'label' => 'Coupon Name',
   		'allowEmpty' => FALSE,
   		'autocomplete' => 'off',
   		'description' => 'This is for identification only.',
			'maxlength' => 64,
			'validators' => array(
				array('NotEmpty', true),
			),
			'filters' => array(
				'StringTrim',
			),
    ));
    $this->name->getDecorator('Description')->setOptions(array('placement' => 'APPEND'));
    
    // Description
    $this->addElement('Textarea', 'description', array(
      'label' => 'Coupon Description',
      'description' => 'To make this coupon more relevant for users, enter its description which matches its properties.',
      'maxlength' => '10000',
      'filters' => array(
        'StripTags',
        new Engine_Filter_Censor(),
        new Engine_Filter_EnableLinks(),
        new Engine_Filter_StringLength(array('max' => 10000)),
      ),
    ));
    
    $this->addElement('File', 'photo', array(
      'label' => 'Coupon Photo'
    ));
    
    //ELEMENT CODE
    $this->addElement('Text', 'code', array(
			'label' => 'Coupon Code',
			'description' => 'Enter the coupon code which users will enter to avail discount. This code cannot be edited later. (Note: Coupon code should be in between 4 and 16 characters in length and can contain alphabets, numbers, or a combination of both. Special characters other than hyphen (-) are not allowed.)',
			'maxlength' => 16,
			'autocomplete' => 'off',
			'allowEmpty' => FALSE,
			'validators' => array(
				array('NotEmpty', true),
				array('StringLength', true, array(4, 16)),
				array('Regex', true, array('/^[a-zA-Z0-9-_ ]+$/')),
			),
    ));
    $this->code->getValidator('Regex')->setMessage('Please enter valid coupon code.', 'regexNotMatch');
    
    $couponId = Zend_Controller_Front::getInstance()->getRequest()->getParam('coupon_id', null);

    if($couponId) {
        $usgaeCount = Engine_Api::_()->getDbtable( 'usages' , 'sitecoupon' )->getOneTimeUsages($couponId);
    }

    if(!Engine_Api::_()->hasModuleBootstrap('sitegateway') || !$couponId || ($couponId && !$usgaeCount)) { 
        $date = (string) date('Y-m-d');
        $this->addElement('CalendarDateTime', 'startdate', array(
                'label' => 'Start Date',
                'description' => "Select a start date for this coupon.",
                'value' => $date . ' 00:00:00',
        ));

            $this->addElement('Radio', 'end_settings', array(
                'label' => 'Expiry Date',
                'description' => 'Select an expiry date for this coupon.',
                'onclick' => "updateTextFields(this.value)",
                'multiOptions' => array(
                    "0" => "No end date.",
                    "1" => "End coupon on a specific date.(Please select date by clicking on the calendar icon below. Note : Expiration date should be greater than the start date.)",
                ),
                'value' => 0
        ));

        $this->addElement('CalendarDateTime', 'expirydate', array(
                'value' => $date . ' 00:00:00',
        ));
    }

// 		$this->addElement( 'Radio' , 'recurrence' , array (
// 			'label' => 'Enable for Recurring Payments' ,
// 			'description' => "Do you want this coupon to be applicable for recurring payments?",
// 			'multiOptions' => array (
// 				1 => 'Yes' ,
// 				0 => 'No'
// 			) ,
// 			'value' => 0,
// 		));

    $discountTypeArray = array("percentage" => "Percentage" , "price" => "Price");
		$this->addElement('Select', 'discount_type', array(
			'label' => 'Discount Type',
			'autocomplete' => 'off',
			'description' => 'Select the type of discount. (Note: If you select “Price” here, then you should enter the minimum order total price in the “Minimum Order Total Price” field below.)',
			'allowEmpty' => false,
			'multiOptions' => $discountTypeArray,
		));
		
		$this->addElement('Text', 'discount_value', array(
			'label' => 'Discount Value',
			'description' => 'Enter the value of the discount for above discount type. (Do not add any symbol. For a 10% discount, choose Percentage as discount type and enter discount value as 10.)',
			'maxlength' => 6,
			'autocomplete' => 'off',
			'required' => true,
			'allowEmpty' => false,
			'validators' => array(
				array('Int', true),
				array('GreaterThan', true, array(0)),
			),
    ));
        
    if(Engine_Api::_()->hasModuleBootstrap('sitegateway') || (Engine_Api::_()->hasModuleBootstrap('sitegateway') && $couponId && !$usgaeCount)) {
		$this->addElement('Select', 'duration', array(
			'label' => 'Duration',
			'description' => 'Select the discount duration that will be in effect.[This setting will be only applicable when users make payments using Stripe payment gateway]',
            'onChange' => 'showDurationOptions(this.value)',
            'required' => true,
			'allowEmpty' => false,
			'multiOptions' => array("once" => "Once" , "repeating" => "Multi-month", "forever" => "Forever"),
            'value' => 'once'
		));    
        
        $this->addElement('Integer', 'duration_in_months', array(
                'label' => 'Duration In Months',
                'description' => 'Specifies the number of months the discount will be in effect.[Note: This setting will work only when user make payment using stripe gateway.]',
                'maxlength' => 4,
                'autocomplete' => 'off'
        ));        
        
    }    

    $this->addElement('Text', 'minimum_order', array(
			'label' => 'Minimum Order Total Price',
			'description' => 'Enter the minimum total price for orders for which this coupon should be applicable. (Enter 0 for no minimum order total price limit.)',
			'maxlength' => 6,
			'autocomplete' => 'off',
			'value' => 0,
			'required' => true,
			'allowEmpty' => false,
		  'validators' => array(
				array('Float', true),
				new Engine_Validate_AtLeast(0),
			),
    ));

    $this->addElement('Text', 'maximum_per_code', array(
			'label' => 'Maximum Number of Redemptions (Per Code)',
			'description' => 'Enter the maximum number of times the code of this coupon can be used. (Enter 0 for unlimited. Note : This count will start from the time you save this form.)',
			'required' => true,
			'autocomplete' => 'off',
			'maxlength' => 4,
			'value' => 0,
			'validators' => array(
				array('Int', true),
			),
    ));

		$this->addElement('Text', 'maximum_per_user', array(
			'label' => 'Maximum Number of Redemptions (Per User)',
			'description' => 'Enter the maximum number of times the code of this coupon can be used by a single user. (Enter 0 for unlimited.)',
			'required' => true,
			'autocomplete' => 'off',
			'maxlength' => 3,
			'value' => 0,
			'validators' => array(
				array('Int', true),
			),
    ));

    // Element : restriction
    $this->addElement('Radio', 'restriction_type', array(
			'label' => 'Restrictions',
			'description' => 'Do you want to implement any User or Member Level restrictions on the use of this coupon code?',
			'multiOptions' => array(
				'0' => 'No, do not implement any restrictions.',
				'1' => 'Yes, allow this coupon code to be only used by certain Member Levels. (You can choose the Member Levels below.)',
				'2' => 'Yes, allow this coupon code to be only used by certain users. (You can enter the users below.)',
			),
			'value' => 0,
			'onclick' => 'showprofileOption(this.value)',
    ));

	  //PREPARE LEVELS
		$levels = Engine_Api::_()->getDbtable('levels', 'authorization')->fetchAll();
		$levelKey = array();
		foreach ($levels as $level) {
		  if ($level->type == 'public') {
        continue;
      }
			$levels_prepared[$level->getIdentity()] = $level->getTitle();
			$levelKey[] = $level->getIdentity();
		}
		reset($levels_prepared);

		$this->addElement('Multiselect', 'level_ids', array(
			'label' => 'Member Levels Restrictions',
			'description' => 'Select the Member Levels who should be able to use this coupon code. (Use CTRL-click to select multiple levels.)',
			'multiOptions' => $levels_prepared,
			'value' => $levelKey,
		));

    // init to
    $this->addElement('Text', 'user_ids_select',array(
        'label'=>'User Restrictions',
        'description' => 'Select the users who should be able to use this coupon code. (Using the auto-suggest fields, enter a maximum of 5 users.)',
        'autocomplete'=>'off'));
    Engine_Form::addDefaultDecorators($this->user_ids_select);

    // Init to Values
    $this->addElement('Hidden', 'user_ids', array(
      'label' => '',
      'order' => 150,
      'filters' => array(
        'HtmlEntities'
      ),
    ));
    Engine_Form::addDefaultDecorators($this->user_ids);

    $formUsages = 1;
    $contentModule = Engine_Api::_()->getDbtable('types', 'sitecoupon')->getEnabledModules($formUsages);
    $contentModuleArray = array();

		if( !empty($contentModule) ) {
			$contentModuleArray[0] = 'Select All';
			//$contentModuleArray['selectall'] = 'Select All';
			foreach ($contentModule as $modules) {
				$contentModuleArray[$modules['package_type']] = $modules['title'];
			}
		}

		$this->addElement('Select', 'package_type', array(
			'label' => 'Ordered Item',
			'description' => 'Select the ordered product type for which this coupon should be applicable. (You can choose particular plans / packages of the chosen product type below for which this coupon  should be applicable.)',
			'allowEmpty' => false,
			'required' => true,
			'onchange' => 'setModuleName(this.value)',
			'multiOptions' => $contentModuleArray,
		));

    // init to
    $this->addElement('Text', 'package_name_select',array(
			'label'=>'Package Name',
			'description' => 'Select the package corresponding Content Module from the auto-suggest Package field.',
			'autocomplete'=>'off'
    ));
    Engine_Form::addDefaultDecorators($this->package_name_select);

    // Init to Values
    $this->addElement('Hidden', 'package_ids', array(
      'label' => '',
      'order' => 180,
      'filters' => array(
        'HtmlEntities'
      ),
    ));
    Engine_Form::addDefaultDecorators($this->package_ids);

		$this->addElement('Checkbox', 'status', array(
				'description' => 'Coupon Status',
				'label' => 'Check this to enable / activate this coupon, uncheck to disable the coupon.',
				'value' => 1,
		));

		// Element: execute
    $this->addElement('Button', 'execute', array(
			'label' => 'Create Coupon',
			'type' => 'submit',
			'ignore' => true,
			'decorators' => array('ViewHelper'),
    ));

    // Element: cancel
    $this->addElement('Cancel', 'cancel', array(
			'label' => 'cancel',
			'prependText' => ' or ',
			'ignore' => true,
			'link' => true,
			'href' => Zend_Controller_Front::getInstance()->getRouter()->assemble(array('controller' => 'manage', 'action' => 'index')),
			'decorators' => array('ViewHelper'),
    ));

    // DisplayGroup: buttons
    $this->addDisplayGroup(array('execute', 'cancel'), 'buttons', array(
			'decorators' => array(
				'FormElements',
				'DivDivDivWrapper',
			)
    ));
  }
}