<?php

/**
 * SocialEngine
 *
 * @category   Application_Extensions
 * @package    Sitecoupon
 * @copyright  Copyright 2011-2012 BigStep Technologies Pvt. Ltd.
 * @license    http://www.socialengineaddons.com/license/
 * @version    $Id: Mail.php 6590 2012-06-24 9:40:21Z SocialEngineAddOns $
 * @author     SocialEngineAddOns
 */

class Sitecoupon_Form_Admin_Mail extends Engine_Form {

  public function init()	{
			
		$settings = Engine_Api::_()->getApi('settings', 'core');
	
	  // Decorators
    $this->loadDefaultDecorators();
	  $this->getDecorator('Description')->setOption('escape', false);

    $this->setTitle('Email Coupon')
        ->setDescription('Using this form, you will be able to select and send a coupon via email to your site\'s members and others by choosing who should receive your email. Emails are sent out using a queue system, so they will be sent out over time. An email will be sent to you when all emails have been sent.<br />You can enter your message below which is inserted into the email template chosen from "Settings" > "Mail Templates" section.<br />This can be a great way to motivate users and visitors to Subscribe to your website, or to create new Pages, Businesses and Advertisements on your website by using promotional coupon.');

    $settings = Engine_Api::_()->getApi('settings', 'core')->core_mail;
		if( !@$settings['queueing'] ) {
			$this->addElement('Radio', 'queueing', array(
				'label' => 'Utilize Mail Queue', 
        'order' => 1,
				'description' => 'Mail queueing permits the emails to be sent out over time, preventing your mail server from being overloaded by outgoing emails.  It is recommended you utilize mail queueing for large email blasts to help prevent negative performance impacts on your site.',
				'multiOptions' => array(
					1 => 'Utilize Mail Queue (recommended)',
					0 => 'Send all emails immediately (only recommended for less than 100 recipients).',
				),
				'value' => 1,
			));
		}
		
    $this->addElement('Text', 'from_address', array(
      'label' => 'From',
      'value' => (!empty($settings['from']) ? $settings['from'] : 'noreply@' . $_SERVER['HTTP_HOST']),
      'required' => true,
      'allowEmpty' => false,
      'validators' => array(
        'EmailAddress',
      )
    ));
    $this->from_address->getValidator('EmailAddress')->getHostnameValidator()->setValidateTld(false);

    $this->addElement('Text', 'from_name', array(
      'label' => 'From (name)',
      'required' => true,
      'allowEmpty' => false,
      'value' => (!empty($settings['name']) ? $settings['name'] : 'Site Administrator'),
    ));

    $couponId = Zend_Controller_Front::getInstance()->getRequest()->getParam('id', null);
		$disable = false;
		if (!empty($couponId)) {
			$disable = true;
		}
		
    // init to
    $this->addElement('Text', 'coupon_code',array(
			'label'=>'Coupon Code',
			'description' => 'Enter the coupon code. (Use the auto-suggest field to select the coupon code.)',
			'disable' => $disable,
			'autocomplete'=>'off'
    ));
    Engine_Form::addDefaultDecorators($this->coupon_code);

    // Init to Values
    $this->addElement('Hidden', 'coupon_id', array(
      'order' => 985,
      'label' => '',
    ));

    // Element : restriction
    $this->addElement('Radio', 'coupon_mail', array(
			'label' => 'Email Who?',
			'multiOptions' => array(
				'0' => 'Restricted Members (Email will be sent to users based on restrictions implemented on the selected coupon.)',
				'1' => 'Particular Members (You can enter the members using the auto-suggest below.)',
				'2' => 'Non-members (You can enter email addresses below.)',
			),
			'value' => 0,
			'onclick' => 'showprofileOption(this.value)',
    ));

    // init to
    $this->addElement('Text', 'user_ids',array(
        'label'=>'Members to Email',
        'autocomplete'=>'off'));
    Engine_Form::addDefaultDecorators($this->user_ids);

    // Init to Values
    $this->addElement('Hidden', 'toValues', array(
      'label' => '',
      'order' => 500,
      'filters' => array(
        'HtmlEntities'
      ),
    ));
    Engine_Form::addDefaultDecorators($this->toValues);

    // Init recipients
    $this->addElement('Textarea', 'recipients', array(
      'label' => 'Recipients',
      'description' => 'Enter email addresses separated by commas below.',
      //'required' => true,
      'allowEmpty' => false,
//       'validators' => array(
//         new Engine_Validate_Callback(array($this, 'validateEmails')),
//       ),
    ));
    //$this->recipients->getValidator('Engine_Validate_Callback')->setMessage('Please enter only valid email addresses.');
    $this->recipients->getDecorator('Description')->setOptions(array('placement' => 'APPEND'));


    $this->addElement('Text', 'subject', array(
      'label' => 'Subject',
      'value' => "Special Discount Coupon For You!",
      'required' => true,
      'allowEmpty' => false,
    ));

    $this->addElement('Textarea', 'body', array(
      'label' => 'Message Body',
      'value' => "Grab this chance and save money by using this Limited Period Discount Coupon.",
      'required' => true,
      'allowEmpty' => false,
      'description' => '(HTML or Plain Text)',
    ));
    $this->body->getDecorator('Description')->setOptions(array('placement' => 'APPEND'));

    $this->addElement('Textarea', 'body_text', array(
      'label' => 'Body (text)',
    ));

    $this->addDisplayGroup(array('body_text'), 'advanced', array(
      'decorators' => array(
        'FormElements',
        array('Fieldset', array('style' => 'display:none;')),
      ),
    ));

 		// Element: execute
    $this->addElement('Button', 'execute', array(
			'label' => 'Send Emails',
			'type' => 'submit',
			'ignore' => true,
			'decorators' => array('ViewHelper'),
    ));

    if (!empty($couponId)) {
			// Element: cancel
			$this->addElement('Cancel', 'cancel', array(
				'label' => 'skip',
				'prependText' => ' or ',
				'ignore' => true,
				'link' => true,
				'href' => Zend_Controller_Front::getInstance()->getRouter()->assemble(array('controller' => 'manage', 'action' => 'index')),
				'decorators' => array('ViewHelper'),
			));

			// DisplayGroup: buttons
			$this->addDisplayGroup(array('execute', 'cancel'), 'buttons', array(
				'decorators' => array(
					'FormElements',
					'DivDivDivWrapper',
				)
			));
    }
  }  
  
//   public function validateEmails($value)
//   {
//     // Not string?
//     if( !is_string($value) || empty($value) ) {
//       return false;
//     }
// 
//     // Validate emails
//     $validate = new Zend_Validate_EmailAddress();
// 
//     $emails = array_unique(array_filter(array_map('trim', preg_split("/[\s,]+/", $value))));
// 
//     if( empty($emails) ) {
//       return false;
//     }
//     
//     foreach( $emails as $email ) {
//       if( !$validate->isValid($email) ) {
//         return false;
//       }
//     }
// 
//     return true;
//   }
}