<?php

/**
 * SocialEngine
 *
 * @category   Application_Extensions
 * @package    Sitecoupon
 * @copyright  Copyright 2011-2012 BigStep Technologies Pvt. Ltd.
 * @license    http://www.socialengineaddons.com/license/
 * @version    $Id: Coupons.php 6590 2012-06-24 9:40:21Z SocialEngineAddOns $
 * @author     SocialEngineAddOns
 */
class Sitecoupon_Model_DbTable_Coupons extends Engine_Db_Table {

  protected $_name = 'sitecoupon_coupons';
  protected $_rowClass = 'Sitecoupon_Model_Coupon';


  /**
   * Get pages to add as item of the day
   * @param string $title : search text
   * @param int $limit : result limit
   */
  public function getCoupons($title, $limit = 10, $name) {

    //MAKE QUERY
    $select = $this->select()
			             ->from($this->info('name'), array('coupon_id', 'name', 'photo_id', 'code'));

		if ($name == 'mail') {
			$select->where('code  LIKE ? ', '%' . $title . '%')->order('code ASC');
		} 
		else {
			$select->where('startdate <= ?', date('y-m-d'))
						->where('expirydate >= ?', date('y-m-d'))
						->where('name  LIKE ? ', '%' . $title . '%')
						->orWhere('description  LIKE ? ', '%' . $title . '%')
						->where('status = ?', '1')
						->order('name ASC');
		}
		
		$select->limit($limit);
		
    //FETCH RESULTS
    return $this->fetchAll($select);
  }


  /**
   * Get code.
   *
   * @param string $code
   */
  public function getCode($code) {

    $couponsTableName = $this->info('name');

		//START CHECK FOR CODE.
		$couponsTableSelect = $this->select()
			->from($couponsTableName)
			->where($couponsTableName .'. code = ?', strtoupper($code))
			->where($couponsTableName .'. startdate <= ?', date('y-m-d'))
			->where($couponsTableName .'. expirydate >= ?', date('y-m-d'))
			->where($couponsTableName .'. status = ?', 1);
		return $this->fetchRow($couponsTableSelect);
  }
  
//   /**
//    * Get gateway coupon params.
//    *
//    * @param string $code
//    * @param int $values
//    */
//   public function getGatewayCouponParams($values, $code) {
// 
//     $expirydate = $values['expirydate'];
//     $params = array(
// 			'coupon_code' => $code,
// 			'date_expire' => date('Y-m-d', $expirydate),
// 			'new_code' => $values['code'],
// 			'type' => 'product',
// 			'minimum_purchase' => $values['minimum_order'],
// 			'product_id' => NULL,
//     );
//     
//     if ($values['discount_type'] == 'percentage') {
//       $params['percentage_off'] = (int)$values['discount_value'];
//     } else {
//       $params['value_off'] = (int)$values['discount_value'];
//     }
// 
//     if (empty($values['package_name']) && empty($values['package_type'])) {
//     	$modules_enabled = Engine_Api::_()->getApi( 'settings' , 'core' )->getSetting( 'modules.enabled' ) ;
// 			if (!empty($modules_enabled)) {
// 				$contentModuleEn = unserialize($modules_enabled) ;
// 			}
// 			$allproductId = array();
// 			foreach($contentModuleEn as $content) {
//         $package_ids = Engine_Api::_()->sitecoupon()->getPackageIds($content);
// 				if (!empty($package_ids)) {
// 					$allproductId = array_merge($allproductId, Engine_Api::_()->sitecoupon()->getProductIds($content, $package_ids));
// 				}
// 			}
// 			
// 			$params['product_id'] = $allproductId;
// 			
//       //$params['select_all'] = true;
//     } elseif(empty($values['package_name']) && !empty($values['package_type'])) {
// 				$package_ids = Engine_Api::_()->sitecoupon()->getPackageIds($values['package_type']);
// 				if ( !empty($package_ids) ) { 
// 					$params['product_id'] = Engine_Api::_()->sitecoupon()->getProductIds($values['package_type'], $package_ids);
// 				}
//     } else {
// 			$params['product_id'] = Engine_Api::_()->sitecoupon()->getProductIds($values['package_type'], explode(',', $values['package_name'])); //*/array(4665948939,4666012866);    
//     }
// 
//     return $params;
//   }



  /**
   * This is use for in the sitepage, comunityads and sitebusiness plugin create a new package. here we get the all package_type coupon ids and update the coupon.
   *
   * @param string $package_type
   */
  public function editCouponsAfterCreateNewPackage($package_type) {

    $couponTableName = $this->info('name');
    $select = $this->select()
            ->from($couponTableName)
            ->where($couponTableName . '.package_ids  IS NULL')
            ->where($couponTableName . '.package_type = ?',  $package_type);
    $coupon_ids = $this->fetchAll($select);

		//START TO CREATE COUPON IN 2CHECKOUT.
		$gateway = Engine_Api::_()->sitecoupon()->enabled2Checkout();
		if (!empty($gateway)) {

			foreach($coupon_ids as $couponcode) {

				$params = array(
					'coupon_code' => $couponcode['code'],
					'date_expire' => $couponcode['expirydate'],
					'type' => 'product',
					'percentage_off' => NULL,
					'value_off' => NULL,
					'minimum_purchase' => $couponcode['minimum_order'],
					'product_id' => NULL,
					'select_all' => false,
				);

				if ($couponcode['discount_type'] == 'percentage') {
				  unset($params['value_off']);
					$params['percentage_off'] = (int)$couponcode['discount_value'];
				}
				else {
				  unset($params['percentage_off']);
					$params['value_off'] = (int)$couponcode['discount_value'];
				}
				
				$package_ids = $this->getPackageIds($couponcode['package_type']);
				if (!empty($package_ids)) {
				  unset($params['select_all']);
					$params['product_id'] = $this->getProductIds($couponcode['package_type'], $package_ids);
				}
		
				//START TO CREATE COUPON IN 2CHECKOUT.
				//$gateway = Engine_Api::_()->sitecoupon()->enabled2Checkout();
				//if (!empty($gateway)) {
					$gatewayPlugin = $gateway->getGateway();
					
					if (!method_exists($gatewayPlugin, 'getService'))
						return;
						
					$gatewayPluginService = $gateway->getService();
					if (method_exists($gatewayPluginService, 'updateCoupon')) {
						$response = $gatewayPluginService->updateCoupon($couponcode['code'], $params);
					}
				//}
			}
		  return $couponIds;
	  }
		//END 2CHECKOUT WORK.
  }

  public function getProductIds($package_type, $package_ids) {
  
    $productIdsArray = array();
    $gateway = Engine_Api::_()->sitecoupon()->enabled2Checkout();

    if (!empty($gateway)) {
      $gatewayPlugin = $gateway->getGateway();

      if (!method_exists($gatewayPlugin, 'getService'))
        return;

      $gatewayPluginService = $gateway->getService();

      if (method_exists($gatewayPluginService, 'createCoupon')) {
        foreach ($package_ids as $packageid) {
          $response = $gatewayPluginService->detailVendorProduct(Engine_Api::_()->getItem($package_type, $packageid)->getProduct()->sku);
          $productIdsArray[] = $response['product_id'];
        }
      }
      return $productIdsArray;
    }
  }
  
  public function getPackageIds($package_type) {

    $packageTable = Engine_Api::_()->getItemTable($package_type);
    $packageTableName = $packageTable->info('name');
    $package_ids = $packageTable->select()
            ->from($packageTableName, array('package_id'))
            ->where($packageTableName . '.price > ?', 0)
            ->where($packageTableName . '.enabled = ?', 1);
    return $package_ids->query()->fetchAll(Zend_Db::FETCH_COLUMN);
  }
}
?>