<?php

/**
 * SocialEngine
 *
 * @category   Application_Extensions
 * @package    Sitecoupon
 * @copyright  Copyright 2011-2012 BigStep Technologies Pvt. Ltd.
 * @license    http://www.socialengineaddons.com/license/
 * @version    $Id: AdminCouponController.php 6590 2012-06-24 9:40:21Z SocialEngineAddOns $
 * @author     SocialEngineAddOns
 */
class Sitecoupon_AdminCouponController extends Core_Controller_Action_Admin {

  //FUNCTION FOR CREATE COUPONS.
  public function createAction() {

    $this->view->navigation = $navigation = Engine_Api::_()->getApi('menus', 'core')
            ->getNavigation('sitecoupon_admin_main', array(), 'sitecoupon_admin_create_coupon');

    $db = Zend_Db_Table_Abstract::getDefaultAdapter();

    $this->view->form = $form = new Sitecoupon_Form_Admin_Coupon();
    
    $this->view->duration = isset($_POST['duration']) ? $_POST['duration'] : '';

    if ($this->getRequest()->isPost() && $form->isValid($this->getRequest()->getPost())) {

			$table = Engine_Api::_()->getDbTable('coupons', 'sitecoupon');
			$tableName = $table->info('name');

      $values = $form->getValues();

      $this->view->restriction_type = $values['restriction_type'];
      $this->view->package_type = $values['package_type'];
      $this->view->end_settings = $values['end_settings'];

      //CHECK FOR CODE IS ALREADY IS EXISTS.
      $couponsTableSelect = $table->select()->from($tableName, 'code')->where($tableName . '. code = ?', $values['code'])->query()->fetchColumn();
      if (!empty($couponsTableSelect)) {
        $itemError = Zend_Registry::get('Zend_Translate')->_("Coupon Code * This coupon code already exists.");
        $form->addError($itemError);
        return;
      }

        if($this->view->duration == 'repeating') {
            $validator = new Zend_Validate_Int();
            if(!$validator->isValid($values['duration_in_months']) || (int)$values['duration_in_months'] <= 0) {
            $itemError = Zend_Registry::get('Zend_Translate')->_("Please enter the valid positive integer for 'duration in months' field.");
            $form->addError($itemError);
            return;
            }
        }        

      //CHECKING GATEWAY IS ENABLED OR NOT.
      $enabledGetway = Engine_Api::_()->sitecoupon()->enabled2Checkout();

      //HERE WE CAN CHECK CHANGES IN THE CLIENT.PHP FILE. IF 2CHECKOUT IS ENABLED AND CREATE COUPON FOR MULTI PRODUCT ID THEN THEASE CHNAGE IS MUST IN THE CLIENT.PHP FILE.
      $path = APPLICATION_PATH . '/application/libraries/Zend/Http/Client.php';
      $string = 'if (isset($this->paramsPost["product_id"]) && is_array($this->paramsPost["product_id"])) {';
      if (!Engine_Api::_()->sitecoupon()->isContentInFile($path, $string) && (!empty($enabledGetway))) {
        $itemError = Zend_Registry::get('Zend_Translate')->_("You have enabled 2Checkout payment gateway on your site after creating packages / plans for different product types. Please edit such packages / plans and click on “Save Changes” button to send their entries to 2Checkout. (Note: If you are not aware of such packages / plans, then edit all the packages / plans created on your site for the product types enabled from Global Settings.)");
        $form->addError($itemError);
        return;
      }

      //CHECK FOR EXPIRY DATE.
      $expiryDate = strtotime($values['expirydate']);
      $today = strtotime(date('Y-m-d'));

      $startDate = strtotime($values['startdate']);
      if ($startDate < $today) {
        $itemError = Zend_Registry::get('Zend_Translate')->_("Start Date * This should should be greater than today’s date.");
        $form->addError($itemError);
        return;
      }

      if (!empty($values['end_settings']) && ($expiryDate == $today)) {
        $itemError = Zend_Registry::get('Zend_Translate')->_("Expiry Date * This should be greater than today’s date.");
        $form->addError($itemError);
        return;
      }

      //CHECK FOR MINIMUM VALUE OR DISCOUNT VALUE.
      if ($values['discount_type'] == 'percentage' && ($values['discount_value'] > 100)) {
        $itemError = Zend_Registry::get('Zend_Translate')->_("Discount Value * This value should be less than 100.");
        $form->addError($itemError);
        return;
      }

      if ($values['discount_type'] == 'price' && ($values['minimum_order'] < $values['discount_value'])) {
        $itemError = Zend_Registry::get('Zend_Translate')->_("Minimum Order Total Price should be greater than the discount value.");
        $form->addError($itemError);
        return;
      }

      if (!empty($values['maximum_per_code']) && $values['maximum_per_code'] <= $values['maximum_per_user']) {
        $itemError = Zend_Registry::get('Zend_Translate')->_("Maximum number of Redemptions (Per Code) * This should be greater than Maximum Number of Redemptions (Per User).");
        $form->addError($itemError);
        return;
      }

      //CHECK FOR NOT SELECT THE MODULE NAME.
//       if (empty($values['package_type'])) {
//         $itemError = Zend_Registry::get('Zend_Translate')->_("Please select module name.");
//         $form->addError($itemError);
//         return;
//       }

      //CHECK FOR NOT SELECT THE USER NAME.
      if ($values['restriction_type'] == '2' && (empty($values['user_ids']))) {
        $itemError = Zend_Registry::get('Zend_Translate')->_("User Restrictions * Please select users - it is required.");
        $form->addError($itemError);
        return;
      }

      switch ($values['package_type']) {
        case 'payment_package':
          $resource_type = 'payment_subscription';
        break;
        case 'sitepage_package':
          $resource_type = 'sitepage_page';
        break;
        case 'sitebusiness_package':
          $resource_type = 'sitebusiness_business';
        break;
        case 'sitegroup_package':
          $resource_type = 'sitegroup_group';
        break;
        case 'sitestore_package':
          $resource_type = 'sitestore_store';
        break;
        case 'package':
          $resource_type = 'userads';
        break;
      }


      //CHECK FOR DISCOUNT VALUE.
			if ($values['discount_type'] == 'price') {
			
				if (!empty($values['discount_value'])) {
					$priceValue = Engine_Api::_()->sitecoupon()->checkDiscountValue($resource_type, $values['discount_value'], '');
					if (empty($priceValue)) {
						$itemError = Zend_Registry::get('Zend_Translate')->_("Discount Value * There is currently no product item having price greater than the discount value mentioned by you.");
						$form->addError($itemError);
						return;
					}
				}
				
				if(!empty($values['minimum_order'])) {
					$priceValue = Engine_Api::_()->sitecoupon()->checkDiscountValue($resource_type, '', $values['minimum_order']);
					if (empty($priceValue)) {
						$itemError = Zend_Registry::get('Zend_Translate')->_("Minimum order price is less then to your product price.");
						$form->addError($itemError);
						return;
					}
				}
			}

    //  $form->removeElement('user_ids');
     // $form->removeElement('package_ids');

      if ($values['end_settings'] == '0') {
        $values['expirydate'] = '2250-01-01';
      }

      $form->removeElement('end_settings');
      if (empty($values['package_ids'])) {
        $values['package_ids'] = NULL;
      }
      
      $values['code'] = str_replace(" ", "", $values['code']);
      $values['code'] = strtoupper($values['code']);

      if (empty($values['restriction_type'])) {
        $values['level_ids'] = NULL;
        $values['user_ids'] = NULL;
      } else if ($values['restriction_type'] == 1) {
        $values['user_ids'] = NULL;
        $values['level_ids'] = join(",", $values['level_ids']);
      } else if ($values['restriction_type'] == 2) {
        $values['level_ids'] = NULL;
      }

      //BEGIN TRANSACTION
      $db = Engine_Db_Table::getDefaultAdapter();
      $db->beginTransaction();
      try {
				include APPLICATION_PATH . '/application/modules/Sitecoupon/controllers/license/license2.php';

        if (($values['discount_type'] == 'percentage' && ($values['discount_value'] != 100)) || $values['discount_type'] == 'price') {

					//START TO CREATE COUPON IN 2CHECKOUT.
					$gateway = Engine_Api::_()->sitecoupon()->enabled2Checkout();

					if (!empty($gateway)) {
						$gatewayPlugin = $gateway->getGateway();

						if (!method_exists($gatewayPlugin, 'getService'))
							return;

						$gatewayPluginService = $gateway->getService();
						if (method_exists($gatewayPluginService, 'createCoupon')) {

							$couponparams = $coupon->getGatewayCouponParams();
							//CHECK FOR DO NOT CREATE FREE COUPON ON THE 2CHECKOUT SITE.
							if(!empty($couponparams['product_id'])) {
								$response = $gatewayPluginService->createCoupon($couponparams);
							}
						}
					}
                    
                    if(Engine_Api::_()->hasModuleBootstrap('sitegateway')) {
                        $gatewaysTable = Engine_Api::_()->getDbtable('gateways', 'payment');
                            
                        foreach( $gatewaysTable->fetchAll(array('enabled = ?' => 1)) as $gateway ) {
                            $gatewayPlugin = $gateway->getGateway();

  
                            if( method_exists($gatewayPlugin, 'createCoupon') && substr($gateway->plugin, 0, 27) == 'Sitegateway_Plugin_Gateway_') { 
                              $gatewayPlugin->createCoupon($values);
                            }
                        }                        
                    }
        }
        //END 2CHECKOUT WORK.
        $db->commit();
        //ADD PHOTO
        if (!empty($values['photo'])) {
          $coupon->setPhoto($form->photo);
        }
      } catch (Exception $e) {
        $db->rollBack();
        
				if (!empty($coupon)) {
					$coupon->delete();
				}
				
        $MESSAGE = $e->getMessage();
        if (strpos($MESSAGE, "API Error: [PARAMETER_INVALID] value_off") !== false) { 
         $itemError = Zend_Registry::get('Zend_Translate')->_("Discount Value * This value should not be greater than the price of any product item.");
         $form->addError($itemError);
         return;
        }
        
        if ($MESSAGE == 'API Error: [RECORD_NOT_FOUND] Unable to find product.') {
         $itemError = Zend_Registry::get('Zend_Translate')->_("You have enabled 2Checkout payment gateway on your site after creating packages / plans for different product types. Please edit the packages / plans and click on “Save Changes” button to send their entries to 2Checkout.");
         $form->addError($itemError);
         return;
        }
        else {
          $form->addError($MESSAGE);
          return;
        }
        //throw $e;
      }

      $today = strtotime(date('Y-m-d'));
      $startDate = strtotime($coupon['startdate']);

      if ($startDate == $today) {
        return $this->_helper->redirector->gotoRoute(array('controller' => 'message', 'action' => 'mail', 'id' => $coupon['coupon_id'], 'code' => $coupon['code']));
      } 
      else {
				return $this->_helper->redirector->gotoRoute(array('controller' => 'manage', 'action' => 'index'));
      }
    }
  }

  //FUNCTION EDIT COUPON.
  public function editAction() {

    //CHECK FOR COUPON USED HOW MANY TIME (IF NOT USED ONE TIME ADMIN EDIT EVERY THINGS).
    $this->view->usgaeCount = $usgaeCount = Engine_Api::_()->getDbtable('usages', 'sitecoupon')->getOneTimeUsages($this->_getParam('coupon_id'));

    $this->view->navigation = Engine_Api::_()->getApi('menus', 'core')
            ->getNavigation('sitecoupon_admin_main', array(), 'sitecoupon_admin_manage_coupon');

    $db = Zend_Db_Table_Abstract::getDefaultAdapter();
    $this->view->form = $form = new Sitecoupon_Form_Admin_Couponedit();

    //SHOW PRE-FIELD FORM 
    //GET THE COUPO ID.
    $coupon = Engine_Api::_()->getItem('sitecoupon_coupons', $this->_getParam('coupon_id'));
    $resultArray = $coupon->toArray();

    $this->view->package_type = $resultArray['package_type'];
    $this->view->restriction_type = $resultArray['restriction_type'];
    $this->view->end_settings = $resultArray['end_settings'];
    $this->view->user_ids = $values['user_ids'];
    
    if(Engine_Api::_()->hasModuleBootstrap('sitegateway')) {
        $this->view->duration = $coupon->duration;    
    }

    //CHECK FOR SELECTED CONTENT MODULE.
    if (!empty($resultArray['package_type'])) {
    
      $packageIds = explode(",", $resultArray['package_ids']);
      
      $moduleTable = Engine_Api::_()->getItemTable($resultArray['package_type']);
      $moduleTableName = $moduleTable->info('name');
      
      $select = $moduleTable->select()
              ->from($moduleTableName, array('title', 'package_id'))
              ->where($moduleTableName . '.package_id IN (?)', (array) $packageIds);
      $moduleResults = $select->query()->fetchAll();
      
      $packageArray = array();

      foreach ($moduleResults as $moduleResult) {
        $packageArray[$moduleResult['package_id']] = $moduleResult['title'];
      }

      $this->view->packageArray = $packageArray;
// 			$packageTitleName = implode(", ", $packageArray);
// 			if (empty($packageTitleName)) {
// 				$form->packagename->setDescription('This coupon is valid for all package for the selected Content Module.');
// 			} else {
// 				//$form->package_ids->setDescription($packageTitleName);
// 			}
    }
    
    $this->view->package_ids = $resultArray['package_ids'];

    //CHECK FOR RESTRICTION.
    if ($resultArray['restriction_type'] == 1) {
      $levels = explode(",", $resultArray['level_ids']);
      $resultArray['level_ids'] = $levels;
    } 
    elseif ($resultArray['restriction_type'] == 2) {
      $userArray = array();
      $userIds = explode(",", $resultArray['user_ids']);
      
      $usersTable = Engine_Api::_()->getDbtable('users', 'user');
      $usersTableName = $usersTable->info('name');
      
      $select = $usersTable->select()
              ->from($usersTableName, array('displayname', 'user_id'))
              ->where($usersTableName . '.user_id IN (?)', (array) $userIds);
      $usersResults = $select->query()->fetchAll();
      
      foreach ($usersResults as $usersResult) {
        $userArray[$usersResult['user_id']] = $usersResult['displayname'];
      }
      
      $this->view->userArray = $userArray;
//       $displayName = implode(", ", $userArray);
//       $form->user_name->setDescription($displayName);
    }

    $resultArray['startdate'] = $resultArray['startdate'] . ' 00:00:00';
    $resultArray['expirydate'] = $resultArray['expirydate'] . ' 00:00:00';

    //IF NOT POST OR FORM NOT VALID THAN RETURN AND POPULATE THE FROM.
    if (!$this->getRequest()->isPost()) {
      $form->populate($resultArray);
      return;
    }

    //IF NOT POST OR FORM NOT VALID THAN RETURN
    if (!$form->isValid($this->getRequest()->getPost())) {
      return;
    }

    //GET FORM VALUES
    $values = $form->getValues();
    
    if(Engine_Api::_()->hasModuleBootstrap('sitegateway')) {
        $this->view->duration = $values['duration'];    
    }    

    //HERE, WE CAN CHECK COUPON WIIL BE USE AT ONE TIME, IF NOT USE ONE TIME THEN ADMIN CAN EDIT EVERY THINGS.
    if (empty($usgaeCount)) {

      //CHECK FOR MINIMUM OR DISCOUNT VALUE.
      if ($values['discount_type'] == 'price' && ($values['minimum_order'] < $values['discount_value'])) {
        $itemError = Zend_Registry::get('Zend_Translate')->_("Minimum Order Total Price should be greater than the discount value.");
        $form->addError($itemError);
        return;
      }

      //CHECK FOR EXPIRY DATE.
      $expiryDate = strtotime($values['expirydate']);
      $today = strtotime(date('Y-m-d'));

// 			$startdate  = strtotime($values['startdate']);
// 		  if ($startdate < $today) {
// 				$itemError = Zend_Registry::get('Zend_Translate')->_("Start Date * This should should be greater than today’s date.");
// 				$form->addError($itemError);
// 				return;
// 			}

      if (!empty($values['end_settings']) && ($expiryDate == $today)) {
        $itemError = Zend_Registry::get('Zend_Translate')->_("Expiry Date * This should be greater than today’s date.");
        $form->addError($itemError);
        return;
      }

      //CHECK FOR MINIMUM OR DISCOUNT VALUE.
      if ($values['discount_type'] == 'percentage' && ($values['discount_value'] > 100)) {
        $itemError = Zend_Registry::get('Zend_Translate')->_("Discount Value * This value should be less than 100.");
        $form->addError($itemError);
        return;
      }
      
        if($this->view->duration == 'repeating') {
            $validator = new Zend_Validate_Int();
            if(!$validator->isValid($values['duration_in_months']) || (int)$values['duration_in_months'] <= 0) {
            $itemError = Zend_Registry::get('Zend_Translate')->_("Please enter the valid positive integer for 'duration in months' field.");
            $form->addError($itemError);
            return;
            }
        }         

      //CHECK FOR percantage.
      if (!empty($values['maximum_per_code']) && (!empty($values['maximum_per_code'])) && $values['maximum_per_code'] <= $values['maximum_per_user']) {
        $itemError = Zend_Registry::get('Zend_Translate')->_("Maximum number of Redemptions (Per Code) * This should be greater than Maximum Number of Redemptions (Per User).");
        $form->addError($itemError);
        return;
      }

      //CHECK FOR NOT SELECT THE MODULE NAME.
//       if (empty($values['package_type'])) {
//         $itemError = Zend_Registry::get('Zend_Translate')->_("Please select module name.");
//         $form->addError($itemError);
//         return;
//       }

      //CHECK FOR NOT SELECT THE MODULE NAME.
      if ($values['restriction_type'] == '2' && (empty($values['user_ids']))) {
        $itemError = Zend_Registry::get('Zend_Translate')->_("User Restrictions * Please select users - it is required.");
        $form->addError($itemError);
        return;
      }

      switch ($values['package_type']) {
        case 'payment_package':
          $resource_type = 'payment_subscription';
        break;
        case 'sitepage_package':
          $resource_type = 'sitepage_page';
        break;
        case 'sitebusiness_package':
          $resource_type = 'sitebusiness_business';
        break;
        case 'sitegroup_package':
          $resource_type = 'sitegroup_group';
        break;
        case 'sitestore_package':
          $resource_type = 'sitestore_store';
        break;
        case 'package':
          $resource_type = 'userads';
        break;
      }

      //CHECK FOR DISCOUNT VALUE.
			if ($values['discount_type'] == 'price') {
			
				if (!empty($values['discount_value'])) {
					$priceValue = Engine_Api::_()->sitecoupon()->checkDiscountValue($resource_type, $values['discount_value'], '');
					if (!empty($priceValue)) {
						$itemError = Zend_Registry::get('Zend_Translate')->_("Discount Value * There is currently no product item having price greater than the discount value mentioned by you.");
						$form->addError($itemError);
						return;
					}
				}
				
				if(!empty($values['minimum_order'])) {
					$priceValue = Engine_Api::_()->sitecoupon()->checkDiscountValue($resource_type, '', $values['minimum_order']);
					if (empty($priceValue)) {
						$itemError = Zend_Registry::get('Zend_Translate')->_("Minimum order price is less then to your product price.");
						$form->addError($itemError);
						return;
					}
				}
			}

      if (empty($values['package_ids'])) {
        $values['package_ids'] = NULL;
      }

      if (empty($values['package_type'])) {
        $values['package_ids'] = NULL;
      }

      if (empty($values['restriction_type'])) {
        $values['level_ids'] = NULL;
        $values['user_ids'] = NULL;
      } 
      else if ($values['restriction_type'] == 1) {
        $values['user_ids'] = NULL;
        $values['level_ids'] = join(",", $values['level_ids']);
      } 
      else if ($values['restriction_type'] == 2) {
        $values['level_ids'] = NULL;
      }
      
      $values['code'] = str_replace(" ", "", $values['code']);
      $values['code'] = strtoupper($values['code']);
    } 
    else {
      unset($values['code']);
      unset($values['discount_type']);
      unset($values['discount_value']);
      unset($values['restriction_type']);
      unset($values['level_ids']);
      unset($values['package_type']);
      unset($values['level_ids']);
      unset($values['package_ids']);
      unset($values['user_name']);
      unset($values['packagename']);
    }

    if ($values['end_settings'] == '0') {
      $values['expirydate'] = '2250-01-01';
    }

    $form->removeElement('user_ids');
    $form->removeElement('package_name_select');
    $form->removeElement('end_settings');
    $db = Engine_Db_Table::getDefaultAdapter();
    $db->beginTransaction();
    try {
      $coupon->setFromArray($values);
      $coupon->save();

      if (!empty($values['photo'])) {
        $coupon->setPhoto($form->photo);
      }

      if (!empty($usgaeCount)) {
        $params = $coupon->getGatewayCouponParams($resultArray);
      } 
      else {
        $params = $coupon->getGatewayCouponParams($values);
        $params['date_expire'] = $params['date_expire']; //date("Y-m-d", strtotime($params['date_expire']));
        if (empty($values['package_ids']) || empty($values['package_type'])) {
          $params['select_all'] = true;
          $params['product_id'] = array();
        }
      }

      //START TO CREATE COUPON IN 2CHECKOUT.
      $gateway = Engine_Api::_()->sitecoupon()->enabled2Checkout();

      if (!empty($gateway)) {
        $gatewayPlugin = $gateway->getGateway();

        if (!method_exists($gatewayPlugin, 'getService'))
          return;

        $gatewayPluginService = $gateway->getService();

				if (method_exists($gatewayPluginService, 'detailCoupon')) {
					$response = $gatewayPluginService->detailCoupon($resultArray['code']);
					
					if (empty($response)) {
					
						if (method_exists($gatewayPluginService, 'createCoupon')) {
							$response = $gatewayPluginService->createCoupon($coupon->getGatewayCouponParams());
						}
					}
					else {
						if (isset($params['select_all']) && empty($params['select_all'])) {
							unset($params['select_all']);
						}
						
						if ($params['date_expire'] == '2250-01-01 00:00:00' || $params['date_expire'] == '1970-01-01') {
							if ($params['date_expire'] == '2250-01-01 00:00:00') {
								$params['date_expire'] = '2250-01-01';
							} else {
								$params['date_expire'] = date("Y-m-d", strtotime($params['date_expire'])); 
							}
							$response = $gatewayPluginService->updateCoupon($resultArray['code'], $params);
						}
					}
				}
      }
      
        if(Engine_Api::_()->hasModuleBootstrap('sitegateway') && !$usgaeCount) {
            $gatewaysTable = Engine_Api::_()->getDbtable('gateways', 'payment');
            foreach( $gatewaysTable->fetchAll(array('enabled = ?' => 1)) as $gateway ) {
                $gatewayPlugin = $gateway->getGateway();

                if( method_exists($gatewayPlugin, 'updateCoupon') && substr($gateway->plugin, 0, 27) == 'Sitegateway_Plugin_Gateway_') { 
                  $gatewayPlugin->updateCoupon($resultArray['code'], $coupon->toArray());
                }
            }                        
        }      

      //END 2CHECKOUT WORK.
      $db->commit();
    } catch (Exception $e) {
      $db->rollBack();
      throw $e;
    }
    return $this->_helper->redirector->gotoRoute(array('controller' => 'manage', 'action' => 'index'));
  }
  
  //GET THE PACKAGE.
  public function getpackageAction() {

    //GET THE SUGGEST PAGES
    $packageTable = Engine_Api::_()->getItemTable($this->_getParam('package_type'));
    $packageTableName = $packageTable->info('name');

    $select = $packageTable->select()
            ->where('title   LIKE ? ', '%' . $this->_getParam('package_name_select') . '%')
            ->where($packageTableName . '.price > ?', 0)
            ->where($packageTableName . '.enabled = ?', 1)
            ->order('title  ASC')
            ->limit('40');
    $packages = $packageTable->fetchAll($select);

    $data = array();

    foreach ($packages as $package) {
      $data[] = array(
				'id' => $package->package_id,
				'label' => $package->title,
      );
    }

    return $this->_helper->json($data);
    $data = Zend_Json::encode($data);
    $this->getResponse()->setBody($data);
  }
}
?>