<?php

/**
 * SocialEngine
 *
 * @category   Application_Extensions
 * @package    Sitecrowdfunding
 * @copyright  Copyright 2017-2021 BigStep Technologies Pvt. Ltd.
 * @license    http://www.socialengineaddons.com/license/
 * @version    $Id: Cash.php 2017-03-27 9:40:21Z SocialEngineAddOns $
 * @author     SocialEngineAddOns
 */
class Sitecrowdfunding_Plugin_Gateway_Cash extends Engine_Payment_Plugin_Abstract {

    protected $_gatewayInfo;
    protected $_gateway;

    /**
     * Constructor
     */
    public function __construct(Zend_Db_Table_Row_Abstract $gatewayInfo) {
        $this->_gatewayInfo = $gatewayInfo;
    }

    /**
     * Get the service API
     *
     * @return Engine_Service_PayPal
     */
    public function getService() {
        return $this->getGateway()->getService();
    }

    /**
     * Get the gateway object
     *
     * @return Engine_Payment_Gateway
     */
    public function getGateway() {
        if (null == $this->_gateway) {
            $class = 'Engine_Payment_Gateway_Testing';
            Engine_Loader::loadClass($class);
            $gateway = new $class(array(
                'config' => (array) $this->_gatewayInfo->config,
                'testMode' => $this->_gatewayInfo->test_mode,
                'currency' => Engine_Api::_()->getApi('settings', 'core')->getSetting('payment.currency', 'USD'),
            ));
            if (!($gateway instanceof Engine_Payment_Gateway)) {
                $error_msg1 = Zend_Registry::get('Zend_Translate')->_('Plugin class not instance of Engine_Payment_Gateway');
                throw new Engine_Exception($error_msg1);
            }
            $this->_gateway = $gateway;
        }

        return $this->_gateway;
    }

    // Actions

    /**
     * Create a transaction object from specified parameters
     *
     * @return Engine_Payment_Transaction
     */
    public function createTransaction(array $params) {
        $transaction = new Engine_Payment_Transaction($params);
        $transaction->process($this->getGateway());
        return $transaction;
    }

    /**
     * Create an ipn object from specified parameters
     *
     * @return Engine_Payment_Ipn
     */
    public function createIpn(array $params) {
        $ipn = new Engine_Payment_Ipn($params);
        $ipn->process($this->getGateway());
        return $ipn;
    }

    public function detectIpn(array $params)
    {
        return false; // Never detect this as an IPN, or it will break real IPNs
    }

    // SEv4 Specific

    /**
     * Create a transaction for a subscription
     *
     * @param User_Model_User $user
     * @param Zend_Db_Table_Row_Abstract $subscription
     * @param Zend_Db_Table_Row_Abstract $package
     * @param array $params
     * @return Engine_Payment_Gateway_Transaction
     */
    public function createSubscriptionTransaction(User_Model_User $user, Zend_Db_Table_Row_Abstract $subscription, Payment_Model_Package $package, array $params = array()) {
        
    }

    /**
     * Process return of subscription transaction
     *
     * @param Payment_Model_Order $order
     * @param array $params
     */
    public function onSubscriptionTransactionReturn(
    Payment_Model_Order $order, array $params = array()) {
        
    }

    /**
     * Create a transaction for order
     *
     * @param User_Model_User $user
     * @param $order_id
     * @param array $params
     * @return Engine_Payment_Gateway_Transaction
     */
    public function createUserOrderTransaction($parent_order_id, array $params = array(), $user = NULL) {
        // Create transaction
        $transaction = $this->createTransaction($params);
        return $transaction;
    }

    /**
     * Process return of user order transaction
     *
     * @param Payment_Model_Order $order
     * @param array $params
     */
    public function onUserOrderTransactionReturn(Payment_Model_Order $order, array $params = array()) {
    }

    public function createProjectTransaction(User_Model_User $user, Zend_Db_Table_Row_Abstract $project, Sitecrowdfunding_Model_Package $package, array $params = array()) {
        // Create transaction
        $transaction = $this->createTransaction($params);

        return $transaction;
    }

    /**
     * Process return of subscription transaction
     *
     * @param Payment_Model_Order $order
     * @param array $params
     */
    public function onPageTransactionReturn(
    Payment_Model_Order $order, array $params = array()) {
        // Check that gateways match
        if ($order->gateway_id != $this->_gatewayInfo->gateway_id) {
            $error_msg2 = Zend_Registry::get('Zend_Translate')->_('Gateways do not match');
            throw new Engine_Payment_Plugin_Exception($error_msg2);
        }

        // Get related info
        $user = $order->getUser();
        $projectOtherinfo = Engine_Api::_()->getDbTable('otherinfo', 'sitecrowdfunding')->getOtherinfo($order->source_id);
        $project = Engine_Api::_()->getItem('sitecrowdfunding_project', $order->source_id);
        $package = $project->getPackage();

        // Check subscription state
        if ($project->status == 'trial') {
            return 'active';
        } else if ($project->status == 'pending') {
            return Zend_Registry::get('Zend_Translate')->_('pending');
        }

        // Check for cancel state - the user cancelled the transaction
        if ($params['state'] == 'cancel') {
            // Cancel order and subscription?
            $order->onCancel();
            $project->onPaymentFailure();
            // Error
            $error_msg3 = Zend_Registry::get('Zend_Translate')->_('Your payment has been cancelled and not been charged. If this is not correct, please try again later.');
            throw new Payment_Model_Exception($error_msg3);
        }

        // Update order with profile info and complete status?
        $order->state = 'pending';
        $order->gateway_transaction_id = crc32(microtime() . $order->order_id);
        $order->save();

        $paymentStatus = 'pending';
        // Insert transaction
        $transactionsTable = Engine_Api::_()->getDbtable('transactions', 'sitecrowdfunding');
        $transaction_id = $transactionsTable->insert(array(
            'user_id' => $order->user_id,
            'gateway_id' => $this->_gatewayInfo->gateway_id,
            'timestamp' => new Zend_Db_Expr('NOW()'),
            'payment_order_id' => $order->order_id,
            'type' => 'payment',
            'source_type' => $project->getType(),
            'source_id' => $project->getIdentity(),
            'state' => $paymentStatus,
            'gateway_transaction_id' => crc32(microtime() . $order->order_id),
            'amount' => $package->price, // @todo use this or gross (-fee)?
            'currency' => $this->getGateway()->getCurrency(),
        ));

        $transaction = Engine_Api::_()->getItem('sitecrowdfunding_transaction', $transaction_id);
        if(isset($_FILES['file']) && !empty($_FILES['file']['name'])) {
            $transaction->setPhoto($_FILES['file']);
        }

            // Check payment status
        if ($paymentStatus == 'pending') {

            // Update subscription info
            $projectOtherinfo->gateway_id = $this->_gatewayInfo->gateway_id;
            $projectOtherinfo->gateway_profile_id = crc32(microtime() . $order->order_id);
            $projectOtherinfo->save();

            // Payment success
            $project->onPaymentSuccess();

            // send notification
            if ($project->didStatusChange()) {
                $httpVar = _ENGINE_SSL ? 'https://' : 'http://';
                $project_baseurl = $httpVar . $_SERVER['HTTP_HOST'] .
                  Zend_Controller_Front::getInstance()->getRouter()->assemble(array('project_id' => $project->project_id, 'slug' => $project->getSlug()), "sitecrowdfunding_entry_view", true);

                Engine_Api::_()->getApi('mail', 'core')->sendSystem($user, 'sitecrowdfunding_payment_package_pending', array(
                  'package_title' => $package->title,
                  'package_description' => $package->description,
                  'package_terms' => $package->getPackageDescription(),
                  'object_link' => $project_baseurl

                ));
            }

            return 'pending';
        } else {

            // Update subscription info
            $projectOtherinfo->gateway_id = $this->_gatewayInfo->gateway_id;
            $projectOtherinfo->gateway_profile_id = crc32(microtime() . $order->order_id);
            $projectOtherinfo->save();

            // Payment pending
            $project->onPaymentPending();

            // send notification
            if ($project->didStatusChange()) {
                $httpVar = _ENGINE_SSL ? 'https://' : 'http://';
                $project_baseurl = $httpVar . $_SERVER['HTTP_HOST'] .
                  Zend_Controller_Front::getInstance()->getRouter()->assemble(array('project_id' => $project->project_id, 'slug' => $project->getSlug()), "sitecrowdfunding_entry_view", true);

                Engine_Api::_()->getApi('mail', 'core')->sendSystem($user, 'sitecrowdfunding_payment_package_pending', array(
                  'package_title' => $package->title,
                  'package_description' => $package->description,
                  'package_terms' => $package->getPackageDescription(),
                  'object_link' => $project_baseurl

                ));
            }

            return 'pending';
        }
    }

    /**
     * Create a transaction for user payment request
     *
     * @param User_Model_User $user
     * @param $request_id
     * @param array $params
     * @return Engine_Payment_Gateway_Transaction
     */
    public function createUserRequestTransaction(User_Model_User $user, $request_id, array $params = array()) {
    }

    /**
     * Create a transaction for user payment request
     *
     * @param User_Model_User $user
     * @param $request_id
     * @param array $params
     * @return Engine_Payment_Gateway_Transaction
     */
    public function createProjectBillTransaction($project_id, $bill_id, $params = array()) {
    }

    /**
     * Process return of user order transaction
     *
     * @param Payment_Model_Order $order
     * @param array $params
     */
    public function onProjectBillTransactionReturn(Payment_Model_Order $order, array $params = array()) {
    }

    /**
     * Process return of user order transaction
     *
     * @param Payment_Model_Order $order
     * @param array $params
     */
    public function onUserRequestTransactionReturn(Payment_Model_Order $order, array $params = array()) {
    }

    /**
     * Process ipn of subscription transaction
     *
     * @param Payment_Model_Order $order
     * @param Engine_Payment_Ipn $ipn
     */
    public function onSubscriptionTransactionIpn(
    Payment_Model_Order $order, Engine_Payment_Ipn $ipn) {
        
    }

    /**
     * Process ipn of page transaction
     *
     * @param Payment_Model_Order $order
     * @param Engine_Payment_Ipn $ipn
     */
    public function onPageTransactionIpn(
    Payment_Model_Order $order, Engine_Payment_Ipn $ipn) {

    }

    /**
     * Cancel a subscription (i.e. disable the recurring payment profile)
     *
     * @params $transactionId
     * @return Engine_Payment_Plugin_Abstract
     */
    public function cancelSubscription($transactionId, $note = null) {
        
    }

    public function cancelProject($transactionId, $note = null) {
        return $this;
    }

    /**
     * Generate href to a project detailing the order
     *
     * @param string $transactionId
     * @return string
     */
    public function getOrderDetailLink($orderId) {
        return false;
    }

    /**
     * Generate href to a page detailing the transaction
     *
     * @param string $transactionId
     * @return string
     */
    public function getTransactionDetailLink($transactionId) {
        return false;
    }

    /**
     * Get raw data about an order or recurring payment profile
     *
     * @param string $orderId
     * @return array
     */
    public function getOrderDetails($orderId) {
        return false;
    }

    /**
     * Get raw data about a transaction
     *
     * @param $transactionId
     * @return array
     */
    public function getTransactionDetails($transactionId) {
        return false;
    }

    // IPN

    /**
     * Process an IPN
     *
     * @param Engine_Payment_Ipn $ipn
     * @return Engine_Payment_Plugin_Abstract
     */
    public function onIpn(Engine_Payment_Ipn $ipn) {
        throw new Engine_Payment_Plugin_Exception('Not implemented');
    }

    // Forms
    public function getGatewayUserForm(){
        $form = new Payment_Form_Gateway_Cash(array('settings'=>$this->_gatewayInfo->config));
        $form->populate((array) $this->_gatewayInfo->config);
        return $form;
    }

    /**
     * Get the admin form for editing the gateway info
     *
     * @return Engine_Form
     */
    public function getAdminGatewayForm() {
        return new Payment_Form_Admin_Gateway_Cash();
    }

    public function processAdminGatewayForm(array $values) {
        return $values;
    }

}
