<?php

/**
 * SocialEngine
 *
 * @category   Application_Extensions
 * @package    Sitecrowdfunding
 * @copyright  Copyright 2017-2021 BigStep Technologies Pvt. Ltd.
 * @license    http://www.socialengineaddons.com/license/
 * @version    $Id: PhotoController.php 2017-03-27 9:40:21Z SocialEngineAddOns $
 * @author     SocialEngineAddOns
 */
class Sitecrowdfunding_PhotoController extends Seaocore_Controller_Action_Standard {

    //COMMON ACTION WHICH CALL BEFORE EVERY ACTION OF THIS CONTROLLER
    public function init() {

        //AUTHORIZATION CHECK
        if (!$this->_helper->requireAuth()->setAuthParams('sitecrowdfunding_project', null, "view")->isValid())
            return;

        //SET SUBJECT
        if (!Engine_Api::_()->core()->hasSubject()) {

            if (0 != ($photo_id = (int) $this->_getParam('photo_id')) &&
                    null != ($photo = Engine_Api::_()->getItem('sitecrowdfunding_photo', $photo_id))) {
                Engine_Api::_()->core()->setSubject($photo);
            } else if (0 != ($project_id = (int) $this->_getParam('project_id')) &&
                    null != ($project = Engine_Api::_()->getItem('sitecrowdfunding_project', $project_id))) {
                Engine_Api::_()->core()->setSubject($project);
            }
        }
        $this->_helper->requireUser->addActionRequires(array(
            'upload',
            'upload-photo',
            'edit',
        ));

        $this->_helper->requireSubject->setActionRequireTypes(array(
            'project' => 'sitecrowdfunding_project',
            'upload' => 'sitecrowdfunding_project',
            'view' => 'sitecrowdfunding_photo',
            'edit' => 'sitecrowdfunding_photo',
        ));
    }

    //ACTION FOR UPLOAD PHOTO
    public function uploadAction() {

        //GET VIEWER
        $viewer = Engine_Api::_()->user()->getViewer();
        $this->view->viewer_id = $viewer_id = $viewer->getIdentity();

        //GET CHANNEL
        $this->view->project_id = $project_id = $this->_getParam('project_id');
        $this->view->project = $project = Engine_Api::_()->getItem('sitecrowdfunding_project', $project_id);
        $this->view->can_edit = $project->authorization()->isAllowed($viewer, "edit");

        $this->view->navigation = Engine_Api::_()->getApi('menus', 'core')->getNavigation("sitecrowdfunding_main");

        if (Engine_Api::_()->sitecrowdfunding()->hasPackageEnable()) {
            $photoCount = Engine_Api::_()->getItem('sitecrowdfunding_package', $project->package_id)->photo_count;
            $paginator = $project->getSingletonAlbum()->getCollectiblesPaginator();
            if (Engine_Api::_()->sitecrowdfunding()->allowPackageContent($project->package_id, "photo")) {
                $this->view->allowed_upload_photo = 1;
                if (empty($photoCount))
                    $this->view->allowed_upload_photo = 1;
                elseif ($photoCount <= $paginator->getTotalItemCount())
                    $this->view->allowed_upload_photo = 0;
            } else {
                $this->view->allowed_upload_photo = 0;
            }
        } else {//AUTHORIZATION CHECK
            $this->view->allowed_upload_photo = $allowed_upload_photo = Engine_Api::_()->authorization()->isAllowed('sitecrowdfunding_project', $viewer, "photo");
        }

        //AUTHORIZATION CHECK
        if (!empty($viewer_id)) {
            $level_id = Engine_Api::_()->user()->getViewer()->level_id;
        } else {
            $level_id = Engine_Api::_()->getDbtable('levels', 'authorization')->fetchRow(array('type = ?' => "public"))->level_id;
        }

        //SELECTED TAB
        $this->view->TabActive = "photo";
        if (isset($_GET['ul']) || isset($_FILES['Filedata'])) {
            return $this->_forwardCustom('upload-photo', null, null, array('format' => 'json', 'project_id' => (int) $project->getIdentity()));
        }
        //GET ALBUM
        $album = $project->getSingletonAlbum();

        //MAKE FORM
        $this->view->form = $form = new Sitecrowdfunding_Form_Photo_Upload();
        //   $form->file->setAttrib('data', array('project_id' => $project->getIdentity()));
        $this->view->tab_id = $content_id = $this->_getParam('content_id');

//CHECK METHOD
        if (!$this->getRequest()->isPost()) {
            return;
        }
        if (!isset($_FILES['filedata'])) {
            $form->removeElement('filedata');
        }

//
        //FORM VALIDATION
        if (!$form->isValid($this->getRequest()->getPost())) {
            return;
        }
        //PROCESS
        $table = Engine_Api::_()->getItemTable('sitecrowdfunding_photo');
        $db = $table->getAdapter();
        $db->beginTransaction();

        try {

            $values = $form->getValues();
            $params = array(
                'project_id' => $project->getIdentity(),
                'user_id' => $viewer->getIdentity(),
            );

            //ADD ACTION AND ATTACHMENTS
            if (isset($values['fancyuploadfileids']) && !empty($values['fancyuploadfileids'])) {
                $values['file'] = explode(" ", $values['fancyuploadfileids']);
            } elseif (isset($_FILES['filedata'])) {
                $photo_id = $project->setPhoto($form->filedata, array('setProjectMainPhoto' => false, 'return' => 'photo'))->photo_id;
                $values['file'] = array($photo_id);
            }
            $api = Engine_Api::_()->getDbtable('actions', 'seaocore');
            $count = 0;
            $currentDate = date('Y-m-d H:i:s');
            $action = $api->addActivity(Engine_Api::_()->user()->getViewer(), $project, Engine_Api::_()->sitecrowdfunding()->getActivtyFeedType($project, 'sitecrowdfunding_photo_upload'), null, array('count' => count($values['file']), 'title' => $project->title));

            foreach ($values['file'] as $photo_id) {
                $photo = Engine_Api::_()->getItem("sitecrowdfunding_photo", $photo_id);

                if (!($photo instanceof Core_Model_Item_Abstract) || !$photo->getIdentity())
                    continue;

                $photo->collection_id = $album->album_id;
                $photo->album_id = $album->album_id;
                $photo->save();
                if ($project->photo_id == 0) {
                    $project->photo_id = $photo->file_id;
                    $project->save();
                }
                // ACTIVITY FEED WILL BE GENERATED ONLY IF PROJECT IS IN PUBLISHED STATE
                if ($project->state == 'published' && $project->approved && $project->is_gateway_configured && $project->start_date <= $currentDate) {
                    if ($action instanceof Activity_Model_Action && $count < 8) {
                        $api->attachActivity($action, $photo, Activity_Model_Action::ATTACH_MULTI);
                    }
                }
                $count++;
            }
            $db->commit();
        } catch (Exception $e) {
            $db->rollBack();
            throw $e;
        }

        if ($this->view->can_edit) {
            return $this->_gotoRouteCustom(array('action' => 'editphotos', 'project_id' => $album->project_id), "sitecrowdfunding_albumspecific", true);
        } else {
            return $this->_gotoRouteCustom(array('project_id' => $album->project_id, 'slug' => $project->getSlug(), 'tab' => $content_id), "sitecrowdfunding_entry_view", true);
        }
    }

    //ACTION FOR UPLOAD PHOTO
    public function uploadPhotoAction() {

        //GET CHANNEL
        $project = Engine_Api::_()->getItem('sitecrowdfunding_project', (int) $this->_getParam('project_id'));

        if (!$this->_helper->requireUser()->checkRequire()) {
            $this->view->status = false;
            $this->view->error = Zend_Registry::get('Zend_Translate')->_('Max file size limit exceeded (probably).');
            return;
        }
        $viewer = Engine_Api::_()->user()->getViewer();

        if (Engine_Api::_()->sitecrowdfunding()->hasPackageEnable()) {
            $photoCount = Engine_Api::_()->getItem('sitecrowdfunding_package', $project->package_id)->photo_count;
            $paginator = $project->getSingletonAlbum()->getCollectiblesPaginator();
            if (Engine_Api::_()->sitecrowdfunding()->allowPackageContent($project->package_id, "photo")) {
                $this->view->allowed_upload_photo = 1;
                if (empty($photoCount))
                    $this->view->allowed_upload_photo = 1;
                elseif ($photoCount <= $paginator->getTotalItemCount())
                    $this->view->allowed_upload_photo = 0;
            } else {
                $this->view->allowed_upload_photo = 0;
            }
        } else {//AUTHORIZATION CHECK
            $this->view->allowed_upload_photo = $allowed_upload_photo = Engine_Api::_()->authorization()->isAllowed('sitecrowdfunding_project', $viewer, "photo");
        }

        if (empty($this->view->allowed_upload_photo)) {
            $this->view->error = Zend_Registry::get('Zend_Translate')->_('Maximum photo upload limit has been exceeded.');
            return;
        }

        if (!$this->getRequest()->isPost()) {
            $this->view->status = false;
            $this->view->error = Zend_Registry::get('Zend_Translate')->_('Invalid request method');
            return;
        }

        $values = $this->getRequest()->getPost();
        $response = Seaocore_Service_FancyUpload::upload();

        if (!empty($response['error'])) {
            $this->view->status = false;
            $this->view->error = Zend_Registry::get('Zend_Translate')->_('Invalid Upload');
            return;
        }

        if (empty($response['path']) || empty(file_exists($response['path']))) {
            $this->view->status = false;
            $this->view->error = Zend_Registry::get('Zend_Translate')->_('No file');
            return;
        }

        $tablePhoto = Engine_Api::_()->getDbtable('photos', 'sitecrowdfunding');
        $db = $tablePhoto->getAdapter();
        $db->beginTransaction();

        try {
            $viewer = Engine_Api::_()->user()->getViewer();
            $photo_id = $project->setPhoto($response['path'], array('setProjectMainPhoto' => false, 'return' => 'photo'))->photo_id;
            $this->view->status = true;
            // $this->view->name = $_FILES['Filedata']['name'];
            $this->view->photo_id = $photo_id;
            $db->commit();
        } catch (Exception $e) {
            $db->rollBack();
            $this->view->status = false;
            $this->view->error = Zend_Registry::get('Zend_Translate')->_($e->getMessage());
            return;
        }
        @unlink($response['path']);
    }

    //ACTION FOR PHOTO DELETE
    public function removeAction() {

        //GET PHOTO ID AND ITEM
        $photo_id = (int) $this->_getParam('photo_id');
        $photo = Engine_Api::_()->getItem('sitecrowdfunding_photo', $photo_id);

        //GET VIEWER
        $viewer = Engine_Api::_()->user()->getViewer();
        $this->view->viewer_id = $viewer->getIdentity();

        //AUTHORIZATION CHECK
        $canEdit = $photo->canEdit();
        if (!$canEdit) {
            return;
        }

        //GET CHANNEL
        $project = $photo->getParent('sitecrowdfunding_project');

        $isajax = (int) $this->_getParam('isajax');
        if ($isajax) {
            $db = Engine_Api::_()->getDbTable('photos', 'sitecrowdfunding')->getAdapter();
            $db->beginTransaction();

            try {
                $photo->delete();
                $db->commit();
            } catch (Exception $e) {
                $db->rollBack();
                throw $e;
            }
        }

        //MAKE FORM
        $this->view->form = $form = new Sitecrowdfunding_Form_Photo_Delete();

        //CHECK METHOD
        if (!$this->getRequest()->isPost()) {
            $form->populate($photo->toArray());
            return;
        }

        //FORM VALIDATION
        if (!$form->isValid($this->getRequest()->getPost())) {
            return;
        }

        $db = Engine_Api::_()->getDbTable('photos', 'sitecrowdfunding')->getAdapter();
        $db->beginTransaction();

        try {
            $photo->delete();
            $db->commit();
        } catch (Exception $e) {
            $db->rollBack();
            throw $e;
        }

        return $this->_forwardCustom('success', 'utility', 'core', array(
                    'messages' => array(Zend_Registry::get('Zend_Translate')->_('Photo deleted')),
                    'layout' => 'default-simple',
                    'parentRedirect' => $project->getHref(),
                    'closeSmoothbox' => true,
        ));
    }

    //ACTION FOR VIEWING THE PHOTO
    public function viewAction() {

        //GET VIEWER
        $viewer = Engine_Api::_()->user()->getViewer();
        $this->view->viewer_id = $viewer_id = $viewer->getIdentity();

        $this->view->project_id = (int) $this->_getParam('project_id');

        //GET PHOTOS
        $this->view->image = $photo = Engine_Api::_()->core()->getSubject();
        //GET ALBUM DETAILS
        $this->view->album = $photo->getCollection();
        //GET SETTINGS
        $this->view->canEdit = $photo->canEdit();

        if (!$viewer || !$viewer_id || $photo->user_id != $viewer->getIdentity()) {
            $photo->view_count = new Zend_Db_Expr('view_count + 1');
            $photo->save();
        }

        $this->view->enablePinit = Engine_Api::_()->getApi('settings', 'core')->getSetting('seaocore.photo.pinit', 0);
    }

}
