<?php

class Siteerror_Form_Admin_Error extends Engine_Form
{

  public function init()
  {
    $this
    ->setTitle('Exception Handling Error Page')
    ->setDescription('Here, you can configure the the custom layout for the Exception Handling Error page on your website. The Exception Handling Error page normally shows up whenever there comes an exceptional error on a page.');

    $coreSettingApi = Engine_Api::_()->getApi('settings', 'core');

    $settingPrefix = 'siteerror.fatalerror.';


    $this->addElement('Radio', 'enable', array(
      'label' => 'Enable Custom Template',
      'description' => "Do you want to enable the custom template for 'Exception Handling Error' page on your website? If you choose 'Yes', then a custom designed template for Exception Handling Error will show to your users.
      [Note: Below mentioned settings may not not apply if you select 'No' for Enable Custom Template]
      ",
      'multiOptions' => array(
        '1' => 'Yes',
        '0' => 'No',
      ),
      'value' => $coreSettingApi->getSetting($settingPrefix . 'enable', 1),
    ));

    $templates = array(
      'template1' => $this->templateOptionLabel('template1.png'),
      'template2' => $this->templateOptionLabel('template2.png'),
      'template3' => $this->templateOptionLabel('template3.png'),
      'template4' => $this->templateOptionLabel('template4.png')
    );
    $this->addElement('Radio', 'template', array(
      'label' => 'Design Template',
      'description' => "Select the pre configured design templates for the Exception Handling Error page on your website. you can change the image for the active template. If you want the default image of template, then simply remove your image from above.",
      'multiOptions' => $templates,
      'escape' => false,
      'value' => $coreSettingApi->getSetting($settingPrefix . 'template', 'template1'),
    ));

    $this->addElement('Text', 'heading', array(
      'label' => 'Heading',
      'description' => 'Enter the heading that you want to display on your custom Exception Handling Error page.',
      'allowEmpty' => false,
      'required' => true,
      'value' => $coreSettingApi->getSetting($settingPrefix . 'heading', "We're sorry!"),
    ));

    $this->addElement('Text', 'subheading', array(
      'label' => 'Sub Heading',
      'description' => 'Enter the sub heading that you want to display on your custom Exception Handling Error page.',
      'value' => $coreSettingApi->getSetting($settingPrefix . 'subheading', "Please try after some time."),
    ));

    $this->addElement('Text', 'body', array(
      'label' => 'Description / Tagline',
      'description' => 'Enter the textual description / tagline that you want to display on your custom Exception Handling Error page.',
      'value' => $coreSettingApi->getSetting($settingPrefix . 'body', "We are currently experiencing some technical issues. Please try again or report this to your site administrator using the contact form."),
    ));

    $this->addElement('Select', 'overlay', array(
      'label' => 'Overlay',
      'description' => "Do you want to set overlay effect for your custom Exception Handling Error page?",
      'multiOptions' => array(
        'siteerrorOverlayOff' => 'Off',
        'siteerrorOverlayDark' => 'Dark Overlay',
        'siteerrorOverlayLight' => 'Light Overlay',
      ),
      'value' => $coreSettingApi->getSetting($settingPrefix . 'overlay', 'siteerrorOverlayOff'),
    ));

    $this->addElement('File', 'background_photo', array(
      'label' => 'Background Image',
      'description' => 'Choose a background image to be displayed on your custom Exception Handling page.
      [Note: If you do not upload an image, then default background image will display.]'
    ));
    $this->background_photo->addValidator('Extension', false, 'jpg,jpeg,JPG,JPEG,png,PNG,gif,GIF');

    $fileId = $coreSettingApi->getSetting($settingPrefix . 'background.photo', 0);
    $photoUrl = Engine_Api::_()->siteerror()->getPhotoUrl($fileId);
    if( $photoUrl ) {
      $this->addElement('Dummy', 'custom_photo_preview', array(
        'description' => '<img src="' . $photoUrl . '" alt="" />',
        'escape' => false,
      ));
      $this->custom_photo_preview->getDecorator('Description')->setOptions(array('escape' => false));
      $this->addElement('Checkbox', 'remove_photo', array(
        'label' => 'Remove Background Image.'
      ));
    }

    $this->addElement('File', 'front_photo', array(
      'label' => 'Front Image',
      'description' => 'Choose a front image to be displayed on your custom Exception Handling page.
      [Note: Front image will be shown only in the templates which support it. If you do not upload an image, then default front image will display.]'
    ));
    $this->front_photo->addValidator('Extension', false, 'jpg,jpeg,JPG,JPEG,png,PNG,gif,GIF');
    $fileId = $coreSettingApi->getSetting($settingPrefix . 'front.photo', 0);
    $photoUrl = Engine_Api::_()->siteerror()->getPhotoUrl($fileId);
    if( $photoUrl ) {
      $this->addElement('Dummy', 'custom_front_photo_preview', array(
        'description' => '<img src="' . $photoUrl . '" alt="" />',
        'escape' => false,
      ));
      $this->custom_front_photo_preview->getDecorator('Description')->setOptions(array('escape' => false));
      $this->addElement('Checkbox', 'remove_front_photo', array(
        'label' => 'Remove Front Image.'
      ));
    }

    $this->addElement('Button', 'execute', array(
      'label' => 'Save Settings',
      'type' => 'submit',
      'ignore' => true,
      'decorators' => array('ViewHelper'),
    ));
  }

  private function templateOptionLabel($template)
  {
    return '<div><img src="./application/modules/Siteerror/externals/images/templates/exceptionalerror/' . $template . '" alt="" /></div>';
  }

}