<?php

class Siteerror_Form_Admin_PageNotFound extends Engine_Form
{

  public function init()
  {
    $this
    ->setTitle('404 Page Not Found Page')
    ->setDescription('Here, you can configure the custom layout for the 404 Page Not Found page on your website. The 404 Page Not Found page normally shows up when a page / page URL is not found, i.e. if user tries to open a URL that does not exist.');

    $coreSettingApi = Engine_Api::_()->getApi('settings', 'core');

    $settingPrefix = 'siteerror.pagenotfound.';
    $this->addElement('Radio', '301redirect', array(
      'label' => 'Enable Automatic Redirection of 404 page Visitors to Homepage',
      'description' => 'Do you want to automatically redirect users who observe a 404 Page Not Found error to the homepage of your website? (We recommend you to choose “Yes” because Google ranks a website according to the number of 404 Page Not Found errors observed on it. The more the number of such errors the lower is the website’s rank. Automatic redirection to homepage will reduce the no. of such error and hence, it will help improve website’s rank, Note: This setting will only work for the links which are opened directly by entering URL and when user is not redirected to this page from any other webpage.',
      'multiOptions' => array(
        '1' => 'Yes',
        '0' => 'No',
      ),
      'value' => $coreSettingApi->getSetting($settingPrefix . '301redirect', 0),
    ));


    $this->addElement('Radio', 'enable', array(
      'label' => 'Enable Custom Template',
      'description' => "Do you want to enable the custom template for '404 Page Not Found' page on your website? If you choose 'Yes', then a custom designed template for 404 Page Not Found will show to your users.
      [Note: Below mentioned settings may not not apply if you select 'No' for Enable Custom Template]
      ",
      'multiOptions' => array(
        '1' => 'Yes',
        '0' => 'No',
      ),
      'value' => $coreSettingApi->getSetting($settingPrefix . 'enable', 1),
    ));

    $templates = array(
      'template1' => $this->templateOptionLabel('template1.png'),
      'template2' => $this->templateOptionLabel('template2.png'),
      'template3' => $this->templateOptionLabel('template3.png'),
      'template4' => $this->templateOptionLabel('template4.png')
    );
    $this->addElement('Radio', 'template', array(
      'label' => 'Design Template',
      'description' => "Select one template from below preconfigured design templates for 404 Page Not Found page on your website. You can change the image used for the active template, but if you want to show default image, then simply remove your image from below.",
      'multiOptions' => $templates,
      'escape' => false,
      'value' => $coreSettingApi->getSetting($settingPrefix . 'template', 'template1'),
    ));

    $this->addElement('Text', 'heading', array(
      'label' => 'Heading',
      'description' => 'Enter the heading that you want to display on your custom 404 Page Not Found page.',
      'allowEmpty' => false,
      'required' => true,
      'value' => $coreSettingApi->getSetting($settingPrefix . 'heading', "OOPS!"),
    ));

    $this->addElement('Text', 'subheading', array(
      'label' => 'Sub Heading',
      'description' => 'Enter the sub heading that you want to display on your custom 404 Page Not Found page.',
      'value' => $coreSettingApi->getSetting($settingPrefix . 'subheading', 'Error 404: Page Not Found'),
    ));

    $this->addElement('Text', 'body', array(
      'label' => 'Description / Tagline',
      'description' => 'Enter the textual description / tagline that you want to display on your custom 404 Page Not Found page.',
      'value' => $coreSettingApi->getSetting($settingPrefix . 'body', 'Rather search for something else?'),
    ));

    $this->addElement('Radio', 'showSearchForm', array(
      'label' => 'Show Search Textbox',
      'description' => "Do you want to show search textbox on your custom 404 Page Not Found page?",
      'multiOptions' => array(
        '1' => 'Yes',
        '0' => 'No',
      ),
      'value' => $coreSettingApi->getSetting($settingPrefix . 'showSearchForm', 1),
    ));

    $this->addElement('Radio', 'showHomeButton', array(
      'label' => 'Show “Go to Home” Button',
      'description' => "Do you want to show “Go to Home” button on your custom 404 Page Not Found page?",
      'multiOptions' => array(
        '1' => 'Yes',
        '0' => 'No',
      ),
      'value' => $coreSettingApi->getSetting($settingPrefix . 'showHomeButton', 1),
    ));

    $this->addElement('Radio', 'showGoBack', array(
      'label' => 'Show “Go Back” Button',
      'description' => "Do you want to show “Go Back” button on your custom 404 Page Not Found page?",
      'multiOptions' => array(
        '1' => 'Yes',
        '0' => 'No',
      ),
      'value' => $coreSettingApi->getSetting($settingPrefix . 'showGoBack', 1),
    ));

    $this->addElement('Select', 'overlay', array(
      'label' => 'Overlay',
      'description' => "Do you want to set overlay effect for your custom 404 Page Not Found page?",
      'multiOptions' => array(
        'siteerrorOverlayOff' => 'Off',
        'siteerrorOverlayDark' => 'Dark Overlay',
        'siteerrorOverlayLight' => 'Light Overlay',
      ),
      'value' => $coreSettingApi->getSetting($settingPrefix . 'overlay', 'siteerrorOverlayOff'),
    ));

    $this->addElement('File', 'background_photo', array(
      'label' => 'Background Image',
      'description' => 'Choose a background image to be displayed on your custom 404 Page Not Found page.
      [Note: If you do not upload an image, then default background image will display.]'
    ));
    $this->background_photo->addValidator('Extension', false, 'jpg,jpeg,JPG,JPEG,png,PNG,gif,GIF');

    $fileId = $coreSettingApi->getSetting($settingPrefix . 'background.photo', 0);
    $photoUrl = Engine_Api::_()->siteerror()->getPhotoUrl($fileId);
    if( $photoUrl ) {
      $this->addElement('Dummy', 'custom_photo_preview', array(
        'description' => '<img src="' . $photoUrl . '" alt="" />',
        'escape' => false,
      ));
      $this->custom_photo_preview->getDecorator('Description')->setOptions(array('escape' => false));
      $this->addElement('Checkbox', 'remove_photo', array(
        'label' => 'Remove Background Image.'
      ));
    }

    $this->addElement('File', 'front_photo', array(
      'label' => 'Front Image',
      'description' => 'Choose a front image to be displayed on your custom 404 Page Not Found page.
      [Note: Front image will be shown only in the templates which support it. If you do not upload an image, then default front image will display.]'
    ));
    $this->front_photo->addValidator('Extension', false, 'jpg,jpeg,JPG,JPEG,png,PNG,gif,GIF');
    $fileId = $coreSettingApi->getSetting($settingPrefix . 'front.photo', 0);
    $photoUrl = Engine_Api::_()->siteerror()->getPhotoUrl($fileId);
    if( $photoUrl ) {
      $this->addElement('Dummy', 'custom_front_photo_preview', array(
        'description' => '<img src="' . $photoUrl . '" alt="" />',
        'escape' => false,
      ));
      $this->custom_front_photo_preview->getDecorator('Description')->setOptions(array('escape' => false));
      $this->addElement('Checkbox', 'remove_front_photo', array(
        'label' => 'Remove Front Image.'
      ));
    }

    $this->addElement('Button', 'execute', array(
      'label' => 'Save Settings',
      'type' => 'submit',
      'ignore' => true,
      'decorators' => array('ViewHelper'),
    ));
  }

  private function templateOptionLabel($template)
  {
    return '<div><img src="./application/modules/Siteerror/externals/images/templates/page-not-found/' . $template . '" alt="" /></div>';
  }

}