<?php

/**
 * SocialEngine
 *
 * @category   Application_Extensions
 * @package    Siteestore
 * @copyright  Copyright 2011-2012 BigStep Technologies Pvt. Ltd.
 * @license    http://www.socialengineaddons.com/license/
 * @version    $Id: Xmlrpc.php 2012-10-22 9:40:21Z SocialEngineAddOns
 * @author     SocialEngineAddOns
 */
class Siteestore_Api_Xmlrpc extends Core_Api_Abstract {

  /**
   * Get Objects of XML-RPC client.
   *
   * @param $host: Host name, which xml-rpc client required.
   * @return object
   */
  protected function getProxy($host) {
    $_proxy = new Zend_XmlRpc_Client($host);
    return $_proxy;
  }

  /**
   * XML-RPC bridge url.
   *
   * @return string
   */
  public function getBridgeUrl() {
    $host = Engine_Api::_()->siteestore()->getHostUrl();
    $xmlrpcUrl = $host . '/api/xmlrpc/?wsdl';
    return $xmlrpcUrl;
  }

  /**
   * Session for XML-RPC bridge, Session will create according to the configure Api Key & Api Password.
   *
   * @param $params: Informtion of the web user and host.
   * @return string
   */
  public function maginto_api_connect($params) {
    $_proxy = $this->getProxy($params['host']);
    $session = $_proxy->call('login', array($params['user'], $params['pass']));
    return $session;
  }

  /**
   * For request through XML-RPC bridge.
   *
   * @param $file_name: Function name, which will call through xml-rpc.
   * @param $attribute: Additionally information, which need to be send while calling respective function.
   */
  public function magento_test_api_connection($file_name = 'socialengineint_seint.getwebsite', $attribute = array()) {
    if (strstr($file_name, 'test_connection')) {
      $file_name = 'socialengineint_seint.getwebsite';
      $testHost = $attribute['siteestore_hostType'] . '://' . $attribute['siteestore_api_host'] . '/api/xmlrpc/?wsdl';
      $testUsername = $attribute['siteestore_api_user'];
      $testPassword = $attribute['siteestore_api_pass'];
      $attribute = array();
    }
    $settings = Engine_Api::_()->getApi('settings', 'core');
    $params['host'] = !empty($testHost) ? $testHost : $this->getBridgeUrl();
    $params['user'] = !empty($testUsername) ? $testUsername : $settings->getSetting('siteestore.api.user', '');
    $params['pass'] = !empty($testPassword) ? $testPassword : $settings->getSetting('siteestore.api.pass', '');
    $params['file_name'] = $file_name;
    $_proxy = $this->getProxy($params['host']);
    try {
      $session = $this->maginto_api_connect($params);
      $tempAttributeArray = array();
      if(!empty($attribute)) {
        foreach($attribute as $attributeParam) {
          $tempAttributeArray[] = $attributeParam;
        }
      }

      $countryList = $_proxy->call('call', array($session, $file_name, $tempAttributeArray));
    } catch (Exception $e) {
      $countryList = null;
    }

    $value = !empty($countryList) ? true : 0;
    $settings->setSetting('siteestore.api.valid', $value);
    return $countryList;
  }

  /**
   * Check configued api information is correct or not.
   *
   * @return string
   */
  public function isApiConnValid() {
    $isApiValid = Engine_Api::_()->getApi('settings', 'core')->getSetting('siteestore.api.valid', 0);
    if (!empty($isApiValid)) {
      $isWebsite = Engine_Api::_()->siteestore()->getWebsite('id');
      if (!empty($isWebsite)) {
        return true;
      } else {
        return false;
      }
    } else {
      $this->magento_test_api_connection();
      return false;
    }
  }

}

?>