<?php

/**
 * SocialEngine
 *
 * @category   Application_Extensions
 * @package    Siteestore
 * @copyright  Copyright 2011-2012 BigStep Technologies Pvt. Ltd.
 * @license    http://www.socialengineaddons.com/license/
 * @version    $Id: Products.php 2012-10-22 9:40:21Z SocialEngineAddOns
 * @author     SocialEngineAddOns
 */
class Siteestore_Model_DbTable_Products extends Engine_Db_Table {

  protected $_name = 'siteestore_products';
  protected $_rowClass = 'Siteestore_Model_Product';

  /**
   * SET THE PRODUCTS DATA INTO THE TABLE ACCORDINGLY. FUNCTION CALL FROM "ADD TO WISLIST", "PRODUCT VIEW PAGE" AND "CHECKOUT PROCESS"
   *
   * @param $data: Array of the product information.
   * @return
   */
  public function setProducts($data) {
    $viewer = Engine_Api::_()->user()->getViewer();
    $viewer_id = $viewer->getIdentity();
    $hostType = Engine_Api::_()->siteestore()->getSEProtocol();
    $getBaseURL = Engine_Api::_()->siteestore()->getGlobalUrls();
    $magentoBaseUrl = Engine_Api::_()->siteestore()->getHostUrl();
    $magentoBaseUrl = str_replace("/index.php", "", $magentoBaseUrl);
    $socilEngineBaseDir = Engine_Api::_()->siteestore()->getSEBaseUrl();
    $socilEngineBaseDir = Engine_Api::_()->siteestore()->getSEBaseUrl();
    $fileName = $magentoBaseUrl . '/media/catalog/product' . $data['product_image'];
    $isProduct = Engine_Api::_()->getItem('siteestore_product', $data['product_id']);
    $requestUri = Zend_Controller_Front::getInstance()->getRequest()->getRequestUri();

    if( strstr($requestUri, "index.php") ) {
      $REQUEST_URI = "index.php/" . $getBaseURL . "/" . $data["request_uri"];
    }else {
      $REQUEST_URI = $getBaseURL . "/" . $data["request_uri"];
    }

    if (empty($isProduct)) {
      if (!empty($viewer_id)) {
        $photo_id = $this->getPhotoId($fileName);
      }
      $photo_id = !empty($photo_id) ? $photo_id : 0;
      $requestUri = Zend_Controller_Front::getInstance()->getRequest()->getRequestUri();
      $row = $this->createRow();
      $row->product_id = $data["product_id"];
      $row->uri = $REQUEST_URI;
      $row->sku = $data["sku"];
      $row->category = !empty($data['categorys']) ? @serialize($data['categorys']) : @serialize(array());
      $row->title = $data["product_title"];
      $row->price = $data["price"];
      $row->date = $data["creation_date"];
      $row->description = $data["product_description"];
      $row->short_description = !empty($data["short_description"]) ? $data["short_description"] : '';
      $row->photo_id = $photo_id;
      $row->status = 1;
      $row->save();

      // Auth activity feed.
      $auth = Engine_Api::_()->authorization()->context;
      $roles = array('owner', 'owner_member', 'owner_member_member', 'owner_network', 'registered', 'everyone');
      foreach ($roles as $role) {
        $auth->setAllowed($row, $role, 'view', 1);
        $auth->setAllowed($row, $role, 'comment', 1);
      }
    } else {
      if (!empty($viewer_id) && !empty($isProduct) && empty($isProduct->photo_id)) {
        $photo_id = $this->getPhotoId($fileName);
        $photo_id = !empty($photo_id) ? $photo_id : 0;
      } else {
        $photo_id = $isProduct->photo_id;
      }

      $category = !empty($data['categorys']) ? @serialize($data['categorys']) : @serialize(array());

      $this->update(array(
          "uri" => $REQUEST_URI,
          "sku" => $data["sku"],
          "title" => $data["product_title"],
          "category" => $category,
          "price" => $data["price"],
          "photo_id" => $photo_id,
          "short_description" => $data["short_description"],
          "description" => $data["product_description"],
          "status" => 1
              ), array('product_id =?' => $data["product_id"]));
    }
    return;
  }

  /**
   * RETURN THE OBJECT OF THE RECORD AFTER FILTERING DATA ACCORDINGLY.
   *
   * @param $data: Array of the product information for filtering data.
   * @return object
   */
  public function getProducts($data = array()) {
    $table = $this->info('name');
    $select = $this->select();

    if (!empty($data)) {
      foreach ($data as $key => $value) {
        $select->where($key, $value);
      }
    }

    $fetchArray = $select->query()->fetchAll();
    return $fetchArray;
  }

  /**
   * RETURN THE DISABLED PRODUCTS AFTER SYNCHRONIZE FOR "ADMIN: MANAGE PRODUCTS" PAGE.
   *
   * @param $params: Array of the product information for filtering data.
   * @return object
   */
  public function getProductsPaginator($params) {
    $table = $this->info('name');
    $select = $this->select();

    $select->order((!empty($params['order']) ? $params['order'] : 'product_id' ) . ' ' . (!empty($params['order_direction']) ? $params['order_direction'] : 'DESC' ));

    if (empty($params['status'])) {
      $select->where('status > ?', 1);
    }
    if (!empty($params['title'])) {
      $select->where('title LIKE ?', '%' . $params['title'] . '%');
    }
    if (!empty($params['description'])) {
      $select->where('description LIKE ?', '%' . $params['description'] . '%');
    }
    if (!empty($params['short_description'])) {
      $select->where('short_description LIKE ?', '%' . $params['short_description'] . '%');
    }
    if (!empty($params['sku'])) {
      $select->where('sku LIKE ?', '%' . $params['sku'] . '%');
    }
    if (!empty($params['price'])) {
      $select->where('price LIKE ?', '%' . $params['price'] . '%');
    }

    $paginator = Zend_Paginator::factory($select);

    if (!empty($params['page'])) {
      $paginator->setCurrentPageNumber($params['page']);
    }
    if (!empty($params['limit'])) {
      $paginator->setItemCountPerPage($params['limit']);
    }

    if (empty($params['limit'])) {
      $page = 10;
      $paginator->setItemCountPerPage($page);
    }

    return $paginator;
  }

  /**
   * UPGRADE THE PRODUCTS INFORMATION.
   *
   * @param $data: Array of the product information for filtering data.
   * @return object
   */
  public function upgradeProducts($data) {
    $requestUri = Zend_Controller_Front::getInstance()->getRequest()->getRequestUri();
    $magentoBaseUrl = Engine_Api::_()->siteestore()->getHostUrl();
    $magentoBaseUrl = str_replace("/index.php", "", $magentoBaseUrl);
    $fileName = $magentoBaseUrl . '/media/catalog/product' . $data['product_image'];
    $photo_id = $this->getPhotoId($fileName);
    $photo_id = !empty($photo_id) ? $photo_id : 0;
    $hostType = Engine_Api::_()->siteestore()->getSEProtocol();
    $getBaseURL = Engine_Api::_()->siteestore()->getGlobalUrls();
    $socilEngineBaseDir = Engine_Api::_()->siteestore()->getSEBaseUrl();

    if( strstr($requestUri, "index.php") ) {
      $REQUEST_URI = "index.php/" . $getBaseURL . "/" . $data["request_uri"];
    }else {
      $REQUEST_URI = $getBaseURL . "/" . $data["request_uri"];
    }

    $category = !empty($data['categorys']) ? @serialize($data['categorys']) : @serialize(array());
    $getProduct = Engine_Api::_()->getItem('siteestore_product', $data['product_id']);
    if( !empty($getProduct->photo_id) ) {
      $file = Engine_Api::_()->getItemTable('storage_file')->getFile($getProduct->photo_id);
      if( !empty($file) ) {
        $file->remove();
      }
    }

    $sku = !empty($data["sku"]) ? $data["sku"] : $getProduct->sku;
    $pro_title = !empty($data["product_title"]) ? $data["product_title"] : $getProduct->title;
    $price = !empty($data["price"]) ? $data["price"] : $getProduct->price;
    $short_description = !empty($data["short_description"]) ? $data["short_description"] : $getProduct->short_description;
    $product_description = !empty($data["product_description"]) ? $data["product_description"] : $getProduct->description;
    $status = !empty($data["status"]) ? $data["status"] : $getProduct->status;
    // $uri = !empty($data["request_uri"]) ? $data["request_uri"]: $getProduct->uri;



    $this->update(array(
        "sku" => $sku,
        "title" => $pro_title,
        "category" => $category,
        "price" => $price,
        "photo_id" => $photo_id,
        "short_description" => $short_description,
        "description" => $product_description,
        "uri" => $REQUEST_URI,
        "status" => $status
            ), array('product_id =?' => $data["product_id"]));
  }

  /**
   * SAVE THE IMAGE INTO THE STORAGE TABLE FROM THE IMAGE LINK AND RETURN THE PHOTO ID.
   *
   * @param $photoLink: Image path.
   * @return int
   */
  public function getPhotoId($photoLink) {
    $viewer = Engine_Api::_()->user()->getViewer();

    // Now try to create thumbnail
    $thumbnail = (string) @$photoLink;
    $thumbnail_parsed = @parse_url($thumbnail);
    $imageId = false;

    if ($thumbnail && $thumbnail_parsed) {
      $tmp_path = APPLICATION_PATH . '/temporary/siteestore';
      $tmp_file = $tmp_path . '/' . md5($thumbnail);

      if (!is_dir($tmp_path) && !mkdir($tmp_path, 0777, true)) {
        throw new Core_Model_Exception('Unable to create tmp link folder : ' . $tmp_path);
      }

      $src_fh = fopen($thumbnail, 'r');
      $tmp_fh = fopen($tmp_file, 'w');
      stream_copy_to_stream($src_fh, $tmp_fh);
      fclose($src_fh);
      fclose($tmp_fh);

      if (($info = getimagesize($tmp_file)) && !empty($info[2])) {
        $ext = Engine_Image::image_type_to_extension($info[2]);
        $thumb_file = $tmp_path . '/thumb_' . md5($thumbnail) . '.' . $ext;

        $image = Engine_Image::factory();
        $image->open($tmp_file)
                ->resize(140, 160)
                ->write($thumb_file)
                ->destroy();

        $thumbFileRow = Engine_Api::_()->storage()->create($thumb_file, array(
            'parent_type' => 'siteestore',
            'parent_id' => $viewer->getIdentity()
                ));

        $imageId = $thumbFileRow->file_id;

        @unlink($thumb_file);
      }

      @unlink($tmp_file);
    }

    return $imageId;
  }

  /**
   * RETURN THE PRODUCTS FOR THE "POPULAR PRODUCTS" WIDGETS.
   *
   * @param $type: Content Type.
   * @param $limit: Limit of content.
   * @return array
   */
  public function popularProducts($type, $limit) {
    $data = array();
    if ($type == 'view') {
      $name = $this->info('name');
      $select = $this->select()
              ->where($name . '.status = ?', 1)
              ->order('view_counts DESC')
              ->limit($limit);
      $fetch = $select->query()->fetchAll();
      return $fetch;
    } else if ($type == 'like') {
      $likeTable = Engine_Api::_()->getItemTable('core_like');
      $likeName = $likeTable->info('name');

      $name = $this->info('name');

      $select = $likeTable->select()
              ->setIntegrityCheck(false)
              ->from($likeName, array('resource_type', 'resource_id', 'COUNT(' . $likeName . '.resource_id) AS like_count'))
              ->where($likeName . '.resource_type = ?', 'siteestore_product')
              ->group('resource_id')
              ->order('like_count DESC')
              ->limit($limit);
      $fetch = $select->query()->fetchAll();

      if (!empty($fetch)) {
        foreach ($fetch as $values) {
          $product = Engine_Api::_()->getItem('siteestore_product', $values['resource_id']);
          if (!empty($product) && $product->status == 1) {
            $likeArray['count'] = $values['like_count'];
            $likeArray['item'] = $product;
            $data[] = $likeArray;
          }
        }
      }
      return $data;
    } else if ($type == 'maxpurchased') {
      $table = Engine_Api::_()->getItemTable('siteestore_order');
      $name = $table->info('name');

      $link_table = Engine_Api::_()->getItemTable('siteestore_product');
      $link_name = $table->info('name');

      $select = $table->select()
              ->setIntegrityCheck(false)
              ->from($name, array('order_id', 'owner_id', 'product_id', 'SUM(' . $name . '.quantity) AS product_count'))
              ->group('product_id')
              ->order('product_count DESC')
              ->limit($limit);

      $fetch = $select->query()->fetchAll();

      if (!empty($fetch)) {
        foreach ($fetch as $values) {
          $productInfo = Engine_Api::_()->getItem('siteestore_product', $values['product_id']);

          if (!empty($productInfo) && $productInfo->status == 1) {
            $orderArray['count'] = $values['product_count'];
            $orderArray['item'] = $productInfo;

            $data[] = $orderArray;
          }
        }
      }
      return $data;
    }
  }
  
  public function setManifestUrl($params){
    $name = $this->info('name');
    $select = $this->select()
            ->from($name, array('product_id', 'uri'))
            ->where('uri LIKE ?', '%' . $params['oldURL'] . '%');
    $fetch = $select->query()->fetchAll();
    if( !empty($fetch) ) {
      foreach( $fetch as $products ){
        $uriArray = @explode("/", $products['uri']);
        $uriArray[0] = $params['newURL'];
        $uriStr = @implode("/", $uriArray);
        
        $this->update(array(
            "uri" => $uriStr,
                ), array('product_id =?' => $products["product_id"]));
      }
    }
    return;
  }

  /**
   * RETURN THE RECENTLY PURCHASED PRODUCTS.
   *
   * @param $limit: Limit of content.
   * @return array
   */
  public function recentlyPurchasedProducts($limit) {
    $fetchProducts = null;
    $orderTable = Engine_Api::_()->getItemTable('siteestore_order');
    $orderName = $orderTable->info('name');
    $select = $orderTable->select()
            ->from($orderName, array('order_id'))
            ->order('field_id DESC')
            ->limit(1);
    $fetch = $select->query()->fetch();
    if (!empty($fetch['order_id'])) {
      $name = $this->info('name');
      $select = $this->select()
              ->setIntegrityCheck(false)
              ->from($name)
              ->join($orderName, "`{$name}`.`product_id`= `{$orderName}`.product_id")
              ->where($orderName . ".order_id = ?", $fetch['order_id'])
              ->where($name . ".status =?", 1)
              ->limit($limit);
      $fetchProducts = $select->query()->fetchAll();
    }
    return $fetchProducts;
  }

}