<?php

/**
 * SocialEngine
 *
 * @category   Application_Extensions
 * @package    Siteeventadmincontact
 * @copyright  Copyright 2013-2014 BigStep Technologies Pvt. Ltd.
 * @license    http://www.socialengineaddons.com/license/
 * @version    $Id: Message.php 6590 2014-01-02 00:00:00Z SocialEngineAddOns $
 * @author     SocialEngineAddOns
 */
class Siteeventadmincontact_Form_Admin_Message_Message extends Engine_Form {

    public function init() {

        //GET DECORATORS
        $this->loadDefaultDecorators();

        //GET DESCRIPTION
        $description = sprintf(Zend_Registry::get('Zend_Translate')->_("Using this form, you will be able to send a message out to all of the Owners and Leaders of Events on your website.<br />You can use this tool to communicate to users about tips to more effectively use Events on your website. You can also inform them about new features added to Events. SocialApps.tech is regularly releasing %s and enhancements and this tool can help you inform your users about them as you make these features available on your website.<br />This can be a great way to motivate users to keep their Events updated and active on your website."), '<a href="http://www.socialengineaddons.com/catalog/advanced-events-extensions" target="_blank">new extensions</a>');

        $this->getDecorator('Description')->setOption('escape', false);

        //SET TITLE AND DESCRIPTION
        $this
                ->setTitle('Message Event Owners and Leaders')
                ->setDescription($description)
                ->setAttrib('name', 'admincontact');

        //PREPARE CATEGORIES
        $categories = Engine_Api::_()->getDbTable('categories', 'siteevent')->getCategories(array('category_id', 'category_name', 'category_slug'));
        if (count($categories) != 0) {
            $categories_prepared[0] = "All Categories";
            foreach ($categories as $category) {
                $categories_prepared[$category->category_id] = $category->category_name;
            }
        }

        $this->addElement('Multiselect', 'categories', array(
            'label' => 'Event Categories',
            'description' => 'Hold down the CTRL key to select or de-select specific Event Categories for which Owners and Leaders of corresponding Events need to be sent messages.',
            'required' => false,
            'allowEmpty' => true,
            'multiOptions' => $categories_prepared,
            'value' => 0
        ));
        $this->categories->getDecorator('Description')->setOptions(array('placement' => 'APPEND'));

        $status_prepared = array("All" => "All Events", "Draft" => "Draft Events", "Published" => "Published Events", "Open" => "Re-publish Events", "Cancel" => "Cancel Events", "Featured" => "Featured Events", "Sponsored" => "Sponsored Events", "Approved" => "Approved Events", "DisApproved" => "Dis-approved Events");

        $this->addElement('Multiselect', 'status', array(
            'label' => 'Status',
            'RegisterInArrayValidator' => false,
            'description' => 'Hold down the CTRL key to select or de-select specific Event Status for which Owners and Leaders of corresponding Events need to be sent messages.',
            'required' => false,
            'allowEmpty' => true,
            'multiOptions' => $status_prepared,
            'value' => "All"
        ));
        $this->status->getDecorator('Description')->setOptions(array('placement' => 'APPEND'));

        $start = new Engine_Form_Element_CalendarDateTime('starttime');
        $start->setLabel("Start Date");
				$start->setDescription("Select the start date of events by using the calendar icon below. [All the events beginning after this date will be selected.]");
        //$start->setAllowEmpty(true);
        $this->addElement($start);

        // End time
        $end = new Engine_Form_Element_CalendarDateTime('endtime');
        $end->setLabel("End Date");
         $end->setDescription("Select the end date of events by using the calendar icon below. [All the events ending before this date will be selected.]");
        //$end->setAllowEmpty(true);
        $this->addElement($end);

        $table = Engine_Api::_()->getDbtable('networks', 'network');
        $select = $table->select()
                ->from($table->info('name'), array('network_id', 'title'))
                ->order('title');
        $result = $table->fetchAll($select);

        $networksOptions = array('0' => 'Everyone');
        foreach ($result as $value) {
            $networksOptions[$value->network_id] = $value->title;
        }

        if (count($networksOptions) > 0) {
            $this->addElement('Multiselect', 'networks_privacy', array(
                'label' => 'Networks Selection',
                'description' => Zend_Registry::get('Zend_Translate')->_("Hold down the CTRL key to select or de-select specific Networks for which Owners and Leaders of corresponding Events need to be sent messages."),
                'multiOptions' => $networksOptions,
                'value' => array(0)
            ));
            $this->networks_privacy->getDecorator('Description')->setOptions(array('placement' => 'APPEND'));
        } else {
            
        }

        //SEND TEST EMAIL
        $this->addElement('Checkbox', 'host_message', array(
            'label' => 'Send this message to Event Hosts (Site Member) also.',
            'value' => 1,
        ));

        $description = sprintf(Zend_Registry::get('Zend_Translate')->_("To compose a message click %s."), '<a href="javascript:void(0);" onclick="getValues();">here</a>');
        $this->addElement('Dummy', 'siteeventadmincontact_sendmessage', array(
            'label' => 'Compose Message',
            'description' => $description,
        ));
        $this->getElement('siteeventadmincontact_sendmessage')->getDecorator('Description')->setOptions(array('placement', 'APPEND', 'escape' => false));
    }

}