<?php

/**
 * SocialEngine
 *
 * @category   Application_Extensions
 * @package    Siteeventdocument
 * @copyright  Copyright 2013-2014 BigStep Technologies Pvt. Ltd.
 * @license    http://www.socialengineaddons.com/license/
 * @version    $Id: Core.php 6590 2014-01-02 00:00:00Z SocialEngineAddOns $
 * @author     SocialEngineAddOns
 */
class Siteeventdocument_Api_Core extends Core_Api_Abstract {

    /**
     * Return document tabid
     *
     * @return tabid
     */
    public function getTabId() {

        $tablecontent = Engine_Api::_()->getDbtable('content', 'core');

        //GET PAGE TABLE
        $tablePage = Engine_Api::_()->getDbtable('pages', 'core');
        $tablePageName = $tablePage->info('name');

        //GET PAGE ID
        $page_id = $tablePage->select()
                ->from($tablePageName, array('page_id'))
                ->where('name = ?', "siteevent_index_view")
                ->query()
                ->fetchColumn();

        if (empty($page_id)) {
            return 0;
        }

        return $tablecontent->select()
                        ->from($tablecontent->info('name'), 'content_id')
                        ->where('name = ?', 'siteeventdocument.profile-siteeventdocuments')
                        ->where('page_id = ?', $page_id)
                        ->limit(1)
                        ->query()
                        ->fetchColumn(0);
    }

    /**
     * Send email to document and page owner if document has been deleted from scirbd
     * @param array $document : document item
     * @param string $siteevent_title : siteevent title
     */
    public function emailDocumentDelete($document, $siteevent_title, $siteevent_user_id) {

        if (empty($document)) {
            return;
        }

        if (empty($siteevent_title)) {
            $siteevent_title = "Event Title";
        }

        $siteevent = Engine_Api::_()->getItem('siteevent_event', $document->event_id);

        $slug = trim(preg_replace('/-+/', '-', preg_replace('/[^a-z0-9-]+/i', '-', strtolower($document->title))), '-');
        $document_title_with_link = '<a href = http://' . $_SERVER['HTTP_HOST'] . Zend_Controller_Front::getInstance()->getRouter()->assemble(array('document_id' => $document->document_id, 'slug' => $slug), 'siteeventdocument_detail_view') . ">$document->title</a>";

        $edit_document_link = 'http://' . $_SERVER['HTTP_HOST'] . Zend_Controller_Front::getInstance()->getRouter()->assemble(array('document_id' => $document->document_id, 'action' => 'edit'), 'siteeventdocument_specific');

        $delete_document_link = 'http://' . $_SERVER['HTTP_HOST'] . Zend_Controller_Front::getInstance()->getRouter()->assemble(array('document_id' => $document->document_id, 'action' => 'delete'), 'siteeventdocument_specific');

        $siteevent_title_with_link = '<a href = http://' . $_SERVER['HTTP_HOST'] . Zend_Controller_Front::getInstance()->getRouter()->assemble(array('event_id' => $document->event_id, 'slug' => $siteevent->getSlug()), 'siteevent_entry_view') . ">$siteevent_title</a>";

        $userTable = Engine_Api::_()->getItemTable('user');
        $document_owner_email_id = $userTable->select()
                ->from($userTable, 'email')
                ->where('`user_id` = ?', $siteevent_user_id)
                ->limit(1)
                ->query()
                ->fetchColumn(0);

        if (!empty($document_owner_email_id)) {
            Engine_Api::_()->getApi('mail', 'core')->sendSystem($document_owner_email_id, 'notify_docowner_siteeventdocument_delete', array(
                'document_title_with_link' => $document_title_with_link,
                'siteevent_title_with_link' => $siteevent_title_with_link,
                'delete_document_link' => $delete_document_link,
                'edit_document_link' => $edit_document_link,
                'queue' => true
            ));
        }

        $userTable = Engine_Api::_()->getItemTable('user');
        $siteevent_owner_email_id = $userTable->select()
                ->from($userTable, 'email')
                ->where('`user_id` = ?', $siteevent->owner_id)
                ->limit(1)
                ->query()
                ->fetchColumn(0);

        if (!empty($siteevent_owner_email_id)) {
            Engine_Api::_()->getApi('mail', 'core')->sendSystem($siteevent_owner_email_id, 'notify_siteeventowner_siteeventdocument_delete', array(
                'document_title_with_link' => $document_title_with_link,
                'siteevent_title_with_link' => $siteevent_title_with_link,
                'delete_document_link' => $delete_document_link,
                'queue' => true
            ));
        }
    }

    /**
     * Delete document from server
     * @param int $document_id : document id
     */
    public function deleteServerDocument($document_id) {

        $document = Engine_Api::_()->getItem('siteeventdocument_document', $document_id);

        $storagemodule = Engine_Api::_()->getDbtable('modules', 'core')->getModule('storage');
        $storageversion = $storagemodule->version;
        if ($storageversion < '4.1.1' && file_exists($document->storage_path) && !empty($document->storage_path)) {
            unlink($document->storage_path);
        }

        if (!empty($document->filename_id)) {
            $storage = Engine_Api::_()->getItem('storage_file', $document->filename_id);
            $fileName = $storage->name;
            $storage->delete();

            $document->storage_path = $fileName;
            $document->filename_id = 0;
            $document->save();
        }
    }

}