<?php

/**
 * SocialEngine
 *
 * @category   Application_Extensions
 * @package    Siteeventdocument
 * @copyright  Copyright 2013-2014 BigStep Technologies Pvt. Ltd.
 * @license    http://www.socialengineaddons.com/license/
 * @version    $Id: Siteeventdocument.php 6590 2014-01-02 00:00:00Z SocialEngineAddOns $
 * @author     SocialEngineAddOns
 */
class Siteeventdocument_Model_Document extends Core_Model_Item_Abstract {

    protected $_owner_type = 'user';
    protected $_parent_type = 'siteevent_event';
    protected $_searchColumns = array('title', 'description', 'fulltext');
    protected $_parent_is_owner = false;

    public function getMediaType() {
        return 'document';
    }

    //ENTRY OF FILE IN STORAGE TABLE
    public function setFile($file_pass) {
        if ($file_pass instanceof Zend_Form_Element_File) {
            $file = $file_pass->getFileName();
        } else if (is_array($file_pass) && !empty($file_pass['tmp_name'])) {
            $file = $file_pass['tmp_name'];
        } else if (is_string($file_pass) && file_exists($file_pass)) {
            $file = $file_pass;
        } else {
            throw new Siteeventdocument_Model_Exception('invalid argument passed to setFile');
        }
        $params = array(
            'parent_type' => 'siteeventdocument_document',
            'parent_id' => $this->getIdentity()
        );

        try {
            $siteeventdocument_return = Engine_Api::_()->storage()->create($file, $params);
        } catch (Exception $e) {
            $msg = $e->getMessage();
            return $msg;
        }

        if (!empty($siteeventdocument_return->file_id)) {

            //UPDATE FILE INFORMATION INTO DATABASE
            $this->modified_date = new Zend_Db_Expr('NOW()');
            $this->filename_id = $siteeventdocument_return->file_id;
            $this->storage_path = APPLICATION_PATH . '/' . $siteeventdocument_return->storage_path;
            $this->save();

            $storagemodule = Engine_Api::_()->getDbtable('modules', 'core')->getModule('storage');
            $storageversion = $storagemodule->version;
            if ($storageversion < '4.1.1') {
                $file_path = $siteeventdocument_return->storage_path;
            } else {
                $file_path = $siteeventdocument_return->map();
            }

            $siteeventdocument_info = array('siteeventdocument' => $this,
                'file_path' => $file_path);
            return $siteeventdocument_info;
        }
    }

    /**
     * Return a file name of document
     *
     * @return file name of document
     * */
    public function getDocumentFileName() {

        //FILENAME FROM STORAGE TABLE
        $tableStorage = Engine_Api::_()->getDbtable('files', 'storage');
        $tableStorageName = $tableStorage->info('name');
        $tableDocumentName = Engine_Api::_()->getDbtable('documents', 'siteeventdocument')->info('name');

        $file_name = $tableStorage->select()
                ->setIntegrityCheck(false)
                ->from($tableDocumentName, array(''))
                ->join($tableStorageName, "$tableStorageName.file_id = $this->filename_id", array('name'))
                ->where($tableStorageName . '.parent_type = ?', 'siteeventdocument_document')
                ->query()
                ->fetchColumn();
        return $file_name;
    }

    /**
     * Gets an absolute URL to the page to view this item
     *
     * @return string
     */
    public function getHref($params = array()) {
        $slug = trim(preg_replace('/-+/', '-', preg_replace('/[^a-z0-9-]+/i', '-', strtolower($this->getTitle()))), '-');

        $tab_id = Engine_Api::_()->siteeventdocument()->getTabId();

        $params = array_merge(array(
            'route' => 'siteeventdocument_detail_view',
            'reset' => true,
            'document_id' => $this->document_id,
            'slug' => $slug,
            'tab_id' => $tab_id,
                ), $params);

        $route = $params['route'];
        $reset = $params['reset'];
        unset($params['route']);
        unset($params['reset']);
        return Zend_Controller_Front::getInstance()->getRouter()
                        ->assemble($params, $route, $reset);
    }

    /**
     * Return a truncate event description
     * */
    public function getDescription() {

        $tmpBody = strip_tags($this->description);
        return ( Engine_String::strlen($tmpBody) > 255 ? Engine_String::substr($tmpBody, 0, 255) . '...' : $tmpBody );
    }

    /**
     * Gets a proxy object for the comment handler
     *
     * @return Engine_ProxyObject
     * */
    public function comments() {
        return new Engine_ProxyObject($this, Engine_Api::_()->getDbtable('comments', 'core'));
    }

    /**
     * Gets a proxy object for the like handler
     *
     * @return Engine_ProxyObject
     * */
    public function likes() {
        return new Engine_ProxyObject($this, Engine_Api::_()->getDbtable('likes', 'core'));
    }

    /**
     * Delete the siteeventdocument and ratings
     * 
     * @param int $document_id
     */
    public function _delete() {

        include_once APPLICATION_PATH . '/application/modules/Siteeventdocument/Api/Scribdsiteevent.php';

        $scribd_api_key = Engine_Api::_()->getApi('settings', 'core')->siteeventdocument_api_key;
        $scribd_secret = Engine_Api::_()->getApi('settings', 'core')->siteeventdocument_secret_key;
        $scribdsiteevent = new Scribdsiteevent($scribd_api_key, $scribd_secret);

        //DELETE DOCUMENT FROM SCRIBD
        if (!empty($this->doc_id)) {
            $scribdsiteevent->my_user_id = $this->owner_id;
            $scribdsiteevent->delete($this->doc_id);
        }

        //DELETE ENTRY FROM engine4_document_fields_search TABLE CORRESPONDIG TO item_id
        $searchTable = Engine_Api::_()->getItem('siteeventdocument_search', $this->document_id);
        if (!empty($searchTable)) {
            $searchTable->delete();
        }

        Engine_Api::_()->getDbtable('ratings', 'siteeventdocument')->delete(array('document_id = ?' => $this->document_id));

        //DELETE DOCUMENT FROM LOCAL SERVER
        $storagemodule = Engine_Api::_()->getDbtable('modules', 'core')->getModule('storage');
        $storageversion = $storagemodule->version;
        if ($storageversion < '4.1.1' && file_exists($this->storage_path) && !empty($this->storage_path)) {
            unlink($this->storage_path);
        }

        //DELETE EVENT
        parent::_delete();
    }

    public function canEdit() {
        $viewer = Engine_Api::_()->user()->getViewer();
        return $this->getParent()->authorization()->isAllowed($viewer, 'edit') || $this->getParent()->authorization()->isAllowed($viewer, 'document.edit') || $this->isOwner($viewer);
    }

}