<?php

/**
 * SocialEngine
 *
 * @category   Application_Extensions
 * @package    Siteeventdocument
 * @copyright  Copyright 2013-2014 BigStep Technologies Pvt. Ltd.
 * @license    http://www.socialengineaddons.com/license/
 * @version    $Id: Menus.php 6590 2010-08-11 9:40:21Z SocialEngineAddOns $
 * @author     SocialEngineAddOns
 */
include_once APPLICATION_PATH . '/application/modules/Siteeventdocument/Api/Scribdsiteevent.php';

class Siteeventdocument_Plugin_Menus {

    //ADD DOCUMENT BACK TO EVENT LINK
    public function onMenuInitialize_SiteeventdocumentGutterBacktoevent() {

        //RETURN FALSE IF SUBJECT IS NOT SET
        if (!Engine_Api::_()->core()->hasSubject('siteeventdocument_document')) {
            return false;
        }

        //GET SUBJECT
        $document = Engine_Api::_()->core()->getSubject();

        $event = Engine_Api::_()->getItem('siteevent_event', $document->event_id);

        return array(
            'class' => 'buttonlink  icon_siteeventdocument_back',
            'route' => 'siteevent_entry_view',
            'params' => array(
                'event_id' => $event->getIdentity(),
                'slug' => $event->getSlug(),
                'tab' => Engine_Api::_()->siteeventdocument()->getTabId(),
            ),
        );
    }

    //ADD DOCUMENT PUBLISH LINK
    public function onMenuInitialize_SiteeventdocumentGutterPublish() {

        //RETURN FALSE IF SUBJECT IS NOT SET
        if (!Engine_Api::_()->core()->hasSubject('siteeventdocument_document')) {
            return false;
        }

        //GET SUBJECT
        $document = Engine_Api::_()->core()->getSubject();
        if (empty($document->draft)) {
            return false;
        }

        //USER IS ALLOWED FOR PUBLISH OR NOT
        $canEdit = $document->canEdit();
        if (!$canEdit) {
            return false;
        }

        return array(
            'class' => 'buttonlink smoothbox icon_siteeventdocument_publish',
            'route' => 'siteeventdocument_specific',
            'params' => array(
                'action' => 'publish',
                'document_id' => $document->getIdentity(),
            ),
        );
    }

    //ADD DOCUMENT EDIT LINK
    public function onMenuInitialize_SiteeventdocumentGutterEdit($row) {

        //RETURN FALSE IF SUBJECT IS NOT SET
        if (!Engine_Api::_()->core()->hasSubject('siteeventdocument_document')) {
            return false;
        }

        //GET SUBJECT
        $document = Engine_Api::_()->core()->getSubject();

        //USER IS ALLOWED FOR PUBLISH OR NOT
        $canEdit = $document->canEdit();
        if (!$canEdit) {
            return false;
        }

        return array(
            'class' => 'buttonlink icon_siteeventdocument_edit',
            'route' => 'siteeventdocument_specific',
            'params' => array(
                'action' => 'edit',
                'document_id' => $document->getIdentity(),
            ),
        );
    }

    //ADD DOCUMENT SHARE LINK
    public function onMenuInitialize_SiteeventdocumentGutterShare() {

        //RETURN FALSE IF SUBJECT IS NOT SET
        if (!Engine_Api::_()->core()->hasSubject('siteeventdocument_document')) {
            return false;
        }

        //GET VIEWER
        $viewer = Engine_Api::_()->user()->getViewer();
        $viewer_id = $viewer->getIdentity();

        //GET SUBJECT
        $document = Engine_Api::_()->core()->getSubject();
        if (empty($viewer_id) || $document->draft == 1 || empty($document->approved) || $document->status != 1) {
            return false;
        }

        return array(
            'class' => 'smoothbox buttonlink seaocore_icon_share',
            'route' => 'default',
            'params' => array(
                'module' => 'activity',
                'controller' => 'index',
                'action' => 'share',
                'type' => $document->getType(),
                'id' => $document->getIdentity(),
                'format' => 'smoothbox',
            ),
        );
    }

    //ADD DOCUMENT DOWNLOAD LINK
    public function onMenuInitialize_SiteeventdocumentGutterDownload($row) {

        //RETURN FALSE IF SUBJECT IS NOT SET
        if (!Engine_Api::_()->core()->hasSubject('siteeventdocument_document')) {
            return false;
        }

        //GET VIEWER
        $viewer = Engine_Api::_()->user()->getViewer();
        $viewer_id = $viewer->getIdentity();

        //GET SUBJECT
        $document = Engine_Api::_()->core()->getSubject();
        if (empty($viewer_id)) {
            return false;
        }

        //DOWNLOAD IS ALLOWED OR NOT FOR THIS LEVEL
        $view_download_allow = Engine_Api::_()->getApi('settings', 'core')->getSetting('siteeventdocument.download.allow', 1);
        if (empty($view_download_allow) || empty($document->download_allow)) {
            return false;
        }

        //GET SCRIBD DETAIL
        $scribd_api_key = Engine_Api::_()->getApi('settings', 'core')->siteeventdocument_api_key;
        $scribd_secret = Engine_Api::_()->getApi('settings', 'core')->siteeventdocument_secret_key;
        $scribd = new Scribdsiteevent($scribd_api_key, $scribd_secret);

        //SET SCRIBD USER ID
        $scribd->my_user_id = $document->owner_id;

        //DOCUMENT FORMAT FOR THIS LEVEL
        $download_format = Engine_Api::_()->getApi('settings', 'core')->getSetting('siteeventdocument.download.format', 'pdf');
        $link = '';
        try {
            $link = $scribd->getDownloadUrl($document->doc_id, $download_format);
            $link = trim($link['download_link']);
        } catch (Exception $e) {
            $this->view->excep_message = $message = $e->getMessage();
            $this->view->excep_error = 1;
        }

        if (empty($link)) {
            return false;
        }

        return array(
            'class' => 'buttonlink icon_siteeventdocument_download',
            'uri' => $link,
            'target' => '_blank'
        );
    }

    //ADD DOCUMENT EMAIL LINK
    public function onMenuInitialize_SiteeventdocumentGutterEmail($row) {

        //RETURN FALSE IF SUBJECT IS NOT SET
        if (!Engine_Api::_()->core()->hasSubject('siteeventdocument_document')) {
            return false;
        }

        //GET VIEWER
        $viewer = Engine_Api::_()->user()->getViewer();
        $viewer_id = $viewer->getIdentity();

        //GET SUBJECT
        $document = Engine_Api::_()->core()->getSubject();
        if (empty($viewer_id) || $document->status != 1) {
            return false;
        }

        //EMAIL IS ALLOWED OR NOT
        $view_email_allow = Engine_Api::_()->getApi('settings', 'core')->getSetting('siteeventdocument.email.allow', 1);
        if (empty($view_email_allow) || empty($document->email_allow)) {
            return false;
        }

        return array(
            'class' => 'buttonlink smoothbox icon_siteeventdocuments_email',
            'route' => 'siteeventdocument_specific',
            'params' => array(
                'action' => 'email',
                'document_id' => $document->getIdentity(),
            ),
        );
    }

    //ADD DOCUMENT REPORT LINK
    public function onMenuInitialize_SiteeventdocumentGutterReport() {

        //RETURN FALSE IF SUBJECT IS NOT SET
        if (!Engine_Api::_()->core()->hasSubject('siteeventdocument_document')) {
            return false;
        }

        //GET VIEWER
        $viewer = Engine_Api::_()->user()->getViewer();
        $viewer_id = $viewer->getIdentity();

        //GET SUBJECT
        $document = Engine_Api::_()->core()->getSubject();
        if (empty($viewer_id)) {
            return false;
        }

        return array(
            'class' => 'smoothbox buttonlink seaocore_icon_report',
            'route' => 'default',
            'params' => array(
                'module' => 'core',
                'controller' => 'report',
                'action' => 'create',
                'subject' => $document->getGuid(),
                'format' => 'smoothbox',
            ),
        );
    }

    //ADD DOCUMENT DELETE LINK
    public function onMenuInitialize_SiteeventdocumentGutterDelete() {

        //RETURN FALSE IF SUBJECT IS NOT SET
        if (!Engine_Api::_()->core()->hasSubject('siteeventdocument_document')) {
            return false;
        }

        //GET SUBJECT
        $document = Engine_Api::_()->core()->getSubject();

        //USER IS ALLOWED OR NOT
        $canEdit = $document->canEdit();
        if (!$canEdit) {
            return false;
        }

        return array(
            'class' => 'buttonlink smoothbox icon_siteeventdocument_delete',
            'route' => 'siteeventdocument_specific',
            'params' => array(
                'action' => 'delete',
                'document_id' => $document->getIdentity(),
            ),
        );
    }

}