<?php

/**
 * SocialEngine
 *
 * @category   Application_Extensions
 * @package    Siteeventdocument
 * @copyright  Copyright 2013-2014 BigStep Technologies Pvt. Ltd.
 * @license    http://www.socialengineaddons.com/license/
 * @version    $Id: AdminManageController.php 6590 2014-01-02 00:00:00Z SocialEngineAddOns $
 * @author     SocialEngineAddOns
 */
class Siteeventdocument_AdminManageController extends Core_Controller_Action_Admin {

    //ACTION FOR MANAGE THE DOCUMENTS
    public function indexAction() {
        //GET NAVIGATION
        $this->view->navigation = Engine_Api::_()->getApi('menus', 'core')
                ->getNavigation('siteevent_admin_main_document', array(), 'siteeventdocument_admin_main_manage');

        //GET NAVIGATION
        $this->view->navigationEvent = Engine_Api::_()->getApi('menus', 'core')
                ->getNavigation('siteevent_admin_main', array(), 'siteevent_admin_main_document');

        $siteeventdocument_admin_tab = '';

        //FORM GENERATION
        $this->view->formFilter = $formFilter = new Siteeventdocument_Form_Admin_Manage_Filter();
        include APPLICATION_PATH . '/application/modules/Siteeventdocument/controllers/license/license2.php';
        $page = $this->_getParam('page', 1);

        //GET USER TABLE
        $tableUser = Engine_Api::_()->getItemTable('user')->info('name');

        //GET SITEEVENT TABLE
        $tableSiteevent = Engine_Api::_()->getItemTable('siteevent_event')->info('name');

        //GET DOCUMENT TABLE
        $tableDocument = Engine_Api::_()->getDbtable('documents', 'siteeventdocument');
        $tableDocumentName = $tableDocument->info('name');

        //MAKE QUERY
        $select = $tableDocument->select()
                ->setIntegrityCheck(false)
                ->from($tableDocumentName)
                ->joinLeft($tableUser, "$tableDocumentName.owner_id = $tableUser.user_id", 'username')
                ->joinLeft($tableSiteevent, "$tableDocumentName.event_id = $tableSiteevent.event_id", 'title AS siteevent_title');

        //GET FORM VALUES
        $values = array();
        if ($formFilter->isValid($this->_getAllParams())) {
            $values = $formFilter->getValues();
        }

        foreach ($values as $key => $value) {
            if (null === $value) {
                unset($values[$key]);
            }
        }

        $values = array_merge(array(
            'order' => 'document_id',
            'order_direction' => 'DESC',
                ), $values);

        $this->view->assign($values);

        $select->order((!empty($values['order']) ? $values['order'] : 'document_id' ) . ' ' . (!empty($values['order_direction']) ? $values['order_direction'] : 'DESC' ));

        //GET PAGINATOR
        $this->view->paginator = $paginator = Zend_Paginator::factory($select);
        $this->view->paginator->setItemCountPerPage(50);
        $this->view->paginator = $paginator->setCurrentPageNumber($page);
    }

    //ACTION FOR MAKE SITEEVENT-DOCUMENT APPROVED/DIS-APPROVED
    public function approvedAction() {
        //GET DOCUMENT ID
        $document_id = $this->_getParam('id');

        //BEGIN TRANSACTION
        $db = Engine_Db_Table::getDefaultAdapter();
        $db->beginTransaction();

        try {
            //GET DOCUMENT OBJECT
            $siteeventdocument = Engine_Api::_()->getItem('siteeventdocument_document', $document_id);

            if ($siteeventdocument->approved == 0) {
                $siteeventdocument->approved = 1;
            } else {
                $siteeventdocument->approved = 0;
            }

            //SAVE IN DATABASE
            $siteeventdocument->save();

            //COMMIT
            $db->commit();
        } catch (Exception $e) {
            $db->rollBack();
            throw $e;
        }

        //REDIRECT
        $this->_redirect('admin/siteeventdocument/manage');
    }

    //ACTION FOR MAKE SITEEVENT-DOCUMENT FEATURED/UN-FEATURED
    public function featuredAction() {
        //GET DOCUMENT ID
        $document_id = $this->_getParam('id');

        //BEGIN TRANSACTION
        $db = Engine_Db_Table::getDefaultAdapter();
        $db->beginTransaction();

        try {
            //GET DOCUMENT OBJECT
            $siteeventdocument = Engine_Api::_()->getItem('siteeventdocument_document', $document_id);

            if ($siteeventdocument->featured == 0) {
                $siteeventdocument->featured = 1;
            } else {
                $siteeventdocument->featured = 0;
            }

            //SAVE IN DATABASE
            $siteeventdocument->save();

            //COMMIT
            $db->commit();
        } catch (Exception $e) {
            $db->rollBack();
            throw $e;
        }

        //REDIRECT
        $this->_redirect('admin/siteeventdocument/manage');
    }

    //ACTION FOR DELETE THE SITEEVENT-DOCUMENT
    public function deleteAction() {
        //SET LAYOUT
        $this->_helper->layout->setLayout('admin-simple');

        //GET DOCUMENT ID
        $this->view->document_id = $document_id = $this->_getParam('id');

        if ($this->getRequest()->isPost()) {

            //DELETE DOCUMENT FROM LOCAL STORAGE
            Engine_Api::_()->getItem('siteeventdocument_document', $document_id)->delete();

            $this->_forward('success', 'utility', 'core', array(
                'smoothboxClose' => 10,
                'parentRefresh' => 10,
                'messages' => array('')
            ));
        }

        //RENDER SCRIPT
        $this->renderScript('admin-manage/delete.tpl');
    }

    //ACTION FOR MULTI DELETE DOCUMENTS
    public function multiDeleteAction() {
        if ($this->getRequest()->isPost()) {
            $values = $this->getRequest()->getPost();
            foreach ($values as $key => $value) {
                if ($key == 'delete_' . $value) {

                    $document_id = (int) $value;

                    //DELETE DOCUMENT BELONGINGS
                    Engine_Api::_()->getItem('siteeventdocument_document', $document_id)->delete();
                }
            }
        }

        //REDIRECT
        return $this->_helper->redirector->gotoRoute(array('action' => 'index'));
    }

}