<?php

/**
 * SocialEngine
 *
 * @category   Application_Extensions
 * @package    Siteeventticket
 * @copyright  Copyright 2015-2016 BigStep Technologies Pvt. Ltd.
 * @license    http://www.socialengineaddons.com/license/
 * @version    $Id: PaymentController.php 2015-05-11 00:00:00Z SocialEngineAddOns $
 * @author     SocialEngineAddOns
 */
class Siteeventticket_PaymentController extends Siteapi_Controller_Action_Standard {

    protected $_user;
    protected $_user_order;

    public function init() {

        // Get user and session
        $user_order_id = $this->getRequestParam('user_order_id');
        // Check viewer and user
        if (!empty($user_order_id)) {
            $this->_user_order = Engine_Api::_()->getItem('siteeventticket_order', $user_order_id);
        }
        $this->_user = Engine_Api::_()->user()->getViewer();
    }

    public function processAction() {
        Engine_Api::_()->getApi('Core', 'siteapi')->setView();

        if (!$this->_user_order) {
            $this->respondWithError('unauthorized');
        }
        try {
            $parent_order_id = $this->_user_order->order_id;
            $event_id = $checkout_event_id = $this->getRequestParam('checkout_event_id');
            if (!empty($checkout_event_id)) {
                $plugin = 'Payment_Plugin_Gateway_PayPal';
                if (Engine_Api::_()->hasModuleBootstrap('sitegateway')) {
                    $gatewayObject = Engine_Api::_()->getItem('payment_gateway', $this->_user_order->gateway_id);
                    if (!empty($gatewayObject)) {
                        $plugin = $gatewayObject->plugin;
                    }
                }

                $event_gateway_id = Engine_Api::_()->getDbtable('sellergateways', 'siteeventticket')->getPayPalGatewayId($event_id, $plugin);
                if (empty($event_gateway_id)) {
                    $this->respondWithError('unauthorized');
                }
            }
            // Get order
            if (!$parent_order_id ||
                    !($user_order = Engine_Api::_()->getItem('siteeventticket_order', $parent_order_id))) {
                $this->respondWithError('unauthorized');
            }

            // Process
            $ordersTable = Engine_Api::_()->getDbtable('orders', 'payment');

            $sourceType = 'siteeventticket_order';
            $sourceId = $parent_order_id;
            $gateway_id = $user_order->gateway_id;
            // Create order
            $ordersTable->insert(array(
                'user_id' => Engine_Api::_()->user()->getViewer()->getIdentity(),
                'gateway_id' => $gateway_id,
                'state' => 'pending',
                'creation_date' => new Zend_Db_Expr('NOW()'),
                'source_type' => $sourceType,
                'source_id' => $sourceId,
            ));
            $order_id = $ordersTable->getAdapter()->lastInsertId();

            if (empty($event_id))
                $gateway = Engine_Api::_()->getItem('siteeventticket_usergateway', $gateway_id);
            else
                $gateway = Engine_Api::_()->getItem('siteeventticket_sellergateway', $event_gateway_id);

            $coreSettings = Engine_Api::_()->getApi('settings', 'core');
            if (Engine_Api::_()->hasModuleBootstrap('sitegateway') && $coreSettings->getSetting('sitegateway.stripeconnect', 0)) {
                $stripeGatewayId = Engine_Api::_()->sitegateway()->getGatewayColumn(array('plugin' => 'Sitegateway_Plugin_Gateway_Stripe', 'columnName' => 'gateway_id'));
                if ($gateway_id == $stripeGatewayId) {
                    if ($coreSettings->getSetting('sitegateway.stripechargemethod', 1) && !$coreSettings->getSetting('siteeventticket.payment.to.siteadmin', 0)) {
                        $gateway = Engine_Api::_()->getItem('siteeventticket_usergateway', $gateway_id);
                    } elseif (!$coreSettings->getSetting('sitegateway.stripechargemethod', 1) && $coreSettings->getSetting('siteeventticket.payment.to.siteadmin', 0)) {
                        $eventGatewayObj = Engine_Api::_()->getDbtable('gateways', 'siteeventticket')->fetchRow(array('event_id = ?' => $user_order->event_id, 'plugin LIKE \'Sitegateway_Plugin_Gateway_Stripe\''));
                        $gateway = Engine_Api::_()->getItem('siteeventticket_gateway', $eventGatewayObj->gateway_id);
                    }
                }
            }

            // Get gateway plugin
            $gatewayPlugin = $gateway->getGateway();
            $plugin = $gateway->getPlugin();

            // Prepare host info
            $schema = 'http://';
            if (!empty($_ENV["HTTPS"]) && 'on' == strtolower($_ENV["HTTPS"])) {
                $schema = 'https://';
            }
            $host = $_SERVER['HTTP_HOST'];

            // Prepare transaction
            $params = array();
//    $params['language'] = $this->_user->language;
            $params['vendor_order_id'] = $order_id;
            $params['return_url'] = $schema . $host
                    . Zend_Controller_Front::getInstance()->getRouter()->assemble(array('action' => 'return', 'controller' => 'payment', 'module' => 'siteeventticket'), 'default')
                    . '?order_id=' . $order_id
                    . '&state=' . 'return';
            $params['cancel_url'] = $schema . $host
                    . Zend_Controller_Front::getInstance()->getRouter()->assemble(array('action' => 'return', 'controller' => 'payment', 'module' => 'siteeventticket'), 'default')
                    . '?order_id=' . $order_id
                    . '&state=' . 'cancel';
            $params['ipn_url'] = $schema . $host
                    . Zend_Controller_Front::getInstance()->getRouter()->assemble(array('action' => 'index', 'controller' => 'ipn', 'module' => 'payment'), 'default')
                    . '?order_id=' . $order_id;
            if (!empty($event_id)) {
                $params['event_id'] = $event_id;

                $params['return_url'] .= '&event_id=' . $event_id . '&event_gateway_id=' . $event_gateway_id;
                $params['cancel_url'] .= '&event_id=' . $event_id . '&event_gateway_id=' . $event_gateway_id;
                $params['ipn_url'] .= '&event_id=' . $event_id . '&event_gateway_id=' . $event_gateway_id;
            }

            $params['source_type'] = $sourceType;
            // Process transaction
            $transaction = $plugin->createUserOrderTransaction($parent_order_id, $params, $this->_user);
            $transactionUrl = $gatewayPlugin->getGatewayUrl();
            $transactionMethod = $gatewayPlugin->getGatewayMethod();
            $transactionData = $transaction->getData();

            // Handle redirection
            $transactionUrl .= '?' . http_build_query($transactionData);
            $response['order_id'] = $order_id;
            $response['method'] = 'online';
            $response['webviewUrl'] = $transactionUrl;
            $this->respondWithSuccess($response, true);
        } catch (Exception $ex) {
            $this->respondWithValidationError('internal_server_error', $ex->getMessage());
        }
    }

}
