<?php

/**
 * SocialEngine
 *
 * @category   Application_Extensions
 * @package    Siteeventticket
 * @copyright  Copyright 2013-2014 BigStep Technologies Pvt. Ltd.
 * @license    http://www.socialengineaddons.com/license/
 * @version    $Id: IndexController.php 6590 2014-01-02 00:00:00Z SocialEngineAddOns $
 * @author     SocialEngineAddOns
 */
class Siteeventticket_TicketController extends Siteapi_Controller_Action_Standard {

    protected $_get_ticket_id;

    public function init() {

        if (!$this->_helper->requireAuth()->setAuthParams('siteevent_event', null, "view")->isValid()) {
            $this->respondWithError('unauthorized');
        }

        $ticket = Engine_Api::_()->getApi('settings', 'core')->getSetting('siteeventticket.ticket.enabled', 1);
        if (empty($ticket)) {
            $this->respondWithError('unauthorized');
        }

        // Set Subject
        if ($this->getRequestParam('event_id') && (0 !== ($event_id = (int) $this->getRequestParam('event_id')) &&
                null !== ($siteevent = Engine_Api::_()->getItem('siteevent_event', $event_id))))
            Engine_Api::_()->core()->setSubject($siteevent);

        // User validation 
        if (!$this->_helper->requireUser()->isValid())
            $this->respondWithError('unauthorized');
    }

    public function indexAction() {
        $viewer = Engine_Api::_()->user()->getViewer();
        $viewer_id = $viewer->getIdentity();
        Engine_Api::_()->getApi('Core', 'siteapi')->setView();

        //RETURN IF VIEWER IS EMPTY
        if (empty($viewer_id)) {
            $this->respondWithError('unauthorized');
        }

        //MUST BE ABLE TO VIEW EVENTS
        if (!Engine_Api::_()->authorization()->isAllowed('siteevent_event', $viewer, "view")) {
            $this->respondWithError('unauthorized');
        }

        if (!Engine_Api::_()->getApi('settings', 'core')->getSetting('siteeventticket.ticket.enabled', 1)) {
            $this->respondWithError('unauthorized');
        }

        $params = array();
        $params['user_id'] = $viewer_id;
        $params['viewType'] = $this->getRequestParam('viewType', 'current');
        $params['my_tickets_page'] = true;

        try {
            //MAKE PAGINATOR
            $paginator = Engine_Api::_()->getDbtable('orders', 'siteeventticket')->getOrdersPaginator($params);
            if ($params['viewType'] == 'current') {
                $totalUpcomingOrderCount = $paginator->getTotalItemCount();

                //CALCULATE PAST ORDERS COUNT
                $params['viewType'] = 'past';
                $totalPastOrderCount = Engine_Api::_()->getDbtable('orders', 'siteeventticket')->getOrdersPaginator($params)->getTotalItemCount();
            } else {
                $totalPastOrderCount = $paginator->getTotalItemCount();

                //CALCULATE CURRENT ORDERS COUNT
                $params['viewType'] = 'current';
                $totalUpcomingOrderCount = Engine_Api::_()->getDbtable('orders', 'siteeventticket')->getOrdersPaginator($params)->getTotalItemCount();
            }

            $response['totalUpcomingOrderCount'] = $totalUpcomingOrderCount;
            $response['totalPastOrderCount'] = $totalPastOrderCount;
            $total_item = $paginator->getTotalItemCount($paginator);

            $paginator->setItemCountPerPage($total_item);
            foreach ($paginator as $ticket) {
                $ticketArray = $ticket->toArray();

                if (isset($ticketArray['ip_address']) && !empty($ticketArray['ip_address']))
                    unset($ticketArray['ip_address']);

                $ticketArray['creation_date'] = Engine_Api::_()->getApi('Siteapi_Core', 'Siteeventticket')->getFormattedDate($ticketArray['creation_date']);
                $ticketArray['occurrence_starttime'] = Engine_Api::_()->getApi('Siteapi_Core', 'Siteeventticket')->getFormattedDate($ticketArray['occurrence_starttime']);
                $ticketArray['occurrence_endtime'] = Engine_Api::_()->getApi('Siteapi_Core', 'Siteeventticket')->getFormattedDate($ticketArray['occurrence_endtime']);

                //Set event title
                $event = Engine_Api::_()->getItem('siteevent_event', $ticket->event_id);

                if($event)
                    $ticketArray['event_title'] = $event->getTitle();

                $ticketDetails = Engine_Api::_()->getDbtable('orderTickets', 'siteeventticket')->getOrderTicketsDetail(array('order_id' => $ticket->order_id, 'columns' => array('title', 'quantity')));
                foreach ($ticketDetails as $ticketDetail) {
                    $ticketArray['order_info'][$ticketDetail->title] = $ticketDetail->quantity;
                }
                foreach ($ticketDetails as $ticketDetail) {
                    $ticketArray['order_info_ios'][][$ticketDetail->title] = $ticketDetail->quantity;
                }

                //Set coupon images
                $getCouponImages = Engine_Api::_()->getApi('Core', 'siteapi')->getContentImage($event, false);
                $ticketArray = array_merge($ticketArray, $getCouponImages);

                if($getCouponImages)
                    $ticketArray['menus'] = $this->_getTicketMenus($ticket->order_id);

                $tempResponse[] = $ticketArray;
            }
            if (!empty($getCouponImages))
                $response['response'] = $tempResponse;
            $this->respondWithSuccess($response, true);
        } catch (Exception $ex) {
            $this->respondWithError('internal_server_error', $ex->getMessage());
        }
    }

    public function ticketsBuyAction() {
        $viewer = Engine_Api::_()->user()->getViewer();
        $viewer_id = $viewer->getIdentity();
        if (!$viewer_id) {
            $this->respondWithError('unauthorized');
        }

        if (!Engine_Api::_()->core()->hasSubject('siteevent_event')) {
            $this->respondWithError('no_record');
        }
        Engine_Api::_()->getApi('Core', 'siteapi')->setView();
        $siteevent = Engine_Api::_()->core()->getSubject('siteevent_event');

        $params = $this->_getAllParams();
        $event_id = $params['event_id'];

        // Get ticket quantity Array
        $ticketArray = $this->_getTicketQuantity($params);
        try {

            //IF TAX IS MANDATORY AND NOT 
            $taxEnabled = Engine_Api::_()->getApi('settings', 'core')->getSetting('siteeventticket.tax.enabled', 0);
            $taxMandatory = Engine_Api::_()->getApi('settings', 'core')->getSetting('siteeventticket.tax.mandatory', 0);
            $taxEventEnabled = Engine_Api::_()->getDbtable('otherinfo', 'siteevent')->getColumnValue($params['event_id'], 'is_tax_allow');
            $tax_rate = Engine_Api::_()->getDbtable('otherinfo', 'siteevent')->getColumnValue($params['event_id'], 'tax_rate');

            if (($taxEnabled && $taxMandatory && (empty($tax_rate) || $tax_rate <= 0))) {
                $this->respondWithError('unauthorized');
            }

            //APPLY TAX ON TICKET SUBTOTAL
            if ($taxEnabled && $taxEventEnabled && $tax_rate > 0) {
                $tax_rate = $tax_rate;
            }

            try {
                $defaultoccurrence_id = $this->_getParam('defaultoccurrence_id', Engine_Api::_()->getDbTable('occurrences', 'siteevent')->getOccurrence());
            } catch (Exception $ex) {
                
            }

            //DEFAULT OCCURRENCE FIRST TIME
            if ($occurrence_id) {
                $params['occurrence_id'] = $occurrence_id;
            } else {
                $params['occurrence_id'] = $defaultoccurrence_id;
            }

            $datesInfo = Engine_Api::_()->getDbtable('occurrences', 'siteevent')->getAllOccurrenceDates($params['event_id'], 0, array('notIncludePastEvents' => 1));

            //DISPLAY HIDDEN TICKETS TO OWNER,ADMIN,SUPER-ADMIN,MODERATORE,LEADER,HOST
            $isLeader = $siteevent->getLeaderList()->get($viewer);
            $host = $siteevent->getHost();
            $host_id = 0;
            if (!empty($host) && $host->getType() == 'user') {
                $host_id = $siteevent->getHost()->getIdentity();
            }
            $params['hiddenTickets'] = false;
            if ($siteevent->isOwner($viewer) || ($viewer->level_id == 1) || $isLeader || ($host_id == $viewer_id)) {
                $params['hiddenTickets'] = true;
            }
            //END
            //CHECK THE COUPON SECTION VISIBILITY
            $showCouponSection = false;
            if (Engine_Api::_()->authorization()->isAllowed('siteevent_event', $siteevent->getOwner(), 'coupon_creation') && Engine_Api::_()->getDbTable('coupons', 'siteeventticket')->getEventCouponCount(array('event_id' => $siteevent->event_id))) {
                $showCouponSection = true;
            }

            //CHECK THE CAPACITY 
            $capacityApplicable = 0;
            if (Engine_Api::_()->getApi('settings', 'core')->getSetting('siteevent.waitlist', 1) && !empty($siteevent->capacity)) {
                $capacityApplicable = 1;
            }

            //DISPLAY TICKETS IN ORDER SELECTED IN WIDGET SETTING
            if (empty($orderBy)) {
                $params['orderby'] = $this->_getParam('orderby', 'ticket_id');
            }

            $params['columns'] = array('status', 'price', 'title', 'quantity', 'ticket_id', 'description', 'is_claimed_display', 'quantity', 'is_same_end_date', 'sell_endtime', 'sell_starttime', 'buy_limit_min', 'buy_limit_max');

            if (Engine_Api::_()->siteevent()->hasPackageEnable()) {
                $package = Engine_Api::_()->getItem('siteeventpaid_package', $siteevent->package_id);
                if (!empty($package) && empty($package->ticket_type)) {
                    $params['showOnlyFreeTickets'] = 1;
                }
            }

            $paginator = $paginator = Engine_Api::_()->getDbTable('tickets', 'siteeventticket')->getTicketsPaginator($params);
            $count = $paginator->getTotalItemCount();
            $currency = Engine_Api::_()->getApi('settings', 'core')->getSetting('payment.currency', 'USD');
            // Prepare Response work start here
            // Set multioptions for Multiple Occurence Events
            if (!empty($datesInfo) && count($datesInfo) > 1) {
                foreach ($datesInfo as $key => $date) {
                    $occurence['starttime'] = Engine_Api::_()->getApi('Siteapi_Core', 'Siteeventticket')->getFormattedDate($date['starttime']);
                    $occurence['endtime'] = Engine_Api::_()->getApi('Siteapi_Core', 'Siteeventticket')->getFormattedDate($date['endtime']);
                    $occurence['occurrence_id'] = $date['occurrence_id'];
                    $totalOccurence[] = $occurence;
                }

                if (isset($totalOccurence) && !empty($totalOccurence)) {
                    $response['occurence'] = $totalOccurence;
                }
            }
            //End multioptions work
            // Set default values
            $response['subTotal'] = 0;
            $response['discountPrice'] = 0;
            $response['tax'] = 0;
            $response['grandTotal'] = 0;
            $response['currency'] = Engine_Api::_()->getApi('settings', 'core')->getSetting('payment.currency', 'USD');
            $tabs['name_column'] = $this->translate("Ticket Name");
            $tabs['claimed_column'] = $this->translate("Claimed Tickets");
            $tabs['close_column'] = $this->translate("Ticket sale will be closed on");
            $tabs['price_column'] = $this->translate("Price");
            $tabs['name'] = $this->translate("Qty");
            $response['tabs'] = $tabs;
            $response['occurrence_id'] = $params['occurrence_id'];
            foreach ($paginator as $item) {
                $itemArray = $item->toArray();

                $itemArray['starttime'] = Engine_Api::_()->getApi('Siteapi_Core', 'Siteeventticket')->getFormattedDate($itemArray['starttime']);
                $itemArray['endtime'] = Engine_Api::_()->getApi('Siteapi_Core', 'Siteeventticket')->getFormattedDate($itemArray['endtime']);

                $itemArray['description'] = $item->description ? $item->description : $item->title;
                if (!empty($item->ticket_id_sold)) {
                    $ticketDetailArray = Zend_Json_Decoder::decode($item->ticket_id_sold);
                    $ticket_sold = $ticketDetailArray['tid_' . $item->ticket_id];
                }
                if ($item->is_claimed_display) {
                    $claimed_column_display = true;
                    if ($item->price > 0)
                        $itemArray['quantity'] = $this->translate($ticket_sold . " of " . $item->quantity . " sold");
                    else
                        $itemArray['quantity'] = $this->translate($ticket_sold . " of " . $item->quantity . " claimed");
                }

                if (isset($ticketArray[$item->ticket_id]) && !empty($ticketArray[$item->ticket_id])) {
                    $tempCartInfoForCoupon[$params['event_id']]['ticket_ids'][$item->ticket_id] = $item->ticket_id;
                    $tempCartInfoForCoupon[$params['event_id']]['unitPrice'][$item->ticket_id] = $item->price;
                }
                if (isset($ticketArray[$item->ticket_id]) && !empty($ticketArray[$item->ticket_id]) && !empty($item->price) && $item->price > 0) {
                    $response['subTotal'] = $response['subTotal'] + $item->price * $ticketArray[$item->ticket_id];
                }

                if ($item->is_same_end_date)
                    $sellClosedOn = Engine_Api::_()->getApi('Siteapi_Core', 'Siteeventticket')->getFormattedDate($item->starttime);
                else if ($item->sell_endtime > $item->endtime)
                    $sellClosedOn = Engine_Api::_()->getApi('Siteapi_Core', 'Siteeventticket')->getFormattedDate($item->endtime);
                else
                    $sellClosedOn = Engine_Api::_()->getApi('Siteapi_Core', 'Siteeventticket')->getFormattedDate($item->sell_endtime);

                $itemArray['sell_endtime'] = $sellClosedOn;

                Engine_Api::_()->getApi('Core', 'siteapi')->setLocal();
                Engine_Api::_()->getApi('Core', 'siteapi')->setLocal();
                if ($item->price > 0) {
                    $itemArray['price'] = Engine_Api::_()->getApi('Siteapi_Core', 'Siteeventticket')->getPriceWithCurrency($item->price);
                    $itemArray['price'] = (int) str_replace(",", "", $itemArray['price']);
                } else
                    $itemArray['price'] = $this->translate('Free');


                if ($item->status == 'open') {
                    if ($sellClosedOn < date('Y-m-d H:i:s')) {
                        $itemArray['status'] = $this->translate("Sale ended");
                        $itemArray['statusColor'] = 'R';
                    } elseif ($item->sell_starttime > date('Y-m-d H:i:s')) {
                        $itemArray['status'] = $this->translate("Sale starts on : ") . $item->sell_starttime;
                        $itemArray['statusColor'] = 'G';
                    } else {
                        if ($ticket_sold >= $item->quantity) {
                            $itemArray['status'] = $this->translate("Sold Out");
                            $itemArray['statusColor'] = 'R';
                        } else {
                            $itemArray['status'] = 1;
                            $itemArray['statusColor'] = 'B';
                            $ticket_for_sale = 1;
                            $min = $item->buy_limit_min;
                            $max = $item->buy_limit_max;
                            $remainingsTickets = $item->quantity - $ticket_sold;
                            if ($min > $remainingsTickets)
                                $min = $remainingsTickets;

                            if ($max > $remainingsTickets)
                                $max = $remainingsTickets;

                            if ($min == 0)
                                $min = 1;
                        }
                    }
                }
                $tempArray[] = $itemArray;
            }

            $response['showCouponSection'] = $showCouponSection;

            // Apply Coupon work start here
            $response['canApplyCoupon'] = (!empty($showCouponSection)) ? 1 : 0;
            if (isset($params['coupon_code']) && !empty($params['coupon_code']))
                $response['coupon_info'] = Engine_Api::_()->getApi('Siteapi_Core', 'Siteeventticket')->canApplyCoupon($tempCartInfoForCoupon, $ticketArray, $response['subTotal'], $params['coupon_code'], $params['event_id']);

            $couponParams = unserialize($response['coupon_info']['siteeventticketCouponDetail']);
            if (isset($response['canApplyCoupon']) && !empty($response['canApplyCoupon']) && isset($params['coupon_code']) && !empty($params['coupon_code']) && isset($response['coupon_info']['siteeventticketCouponDetail'])) {
                $coupon_id = Engine_Api::_()->getDbtable('coupons', 'siteeventticket')->getCouponInfo(array("fetchColumn" => 1, "coupon_code" => $params['coupon_code']));
                $siteeventticketcoupon = Engine_Api::_()->getItem('siteeventticket_coupon', $coupon_id);
                if (!empty($siteeventticketcoupon->discount_type)) { //FOR FIXED PRICE OFF
                    $discountedCouponPrice = $siteeventticketcoupon->discount_amount;
                } else {
                    //For off from each ticket amount
                    foreach ($couponParams as $key => $value) {
                        $ticket = Engine_Api::_()->getItem('siteeventticket_ticket', $key);
                        $discountedCouponPrice += $ticket->price * $ticketArray[$key] * ($siteeventticketcoupon->discount_amount / 100);
                    }
                }
                $response['coupon_code'] = $params['coupon_code'];
            }

            $response['grandTotal'] = Engine_Api::_()->getApi('Siteapi_Core', 'Siteeventticket')->getPriceWithCurrency($response['subTotal']);
            $response['grandTotal'] = (int) str_replace(',', '', $response['grandTotal']);
            if (isset($discountedCouponPrice) && !empty($discountedCouponPrice)) {
                $response['discountPrice'] = Engine_Api::_()->getApi('Siteapi_Core', 'Siteeventticket')->getPriceWithCurrency($discountedCouponPrice);
                $response['discountPrice'] = (int) str_replace(',', '', $response['discountPrice']);
                $response['grandTotal'] = Engine_Api::_()->getApi('Siteapi_Core', 'Siteeventticket')->getPriceWithCurrency($response['subTotal'] - $discountedCouponPrice);
                $response['grandTotal'] = str_replace(',', '', $response['grandTotal']);
            }
            // Apply Coupon work end here

            if (isset($tax_rate) && !empty($tax_rate)) {
                $response['tax_rate'] = $tax_rate;
                $response['tax'] = ($tax_rate / 100) * $response['grandTotal'];
                $response['grandTotal'] = Engine_Api::_()->getApi('Siteapi_Core', 'Siteeventticket')->getPriceWithCurrency($response['grandTotal'] + ($tax_rate / 100) * $response['grandTotal']);
                $response['grandTotal'] = str_replace(',', '', $response['grandTotal']);
            }

            $response['canShowBookNow'] = (isset($ticketArray) && !empty($ticketArray)) ? 1 : 0;
            $response['buyerStep'] = Engine_Api::_()->getApi('settings', 'core')->getSetting('siteeventticket.detail.step', 1);
            if (!empty($capacityApplicable)) {
                $response['error'] = $this->translate("Event is Full");
            } if (!empty($tempArray))
                $response['tickets'] = $tempArray;

            $response['info'] = json_encode($this->_getTicketDetails($response, $ticketArray, $params, $couponParams));

            $this->respondWithSuccess($response, true);
        } catch (Exception $ex) {
            $this->respondWithValidationError('internal_server_error', $ex->getMessage());
        }
    }

    /*
     * displays all the members who have bought tickets for the event 
     * currently being viewed
     */

    public function memberListAction() {

        $response=array();
        $attendees=array();
        $tempUser=array();
        $viewer = Engine_Api::_()->user()->getViewer();

        //GET USER LEVEL ID
        if ($viewer->getIdentity()) {
            $level_id = $viewer->level_id;
        } else {
            $level_id = Engine_Api::_()->getDbtable('levels', 'authorization')->fetchRow(array('type = ?' => "public"))->level_id;
        }

        $subject = Engine_Api::_()->core()->getSubject('siteevent_event');
        $friendsonly = $this->_getParam('friendsonly', 0);

        $canEdit = $subject->authorization()->isAllowed($viewer, "edit");
        $datesInfo = Engine_Api::_()->getDbtable('occurrences', 'siteevent')->getAllOccurrenceDates($subject->event_id);
        $page = $this->_getParam('page', 1);
        $search = $this->_getParam('search');
        $occurrence_id = $this->_getParam('occurrence_id', 'all');

        if (empty($occurrence_id)) {
            $occurrence_id = Zend_Registry::isRegistered('occurrence_id') ? Zend_Registry::get('occurrence_id') : null;
        }

        $event = Engine_Api::_()->core()->getSubject();
        try {


            $paginator = Zend_Paginator::factory($select);
            $paginator->setItemCountPerPage($this->_getParam('limit', 20));
            $paginator->setCurrentPageNumber($this->_getParam('page', $page));
            $response['totalItemCount'] = $paginator->getTotalItemCount();

            foreach ($paginator as $member) {
                if (!empty($member->resource_id)) {
                    $memberInfo = $member;
                    $member = $this->item('user', $memberInfo->user_id);
                } else {

                    $memberInfo = $event->membership()->getMemberInfoCustom($member);
                }

                $tempUser = Engine_Api::_()->getApi('Core', 'siteapi')->validateUserArray($member);
                $tempUser['displayname'] = $member->getTitle();
                $getContentImages = Engine_Api::_()->getApi('Core', 'siteapi')->getContentImage($user);
                $tempUser = array_merge($tempUser, $getContentImages);
                if ($row == NULL) {
                    $tempUser['menus'] = Engine_Api::_()->getApi('Siteapi_Core', 'user')->userFriendship($member);
                } else {
                    $tempUser['menus'] = array();
                }

                $attendees [] = $tempUser;
            }
        } catch (Exception $ex) {
            $this->respondWithError('internal_server_error', $ex->getMessage());
        }
        $response['response'] = $attendees;
        $this->respondWithSuccess($response, true);
    }

    public function _getTicketDetails($response, $ticketArray, $params, $couponParams) {
        foreach ($ticketArray as $ticket_id => $quantity) {
            $ticketObj = Engine_Api::_()->getItem('siteeventticket_ticket', $ticket_id);

            $temp['ticket_column'][$ticket_id]['0'] = (double) $ticketObj->price;
            $temp['ticket_column'][$ticket_id]['1'] = $quantity;
            $temp['ticket_column'][$ticket_id]['coupon_id'] = isset($couponParams[$ticket_id]['coupon_id']) ? $couponParams[$ticket_id]['coupon_id'] : 0;
        }
        if (isset($response['coupon_code']) && !empty($response['coupon_code'])) {
            $temp['coupon_code'] = $response['coupon_code'];
        }
        if (isset($response['grandTotal']) && !empty($response['grandTotal'])) {
            $temp['grandTotal'] = $response['grandTotal'];
        }
        if (isset($response['tax']) && !empty($response['tax'])) {
            $temp['tax'] = $response['tax'];
        }
        if (isset($response['subTotal']) && !empty($response['subTotal'])) {
            $temp['subTotal'] = (int) Engine_Api::_()->getApi('Siteapi_Core', 'Siteeventticket')->getPriceWithCurrency($response['subTotal']);
        }
        if (isset($response['occurrence_id']) && !empty($response['occurrence_id'])) {
            $temp['date_filter_occurrence'] = $response['occurrence_id'];
        }
        return $temp;
    }

    private function _getTicketQuantity($params) {
        // Get ticket quantities
        foreach ($params as $key => $value) {
            if (strpos($key, "ticket_id_") !== false) {
                $tempData = explode('ticket_id_', $key);
                if (!empty($value))
                    $ticketArray[$tempData[1]] = $value;
            }
        }
        return $ticketArray;
    }

    private function _getTicketMenus($order_id) {
        $showSendTicketLink = Engine_Api::_()->hasModuleBootstrap('sitemailtemplates') && file_exists('application/libraries/dompdf/dompdf_config.inc.php');
        $menus[] = array(
            'name' => 'view_order',
            'label' => $this->translate('View Order'),
            'url' => 'advancedeventtickets/order/view',
            'urlParams' => array(
                "order_id" => $order_id
            )
        );
//        if ($showSendTicketLink) {
//            $menus[] = array(
//                'name' => 'email_order',
//                'label' => $this->translate('Email Order'),
//                'url' => 'advancedeventtickets/order/view',
//                'urlParams' => array(
//                    "order_id" => $order_id
//                )
//            );
//        }

        return $menus;
    }

}
