<?php

class Sitefbchat_Form_Admin_Settings_Global extends Engine_Form
{

  public function init()
  {
    $coreSettings = Engine_Api::_()->getApi('settings', 'core');

    $this
      ->setTitle('Global Settings')
      ->setDescription('These settings affect all members in your community.');

    $this->addElement('Select', "sitefbchat_enable_messenger", array(
      'label' => 'Enable FB Customer Chat',
      'description' => 'Do you want to enable the FB Messenger Customer Chat on your website?',
      'allowEmpty' => false,
      'required' => true,
      'multiOptions' => array(
        '1' => 'Yes',
        '0' => 'No',
      ),
      'value' => $coreSettings->getSetting('sitefbchat_enable_messenger', '1'),
    ));

    $required = !empty($_POST["sitefbchat_enable_messenger"]);
    $allowEmpty = !$required;
    $this->addElement('Text', "sitefbchat_page_id", array(
      'label' => 'Facebook Page Id',
      'description' => 'Enter the id of the Facebook page where you want to enable the chat messenger.',
      'required' => $required,
      'allowEmpty' => $allowEmpty,
      'value' => $coreSettings->getSetting('sitefbchat_page_id', ''),
    ));
    $this->getElement('sitefbchat_page_id')->getDecorator('Description')->setOptions(array('placement' => 'PREPEND', 'escape' => false));

    $this->addElement('Text', "sitefbchat_login_greeting", array(
      'label' => 'Greetings Text for FB Logged-in Users',
      'description' => 'Enter the greetings message which will be displayed when users are logged-in into their FB accounts in the same browser.',
      'required' => true,
      'allowEmpty' => false,
      'value' => $coreSettings->getSetting('sitefbchat_login_greeting', 'Hi! How can we help you?'),
    ));
    $this->getElement('sitefbchat_login_greeting')->getDecorator('Description')->setOptions(array('placement' => 'PREPEND', 'escape' => false));

    $this->addElement('Text', "sitefbchat_logout_greeting", array(
      'label' => 'Greetins Text for FB Logged-out Users',
      'description' => 'Enter the greetings message which will be shown when users are logged-out from their FB accounts.',
      'required' => true,
      'allowEmpty' => false,
      'value' => $coreSettings->getSetting('sitefbchat_logout_greeting', 'Hi! How can we help you?'),
    ));
    $this->getElement('sitefbchat_logout_greeting')->getDecorator('Description')->setOptions(array('placement' => 'PREPEND', 'escape' => false));


    $this->addElement('Text', "sitefbchat_theme_color", array(
      'label' => 'Messenger Theme Color',
      'description' => 'Select the color of the FB Messenger Theme color below.',
      'required' => true,
      'allowEmpty' => false,
      'value' => $coreSettings->getSetting('sitefbchat_theme_color', '#0084ff'),
    ));
    $this->getElement('sitefbchat_theme_color')->getDecorator('Description')->setOptions(array('placement' => 'PREPEND', 'escape' => false));



    $this->addElement('Select', "sitefbchat_visibility", array(
      'label' => 'Visibility of FB Messenger ',
      'description' => 'Select the users to whom FB messenger will be visible.',
      'allowEmpty' => false,
      'required' => true,
      'multiOptions' => array(
        'logged-in' => 'Only logged-in members',
        'logged-out' => 'Only logged-out users',
        'all' => 'Both logged-in and logged-out users.',
      ),
      'value' => $coreSettings->getSetting('sitefbchat_visibility', 'all'),
    ));
    $this->getElement('sitefbchat_visibility')->getDecorator('Description')->setOptions(array('placement' => 'PREPEND', 'escape' => false));

    $this->addElement('Select', "sitefbchat_enable_timing", array(
      'label' => 'Custom Start & End Display Time',
      'description' => 'Do you want to display the FB chat box for the custom duration? If chosen Yes, then you will be able to select the Start time and End time of the display of the box. Otherwise, the FB chat box will be displayed 24x7 on your site.',
      'required' => true,
      'allowEmpty' => false,
      'multiOptions' => array(
        '1' => 'Yes',
        '0' => 'No',
      ),
      'value' => $coreSettings->getSetting('sitefbchat_enable_timing', '0'),
    ));


    $start = new Engine_Form_Element_CalendarDateTime('sitefbchat_starttime');
    $start->setLabel("Start Time");
    $start->setValue(date('Y-m-d H:i:s', strtotime($coreSettings->getSetting('sitefbchat_starttime', date('Y-m-d')))));
    $this->addElement($start);
    $this->getElement('sitefbchat_starttime')->getDecorator('Description')->setOptions(array('placement' => 'PREPEND', 'escape' => false));

    $end = new Engine_Form_Element_CalendarDateTime('sitefbchat_endtime');
    $end->setLabel("End Time");
    $end->setValue(date('Y-m-d H:i:s', strtotime($coreSettings->getSetting('sitefbchat_endtime', date('Y-m-d')))));

    $this->addElement($end);
    $this->getElement('sitefbchat_endtime')->getDecorator('Description')->setOptions(array('placement' => 'PREPEND', 'escape' => false));

    $this->addElement('Select', "sitefbchat_allowed_devices", array(
      'label' => 'Allow Devices',
      'description' => 'Select the devices on which the FB Messenger will be displayed on your website.',
      'allowEmpty' => false,
      'required' => true,
      'multiOptions' => array(
        '0' => 'Both Mobile and Web',
        '1' => 'Only Web',
        '2' => 'Only Mobile',
      ),
      'value' => $coreSettings->getSetting('sitefbchat_allowed_devices', '1'),
    ));
    $this->getElement('sitefbchat_allowed_devices')->getDecorator('Description')->setOptions(array('placement' => 'PREPEND', 'escape' => false));

    $this->addElement('Select', "sitefbchat_position", array(
      'label' => 'Position of Messenger',
      'description' => 'Select the position where FB Messenger is to be placed on your website.',
      'allowEmpty' => false,
      'required' => true,
      'multiOptions' => array(
        'bottom_right' => 'Bottom Right',
        'bottom_left' => 'Bottom Left',
      ),
      'value' => $coreSettings->getSetting('sitefbchat_position', '0'),
    ));
    $this->getElement('sitefbchat_position')->getDecorator('Description')->setOptions(array('placement' => 'PREPEND', 'escape' => false));

    $this->addElement('Button', 'submit', array(
      'label' => 'Save Changes',
      'type' => 'submit',
      'ignore' => true
    ));
  }

}