<?php

/**
 * SocialEngine
 *
 * @category   Application_Extensions
 * @package    Sitegdpr
 * @copyright  Copyright 2017-2021 BigStep Technologies Pvt. Ltd.
 * @license    http://www.socialengineaddons.com/license/
 * @version    $Id: Core.php 2018-05-10 9:40:21Z SocialEngineAddOns $
 * @author     SocialEngineAddOns
 */

class Sitegdpr_Api_Core extends Core_Api_Abstract
{

  public function showConsents($formId, $form)
  {
    if( empty($formId) ) {
      return;
    }

    $consents = Engine_Api::_()->getDbtable('consents', 'sitegdpr')->getConsents(array('formId' => $formId));

    if( empty($consents) ) {
      return;
    }


    foreach( $consents as $consent ) {
      $elementName = 'consent_' . $consent->getIdentity();
      if( !empty($form) ) {

        $form->addElement('Checkbox', $elementName, array(
          'description' => $consent->description,
          'label' => $consent->title,
          'required' => true,
          'validators' => array(
            'notEmpty',
            array('GreaterThan', false, array(0)),
          ),
        ));

        $form->$elementName->getValidator('GreaterThan')->setMessage('You must agree to privacy policies to continue.', 'notGreaterThan');
        $form->$elementName->clearDecorators()
          ->addDecorator('ViewHelper')
          ->addDecorator('Description', array('placement' => Zend_Form_Decorator_Abstract::APPEND, 'tag' => 'label', 'class' => 'null', 'escape' => false, 'for' => 'terms'))
          ->addDecorator('DivDivDivWrapper');
      }
    }
  }

  public function UnapprovedCookies($viewerId, $privacyPreferences = null)
  {
    $preferenceTable = Engine_Api::_()->getDbtable('userPreferences', 'sitegdpr');
    if( !empty($viewerId) ) {
      $userPreferences = $preferenceTable->getPreferences($viewerId);
    } else {
      $userPreferences = $privacyPreferences;
    }

    if( empty($userPreferences) ) {
      return array();
    }

    $userPreferences = json_decode($userPreferences);

    $cookiesCategories = Engine_Api::_()->getDbtable('cookiesCategories', 'sitegdpr')->getCategories(array('enabled' => 1));
    foreach( $cookiesCategories as $cookie ) {
      $cookiesIds[] = $cookie->getIdentity();
    }

    if( !empty($userPreferences->cookies) ) {
      $cookiesApproved = explode(',', $userPreferences->cookies);
    } else {
      $cookiesApproved = $cookiesIds;
    }

    $excludedCookiesIds = array_diff($cookiesIds, $cookiesApproved);

    return $this->excludedCookies($excludedCookiesIds);
  }

  public function excludedCookies($cookiesIds)
  {
    $excludedCookies = array();
    foreach( $cookiesIds as $id ) {
      $cookie = Engine_Api::_()->getItem('sitegdpr_cookiesCategory', $id);
      $domain = '';
      if( $cookie->is_thirdparty_cookie ) {
        $domain = $cookie->cookie_domain;
      }
      $cookiesList = explode(',', $cookie->cookies);
      foreach( $cookiesList as $cookieName ) {
        $cookiesWithDomain = $cookieName . '|| ' . $domain;
        array_push($excludedCookies, $cookiesWithDomain);
      }
    }

    return $excludedCookies;
  }

}
