<?php

/**
 * SocialEngine
 *
 * @category   Application_Extensions
 * @package    Sitegdpr
 * @copyright  Copyright 2017-2021 BigStep Technologies Pvt. Ltd.
 * @license    http://www.socialengineaddons.com/license/
 * @version    $Id: AdminCookiesController.php 2018-05-10 9:40:21Z SocialEngineAddOns $
 * @author     SocialEngineAddOns
 */
class Sitegdpr_GeneralController extends Core_Controller_Action_Standard
{

  public function savePreferencesAction()
  {
    $request = Zend_Controller_Front::getInstance()->getRequest();
    $userPreferencesArray = $request->getParam('preferences');
    if( empty($userPreferencesArray) ) {
      $userPreferencesArray = array('cookiesAccepted' => 1);
    }

    $auditLog = Engine_Api::_()->getDbtable('auditLogs', 'sitegdpr');
    $userPreferences = json_encode($userPreferencesArray);

    $preferenceTable = Engine_Api::_()->getDbtable('userPreferences', 'sitegdpr');

    $viewer = Engine_Api::_()->user()->getViewer();
    if( !empty($viewer->getIdentity()) ) {
      $viewerId = $viewer->getIdentity();
      $preferenceId = $preferenceTable->alreadyExists($viewerId);

      if( $preferenceId ) {
        $preference = Engine_Api::_()->getItem('sitegdpr_userPreference', $preferenceId);
        $preference->consents = $userPreferences;
      } else {
        $preference = $preferenceTable->createRow();
        $preference->consents = $userPreferences;
        $preference->user_id = $viewerId;
        $preference->accepted_date = date('Y-m-d H:i:s');
      }

      $preference->modified_date = date('Y-m-d H:i:s');

      if( isset($userPreferencesArray['cookies']) ) {
        $cookieIdsString = $userPreferencesArray['cookies'];
        $cookieIdsArray = explode(',', $cookieIdsString);
        $auditLog->setAuditLog('Preference', 'Cookies', $cookieIdsArray);
      }

      if( isset($userPreferencesArray['consents']) ) {
        $consentsIdsString = $userPreferencesArray['consents'];
        $consentsIdsArray = explode(',', $consentsIdsString);
        $auditLog->setAuditLog('Preference', 'Consents', $consentsIdsArray);
      }

      if( isset($userPreferencesArray['cookiesAccepted']) ) {
//        $consentsIdsString = $userPreferencesArray['consents'];
//        $consentsIdsArray = explode(',', $consentsIdsString);
        $auditLog->setAuditLog('All', 'CookiesAccepted');
      }


      $preference->save();

      Engine_Hooks_Dispatcher::getInstance()->callEvent('onUserPreferenceSaveAfter', array(
        'preferences' => $userPreferencesArray,
        'userId' => $viewerId
      ));

      $UnapprovedCookies = Engine_Api::_()->getApi('core', 'sitegdpr')->UnapprovedCookies($viewerId);
    } else {
      $UnapprovedCookies = Engine_Api::_()->getApi('core', 'sitegdpr')->UnapprovedCookies(0, $userPreferences);
    }

    $_SESSION['privacy_preferences'] = $userPreferences;
    $_SESSION['UnapprovedCookies'] = $UnapprovedCookies;
    $_SESSION['isUnapprovedCookiesSet'] = true;


    $this->view->resp = true;
    $this->view->msg = 'Preferences saved successfully';
    return;
  }

  public function userPreferencesAction()
  {
    $viewer = Engine_Api::_()->user()->getViewer();

    Engine_Api::_()->core()->setSubject($viewer);

    // Set up require's
    $this->_helper->requireUser();
    $this->_helper->requireSubject();
    $this->_helper->requireAuth()->setAuthParams($viewer, null, 'edit');

    $this->view->viewerId = $viewerId = $viewer->getIdentity();

    $this->view->navigation = Engine_Api::_()->getApi('menus', 'core')
      ->getNavigation('user_settings', array(), 'gdpr_user_settings_preferences');

    $this->view->cookiesCategories = Engine_Api::_()->getDbtable('cookiesCategories', 'sitegdpr')->getCategories(array('enabled' => 1));
    $this->view->consents = Engine_Api::_()->getDbtable('consents', 'sitegdpr')->getConsents(array('enabled' => 1));
    $this->view->userPreferences = Engine_Api::_()->getDbtable('userPreferences', 'sitegdpr')->getPreferences($viewerId);
  }

  public function privacyCenterAction()
  {
    $table = Engine_Api::_()->getDbtable('privacyCenterComponents', 'sitegdpr');
    $select = $table->select();
    $select->where('enabled =?', 1)
      ->order('order ASC');

    $this->view->privacyCenterComponents = $privacyCenterComponets = $table->fetchAll($select);
  }

  public function contactusAction()
  {
    // In smoothbox
    $this->_helper->layout->setLayout('default-simple');

    $request = Zend_Controller_Front::getInstance()->getRequest();
    $type = $request->getParam('type');

    // Generate and assign form
    $form = $this->view->form = new Sitegdpr_Form_Contact();
    $componentItem = Engine_Api::_()->getItem('sitegdpr_privacyCenterComponent', $type);

    switch( $type ) {
      case 2:
        $formType = 'UNSUBSCRIBE';
        $title = 'Unsubscribe';
        $description = 'If in case you do not want any promotional emails or newsletters regarding our latest releases, you can unsubscribe it by filling this form.';
        break;
      case 3:
        $formType = 'DELETE';
        $title = 'Abolish Data';
        $description = 'You can request here for abolishing all your data that we have accessed till now.';
        break;
      case 4:
        $formType = 'ARCHIVE';
        $title = 'Apply for Record';
        $description = 'You can apply for the record of all your personal data that we have accessed till now. We will send you the copy of that record immediately after getting this request.';
        break;
      default:
        $formType = 'DPO';
        $title = 'Contact Data Protection Officer';
        $description = 'You can anytime contact our Data Protection Officer in case you have any special requests or queries by filling up this form';
    }

    $form->setTitle($this->view->translate($componentItem->name));
    $form->setDescription($this->view->translate($componentItem->description));
    $form->setAction($this->view->url(array()));
    $form->form_type->setValue($formType);

    $viewer = Engine_Api::_()->user()->getViewer();
    if( !empty($viewer->getIdentity()) ) {
      $name = explode(' ', $viewer->getTitle());
      $fname = $name[0];

      if( !empty($name[2]) ) {
        $lname = $name[2];
      } else if( !empty($name[1]) ) {
        $lname = $name[1];
      } else {
        $lname = '';
      }

      $form->first_name->setValue($fname);
      $form->last_name->setValue($lname);
      $form->email->setValue($viewer->email);
      $form->email->setAttrib('readonly', 'readonly');
      $form->first_name->setAttrib('readonly', 'readonly');
      if( !empty($lname) ) {
        $form->last_name->setAttrib('readonly', 'readonly');
      }
    }

    // Check post
    if( !$this->getRequest()->isPost() ) {
      return;
    }

    if( !$form->isValid($this->getRequest()->getPost()) ) {
      return;
    }

    // Process
    $values = $form->getValues();

    $table = Engine_Api::_()->getDbtable('requests', 'sitegdpr');
    $db = $table->getAdapter();
    $db->beginTransaction();
    // Update row
    try {
      $requestRow = $table->createRow();
      $requestRow->setFromArray($values);
      $requestRow->user_id = $viewer->getIdentity();
      $requestRow->requested_date = date('Y-m-d H:i:s');
      $requestRow->save();
      Engine_Api::_()->getDbtable('auditLogs', 'sitegdpr')->setAuditLog('Request', $formType);
      $db->commit();
    } catch( Exception $e ) {
      $db->rollBack();
      throw $e;
    }

    return $this->_forward('success', 'utility', 'core', array(
        'smoothboxClose' => 10,
//        'parentRefresh' => 10,
//        'messages' => array('Your request send successfully.')
    ));
  }

}
