<?php

/**
 * SocialEngine
 *
 * @category   Application_Extensions
 * @package    Sitegifplayer
 * @copyright  Copyright 2015-2016 BigStep Technologies Pvt. Ltd.
 * @license    http://www.socialengineaddons.com/license/
 * @version    $Id: Stickers.php 6590 2016-07-07 00:00:00Z SocialEngineAddOns $
 * @author     SocialEngineAddOns
 */
class Sitegifplayer_Model_DbTable_Photos extends Engine_Db_Table
{

  protected $_rowClass = 'Sitegifplayer_Model_Photo';

  public function getPaginator($params = array())
  {
    $limit = 10;
    if( !empty($params['limit']) ) {
      $limit = $params['limit'];
      unset($params['limit']);
    }
    $paginator = Zend_Paginator::factory($this->_getSelect($params));
    $paginator->setItemCountPerPage($limit);
    if( !empty($params['page']) ) {
      $paginator->setCurrentPageNumber($params['page']);
    }
    return $paginator;
  }

  public function getPhotos($params = array())
  {
    return $this->fetchAll($this->_getSelect($params));
  }

  protected function _getSelect($params = array())
  {
    $select = $this->select();
    if( empty($params['ignoreFile']) ) {
      $select->where('file_id > ?', 0);
    }
    if( !empty($params['search']) ) {
      $select->where('title LIKE ?', '%' . $params['search'] . '%');
    }
    if( $params['enabled'] != '' ) {
      $select->where('enabled = ?', $params['enabled']);
    }
    if( !empty($params['limit']) ) {
      $select->limit($params['limit']);
    }
    $orders = array(
      'recent' => 'creation_date DESC',
      'popular' => 'used_count DESC'
    );
    if( !empty($params['show']) && isset($orders[$params['show']]) ) {
      $select->order($orders[$params['show']]);
    }
    $select->order('order ASC');
    return $select;
  }

  public function addPhoto($file, $options = array(), $addAsJob = false)
  {
    $photo = $this->createRow();
    $photo->enabled = 1;
    if( $options ) {
      $photo->setFromArray($options);
    }
    $photo->save();
    $photo->order = $photo->photo_id;
    if( $addAsJob ) {
      Engine_Api::_()->getDbtable('jobs', 'core')->addJob('giphy_import', array(
        'photo_id' => $photo->photo_id,
        'code' => $options['code'],
        'file' => $file,
        'type' => 'giphy'
      ));
    } else {
      $photo->setPhoto($file);
    }
    $photo->save();
    return $photo;
  }

  public function getByCode($code)
  {
    return $this->fetchRow($this->select()->where('code =?', $code));
  }

}
