<?php

/**
 * SocialEngine
 *
 * @category   Application_Extensions
 * @package    Sitegroupdocument
 * @copyright  Copyright 2010-2011 BigStep Technologies Pvt. Ltd.
 * @license    http://www.socialengineaddons.com/license/
 * @version    $Id: Global.php 2011-05-05 9:40:21Z SocialEngineAddOns $
 * @author     SocialEngineAddOns
 */
class Sitegroupdocument_Form_Admin_Global extends Engine_Form {
    
    // IF YOU WANT TO SHOW CREATED ELEMENT ON PLUGIN ACTIVATION THEN INSERT THAT ELEMENT NAME IN THE BELOW ARRAY.
    public $_SHOWELEMENTSBEFOREACTIVATE;

    public function init() {
        $this
                ->setTitle('Global Settings')
                ->setDescription('These settings affect all members in your community.');
        
        $isPluginActivate = Engine_Api::_()->getApi('settings', 'core')->getSetting('sitegroupdocument.navi.auth', null);
        if (!empty($isPluginActivate)) {
            $required_value = true;
            $this->_SHOWELEMENTSBEFOREACTIVATE = array('submit_lsetting', 'environment_mode', 'include_in_package');
        } else {
            $required_value = false;
            $this->_SHOWELEMENTSBEFOREACTIVATE = array('submit_lsetting', 'environment_mode', 'include_in_package', 'sitegroupdocument_api_key', 'sitegroupdocument_secret_key');
        }
        

        $this->addElement('Text', 'sitegroupdocument_lsettings', array(
            'label' => 'Enter License key',
            'description' => "Please enter your license key that was provided to you when you purchased this plugin. If you do not know your license key, please contact the Support Team of SocialApps.tech from the Support section of your Account Area.(Key Format: XXXXXX-XXXXXX-XXXXXX )",
            'value' => Engine_Api::_()->getApi('settings', 'core')->getSetting('sitegroupdocument.lsettings'),
        ));

        $isActive = Engine_Api::_()->getApi('settings', 'core')->getSetting('sitegroupdocument.isActivate', null);
        $global_settings_file = APPLICATION_PATH . '/application/settings/general.php';
        if (file_exists($global_settings_file)) {
            $generalConfig = include $global_settings_file;
        } else {
            $generalConfig = array();
        }

				//GET SCRIBD KEYS IF OTHER DOCUMENT PLUGIN IS ALREADY INSTALLED AND HAVING THESE KEYS.
				$coreApi = Engine_Api::_()->getApi('settings', 'core');
				$scribd_api_key = $coreApi->getSetting('sitegroupdocument.api.key');
				$scribd_secret_key = $coreApi->getSetting('sitegroupdocument.secret.key');
				if (empty($scribd_api_key) && empty($scribd_secret_key)) {
					Engine_Api::_()->seaocore()->getScribdApiKeys('sitegroupdocument');
				}

        $this->addElement('Text', 'sitegroupdocument_api_key', array(
            'label' => 'Scribd API Key',
            'required' => true,
            'description' => 'The Scribd API Key for your website. [Please visit the FAQ section to see how to obtain these credentials.]',
            'value' => Engine_Api::_()->getApi('settings', 'core')->getSetting('sitegroupdocument.api.key', ''),
        ));

        $this->addElement('Text', 'sitegroupdocument_secret_key', array(
            'label' => 'Scribd Secret Key',
            'required' => true,
            'description' => 'The Scribd Secret Key for your website. [Please visit the FAQ section to see how to obtain these credentials.]',
            'value' => Engine_Api::_()->getApi('settings', 'core')->getSetting('sitegroupdocument.secret.key', ''),
        ));

        if (Engine_Api::_()->sitegroup()->hasPackageEnable()) {
            $this->addElement('Checkbox', 'include_in_package', array(
                'label' => 'Enable documents module for the default package that was created upon installation of the "Groups / Communities Plugin". If enabled, Documents App will also be enabled for the Groups created so far under the default package.',
                'description' => 'Enable Documents Module for Default Package',
                'value' => 1,
            ));
        }

        if ((!empty($generalConfig['environment_mode']) ) && ($generalConfig['environment_mode'] != 'development')) {
            $this->addElement('Checkbox', 'environment_mode', array(
                'label' => 'Your community is currently in "Production Mode". We recommend that you momentarily switch your site to "Development Mode" so that the CSS of this plugin renders fine as soon as the plugin is installed. After completely installing this plugin and visiting few groups of your site, you may again change the System Mode back to "Production Mode" from the Admin Panel Home. (In Production Mode, caching prevents CSS of new plugins to be rendered immediately after installation.)',
                'description' => 'System Mode',
//          'value' => 1,
            ));
        } else {
            $this->addElement('Hidden', 'environment_mode', array('order' => 990, 'value' => 0));
        }

        // Add submit button
        $this->addElement('Button', 'submit_lsetting', array(
            'label' => 'Activate Your Plugin Now',
            'type' => 'submit',
            'ignore' => true
        ));

        $this->addElement('Radio', 'sitegroupdocument_default_visibility', array(
            'label' => 'Visibility for Group Documents',
            'description' => 'Group documents visible only on this website will be private and available only on your website, whereas the ones which will be public on Scribd.com will be available to everyone on Scribd.(Note : This setting will only apply to new Group documents created and not to the existing Group documents on the site.)',
            'multiOptions' => array(
                'public' => 'Public on Scribd.com',
                'private' => 'Only on this website'
            ),
            'value' => Engine_Api::_()->getApi('settings', 'core')->getSetting('sitegroupdocument.default.visibility', 'private'),
        ));

        $this->addElement('Radio', 'sitegroupdocument_visibility_option', array(
            'description' => 'Show visibility option to users. Allow users to choose whether their Group documents will be public or private,i.e., available only on your website, or also on Scribd.com.',
            'multiOptions' => array(
                1 => ' 	Yes',
                0 => ' 	No'
            ),
            'value' => Engine_Api::_()->getApi('settings', 'core')->getSetting('sitegroupdocument.visibility.option', 1),
        ));

        $this->addElement('Radio', 'sitegroupdocument_carousel', array(
            'label' => 'Featured Documents Carousel',
            'description' => 'Do you want to show the carousel for featured documents in Groups in the Documents tab of Groups?',
            'multiOptions' => array(
                1 => 'Yes',
                0 => 'No'
            ),
            'value' => Engine_Api::_()->getApi('settings', 'core')->getSetting('sitegroupdocument.carousel', 1),
        ));

        if (!empty($isActive)) {
            $this->addElement('Text', 'sitegroupdocument_number_carousel', array(
                'label' => 'Documents in Featured Carousel',
                'description' => 'How many documents should be shown in the carousel for featured documents (value cannot be empty or zero) ?',
                'required' => $required_value,
                'value' => Engine_Api::_()->getApi('settings', 'core')->getSetting('sitegroupdocument.number.carousel', 15),
                'validators' => array(
                    array('Int', true),
                    array('GreaterThan', true, array(0)),
                ),
            ));
        }

        $this->addElement('Radio', 'sitegroupdocument_featured', array(
            'label' => 'Making Group Documents Highlighted',
            'description' => 'Allow Group Admins to make documents in their Groups as highlighted.',
            'multiOptions' => array(
                1 => 'Yes',
                0 => 'No'
            ),
            'value' => Engine_Api::_()->getApi('settings', 'core')->getSetting('sitegroupdocument.featured', 1),
        ));

        $this->addElement('Radio', 'sitegroupdocument_show_editor', array(
            'label' => 'WYSIWYG Editor',
            'description' => 'Allow WYSIWYG editor for description of Group documents.',
            'multiOptions' => array(
                1 => 'Yes',
                0 => 'No'
            ),
            'value' => Engine_Api::_()->getApi('settings', 'core')->getSetting('sitegroupdocument.show.editor', 1),
        ));

        $filesize = (int) ini_get('upload_max_filesize') * 1024;
        $show_description = Zend_Registry::get('Zend_Translate')->_('Enter the maximum Group document file size in KB. Valid values are from 1 to %s KB.');
        $show_description = sprintf($show_description, $filesize);
        $this->addElement('Text', 'sitegroupdocument_filesize', array(
            'label' => 'Maximum file size',
            'description' => $show_description,
            'value' => Engine_Api::_()->getApi('settings', 'core')->getSetting('sitegroupdocument.filesize', 2048),
        ));

        $this->addElement('Radio', 'sitegroupdocument_scribd_viewer', array(
            'label' => 'Default Document Viewer Type',
            'description' => 'Select the default viewer type for documents on your site. (Note: Secure documents can be viewed in Flash reader only because secure documents use access-management technology which is available in Flash only. Therefore, secure documents will always be viewed in Flash reader, even if you choose HTML5 reader as default.)',
            'multiOptions' => array(
                1 => 'Flash Reader',
                0 => 'HTML5 Reader'
            ),
            'value' => Engine_Api::_()->getApi('settings', 'core')->getSetting('sitegroupdocument.scribd.viewer', 1),
        ));

        $this->addElement('Radio', 'sitegroupdocument_fullscreen_button', array(
            'label' => 'Fullscreen option in Flash Reader',
            'description' => "Do you want the 'Fullscreen' option to be available in the Flash Reader?",
            'multiOptions' => array(
                0 => 'Yes',
                1 => 'No'
            ),
            'value' => Engine_Api::_()->getApi('settings', 'core')->getSetting('sitegroupdocument.fullscreen.button', 0),
        ));

        $this->addElement('Radio', 'sitegroupdocument_flash_mode', array(
            'label' => 'Default View Mode in Flash Reader',
            'description' => 'Choose the default view mode of Flash Reader for viewing documents. Users will be able to change the mode in the viewer.',
            'multiOptions' => array(
                'list' => 'List',
                'book' => 'Book',
                'slide' => 'Slide',
                'tile' => 'Tile'
            ),
            'value' => Engine_Api::_()->getApi('settings', 'core')->getSetting('sitegroupdocument.flash.mode', 'list'),
        ));

        $this->addElement('Radio', 'sitegroupdocument_disable_button', array(
            'label' => 'Disabled links in Reader',
            'description' => 'Do you want the disabled links in the Document Viewer like Download, etc to be hidden?',
            'multiOptions' => array(
                1 => 'Yes',
                0 => 'No'
            ),
            'value' => Engine_Api::_()->getApi('settings', 'core')->getSetting('sitegroupdocument.disable.button', 0),
        ));

        $this->addElement('Radio', 'sitegroupdocument_rating', array(
            'label' => 'Group Document Rating',
            'description' => 'Allow logged-in users to give rating to Group documents.',
            'multiOptions' => array(
                1 => 'Yes',
                0 => 'No'
            ),
            'value' => Engine_Api::_()->getApi('settings', 'core')->getSetting('sitegroupdocument.rating', 1),
        ));

        $this->addElement('Radio', 'sitegroupdocument_report', array(
            'label' => 'Report as inappropriate',
            'description' => 'Allow logged-in users to report Group documents as inappropriate.',
            'multiOptions' => array(
                1 => 'Yes',
                0 => 'No'
            ),
            'value' => Engine_Api::_()->getApi('settings', 'core')->getSetting('sitegroupdocument.report', 1),
        ));

        $this->addElement('Radio', 'sitegroupdocument_share', array(
            'label' => 'Social Sharing Buttons',
            'description' => 'Do you want to show social sharing buttons on the Group document\'s view group?',
            'multiOptions' => array(
                1 => 'Yes',
                0 => 'No'
            ),
            'value' => Engine_Api::_()->getApi('settings', 'core')->getSetting('sitegroupdocument.share', 1),
        ));

        $this->addElement('Text', 'sitegroupdocument_viewer_height', array(
            'label' => 'Document Viewer Height',
            'description' => 'What should be the height in pixels of the document viewer on document view group ?',
            'value' => Engine_Api::_()->getApi('settings', 'core')->getSetting('sitegroupdocument.viewer.height', 600),
        ));

        $this->addElement('Text', 'sitegroupdocument_viewer_width', array(
            'label' => 'Document Viewer Width',
            'description' => 'What should be the width in pixels of the document viewer on document view group ?',
            'value' => Engine_Api::_()->getApi('settings', 'core')->getSetting('sitegroupdocument.viewer.width', 730),
        ));

        $this->addElement('Checkbox', 'sitegroupdocument_licensing_option', array(
            'label' => 'Selecting this will allow users to choose the license to be associated with their Group documents.',
            'description' => 'Show license option to users',
            'value' => Engine_Api::_()->getApi('settings', 'core')->getSetting('sitegroupdocument.licensing.option', 1),
        ));

        $this->addElement('Select', 'sitegroupdocument_licensing_scribd', array(
            'label' => 'License associated with Group documents',
            'description' => 'Choose the license to be associated with the Group documents on your site. The license will be shown on your site, as well as on Scribd.com.',
            'multiOptions' => array(
                'ns' => 'Unspecified - no licensing information associated',
                'by' => 'By attribution (by)',
                'by-nc' => 'By attribution, non-commercial (by-nc)',
                'by-nc-nd' => 'By attribution, non-commercial, non-derivative (by-nc-nd)',
                'by-nc-sa' => 'By attribution, non-commercial, share alike (by-nc-sa)',
                'by-nd' => 'By attribution, non-derivative (by-nd)',
                'by-sa' => 'By attribution, share alike (by-sa)',
                'pd' => 'Public domain',
                'c' => 'Copyright - all rights reserved',
            ),
            'value' => Engine_Api::_()->getApi('settings', 'core')->getSetting('sitegroupdocument.licensing.scribd', 'ns'),
        ));
        $this->sitegroupdocument_licensing_scribd->getDecorator('Description')->setOption('placement', 'append');

        $this->addElement('Checkbox', 'sitegroupdocument_include_full_text', array(
            'label' => "If this option is checked, the full text for a Group document will be visible if downloading is enabled for that Group document and if the iPaper viewer is not visible because of javascript being disabled on user's browser. Also, full text on the group allows search engines to index content, and increases SEO.",
            'description' => 'Include full text on groups',
            'value' => Engine_Api::_()->getApi('settings', 'core')->getSetting('sitegroupdocument.include.full.text', 1),
        ));

        $this->addElement('Radio', 'sitegroupdocument_visitor_fulltext', array(
            'label' => '',
            'description' => 'Do you want full texts for Group documents to be included on Group document groups for non-logged-in users also? (Choosing "Yes" over here will enable full text on your Group document groups to be indexed by search engines.)',
            'multiOptions' => array(
                1 => 'Yes',
                0 => 'No'
            ),
            'value' => Engine_Api::_()->getApi('settings', 'core')->getSetting('sitegroupdocument.visitor.fulltext', 1),
        ));

        $this->addElement('Checkbox', 'sitegroupdocument_save_local_server', array(
            'label' => "Save Group documents on your site's server.",
            'description' => 'Save Group documents on server',
            'value' => Engine_Api::_()->getApi('settings', 'core')->getSetting('sitegroupdocument.save.local.server', 1),
        ));

        $this->addElement('Radio', 'sitegroupdocument_download_allow', array(
            'label' => 'Group Document downloading',
            'description' => 'Enable downloading of Group documents.',
            'multiOptions' => array(
                1 => 'Yes',
                0 => 'No'
            ),
            'value' => Engine_Api::_()->getApi('settings', 'core')->getSetting('sitegroupdocument.download.allow', 1),
        ));

        $this->addElement('Radio', 'sitegroupdocument_download_show', array(
            'description' => 'Show option to users during Group document creation to allow downloading of their Group documents.',
            'multiOptions' => array(
                1 => 'Yes',
                0 => 'No'
            ),
            'value' => Engine_Api::_()->getApi('settings', 'core')->getSetting('sitegroupdocument.download.show', 1),
        ));

        $this->addElement('Select', 'sitegroupdocument_download_format', array(
            'label' => 'Download Format',
            'description' => 'Select the format in which the downloadable Group documents will be downloaded in.',
            'multiOptions' => array(
                'pdf' => 'PDF',
                'original' => 'Original Group Document Format',
                'txt' => 'Plain Text'
            ),
            'value' => Engine_Api::_()->getApi('settings', 'core')->getSetting('sitegroupdocument.download.format', 'pdf'),
        ));

        $this->addElement('Radio', 'sitegroupdocument_secure_allow', array(
            'label' => 'Secure iPaper Settings',
            'description' => 'Secure Group document iPaper cannot be embedded on other sites. Note that this is a permanent setting for a Group document during its first upload. Thus any change in this setting will only work for new Group document uploads.(Note : This setting will only apply to new Group documents created and not to the existing Group documents on the site.)',
            'multiOptions' => array(
                 1 => 'Make iPaper Group documents secure. Do not allow embedding on other sites. (Note: Secure documents can be viewed in Flash reader only because secure documents use access-management technology which is available in Flash only. Therefore, secure documents will always be viewed in Flash reader, even if you choose HTML5 reader as default.)',
                0 => 'Do not make iPaper Group documents secure. Allow embedding on other sites.'
            ),
            'value' => Engine_Api::_()->getApi('settings', 'core')->getSetting('sitegroupdocument.secure.allow', 0),
        ));

        $this->addElement('Radio', 'sitegroupdocument_secure_show', array(
            'description' => 'Show security option to users. Allow users to choose if their Group documents should be secure or not.',
            'multiOptions' => array(
                1 => 'Yes',
                0 => 'No'
            ),
            'value' => Engine_Api::_()->getApi('settings', 'core')->getSetting('sitegroupdocument.secure.show', 1),
        ));

        $this->addElement('Radio', 'sitegroupdocument_email_allow', array(
            'label' => 'Email attachment Settings',
            'description' => 'Enable emailing as attachments for Group documents on your site.',
            'multiOptions' => array(
                1 => 'Yes',
                0 => 'No'
            ),
            'value' => Engine_Api::_()->getApi('settings', 'core')->getSetting('sitegroupdocument.email.allow', 1),
        ));

        $this->addElement('Radio', 'sitegroupdocument_email_show', array(
            'description' => 'Allow members to choose during Group document creation if their Group documents could be emailed as attachments or not.',
            'multiOptions' => array(
                1 => 'Yes',
                0 => 'No'
            ),
            'value' => Engine_Api::_()->getApi('settings', 'core')->getSetting('sitegroupdocument.email.show', 1),
        ));

        // Order of group document group
        $this->addElement('Radio', 'sitegroupdocument_order', array(
            'label' => 'Default Ordering in Group Documents listing',
            'description' => 'Select the default ordering of documents in Group Documents listing. (This widgetized group will list all Group Documents. Sponsored documents are documents created by paid Groups.)',
            'multiOptions' => array(
                1 => 'All documents in descending order of creation.',
                2 => 'All documents in alphabetical order.',
                3 => 'Featured documents followed by others in descending order of creation.',
                4 => 'Sponsored documents followed by others in descending order of creation.(If you have enabled packages.)',
                5 => 'Featured documents followed by sponsored documents followed by others in descending order of creation.(If you have enabled packages.)',
                6 => 'Sponsored documents followed by featured documents followed by others in descending order of creation.(If you have enabled packages.)',
            ),
            'value' => Engine_Api::_()->getApi('settings', 'core')->getSetting('sitegroupdocument.order', 1),
        ));

        $this->addElement('Radio', 'sitegroupdocument_document_show_menu', array(
            'label' => 'Documents Link',
            'description' => 'Do you want to show the Documents link on Groups Navigation Menu? (You might want to show this if Documents from Groups are an important component on your website. This link will lead to a widgetized group listing all Group Documents, with a search form for Group Documents and multiple widgets.',
            'multiOptions' => array(
                1 => 'Yes',
                0 => 'No'
            ),
            'value' => Engine_Api::_()->getApi('settings', 'core')->getSetting('sitegroupdocument.document.show.menu', 1),
        ));

        $view = Zend_Registry::isRegistered('Zend_View') ? Zend_Registry::get('Zend_View') : null;
        $field = 'sitegroupdocument_code_share';
        $this->addElement('Dummy', "$field", array(
            'label' => 'Social Share Widget Code',
            'description' => "<a class='smoothbox' href='". $view->url(array('module' => 'seaocore', 'controller' => 'settings', 'action' => 'social-share', 'field' => "$field"), 'admin_default', true) ."'>Click here</a> to add your social share code.",
            'ignore' => true,
        ));
        $this->$field->addDecorator('Description', array('placement' => 'PREPEND', 'class' => 'description', 'escape' => false));

        if (!empty($isActive)) {
            $this->addElement('Text', 'sitegroupdocument_truncation_limit', array(
                'label' => 'Title Truncation Limit',
                'description' => 'What maximum limit should be applied to the number of characters in the titles of items in the widgets? (Enter a number between 1 and 999. Titles having more characters than this limit will be truncated. Complete titles will be shown on mouseover.)',
                'required' => $required_value,
                'maxLength' => 3,
                'value' => Engine_Api::_()->getApi('settings', 'core')->getSetting('sitegroupdocument.truncation.limit', 13),
                'validators' => array(
                    array('Int', true),
                    array('GreaterThan', true, array(0)),
                ),
            ));
            $this->addElement('Text', 'sitegroupdocument_manifestUrl', array(
                'label' => 'Group Documents URL alternate text for "group-documents"',
                'allowEmpty' => false,
                'required' => $required_value,
                'description' => 'Please enter the text below which you want to display in place of "groupdocuments" in the URLs of this plugin.',
                'value' => Engine_Api::_()->getApi('settings', 'core')->getSetting('sitegroupdocument.manifestUrl', "group-documents"),
            ));
        }

        $this->addElement('Button', 'submit', array(
            'label' => 'Save Changes',
            'type' => 'submit',
            'ignore' => true
        ));
    }

}

?>
