<?php

/**
 * SocialEngine
 *
 * @category   Application_Extensions
 * @package    Sitegroupintegration
 * @copyright  Copyright 2015-2016 BigStep Technologies Pvt. Ltd.
 * @license    http://www.socialengineaddons.com/license/
 * @version    IndexController.php 2015-09-17 00:00:00Z SocialEngineAddOns $
 * @author     SocialEngineAddOns
 */
class Sitegroupintegration_IndexController extends Siteapi_Controller_Action_Standard {
    /*
     * Store listing info
     */

    protected $_listingType;

    /*
     * Store listing type id
     */
    protected $_listingTypeId;

    public function init() {
        // Set listing type array
        $this->_listingTypeId = $this->getRequestParam('listingtype_id', 1);
        if ($this->_listingTypeId != -1 && !empty($this->_listingTypeId)) {
            $this->_listingType = Engine_Api::_()->getItem('sitereview_listingtype', $this->_listingTypeId);

            if (empty($this->_listingType))
                $this->respondWithError('no_record');

            if (!$this->_helper->requireAuth()->setAuthParams('sitereview_listing', null, "view_listtype_$this->_listingTypeId")->isValid())
                $this->respondWithError('unauthorized');
        }

        // Update listing expiration.
        if (Engine_Api::_()->getDbtable('modules', 'core')->isModuleEnabled('sitereviewpaidlisting')) {
            if ((Engine_Api::_()->getApi('settings', 'core')->getSetting('sitereviewpaidlisting.task.updateexpiredlistings') + 900) <= time()) {
                Engine_Api::_()->sitereviewpaidlisting()->updateExpiredListings($this->_listingTypeId);
            }
        }
    }

    /*
     * Calling of browse listings
     * 
     * @return array
     */

    public function indexAction() {
        $this->validateRequestMethod();

        // Set view
        Engine_Api::_()->getApi('Core', 'siteapi')->setView();
        $group_id = $this->getRequestParam('group_id');

        if (!isset($group_id) || empty($group_id))
            $this->respondWithError('no_record');

        $sitegroup = Engine_Api::_()->getItem('sitegroup_group', $group_id);

        if (!isset($sitegroup) || empty($sitegroup))
            $this->respondWithError('no_record');

        //SET Sitegroup SUBJECT
        Engine_Api::_()->core()->setSubject($sitegroup);

        $viewer = Engine_Api::_()->user()->getViewer();
        $viewer_id = $viewer->getIdentity();
        $level_id = !empty($viewer_id) ? $viewer->level_id : Engine_Api::_()->getDbtable('levels', 'authorization')->fetchRow(array('type = ?' => "public"))->level_id;

        $listing_plural_uc = @ucfirst($this->_listingType->title_plural);

        $response = array();
        $params = $this->_getAllParams();

        // Set the view type
        $params['type'] = 'browse';

        $params['listingtype_id'] = $this->_listingTypeId;
        $params['resource_type'] = 'sitereview_listing';


        if (!isset($params['category_id']))
            $params['category_id'] = 0;

        if (!isset($params['subcategory_id']))
            $params['subcategory_id'] = 0;

        if (!isset($params['subsubcategory_id']))
            $params['subsubcategory_id'] = 0;

        if (isset($this->_listingType->location) && !empty($this->_listingType->location)) {
            // Set location of app dashboard
            if (isset($_GET['restapilocation']) && !empty($_GET['restapilocation']))
                $params['location'] = $_GET['restapilocation'];

            // Set location of adv search form
            if (isset($_GET['location']) && !empty($_GET['location']))
                $params['location'] = $_GET['location'];
        }
        else {
            if (isset($params['location']) && !empty($params['location']))
                unset($params['location']);
        }

        // Set the order by value
        if (!isset($params['orderby']) && empty($params['orderby']))
            $params['orderby'] = 'creation_date';

        // Set the default show closed value
        if (!isset($params['showClosed']) && empty($params['showClosed']))
            $params['showClosed'] = 1;

        // Set the default show closed value
        if (!isset($params['group_id']) && empty($params['group_id']))
            $params['group_id'] = $params['group_id'];

        // Set the min price value
        if (isset($params['min_price']) && !empty($params['min_price']))
            $params['price']['min'] = $params['min_price'];

        // Set the max price value
        if (isset($params['max_price']) && !empty($params['max_price']))
            $params['price']['max'] = $params['max_price'];

        // Set the page value
        if (!isset($params['page']) && empty($params['page']))
            $params['page'] = 1;

        // Set the page limit
        if (!isset($params['limit']) && empty($params['limit']))
            $params['limit'] = 20;


        // Set friends array in case of friends listing search.
        if ($params['show'] == 2) {
            $friends = $viewer->membership()->getMembers();

            $ids = array();
            foreach ($friends as $friend) {
                $ids[] = $friend->user_id;
            }

            $params['users'] = $ids;
        }

        $row = Engine_Api::_()->getDbTable('searchformsetting', 'seaocore')->getFieldsOptions('sitereview_listtype_' . $this->_listingTypeId, 'show');
        if ($viewer->getIdentity() && !empty($row) && !empty($row->display) && $params['show'] == 3 && !isset($_GET['show'])) {
            $params['show'] = 3;
        }

        try {
            $paginator = Engine_Api::_()->getDbtable('contents', 'sitegroupintegration')->getResults($params);
            $paginator->setItemCountPerPage($params['limit']);
            $paginator = $paginator->setCurrentPageNumber($params['page']);
            $response['totalItemCount'] = $paginator->getTotalItemCount();
            $response['canCreate'] = Engine_Api::_()->authorization()->getPermission($level_id, 'sitereview_listing', "create_listtype_$this->_listingTypeId");

            foreach ($paginator as $listing) {
                $listingArray = $listing->toArray();

                // Set the price & currency 
                if (isset($listingArray['price']) && $listingArray['price'] > 0) {
                    $listingArray['currency'] = Engine_Api::_()->getApi('settings', 'core')->getSetting('payment.currency', 'USD');
                } else if (isset($listingArray['price']))
                    unset($listingArray['price']);

                // Set owner images & title
                if (isset($listing->owner_id) && !empty($listing->owner_id)) {
                    $getContentImages = Engine_Api::_()->getApi('Core', 'siteapi')->getContentImage($listing, true);
                    $listingArray = array_merge($listingArray, $getContentImages);

                    $listingArray["owner_title"] = $listing->getOwner()->getTitle();
                }

                // Set listing images  
                $getContentImages = Engine_Api::_()->getApi('Core', 'siteapi')->getContentImage($listing);
                $listingArray = array_merge($listingArray, $getContentImages);

                $isAllowedView = $listing->authorization()->isAllowed($viewer, 'view');
                $listingArray["allow_to_view"] = empty($isAllowedView) ? 0 : 1;

                $isAllowedEdit = $listing->authorization()->isAllowed($viewer, 'edit');
                $listingArray["edit"] = empty($isAllowedEdit) ? 0 : 1;

                $isAllowedDelete = $listing->authorization()->isAllowed($viewer, 'delete');
                $listingArray["delete"] = empty($isAllowedDelete) ? 0 : 1;
                $response['response'][] = $listingArray;
            }

            $this->respondWithSuccess($response, true);
        } catch (Exception $ex) {
            $this->respondWithError('internal_server_error', $ex->getMessage());
        }
    }

}
