<?php

/**
 * SocialEngine
 *
 * @category   Application_Extensions
 * @package    Sitegroupnote
 * @copyright  Copyright 2010-2011 BigStep Technologies Pvt. Ltd.
 * @license    http://www.socialengineaddons.com/license/
 * @version    $Id: Menus.php 2011-05-05 9:40:21Z SocialEngineAddOns $
 * @author     SocialEngineAddOns
 */
class Sitegroupnote_Plugin_Menus {

  public function canViewNotes() {

    if (!Engine_Api::_()->getApi('settings', 'core')->getSetting('sitegroupnote.note.show.menu', 1)) {
      return false;
    }

    $table = Engine_Api::_()->getDbTable('notes', 'sitegroupnote');
    $rName = $table->info('name');
    $table_groups = Engine_Api::_()->getDbtable('groups', 'sitegroup');
    $rName_groups = $table_groups->info('name');
    $select = $table->select()
                    ->setIntegrityCheck(false)
                    ->from($rName_groups, array('photo_id', 'title as sitegroup_title'))
                    ->join($rName, $rName . '.group_id = ' . $rName_groups . '.group_id');

    $select = $select
                    ->where($rName_groups . '.closed = ?', '0')
                    ->where($rName_groups . '.approved = ?', '1')
                    ->where($rName_groups . '.search = ?', '1')
                    ->where($rName_groups . '.declined = ?', '0')
                    ->where($rName_groups . '.draft = ?', '1');
    if (Engine_Api::_()->sitegroup()->hasPackageEnable()) {
      $select->where($rName_groups . '.expiration_date  > ?', date("Y-m-d H:i:s"));
    }
    $row = $table->fetchAll($select);
    $count = count($row);
    if (empty($count)) {
      return false;
    }
    return true;
  }


  //SITEMOBILE GROUP NOTE MENUS
  public function onMenuInitialize_SitegroupnoteWrite($row) {

    $subject = Engine_Api::_()->core()->getSubject();

    $sitegroupnote = $this->getSitegroupNoteObject();

    if (empty($sitegroupnote)) {
      return false;
    }
    //GROUP ID
    $group_id = $sitegroupnote->group_id;

    $sitegroup = Engine_Api::_()->getItem('sitegroup_group', $group_id);
    //START MANAGE-ADMIN CHECK
    $isManageAdmin = Engine_Api::_()->sitegroup()->isManageAdmin($sitegroup, 'sncreate');
    if (empty($isManageAdmin)) {
      $can_create = 0;
    } else {
      $can_create = 1;
    }

    //CHECKS FOR WRITE
    if (empty($can_create)) {
      return false;
    }

    return array(
        'label' => 'Write a Note',
        'route' => 'sitegroupnote_create',
        'class' => 'ui-btn-action',
        'params' => array(
            'group_id' => $group_id,
            'tab' => Zend_Controller_Front::getInstance()->getRequest()->getParam('tab')
        )
    );
  }

  public function onMenuInitialize_SitegroupnotePublish($row) {
    $subject = Engine_Api::_()->core()->getSubject();

    $check = $this->commonChecks();

    if (empty($check)) {
      return false;
    }
    $sitegroupnote = $this->getSitegroupNoteObject();

    if (empty($sitegroupnote)) {
      return false;
    }
    if ($sitegroupnote->draft != 1) {
      return false;
    }
    return array(
        'label' => 'Publish Note',
        'route' => 'sitegroupnote_publish',
        'class' => 'ui-btn-action smoothbox',
        'params' => array(
            'note_id' => $subject->getIdentity(),
            'tab' => Zend_Controller_Front::getInstance()->getRequest()->getParam('tab')
        )
    );
  }

  public function onMenuInitialize_SitegroupnoteEdit($row) {
    $subject = Engine_Api::_()->core()->getSubject();
    $sitegroupnote = $this->getSitegroupNoteObject();

    if (empty($sitegroupnote)) {
      return false;
    }
    //GROUP ID
    $group_id = $sitegroupnote->group_id;

    $check = $this->commonChecks();

    if (empty($check)) {
      return false;
    }

    return array(
        'label' => 'Edit Note',
        'route' => 'sitegroupnote_edit',
        'class' => 'ui-btn-action',
        'params' => array(
            'note_id' => $subject->getIdentity(),
            'group_id' => $group_id,
            'tab' => Zend_Controller_Front::getInstance()->getRequest()->getParam('tab')
        )
    );
  }

  public function onMenuInitialize_SitegroupnoteDelete($row) {
    $subject = Engine_Api::_()->core()->getSubject();
    $sitegroupnote = $this->getSitegroupNoteObject();

    if (empty($sitegroupnote)) {
      return false;
    }
    //GROUP ID
    $group_id = $sitegroupnote->group_id;

    $check = $this->commonChecks();

    if (empty($check)) {
      return false;
    }

    return array(
        'label' => 'Delete Note',
        'route' => 'sitegroupnote_delete',
        'class' => 'ui-btn-danger',
        'params' => array(
            'note_id' => $subject->getIdentity(),
            'group_id' => $group_id,
            'tab' => Zend_Controller_Front::getInstance()->getRequest()->getParam('tab')
        )
    );
  }

  public function onMenuInitialize_SitegroupnoteAdd($row) {
    $viewer = Engine_Api::_()->user()->getViewer();
    $subject = Engine_Api::_()->core()->getSubject();

    $sitegroupnote = $this->getSitegroupNoteObject();

    if (empty($sitegroupnote)) {
      return false;
    }
    //GROUP ID
    $group_id = $sitegroupnote->group_id;

    $owner_id = $sitegroupnote->owner_id;

    $viewer_id = $viewer->getIdentity();

    $allow_image = Engine_Api::_()->getApi('settings', 'core')->sitegroupnote_allow_image;

    //CHECKS FOR ADD PHOTOS
    if ($owner_id != $viewer_id || empty($allow_image)) {
      return false;
    }

    if (Engine_API::_()->seaocore()->checkSitemobileMode('fullsite-mode')) {
			return array(
					'label' => 'Add Photos',
					'route' => 'sitegroupnote_photoupload',
					'class' => 'ui-btn-action',
					'params' => array(
							'note_id' => $subject->getIdentity(),
							'group_id' => $group_id,
              'tab' => Zend_Controller_Front::getInstance()->getRequest()->getParam('tab')
					)
			);
    } else {
			return array(
					'label' => 'Add Photos',
					'route' => 'sitegroupnote_sitemobilephotoupload',
					'class' => 'ui-btn-action',
					'params' => array(
							'note_id' => $subject->getIdentity(),
							'group_id' => $group_id,
              'tab' => Zend_Controller_Front::getInstance()->getRequest()->getParam('tab')
					)
			);
    }
  }

  //PHOTO VIEW GROUP OPTIONS
  public function onMenuInitialize_SitegroupnotePhotoEdit($row) {

     //GET VIEWER ID
    $viewer_id = Engine_Api::_()->user()->getViewer()->getIdentity();

    $subject = Engine_Api::_()->core()->getSubject();
    //GET ALBUM ID
    $note_id = $subject->note_id;
    
    $sitegroupnote = Engine_Api::_()->getItem('sitegroupnote_note', $note_id);
    
    //GET GROUP ID
    $group_id = $sitegroupnote->group_id;

    $sitegroup = Engine_Api::_()->getItem('sitegroup_group', $group_id);
    
    //START MANAGE-ADMIN CHECK
    $isManageAdmin = Engine_Api::_()->sitegroup()->isManageAdmin($sitegroup, 'edit');
    if (empty($isManageAdmin)) {
      $can_edit = 0;
    } else {
      $can_edit = 1;
    }
    
    //PHOTO OWNER, GROUP OWNER AND SUPER-ADMIN CAN EDIT PHOTO
    if ($viewer_id != $sitegroupnote->owner_id && $can_edit != 1) {
      return false;
    }


    return array(
        'label' => 'Edit',
        'route' => 'sitegroupnote_photoedit',
        'class' => 'ui-btn-action smoothbox',
        'params' => array(
           'action' => 'photoedit',
            'photo_id' => $subject->photo_id,
            'note_id' => $note_id,
            'group_id' => $group_id,
             'tab' => Zend_Controller_Front::getInstance()->getRequest()->getParam('tab')
        )
    );
  }

  public function onMenuInitialize_SitegroupnotePhotoDelete($row) {


     //GET VIEWER ID
    $viewer_id = Engine_Api::_()->user()->getViewer()->getIdentity();

    $subject = Engine_Api::_()->core()->getSubject();
    //GET ALBUM ID
    $note_id = $subject->note_id;
    
    $sitegroupnote = Engine_Api::_()->getItem('sitegroupnote_note', $note_id);
    
    //GET GROUP ID
    $group_id = $sitegroupnote->group_id;

    $sitegroup = Engine_Api::_()->getItem('sitegroup_group', $group_id);
    
    //START MANAGE-ADMIN CHECK
    $isManageAdmin = Engine_Api::_()->sitegroup()->isManageAdmin($sitegroup, 'edit');
    if (empty($isManageAdmin)) {
      $can_edit = 0;
    } else {
      $can_edit = 1;
    }
    
    //PHOTO OWNER, GROUP OWNER AND SUPER-ADMIN CAN EDIT PHOTO
    if ($viewer_id != $sitegroupnote->owner_id && $can_edit != 1) {
      return false;
    }

    return array(
        'label' => 'Delete',
        'route' => 'sitegroupnote_removeimage',
        'class' => 'ui-btn-danger',
        'params' => array(
            'action' => 'remove',
            'photo_id' => $subject->photo_id,
            'note_id' => $note_id,
            'group_id' => $group_id,
            'owner_id' => $subject->user_id,
            'tab' => Zend_Controller_Front::getInstance()->getRequest()->getParam('tab')
        )
    );
  }

  public function onMenuInitialize_SitegroupnotePhotoShare($row) {
    $subject = Engine_Api::_()->core()->getSubject();
    //GET VIEWER ID
    $viewer_id = Engine_Api::_()->user()->getViewer()->getIdentity();
    
    if(!$viewer_id){
      return false;
    }
    if (!SEA_PHOTOLIGHTBOX_SHARE) {
      return false;
    }
    return array(
        'label' => 'Share',
        'class' => 'ui-btn-action smoothbox',
        'route' => 'default',
        'params' => array(
            'module' => 'activity',
            'action' => 'share',
            'type' => $subject->getType(),
            'id' => $subject->getIdentity(),
        )
    );
  }

  public function onMenuInitialize_SitegroupnotePhotoReport($row) {
    $subject = Engine_Api::_()->core()->getSubject();
    //GET VIEWER ID
    $viewer_id = Engine_Api::_()->user()->getViewer()->getIdentity();
    
    if(!$viewer_id){
      return false;
    }
    if (!SEA_PHOTOLIGHTBOX_REPORT) {
      return false;
    }
    return array(
        'label' => 'Report',
        'class' => 'ui-btn-action smoothbox',
        'route' => 'default',
        'params' => array(
            'module' => 'core',
            'controller' => 'report',
            'action' => 'create',
            'subject' => $subject->getGuid(),
        )
    );
  }

   //COMMON FUNCTION
  public function commonChecks() {
    $viewer = Engine_Api::_()->user()->getViewer();
    $subject = Engine_Api::_()->core()->getSubject();

    $sitegroupnote = $this->getSitegroupNoteObject();

    if (empty($sitegroupnote)) {
      return false;
    }
    //GROUP ID
    $group_id = $sitegroupnote->group_id;
    $owner_id = $sitegroupnote->owner_id;

    $sitegroup = Engine_Api::_()->getItem('sitegroup_group', $group_id);

    $viewer_id = $viewer->getIdentity();

    //EDIT
    $isManageAdmin = Engine_Api::_()->sitegroup()->isManageAdmin($sitegroup, 'edit');
    if (empty($isManageAdmin)) {
      $can_edit = 0;
    } else {
      $can_edit = 1;
    }

    //CHECKS FOR DELETE
    if ($owner_id != $viewer_id && empty($can_edit)) {
      return false;
    } else {
      return true;
    }
  }

  public function getSitegroupNoteObject() {
    $subject = Engine_Api::_()->core()->getSubject();
    //GET NOTE ID
    $note_id = $subject->getIdentity();
    //GET NOTE ITEM
    $sitegroupnote = Engine_Api::_()->getItem('sitegroupnote_note', $note_id);
    //ASK
    if (empty($sitegroupnote)) {
      return false;
    }
    return $sitegroupnote;
  }

}
?>