<?php

/**
 * SocialEngine
 *
 * @category   Application_Extensions
 * @package    Sitegroup
 * @copyright  Copyright 2010-2011 BigStep Technologies Pvt. Ltd.
 * @license    http://www.socialengineaddons.com/license/
 * @version    $Id: Menus.php 2011-05-05 9:40:21Z SocialEngineAddOns $
 * @author     SocialEngineAddOns
 */
class Sitegroupoffer_Plugin_Menus {

  public function canViewOffers() {

    if (!Engine_Api::_()->getApi('settings', 'core')->getSetting('sitegroupoffer.offer.show.menu', 1)) {
      return false;
    }

    $viewer = Engine_Api::_()->user()->getViewer();
    $viewer_id = $viewer->getIdentity();
    
    
    $table = Engine_Api::_()->getDbtable('offers', 'sitegroupoffer');
    $rName = $table->info('name');
    $table_groups = Engine_Api::_()->getDbtable('groups', 'sitegroup');
    $rName_groups = $table_groups->info('name');
    $today = date("Y-m-d H:i:s");
    if (!empty($viewer_id)) {
      // Convert times
      $oldTz = date_default_timezone_get();
      date_default_timezone_set($viewer->timezone);
      $today = date("Y-m-d H:i:s");
      date_default_timezone_set($oldTz);
    }
    $select = $table->select()
                    ->setIntegrityCheck(false)
                    ->from($rName_groups, array('photo_id', 'title as sitegroup_title'))
                    ->join($rName, $rName . '.group_id = ' . $rName_groups . '.group_id')
                    ->where("($rName.end_settings = 1 AND $rName.end_time >= '$today' OR $rName.end_settings = 0) ");

    $select = $select
                    ->where($rName_groups . '.closed = ?', '0')
                    ->where($rName_groups . '.approved = ?', '1')
                    ->where($rName_groups . '.search = ?', '1')
                    ->where($rName_groups . '.declined = ?', '0')
                    ->where($rName_groups . '.draft = ?', '1');
    if (Engine_Api::_()->sitegroup()->hasPackageEnable()) {
      $select->where($rName_groups . '.expiration_date  > ?', date("Y-m-d H:i:s"));
    }
    $row = $table->fetchAll($select);
    $count = count($row);
    if (empty($count)) {
      return false;
    }
    return true;
  }

  //SITEMOBILE GROUP ALBUM MENUS
  public function onMenuInitialize_SitegroupofferAdd($row) {

    $can_create_offer = $this->commonChecks();

    //CHECKS FOR ADD OFFER
    if (empty($can_create_offer)) {
      return false;
    }

    $sitegroupoffer = $this->getSitegroupOfferObject();

    if (empty($sitegroupoffer)) {
      return false;
    }

    $group_id = $sitegroupoffer->group_id;
    return array(
        'label' => 'Add an Offer',
        'route' => 'sitegroupoffer_general',
        'class'=>'ui-btn-action',
        'params' => array(
            'action' => 'create',
            'group_id' => $group_id,
            'tab' => Zend_Controller_Front::getInstance()->getRequest()->getParam('tab')
        )
    );
  }

  public function onMenuInitialize_SitegroupofferEdit($row) {

    $subject = Engine_Api::_()->core()->getSubject();

    $can_create_offer = $this->commonChecks();

    //CHECKS FOR EDIT OFFER
    if (empty($can_create_offer)) {
      return false;
    }

    $sitegroupoffer = $this->getSitegroupOfferObject();

    if (empty($sitegroupoffer)) {
      return false;
    }

    $group_id = $sitegroupoffer->group_id;

    return array(
        'label' => 'Edit Offer',
        'route' => 'sitegroupoffer_general',
        'class'=>'ui-btn-action',
        'params' => array(
            'action' => 'edit',
            'offer_id' => $subject->getIdentity(),
            'group_id' => $group_id,
            'tab' => Zend_Controller_Front::getInstance()->getRequest()->getParam('tab')
        )
    );
  }

  public function onMenuInitialize_SitegroupofferDelete($row) {

    $subject = Engine_Api::_()->core()->getSubject();

    $can_create_offer = $this->commonChecks();

    //CHECKS FOR DELETE OFFER
    if (empty($can_create_offer)) {
      return false;
    }

    $sitegroupoffer = $this->getSitegroupOfferObject();

    if (empty($sitegroupoffer)) {
      return false;
    }

    $group_id = $sitegroupoffer->group_id;
    return array(
        'label' => 'Delete Offer',
        'route' => 'sitegroupoffer_general',
        'class'=>'ui-btn-danger',
        'params' => array(
            'action' => 'delete',
            'offer_id' => $subject->getIdentity(),
            'group_id' => $group_id,
            'tab' => Zend_Controller_Front::getInstance()->getRequest()->getParam('tab')
        )
    );
  }

//  public function onMenuInitialize_SitegroupofferPrint($row) {
//
//    $subject = Engine_Api::_()->core()->getSubject();
//
//    $sitegroupoffer = $this->getSitegroupOfferObject();
//
//    if (empty($sitegroupoffer)) {
//      return false;
//    }
//
//    $group_id = $sitegroupoffer->group_id;
//    return array(
//        'label' => 'Print Offer',
//        'route' => 'sitegroupoffer_general',
//        'target' => '_blank',
//        'params' => array(
//            'action' => 'print',
//            'offer_id' => $subject->getIdentity(),
//            'group_id' => $group_id
//        )
//    );
//  }

  public function onMenuInitialize_SitegroupofferShare($row) {

    $subject = Engine_Api::_()->core()->getSubject();
    return array(
        'label' => 'Share',
        'route' => 'default',
        'class' => 'ui-btn-action smoothbox',
        'params' => array(
            'module' => 'activity',
            'controller' => 'index',
            'action' => 'share',
            'id' => $subject->getIdentity(),
            'type' => 'sitegroupoffer_offer',
        ),

    );
  }

  public function onMenuInitialize_SitegroupofferReport($row) {

    $subject = Engine_Api::_()->core()->getSubject();

    return array(
        'label' => 'Report',
        'route' => 'default',
        'class' => 'ui-btn-action smoothbox',
        'params' => array(
            'module' => 'core',
            'controller' => 'report',
            'action' => 'create',
            'subject' => $subject->getGuid(),
        ),

    );
  }

  public function commonChecks() {

    //$viewer = Engine_Api::_()->user()->getViewer();

    $sitegroupoffer = $this->getSitegroupOfferObject();
    if (empty($sitegroupoffer)) {
      return false;
    }
    $group_id = $sitegroupoffer->group_id;
    $sitegroup = Engine_Api::_()->getItem('sitegroup_group', $group_id);
    //START MANAGE-ADMIN CHECK
    $can_offer = 1;
    $isManageAdmin = Engine_Api::_()->sitegroup()->isManageAdmin($sitegroup, 'offer');
    if (empty($isManageAdmin)) {
      $can_offer = 0;
    }

    $isManageAdmin = Engine_Api::_()->sitegroup()->isManageAdmin($sitegroup, 'edit');
    if (empty($isManageAdmin)) {
      $can_edit = 0;
    } else {
      $can_edit = 1;
    }

    $can_create_offer = '';
    //OFFER CREATION AUTHENTICATION CHECK
    if ($can_edit == 1 && $can_offer == 1) {
      $can_create_offer = 1;
    }

    return $can_create_offer;
  }

  public function getSitegroupOfferObject() {
    $subject = Engine_Api::_()->core()->getSubject();
    $offer_id = $subject->getIdentity();
    $sitegroupoffer = Engine_Api::_()->getItem('sitegroupoffer_offer', $offer_id);

    if (empty($sitegroupoffer)) {
      return false;
    }

    return $sitegroupoffer;
  }

}
?>
