<?php

/**
 * SocialEngine
 *
 * @category   Application_Extensions
 * @package    Sitegroupreview
 * @copyright  Copyright 2010-2011 BigStep Technologies Pvt. Ltd.
 * @license    http://www.socialengineaddons.com/license/
 * @version    $Id: Reviews.php 2011-05-05 9:40:21Z SocialEngineAddOns $
 * @author     SocialEngineAddOns
 */
class Sitegroupreview_Model_DbTable_Reviews extends Engine_Db_Table {

  protected $_rowClass = "Sitegroupreview_Model_Review";

  /**
   * Return review data for checking that viewer has been posted a review or not
   *
   * @param Int group_id
   * @param Int viewer_id
   * @return Zend_Db_Table_Select
   */
  public function canPostReview($group_id, $viewer_id) {

    //MAKE QUERY
    $hasPosted = $this->select()
                    ->from($this->info('name'), array('review_id'))
                    ->where('group_id = ?', $group_id)
                    ->where('owner_id = ?', $viewer_id)
                    ->query()
                    ->fetchColumn();

    //RETURN RESULTS
    return $hasPosted;
  }

  /**
   * Return average recommendetion for group reviews
   *
   * @param Int group_id
   * @return Zend_Db_Table_Select
   */
  public function getAvgRecommendation($group_id) {

    //MAKE QUERY
    $select = $this->select()
                    ->from($this->info('name'), array('*', 'AVG(recommend) AS avg_recommend'))
                    ->where('group_id = ?', $group_id)
                    ->group('group_id');

    //RETURN RESULTS
    return $this->fetchAll($select);
  }

  /**
   * Return total reviews for group
   *
   * @param Int group_id
   * @return Zend_Db_Table_Select
   */
  public function totalReviews($group_id) {

    //MAKE QUERY
    $totalReviews = $this->select()
                    ->from($this->info('name'), array('COUNT(*) AS count'))
                    ->where('group_id = ?', $group_id)
                    ->query()
                    ->fetchColumn();

    //RETURN RESULTS
    return $totalReviews;
  }

  /**
   * Return group reviews
   *
   * @param Int group_id
   * @return Zend_Db_Table_Select
   */
  public function groupReviews($group_id) {

    //MAKE QUERY
    $select = $this->select()
										->where('group_id = ?', $group_id)
										->order('modified_date DESC');
    //RETURN RESULTS
    return Zend_Paginator::factory($select);
  }

  /**
   * Get reviews to add as item of the day
   * @param string $title : search text
   * @param int $limit : result limit
   */
  public function getDayItems($search_text, $limit=10) {

    //GET GROUP TABLE NAME
    $tableGroupName = Engine_Api::_()->getDbTable('groups', 'sitegroup')->info('name');

    //GET ITEM TABLE NAME
    $itemTableName = $this->info('name');

    //MAKE QUERY
    $select = $this->select()
                    ->setIntegrityCheck(false)
                    ->from($itemTableName, array('review_id', 'title', 'owner_id', 'group_id'))
                    ->joinLeft($tableGroupName, "$tableGroupName.group_id = $itemTableName.group_id", array(''))
                    ->where($tableGroupName . '.closed = ?', '0')
                    ->where($tableGroupName . '.declined = ?', '0')
                    ->where($tableGroupName . '.approved = ?', '1')
                    ->where($tableGroupName . '.draft = ?', '1')
                    ->where($itemTableName . '.title  LIKE ? ', '%' . $search_text . '%')
                    ->order($itemTableName . '.title ASC')
                    ->limit($limit);

    //RETURN DATA
    return $this->fetchAll($select);
  }

  /**
   * Return group reviews
   *
   * @param array params
   * @return Zend_Db_Table_Select
   */
  public function reviewRatingData($params = array(),$widgetType = null) {

    //GET GROUP TABLE NAME
    $tableGroup = Engine_Api::_()->getDbtable('groups', 'sitegroup');
    $tableGroupName = $tableGroup->info('name');

    //GET RATING TABLE NAME
    $tableRatingName = Engine_Api::_()->getDbtable('ratings', 'sitegroupreview')->info('name');

    //GET REVIEW TABLE NAME
    $tableReviewName = $this->info('name');

    //MAKE QUERY
    $select = $this->select()
                    ->setIntegrityCheck(false)
                    ->from($tableReviewName)
                    ->joinLeft($tableRatingName, "$tableRatingName.review_id = $tableReviewName.review_id", array('rating'));


    if (isset($params['group_id']) && !empty($params['group_id'])) {
      $select = $select->where($tableReviewName . '.group_id = ?', $params['group_id']);
    }

    if (isset($params['zero_count']) && !empty($params['zero_count'])) {
      $select = $select->where($tableReviewName . '.' . $params['zero_count'] . '!= ?', 0);
    }

    if (isset($params['orderby']) && !empty($params['orderby'])) {
      $select = $select->order($tableReviewName . '.' . $params['orderby']);
    }

    if (isset($params['limit']) && !empty($params['limit'])) {
      if (!isset($params['start_index']))
        $params['start_index'] = 0;
      $select->limit($params['limit'], $params['start_index']);
    }

    if (isset($params['group_validation']) && !empty($params['group_validation'])) {

      $select = $select->joinLeft($tableGroupName, "$tableGroupName.group_id = $tableReviewName.group_id", array('group_id', 'title AS group_title', 'photo_id'))
                      ->where($tableGroupName . '.search = ?', '1')
                      ->where($tableGroupName . '.closed = ?', '0')
                      ->where($tableGroupName . '.approved = ?', '1')
                      ->where($tableGroupName . '.declined = ?', '0')
                      ->where($tableGroupName . '.draft = ?', '1');
      if (!empty($params['category_id'])) {
				$select->where($tableGroupName . '.category_id = ?', $params['category_id']);
			}
			
      if (Engine_Api::_()->sitegroup()->hasPackageEnable()) {
        $select->where($tableGroupName . '.expiration_date  > ?', date("Y-m-d H:i:s"));
      }
    }
    
    if($widgetType == 'browsereview') {
      if (!empty($params['title'])) {
				$select->where($tableGroupName . ".title LIKE ? ", '%' . $params['title'] . '%');
			}

      if (!empty($params['search_review'])) {
				$select->where($tableReviewName . ".title LIKE ? ", '%' . $params['search_review'] . '%');
      }
     
      if ((isset($params['orderby_browse']) && $params['orderby_browse'] == 'view_count') || !empty($params['viewedreview'])) {
			$select = $select
											->order($tableReviewName .'.view_count DESC')
											->order($tableReviewName .'.creation_date DESC');
			} elseif ((isset($params['orderby_browse']) && $params['orderby_browse'] == 'comment_count') || !empty($params['commentedreview'])) {
				$select = $select
												->order($tableReviewName .'.comment_count DESC')
												->order($tableReviewName .'.creation_date DESC');
			} elseif ((isset($params['orderby_browse']) && $params['orderby_browse'] == 'rating')) {
				$select = $select
												->order($tableRatingName .'.rating DESC')
												->order($tableReviewName .'.creation_date DESC');
			} elseif ((isset($params['orderby_browse']) && $params['orderby_browse'] == 'like_count') || !empty($params['likedreview'])) {
				$select = $select
												->order($tableReviewName .'.like_count DESC')
												->order($tableReviewName .'.creation_date DESC');
			}

      if (!empty($params['category_id'])) {
				$select->where($tableGroupName . '.category_id = ?', $params['category_id']);
			}

			if (!empty($params['subcategory'])) {
				$select->where($tableGroupName . '.subcategory_id = ?', $params['subcategory']);
			}

			if (!empty($params['subcategory_id'])) {
				$select->where($tableGroupName . '.subcategory_id = ?', $params['subcategory_id']);
			}

			if (!empty($params['subsubcategory'])) {
				$select->where($tableGroupName . '.subsubcategory_id = ?', $params['subsubcategory']);
			}

			if (!empty($params['subsubcategory_id'])) {
				$select->where($tableGroupName . '.subsubcategory_id = ?', $params['subsubcategory_id']);
			}
     
      if((isset($params['show']) && $params['show'] == 'featured')) {
				$select = $select
												->where($tableReviewName . '.featured = ?', 1)
												->order($tableReviewName .'.creation_date DESC');
			}
      elseif((isset($params['show']) && $params['show'] == 'my_friend_review')) {
        $viewer_id = Engine_Api::_()->user()->getViewer()->getIdentity();
        $membership_table = Engine_Api::_()->getDbtable( 'membership' , 'user' ) ;
				$member_name = $membership_table->info( 'name' ) ;
        $select->joinInner( $member_name , "$member_name . resource_id = $tableReviewName . owner_id" , NULL )
								->where( $member_name . '.user_id = ?' , $viewer_id )
								->where( $member_name . '.active = ?' , 1 );
      }
      elseif (isset($params['show']) && $params['show'] == 'Networks') {
				$select = $tableGroup->getNetworkBaseSql($select, array('browse_network' => 1));
			}
			
			elseif (isset($params['show']) && $params['show'] == 'my_like') {
				$likeTableName = Engine_Api::_()->getDbtable('likes', 'core')->info('name');
				$viewer_id = Engine_Api::_()->user()->getViewer()->getIdentity();
				$select
              ->join($likeTableName, "$likeTableName.resource_id = $tableGroupName.group_id")
							->where($likeTableName . '.poster_type = ?', 'user')
							->where($likeTableName . '.poster_id = ?', $viewer_id)
              ->where($likeTableName . '.resource_type = ?', 'sitegroup_group');
			}
      
      if(empty($params['orderby_browse'])) {
				$order = Engine_Api::_()->getApi('settings', 'core')->getSetting('sitegroupreview.order', 1);
				switch ($order) {
					case "1":
						$select->order($tableReviewName . '.creation_date DESC');
						break;
					case "2":
						$select->order($tableReviewName . '.title');
						break;
					case "3":
						$select->order($tableReviewName . '.featured' . ' DESC');
						break;
				}
      }
    }
    
    $select = $select->order($tableReviewName . '.review_id DESC')->where($tableRatingName . '.reviewcat_id = ?', 0);

    //Start Network work
    if (!isset($params['group_id']) || empty($params['group_id'])) {
     $select = $tableGroup->getNetworkBaseSql($select, array('not_groupBy' => 1, 'extension_group' => $tableReviewName . ".review_id"));
    }
    //End Network work
    //RETURN RESULTS
    if ((isset($params['featured']) && !empty($params['featured'])) || ($widgetType == 'browsereview')) {
      if($widgetType != 'browsereview') {
				$select = $select->where($tableReviewName . '.featured = ?', 1);
      }
      if($widgetType == 'featuredcarousel') {
        return $this->fetchAll($select);
      }
      else {
      return Zend_Paginator::factory($select);
      }
    } else {
      return $this->fetchAll($select);
    }
  }

  /**
   * Return review of the day
   *
   * @return Zend_Db_Table_Select
   */
  public function reviewOfDay() {

    //CURRENT DATE TIME
    $date = date('Y-m-d');

    //GET ITEM OF THE DAY TABLE NAME
    $reviewOfTheDayTableName = Engine_Api::_()->getDbtable('itemofthedays', 'sitegroup')->info('name');

		//GET GROUP TABLE NAME
		$groupTableName = Engine_Api::_()->getDbtable('groups', 'sitegroup')->info('name');

    //GET REVIEW TABLE NAME
    $reviewTableName = $this->info('name');

    //MAKE QUERY
    $select = $this->select()
                    ->setIntegrityCheck(false)
                    ->from($reviewTableName, array('review_id', 'title', 'group_id', 'owner_id', 'body'))
                    ->join($reviewOfTheDayTableName, $reviewTableName . '.review_id = ' . $reviewOfTheDayTableName . '.resource_id')
										->join($groupTableName, $reviewTableName . '.group_id = ' . $groupTableName . '.group_id', array(''))
										->where($groupTableName.'.approved = ?', '1')
										->where($groupTableName.'.declined = ?', '0')
										->where($groupTableName.'.draft = ?', '1')
                    ->where('resource_type = ?', 'sitegroupreview_review')
                    ->where('start_date <= ?', $date)
                    ->where('end_date >= ?', $date)
                    ->order('Rand()');

		//GROUP SHOULD BE AUTHORIZED
    if (Engine_Api::_()->sitegroup()->hasPackageEnable())
      $select->where($groupTableName.'.expiration_date  > ?', date("Y-m-d H:i:s"));

		//GROUP SHOULD BE AUTHORIZED
    $stusShow = Engine_Api::_()->getApi('settings', 'core')->getSetting('sitegroup.status.show', 1);
    if ($stusShow == 0) {
      $select->where($groupTableName.'.closed = ?', '0');
    }

    //RETURN RESULTS
    return $this->fetchRow($select);
  }

  /**
   * Return top reviewers
   *
   * @param int itemCount
   * @return Zend_Db_Table_Select
   */
  public function topReviewers($itemCount,$category_id) {

    //GET USER TABLE INFO
    $tableUser = Engine_Api::_()->getDbtable('users', 'user');
    $tableUserName = $tableUser->info('name');
    
    //GROUP TABLE
    $groupTable = Engine_Api::_()->getDbtable('groups', 'sitegroup');
    $groupTableName = $groupTable->info('name');
    
    //GET REVIEW TABLE NAME
    $tableReviewName = $this->info('name');

    //MAKE QUERY
    $select = $tableUser->select()
                    ->setIntegrityCheck(false)
                    ->from($tableUserName, array('user_id', 'username', 'displayname', 'photo_id'))
                    ->join($tableReviewName, "$tableUserName.user_id = $tableReviewName.owner_id", array('COUNT(engine4_sitegroupreview_reviews.review_id) AS review_count', 'MAX(engine4_sitegroupreview_reviews.review_id) as max_review_id'));
    if(!empty($category_id)) {
			$select ->join($groupTableName, "$tableReviewName.group_id = $groupTableName.group_id", array())
							->where($groupTableName . '.category_id = ?', $category_id);
    }
    $select->group($tableUserName . ".user_id")
						->order('review_count DESC')
						->order('user_id DESC')
						->limit($itemCount);

    //RETURN THE RESULTS
    return $tableUser->fetchAll($select);
  }
 
  public function topcreatorData($limit = null,$category_id) {

    //REVIEW TABLE NAME
    $reviewTableName = $this->info('name');

    //GROUP TABLE
    $groupTable = Engine_Api::_()->getDbtable('groups', 'sitegroup');
    $groupTableName = $groupTable->info('name');

    $select = $this->select()
                    ->setIntegrityCheck(false)
                    ->from($groupTableName, array('photo_id', 'title as sitegroup_title','group_id'))
                    ->join($reviewTableName, "$groupTableName.group_id = $reviewTableName.group_id", array("COUNT($groupTableName.group_id) AS item_count"))
                    ->where($groupTableName.'.approved = ?', '1')
										->where($groupTableName.'.declined = ?', '0')
										->where($groupTableName.'.draft = ?', '1')
                    ->group($reviewTableName . ".group_id")
                    ->order('item_count DESC')
                    ->limit($limit);

    if (!empty($category_id)) {
      $select->where($groupTableName . '.category_id = ?', $category_id);
    }
    
    return $select->query()->fetchAll();
  }

}
?>