<?php

/**
 * SocialEngine
 *
 * @category   Application_Extensions
 * @package    Sitegroupreview
 * @copyright  Copyright 2015-2016 BigStep Technologies Pvt. Ltd.
 * @license    http://www.socialengineaddons.com/license/
 * @version    ReviewController.php 2015-09-17 00:00:00Z SocialEngineAddOns $
 * @author     SocialEngineAddOns
 */
class Sitegroupreview_ReviewController extends Siteapi_Controller_Action_Standard {

    public function init() {

        $viewer = Engine_Api::_()->user()->getViewer();

        $group_id = $this->_getParam('group_id');
        // Set Subject
        if (!empty($group_id)) {
            $sitegroup = Engine_Api::_()->getItem('sitegroup_group', $group_id);
            if (!empty($sitegroup))
                Engine_Api::_()->core()->setSubject($sitegroup);
        }

        // Authorization check
        if (!$this->_helper->requireAuth()->setAuthParams('sitegroup_group', $viewer, "view")->isValid())
            $this->respondWithError('unauthorized');
    }

    /*
     * Calling of review search form
     * 
     * @return array
     */

    public function searchAction() {
        $this->validateRequestMethod();
        try {
            $this->respondWithSuccess(Engine_Api::_()->getApi('Siteapi_Core', 'Sitegroupreview')->getReviewSearchForm(), true);
        } catch (Exception $ex) {
            $this->respondWithError('internal_server_error', $ex->getMessage());
        }
    }

    /*
     * Calling of browse reviews of a group
     * 
     * @return array
     */

    public function browseAction() {
        $this->validateRequestMethod();

        Engine_Api::_()->getApi('Core', 'siteapi')->setView();

        // Get viewer info
        $viewer = Engine_Api::_()->user()->getViewer();
        $viewer_id = $viewer->getIdentity();

        // Get user level id
        if (!empty($viewer_id)) {
            $level_id = $viewer->level_id;
        } else {
            $level_id = Engine_Api::_()->getDbtable('levels', 'authorization')->fetchRow(array('type = ?' => "public"))->level_id;
        }

        // Check if review is allowed or not
        $allow_review = Engine_Api::_()->getApi('settings', 'core')->getSetting('sitegroupreview.allowreview', 1);
        if (empty($allow_review)) {
            $this->respondWithError('unauthorized');
        }

        // Page subject should be set
        if (!Engine_Api::_()->core()->hasSubject('sitegroup_group'))
            $this->respondWithError('no_record');

        // Get Subject
        $sitegroup = Engine_Api::_()->core()->getSubject('sitegroup_group');
        $group_id = $sitegroup->group_id;

        $params = $this->_getAllParams();

        // Set the page value
        if (!isset($params['page']) && empty($params['page']))
            $params['page'] = 1;

        // Set the page limit
        if (!isset($params['limit']) && empty($params['limit']))
            $params['limit'] = 10;

        try {
            // Get review table
            $reviewTable = Engine_Api::_()->getDbTable('reviews', 'sitegroupreview');
            // Get rating table
            $ratingTable = Engine_Api::_()->getDbTable('ratings', 'sitegroupreview');

            // Review id of the viewer if review already posted
            $hasPosted = $reviewTable->canPostReview($group_id, $viewer_id);

            // Check viewer can create review
            $create_level_allow = $create_level_allow = Engine_Api::_()->authorization()->getPermission($level_id, 'sitegroupreview_review', "review_create");

            $create_review = ($sitegroup->owner_id == $viewer_id) ? Engine_Api::_()->getApi('settings', 'core')->getSetting('sitegroupreview.allowownerreview', 1) : 1;

            if (!$create_review || empty($create_level_allow)) {
                $can_create = 0;
            } else {
                $can_create = 1;
            }

            // Get paginator
            $paginator = $reviewTable->groupReviews($group_id);
            $paginator->setItemCountPerPage($params['limit']);
            $paginator->setCurrentPageNumber($params['page']);
            $totalReviews = $paginator->getTotalItemCount();

            // Rating & Recomendations work start
            $noReviewCheck = $reviewTable->getAvgRecommendation($group_id);
            if (!empty($noReviewCheck)) {
                $noReviewCheck = $noReviewCheck->toArray();
                if ($noReviewCheck)
                    $recommend_percentage = round($noReviewCheck[0]['avg_recommend'] * 100, 3);
            }

            $ratings_params = $ratingTable->ratingbyCategory($group_id);
            $rating_params_data = array();
            if (!empty($ratings_params)) {
                foreach ($ratings_params as $value) {
                    if ($value['reviewcat_name'])
                        $rating_params_data[] = $value;
                }
            }
            if (isset($params['getRating']) && !empty($params['getRating'])) {
                $ratings['rating_avg'] = $sitegroup->rating;
                $ratings['rating_users'] = $sitegroup->review_count;
                $ratings['breakdown_ratings_params'] = $rating_params_data;
                $ratings['review_id'] = $hasPosted;
                $ratings['recomended'] = $recommend_percentage . " %";
                $response['ratings'] = $ratings;
            }
            // Rating & Recomendations work end

            foreach ($paginator as $review) {
                $params = $review->toArray();

                if (isset($params['recommend']))
                    $params['recommend'] = empty($params['recommend']) ? $this->translate('No') : $this->translate('Yes');

                if (isset($params['body']) && !empty($params['body']))
                    $params['body'] = strip_tags($params['body']);

                if (!empty($review->owner_id))
                    $params ["owner_title"] = $review->getOwner()->getTitle();

                $params['group_title'] = $sitegroup->title;
                $params['category_name'] = Engine_Api::_()->getItem('sitegroup_category', $sitegroup->category_id)->category_name;

                $user_ratings = Engine_Api::_()->getDbtable('ratings', 'sitegroupreview')->ratingsData($review->review_id, $review->getOwner()->getIdentity(), $review->group_id, 0);
                $params['overall_rating'] = $user_ratings[0]['rating'];

                // Owner images 
                $getContentImages = Engine_Api::_()->getApi('Core', 'siteapi')->getContentImage($review, true);
                $params = array_merge($params, $getContentImages);

                // Group images 
                $getContentImages = Engine_Api::_()->getApi('Core', 'siteapi')->getContentImage($sitegroup);
                $params = array_merge($params, $getContentImages);
                $params['isShowProsCons'] =  Engine_Api::_()->getApi('settings', 'core')->getSetting('sitegroupreview.proscons', 1);
                // Get gutter menus of review
                $guttermenu = $this->guttermenu($sitegroup, $review, 'browse');
                $params['guttermenu'] = $guttermenu;

                // Get rating params
                $profileRating = $ratingTable->profileRatingbyCategory($review->review_id);
                $breakdown_ratings_params = array();

                if (!empty($profileRating)) {
                    foreach ($profileRating as $value) {
                        if (!empty($value['reviewcat_name']))
                            $breakdown_ratings_params[] = $value;
                    }
                }

                $params['breakdown_ratings_params'] = $breakdown_ratings_params;

                // isliked
                $corelikesTable = Engine_Api::_()->getDbtable('likes', 'core');
                $isliked = $corelikesTable->getLike($review, $viewer);
                $params['is_liked'] = false;
                if ($isliked)
                    $params['is_liked'] = true;

                $tempResponse[] = $params;
            }
            if (isset($tempResponse) && !empty($tempResponse))
                $response['total_reviews'] = $totalReviews;
            $response['canCreate'] = $can_create;
            $response['reviews'] = $tempResponse;
            $this->respondWithSuccess($response, true);
        } catch (Exception $ex) {
            $this->respondWithValidationError('internal_server_error', $ex->getMessage());
        }
    }

    /**
     * Create a review
     * 
     */
    public function createAction() {
        // Get viewer info
        $viewer = Engine_Api::_()->user()->getViewer();
        $viewer_id = $viewer->getIdentity();
        $create_level_allow = Engine_Api::_()->authorization()->getPermission($viewer->level_id, 'sitegroupreview_review', "create");

        if (!$create_level_allow)
            $this->respondWithError('unauthorized');

        if (Engine_Api::_()->core()->hasSubject('sitegroup_group'))
            $sitegroup = $subject = Engine_Api::_()->core()->getSubject('sitegroup_group');
        else
            $this->respondWithError('no_record');

        // Check if this user has already reviewed on this group
        $review = Engine_Api::_()->getDbtable('reviews', 'sitegroupreview')->canPostReview($sitegroup->group_id, $viewer_id);

        if (!empty($review)) {
            $this->respondWithError('review_already_present');
        }

        // Core settings
        $coreApi = Engine_Api::_()->getApi('settings', 'core');
        $sitegroupreview_proscons = $coreApi->getSetting('sitegroupreview.proscons', 1);
        $sitegroupreview_limit_proscons = $coreApi->getSetting('sitegroupreview.limit.proscons', 500);
        $sitegroupreview_recommend = $coreApi->getSetting('sitegroupreview.recommend', 1);
        $ratingParams = Engine_Api::_()->getDbtable('reviewcats', 'sitegroupreview')->reviewParams($sitegroup->category_id);
        $profileTypeReview = Engine_Api::_()->getDbtable('categories', 'sitegroup')->getProfileType(array(), $sitegroup->category_id);

        $getForm = Engine_Api::_()->getApi('Siteapi_Core', 'Sitegroupreview')->getReviewCreateForm(array("settingsReview" => array('sitegroupreview_proscons' => $sitegroupreview_proscons, 'sitegroupreview_limit_proscons' => $sitegroupreview_limit_proscons, 'sitegroupreview_recommend' => $sitegroupreview_recommend), 'item' => $sitegroup, 'profileTypeReview' => $profileTypeReview));

        if ($this->getRequest()->isGet()) {
            $ratingParam = array();
            $ratingParam[] = array(
                'type' => 'Rating',
                'name' => 'review_rate_0',
                'label' => $this->translate('Overall Rating')
            );


            foreach ($ratingParams as $ratingparam_id) {
                $ratingParam[] = array(
                    'type' => 'Rating',
                    'name' => 'review_rate_' . $ratingparam_id->reviewcat_id,
                    'label' => $ratingparam_id->reviewcat_name
                );
            }
            $response['form'] = $getForm;
            $response['ratingParams'] = $ratingParam;
            $this->respondWithSuccess($response, true);
        }

        if ($this->getRequest()->isPost()) {
            // Convert post data into an array
            $values = $postData = $this->_getAllParams();
            foreach ($getForm as $element) {
                if (isset($_REQUEST[$element['name']]))
                    $values[$element['name']] = $_REQUEST[$element['name']];
            }

            // Start form validation
            $validators = Engine_Api::_()->getApi('Siteapi_FormValidators', 'sitegroupreview')->getReviewCreateFormValidators(array("settingsReview" => array('sitegroupreview_proscons' => $sitegroupreview_proscons, 'sitegroupreview_limit_proscons' => $sitegroupreview_limit_proscons, 'sitegroupreview_recommend' => $sitegroupreview_recommend), 'item' => $sitegroup, 'profileTypeReview' => $profileTypeReview));
            $values['validators'] = $validators;
            $validationMessage = $this->isValid($values);

            // Response validation error
            if (!empty($validationMessage) && @is_array($validationMessage)) {
                $this->respondWithValidationError('validation_fail', $validationMessage);
            }

            $db = Engine_Db_Table::getDefaultAdapter();
            $db->beginTransaction();
            try {
                $values['owner_id'] = $viewer_id;
                $values['resource_id'] = $sitegroup->group_id;
                $values['resource_type'] = $sitegroup->getType();
                $values['profile_type_review'] = $profileTypeReview;
                $values['type'] = $viewer_id ? 'user' : 'visitor';

                if (!Engine_Api::_()->getApi('settings', 'core')->getSetting('sitegroupreview.recommend', 1)) {
                    $values['recommend'] = 0;
                }
                // Add review
                $reviewTable = Engine_Api::_()->getDbtable('reviews', 'sitegroupreview');
                $review = $reviewTable->createRow();
                $review->setFromArray($values);
                $review->view_count = 1;
                $review->save();

                $review_id = $review->review_id;

                // increment review count
                if (!empty($viewer_id))
                    $sitegroup->review_count++;
                $sitegroup->save();

                $reviewRatingTable = Engine_Api::_()->getDbtable('ratings', 'sitegroupreview');
                if (!empty($review_id)) {
                    $reviewRatingTable->delete(array('review_id = ?' => $review->review_id));
                }

                //DO ENTRY IN REVIEW RATING TABLE
                foreach ($_POST as $key => $ratingdata) {
                    $string_exist = strstr($key, 'review_rate_');
                    if ($string_exist) {
                        $reviewcat_id = explode('review_rate_', $key);
                        $reviewRatingTable = Engine_Api::_()->getDbtable('ratings', 'sitegroupreview');
                        $reviewRating = $reviewRatingTable->createRow();
                        $reviewRating->review_id = $review->review_id;
                        $reviewRating->category_id = $sitegroup->category_id;
                        $reviewRating->group_id = $review->group_id;
                        $reviewRating->reviewcat_id = $reviewcat_id[1];
                        $reviewRating->rating = $ratingdata;
                        $reviewRating->save();
                    }
                }

                //UPDATE RATING IN GROUP TABLE
                Engine_Api::_()->getDbtable('ratings', 'sitegroupreview')->groupRatingUpdate($review->group_id);

                if (!empty($review_id) && !empty($viewer_id)) {
                    $activityApi = Engine_Api::_()->getDbtable('actions', 'seaocore');

                    // Activity feed
                    $action = $activityApi->addActivity($viewer, $sitegroup, 'sitegroupreview_new');

                    if ($action != null) {
                        $activityApi->attachActivity($action, $review);
                    }
                }

                $db->commit();
                $this->successResponseNoContent('no_content', true);
            } catch (Exception $e) {
                $this->respondWithValidationError('internal_server_error', $e->getMessage());
            }
        }
    }

    /*
     * Returns review detail
     *
     */

    public function viewAction() {
        $this->validateRequestMethod();

        // Require user
        if (!$this->_helper->requireUser()->isValid())
            $this->respondWithError('unauthorized');

        // Gets logged in user info
        $viewer = Engine_Api::_()->user()->getViewer();
        $viewer_id = $viewer->getIdentity();
        $review_id = $this->_getParam('review_id', null);
        if ($review_id) {
            $review = Engine_Api::_()->getItem('sitegroupreview_review', $review_id);
        }

        if (!$review) {
            $this->respondWithError('no_record');
        }

        if (!Engine_Api::_()->core()->hasSubject('sitegroup_group')) {
            $this->respondWithError('no_record');
        }

        // Get the group 
        $sitegroup = Engine_Api::_()->core()->getSubject('sitegroup_group');

        $params = array();
        $params = $review->toArray();
        $params['owner_title'] = $review->getOwner()->getTitle();

        // Get location
        if (!empty($sitegroup->location) && Engine_Api::_()->getApi('settings', 'core')->getSetting('sitegroup.location', 1)) {
            $params['location'] = $sitegroup->location;
        }

        $params['tag'] = $sitegroup->getKeywords(', ');

        $tableCategory = Engine_Api::_()->getDbTable('categories', 'sitegroup');

        $category_id = $sitegroup->category_id;

        if (!empty($category_id)) {

            $params['categoryname'] = Engine_Api::_()->getItem('sitegroup_category', $category_id)->category_name;
            $subcategory_id = $sitegroup->subcategory_id;

            if (!empty($subcategory_id)) {

                $params['subcategoryname'] = Engine_Api::_()->getItem('sitegroup_category', $subcategory_id)->category_name;

                $subsubcategory_id = $sitegroup->subsubcategory_id;

                if (!empty($subsubcategory_id)) {

                    $params['subsubcategoryname'] = Engine_Api::_()->getItem('sitegroup_category', $subsubcategory_id)->category_name;
                }
            }
        }

        // Get the rating if present
        $ratingParams = Engine_Api::_()->getDbtable('ratings', 'sitegroupreview')->profileRatingbyCategory($review->review_id);

        $params['ratingParams'] = $ratingParams;
        $guttermenu = $this->guttermenu($sitegroup, $review, 'view');
        if ($params['comment_count'] > 0) {

            $guttermenu['comments'] = array(
                'title' => $this->translate('List Comments'),
                'name' => 'listcomments',
                'url' => 'advancedgroups/review/listcomments/' . $sitegroup->group_id . '/' . $review->review_id,
            );
        }

        $response['response'] = $params;
        $this->respondWithSuccess($response, true);
    }

    /*
     * Action for deleting review
     *
     *
     */

    public function deleteAction() {

        // Validate request method
        $this->validateRequestMethod("DELETE");

        // Get logged in user info
        $viewer = Engine_Api::_()->user()->getViewer();
        $viewer_id = $viewer->getIdentity();

        $review_id = $this->_getParam('review_id', $this->_getParam('review_id', null));
        if ($review_id) {
            $review = Engine_Api::_()->getItem('sitegroupreview_review', $review_id);
        }

        if ($review->owner_id != $viewer_id && $viewer->level_id != 1) {
            $this->respondWithError('unauthorized');
        }

        if (!$review) {
            $this->respondWithError('no_record');
        }

        if (!Engine_Api::_()->core()->hasSubject('sitegroup_group')) {
            $this->respondWithError('no_record');
        }
        // Get the group 
        $sitegroup = Engine_Api::_()->core()->getSubject('sitegroup_group');

        $db = Engine_Db_Table::getDefaultAdapter();
        $db->beginTransaction();
        try {
            Engine_Api::_()->sitegroupreview()->deleteContent($review_id);
            $db->commit();
            $this->successResponseNoContent('no_content', true);
        } catch (Exception $ex) {
            $db->rollBack();
            $this->respondWithValidationError('internal_server_error', $ex->getMessage());
        }
    }

    /*
     * Returns comments list of the review
     *
     *
     */

    public function listcommentsAction() {
        $viewer = Engine_Api::_()->user()->getViewer();
        if (!$this->_helper->requireUser()->isValid()) {
            $this->respondWithError('unauthorized');
        }
        $review_id = $this->_getParam('review_id', $this->_getParam('review_id', null));
        if ($review_id) {
            $review = $subject = Engine_Api::_()->getItem('sitegroupreview_review', $review_id);
        }

        if (!$review && empty($review))
            $this->respondWithError('no_record');

        $subjectParent = $subject->getParent();

        $canComment = $subject->authorization()->isAllowed($viewer, 'comment');

        $groupSubject = $subject->getParent();
        $groupApi = Engine_Api::_()->sitegroup();
        $canComment = $groupApi->isManageAdmin($groupSubject, 'comment');
        $groupApi->isManageAdmin($groupSubject, 'edit');
        $viewAllLikes = $this->_getParam('viewAllLikes', false);
        $likes = $subject->likes()->getLikePaginator();
        $likesData = array();
        if (!empty($likes)) {
            foreach ($likes as $like) {
                $likesData[$like->like_id] = $like->toArray();
                $poster = $like->getPoster();
                $posterImages = Engine_Api::_()->getApi('Core', 'siteapi')->getContentImage($poster, true);
                $likesData[$like->like_id]['owner_images'] = $posterImages;
                $likesData[$like->like_id]['owner_title'] = $poster->getTitle();
            }
        }
        // Comments
        // If has a group, display oldest to newest
        if (null !== ( $group = $this->_getParam('group'))) {
            $commentSelect = $subject->comments()->getCommentSelect('ASC');
            $commentSelect->order('comment_id ASC');
            $comments = Zend_Paginator::factory($commentSelect);
            $comments->setCurrentPageNumber($group);
            $comments->setItemCountPerPage(10);
        }
        // If not has a group, show the
        else {
            $commentSelect = $subject->comments()->getCommentSelect('DESC');
            $commentSelect->order('comment_id DESC');

            $comments = Zend_Paginator::factory($commentSelect);
            $comments->setCurrentPageNumber(1);
            $comments->setItemCountPerPage(4);
        }
        $commentsData = array();
        if (!empty($comments)) {
            foreach ($comments as $comment) {
                $poster = $comment->getPoster();
                $posterImages = Engine_Api::_()->getApi('Core', 'siteapi')->getContentImage($poster, true);
                $likes = $comment->likes();
                $commentsData[$comment->comment_id] = $comment->toArray();
                $commentsData[$comment->comment_id]['owner_images'] = $posterImages;
                $commentsData[$comment->comment_id]['owner_title'] = $poster->getTitle();
            }
        }

        $response['comments'] = $commentsData;
        $response['likes'] = $likesData;

        $this->respondWithSuccess($response, true);
    }

    /*
     * Returns comment form and posts comment on a review
     *
     *
     */

    public function commentAction() {
        if (!$this->_helper->requireUser()->isValid()) {
            $this->respondWithError('unauthorized');
        }
        $viewer = Engine_Api::_()->user()->getViewer();
        $review_id = $this->_getParam('review_id', $this->_getParam('review_id', null));
        if ($review_id) {
            $review = $subject = Engine_Api::_()->getItem('sitegroupreview_review', $review_id);
        }

        if (!$review && empty($review))
            $this->respondWithError('no_record');

        $subjectParent = $subject->getParent();


        if ($this->getRequest()->isGet()) {
            $commentform = Engine_Api::_()->getApi('Siteapi_Core', 'Sitegroupreview')->getcommentForm($review->getType(), $review->review_id);
            $this->respondWithSuccess($commentform, true);
        }

        if ($this->getRequest()->isPost()) {
            $values = array();
            $values = $this->_getAllParams();

            // Start form validation
            $validators = Engine_Api::_()->getApi('Siteapi_FormValidators', 'sitegroupreview')->getcommentValidation();
            $values['validators'] = $validators;
            $validationMessage = $this->isValid($values);

            // Response validation error
            if (!empty($validationMessage) && @is_array($validationMessage)) {
                $this->respondWithValidationError('validation_fail', $validationMessage);
            }

            $body = $values['body'];
            $values['type'] = $subject->getType();
            $values['id'] = $subject->review_id;
            $values['identity'] = $subject->review_id;
            $db = $subject->comments()->getCommentTable()->getAdapter();
            $db->beginTransaction();
            try {
                $activityApi = Engine_Api::_()->getDbtable('actions', 'activity');
                $notifyApi = Engine_Api::_()->getDbtable('notifications', 'activity');
                $subjectOwner = $subject->getOwner('user');
                $subject->comments()->addComment($viewer, $body);

                // Activity
                $action = $activityApi->addActivity($viewer, $subject, 'comment_' . $subject->getType(), '', array(
                    'owner' => $subjectOwner->getGuid(),
                    'body' => $body
                ));

                if (!empty($action)) {
                    $activityApi->attachActivity($action, $subject);
                }


                // add notification
//                $notifyApi = Engine_Api::_()->getDbtable('notifications', 'activity');
//                $notifyApi->addNotification($notifyUser, $viewer, $subject, 'commented_commented', array(
//                    'label' => $subject->getShortType()
//                ));
                // Add a notification for all users that commented or like except the viewer and poster
                // @todo we should probably limit this
//                $commentedUserNotifications = array();
//                foreach ($subject->comments()->getAllCommentsUsers() as $notifyUser) {
//                    if ($notifyUser->getIdentity() == $viewer->getIdentity() || $notifyUser->getIdentity() == $subjectOwner->getIdentity())
//                        continue;
//
//                    // Don't send a notification if the user both commented and liked this
//                    $commentedUserNotifications[] = $notifyUser->getIdentity();
//                    $notifyApi->addNotification($notifyUser, $viewer, $subject, 'commented_commented', array(
//                        'label' => $subject->getShortType()
//                    ));
//                }
                // Add a notification for all users that liked
                // @todo we should probably limit this
//                foreach ($subject->likes()->getAllLikesUsers() as $notifyUser) {
//                    // Skip viewer and owner
//                    if ($notifyUser->getIdentity() == $viewer->getIdentity() || $notifyUser->getIdentity() == $subjectOwner->getIdentity())
//                        continue;
//
//                    // Don't send a notification if the user both commented and liked this
//                    if (in_array($notifyUser->getIdentity(), $commentedUserNotifications))
//                        continue;
//
//                    $notifyApi->addNotification($notifyUser, $viewer, $subject, 'liked_commented', array(
//                        'label' => $subject->getShortType()
//                    ));
//
//
//                    //end check for group admin and group owner
//                }
                // Send notification to Page admins
                $sitegroupVersion = Engine_Api::_()->getDbtable('modules', 'core')->getModule('sitegroup')->version;
                if ($sitegroupVersion >= '4.2.9p3') {
                    Engine_Api::_()->sitegroup()->itemCommentLike($subject, 'sitegroup_contentcomment', $baseOnContentOwner);
                }

                // Increment comment count
                Engine_Api::_()->getDbtable('statistics', 'core')->increment('core.comments');

                $db->commit();
                $this->successResponseNoContent('no_content', true);
            } catch (Exception $e) {
                $db->rollBack();
                $this->respondWithValidationError('internal_server_error', $e->getMessage());
            }
        }
    }

    /*
     * Deletes a comment
     *
     *
     */

    public function removecommentAction() {
        $viewer = Engine_Api::_()->user()->getViewer();
        $review_id = $this->_getParam('review_id', $this->_getParam('review_id', null));
        if ($review_id) {
            $review = $subject = Engine_Api::_()->getItem('sitegroupreview_review', $review_id);
        }

        if (!$review && empty($review))
            $this->respondWithError('no_record');
        // Validate request methods
        $this->validateRequestMethod();
        if (!$this->_helper->requireUser()->isValid()) {
            $this->respondWithError('unauthorized');
        }

        // Comment id
        $comment_id = $this->_getParam('comment_id');

        // Comment
        $comment = $subject->comments()->getComment($comment_id);
        if (!$comment) {
            $this->respondWithError('no_record');
        }
        if ($this->getRequest()->isPost()) {
            $commentsremoveform = array(
                'type' => 'int',
                'name' => 'comment_id',
            );
            $response['form'] = $commentsremoveform;
            $this->respondWithSuccess($response, true);
        }
        if ($this->getRequest()->isPost()) {
            // Process
            $db = $subject->comments()->getCommentTable()->getAdapter();
            $db->beginTransaction();

            try {
                $subject->comments()->removeComment($comment_id);
                $db->commit();
                $this->successResponseNoContent('no_content', true);
            } catch (Exception $e) {
                $db->rollBack();
                $this->respondWithValidationError('internal_server_error', $ex->getMessage());
            }
        }
    }

    /*
     *   Updates a review form and posting
     *
     *
     */

    public function editAction() {
        //GET VIEWER INFO
        $viewer = Engine_Api::_()->user()->getViewer();
        $viewer_id = $viewer->getIdentity();

        if (Engine_Api::_()->core()->hasSubject('sitegroup_group'))
            $sitegroup = $subject = Engine_Api::_()->core()->getSubject('sitegroup_group');
        else
            $this->respondWithError('no_record');

        $review_id = $this->_getParam('review_id', $this->_getParam('review_id', null));
        if ($review_id) {
            $review = $subject = Engine_Api::_()->getItem('sitegroupreview_review', $review_id);
        }

        if (!$review && empty($review))
            $this->respondWithError('no_record');

        // core settings
        $coreApi = Engine_Api::_()->getApi('settings', 'core');
        $sitegroupreview_proscons = $coreApi->getSetting('sitegroupreview.proscons', 1);
        $sitegroupreview_limit_proscons = $coreApi->getSetting('sitegroupreview.limit.proscons', 500);
        $sitegroupreview_recommend = $coreApi->getSetting('sitegroupreview.recommend', 1);

        $ratingParams = Engine_Api::_()->getDbtable('reviewcats', 'sitegroupreview')->reviewParams($sitegroup->category_id);

        $ratingParam = array();
        $ratingParam[] = array(
            'type' => 'Rating',
            'name' => 'review_rate_0',
            'label' => $this->translate('Overall Rating')
        );

        $profileTypeReview = Engine_Api::_()->getDbtable('categories', 'sitegroup')->getProfileType(array(), $sitegroup->category_id);

        foreach ($ratingParams as $ratingparam_id) {
            $ratingParam[] = array(
                'type' => 'Rating',
                'name' => 'review_rate_' . $ratingparam_id->reviewcat_id,
                'label' => $ratingparam_id->reviewcat_name
            );
        }

        //GET LEVEL SETTING
        $can_view = Engine_Api::_()->authorization()->getPermission($viewer->level_id, 'sitegroup_group', "view");
        $params = array();
        $params = $review->toArray();
        $params['owner_title'] = $review->getOwner()->getTitle();
        $params['event_type_title'] = 'Events';
        //GET LOCATION
        if (!empty($sitegroup->location) && Engine_Api::_()->getApi('settings', 'core')->getSetting('sitegroup.location', 1)) {
            $params['location'] = $sitegroup->location;
        }

        $params['tag'] = $sitegroup->getKeywords(', ');

        //GET EVENT CATEGORY TABLE
        $tableCategory = Engine_Api::_()->getDbTable('categories', 'sitegroup');

        $category_id = $sitegroup->category_id;

        if (!empty($category_id)) {

            $params['categoryname'] = Engine_Api::_()->getItem('sitegroup_category', $category_id)->category_name;

            $subcategory_id = $sitegroup->subcategory_id;

            if (!empty($subcategory_id)) {

                $params['subcategoryname'] = Engine_Api::_()->getItem('sitegroup_category', $subcategory_id)->category_name;

                $subsubcategory_id = $sitegroup->subsubcategory_id;

                if (!empty($subsubcategory_id)) {

                    $params['subsubcategoryname'] = Engine_Api::_()->getItem('sitegroup_category', $subsubcategory_id)->category_name;
                }
            }
        }

        $response['formValues'] = $params;
        // Get the rating if present
        $ratingParams = Engine_Api::_()->getDbtable('ratings', 'sitegroupreview')->ratingsData($review_id);

        foreach ($ratingParams as $reviewRateMyData) {
            $response['formValues']['review_rate_' . $reviewRateMyData['reviewcat_id']] = $reviewRateMyData['rating'];
        }

        if ($this->getRequest()->isGet()) {
            $response['form'] = Engine_Api::_()->getApi('Siteapi_Core', 'Sitegroupreview')->getReviewCreateForm(array("settingsReview" => array('sitegroupreview_proscons' => $sitegroupreview_proscons, 'sitegroupreview_limit_proscons' => $sitegroupreview_limit_proscons, 'sitegroupreview_recommend' => $sitegroupreview_recommend), 'item' => $sitegroup, 'profileTypeReview' => $profileTypeReview));
            $response['ratingParams'] = $ratingParam;
            $this->respondWithSuccess($response, true);
        }

        if ($this->getRequest()->isPost()) {
            // Convert post data into the array.
            $values = array();
            $getForm = Engine_Api::_()->getApi('Siteapi_Core', 'Sitegroupreview')->getReviewCreateForm(array("settingsReview" => array('sitegroupreview_proscons' => $sitegroupreview_proscons, 'sitegroupreview_limit_proscons' => $sitegroupreview_limit_proscons, 'sitegroupreview_recommend' => $sitegroupreview_recommend), 'item' => $sitegroup, 'profileTypeReview' => $profileTypeReview));
            foreach ($getForm as $element) {
                if (isset($_REQUEST[$element['name']]))
                    $values[$element['name']] = $_REQUEST[$element['name']];
            }

            // Start form validation
            $validators = Engine_Api::_()->getApi('Siteapi_FormValidators', 'sitegroupreview')->getReviewCreateFormValidators(array("settingsReview" => array('sitegroupreview_proscons' => $sitegroupreview_proscons, 'sitegroupreview_limit_proscons' => $sitegroupreview_limit_proscons, 'sitegroupreview_recommend' => $sitegroupreview_recommend), 'item' => $sitegroup, 'profileTypeReview' => $profileTypeReview));
            if (isset($_REQUEST['review_rate_0']) && !empty($_REQUEST['review_rate_0']))
                $values['review_rate_0'] = $_REQUEST['review_rate_0'];


            $values['validators'] = $validators;
            $validationMessage = $this->isValid($values);

            // Response validation error
            if (!empty($validationMessage) && @is_array($validationMessage)) {
                $this->respondWithValidationError('validation_fail', $validationMessage);
            }

            $postData = $this->_getAllParams();

            $db = Engine_Db_Table::getDefaultAdapter();
            $db->beginTransaction();
            try {

                $values['owner_id'] = $viewer_id;
                $values['resource_id'] = $sitegroup->group_id;
                $values['resource_type'] = $sitegroup->getType();
                $values['profile_type_review'] = $profileTypeReview;
                $values['type'] = $viewer_id ? 'user' : 'visitor';

                if (!Engine_Api::_()->getApi('settings', 'core')->getSetting('sitegroupreview.recommend', 1)) {
                    $values['recommend'] = 0;
                }

                $review->setFromArray($values);
                $review->view_count = 1;
                $review->save();

                $review_id = $review->review_id;


                // Increment review count
                if (!empty($viewer_id))
                    $sitegroup->review_count++;
                $sitegroup->save();
                $db->commit();

                $reviewRatingTable = Engine_Api::_()->getDbtable('ratings', 'sitegroupreview');
                $reviewRatingTable->delete(array('review_id = ?' => $review->review_id));

                //DO ENTRY IN REVIEW RATING TABLE
                foreach ($_REQUEST as $key => $ratingdata) {
                    $string_exist = strstr($key, 'review_rate_');
                    if ($string_exist) {
                        $reviewcat_id = explode('review_rate_', $key);
                        $reviewRatingTable = Engine_Api::_()->getDbtable('ratings', 'sitegroupreview');
                        $reviewRating = $reviewRatingTable->createRow();
                        $reviewRating->review_id = $review->review_id;
                        $reviewRating->category_id = $sitegroup->category_id;
                        $reviewRating->group_id = $review->group_id;
                        $reviewRating->reviewcat_id = $reviewcat_id[1];
                        $reviewRating->rating = $ratingdata;
                        $reviewRating->save();
                    }
                }

                //UPDATE RATING IN GROUP TABLE
                Engine_Api::_()->getDbtable('ratings', 'sitegroupreview')->groupRatingUpdate($review->group_id);
                $this->successResponseNoContent('no_content', true);
            } catch (Exception $e) {
                $db->rollBack();
                $this->respondWithValidationError('internal_server_error', $ex->getMessage());
            }
        }
    }

    /*
     * Allows to like a review
     *
     *
     */

    public function likeAction() {
        Engine_Api::_()->getApi('Core', 'siteapi')->setView();
        $viewer = Engine_Api::_()->user()->getViewer();
        $review_id = $this->_getParam('review_id', $this->_getParam('review_id', null));
        if ($review_id) {
            $review = $subject = Engine_Api::_()->getItem('sitegroupreview_review', $review_id);
        }

        if (!$review && empty($review))
            $this->respondWithError('no_record');
        if (!$this->_helper->requireUser()->isValid()) {
            $this->respondWithError('unauthorized');
        }
        if (!$this->_helper->requireAuth()->setAuthParams(null, null, 'comment')->isValid()) {
            $this->respondWithError('unauthorized');
        }

        if ($this->getRequest()->isPost()) {
            $commentedItem = $subject;
            // Process
            $db = $commentedItem->likes()->getAdapter();
            $db->beginTransaction();
            try {
                $commentedItem->likes()->addLike($viewer);
                // Add notification
                $owner = $commentedItem->getOwner();
                if ($owner->getType() == 'user' && $owner->getIdentity() != $viewer->getIdentity()) {
                    $notifyApi = Engine_Api::_()->getDbtable('notifications', 'activity');
                    $notifyApi->addNotification($owner, $viewer, $commentedItem, 'liked', array(
                        'label' => $commentedItem->getShortType()
                    ));
                }

                $sitegroupVersion = Engine_Api::_()->getDbtable('modules', 'core')->getModule('sitegroup')->version;
                if ($sitegroupVersion >= '4.2.9p3') {
                    if (Engine_Api::_()->getDbtable('modules', 'core')->isModuleEnabled('sitegroupmember'))
                        Engine_Api::_()->sitegroupmember()->joinLeave($subject, 'Join');
                    Engine_Api::_()->sitegroup()->itemCommentLike($subject, 'sitegroup_contentlike', '');
                }
                $db->commit();
                $this->successResponseNoContent('no_content', true);
            } catch (Exception $ex) {
                $db->rollBack();
                $this->respondWithValidationError('internal_server_error', $ex->getMessage());
            }
        }
    }

    /*
     *   Allows to ulike a review
     *
     */

    public function unlikeAction() {
        $viewer = Engine_Api::_()->user()->getViewer();
        $review_id = $this->_getParam('review_id', $this->_getParam('review_id', null));
        if ($review_id) {
            $review = $subject = Engine_Api::_()->getItem('sitegroupreview_review', $review_id);
        }

        if (!$review && empty($review))
            $this->respondWithError('no_record');

        if (!$this->_helper->requireUser()->isValid()) {
            $this->respondWithError('unauthorized');
        }
        if (!$this->_helper->requireAuth()->setAuthParams(null, null, 'comment')->isValid()) {
            $this->respondWithError('unauthorized');
        }

        if ($this->getRequest()->isPost()) {
            $commentedItem = $subject;
            // Process
            $db = $commentedItem->likes()->getAdapter();
            $db->beginTransaction();
            try {
                $commentedItem->likes()->removeLike($viewer);

                // Remove notification
                if (Engine_Api::_()->getDbtable('modules', 'core')->isModuleEnabled('sitelike')) {
                    Engine_Api::_()->getDbtable('notifications', 'activity')->delete(array('type = ?' => 'liked', 'subject_id = ?' => $viewer->getIdentity(), 'subject_type = ?' => $viewer->getType(), 'object_type = ?' => $subject->getType(), 'object_id = ?' => $subject->getIdentity()));
                }

                $sitegroupVersion = Engine_Api::_()->getDbtable('modules', 'core')->getModule('sitegroup')->version;
                if ($sitegroupVersion >= '4.2.9p3') {
                    if (Engine_Api::_()->getDbtable('modules', 'core')->isModuleEnabled('sitegroupmember'))
                        Engine_Api::_()->sitegroupmember()->joinLeave($subject, 'Join');
                }

                $db->commit();
                $this->successResponseNoContent('no_content', true);
            } catch (Exception $ex) {
                $db->rollBack();
                $this->respondWithValidationError('internal_server_error', $ex->getMessage());
            }
        }
    }

    /*
     * Returns menu for a review
     *
     * @return array
     */

    private function guttermenu($sitegroup = array(), $review = array(), $action = NULL) {
        $viewer = Engine_Api::_()->user()->getViewer();
        $viewer_id = $viewer->getIdentity();

        // Get user level id
        if (!empty($viewer_id)) {
            $level_id = $viewer->level_id;
        } else {
            $level_id = Engine_Api::_()->getDbtable('levels', 'authorization')->fetchRow(array('type = ?' => "public"))->level_id;
        }
        $guttermenu = array();

        if ($review->owner_id == $viewer_id || $level_id == 1) {
            $guttermenu[] = array(
                'label' => $this->translate("Delete Review"),
                'name' => 'delete',
                'url' => "advancedgroups/review/delete/" . $sitegroup->group_id . "/" . $review->review_id,
            );

            $guttermenu[] = array(
                'label' => $this->translate("Edit Review"),
                'name' => 'edit_review',
                'url' => "advancedgroups/review/edit/" . $sitegroup->group_id . "/" . $review->review_id,
            );
        }

        if ($action == 'view') {
            $guttermenu[] = array(
                'label' => $this->translate("Comment"),
                'url' => "advancedgroups/review/comment/" . $sitegroup->group_id . "/" . $review->review_id,
                'name' => 'comment'
            );

            $likeTable = Engine_Api::_()->getDbtable('likes', 'core');
            if ($likeTable->isLike($review, $viewer)) {
                $guttermenu[] = array(
                    'label' => $this->translate("Unlike"),
                    'url' => "advancedgroups/review/unlike/" . $sitegroup->group_id . "/" . $review->review_id,
                    'name' => 'unlike'
                );
            } else {
                $guttermenu[] = array(
                    'label' => $this->translate("like"),
                    'url' => "advancedgroups/review/like/" . $sitegroup->group_id . "/" . $review->review_id,
                    'name' => 'unlike'
                );
            }
        }

        return $guttermenu;
    }

}
