<?php

/**
 * SocialEngine
 *
 * @category   Application_Extensions
 * @package    Sitegroup
 * @copyright  Copyright 2010-2011 BigStep Technologies Pvt. Ltd.
 * @license    http://www.socialengineaddons.com/license/
 * @version    $Id: Menus.php 2011-05-05 9:40:21Z SocialEngineAddOns $
 * @author     SocialEngineAddOns
 */
class Sitegroupvideo_Plugin_Menus {

  public function canViewVideos() {

    if (!Engine_Api::_()->getApi('settings', 'core')->getSetting('sitegroupvideo.video.show.menu', 1)) {
      return false;
    }

    $table = Engine_Api::_()->getDbtable('videos', 'sitegroupvideo');
    $rName = $table->info('name');
    $table_groups = Engine_Api::_()->getDbtable('groups', 'sitegroup');
    $rName_groups = $table_groups->info('name');
    $select = $table->select()
                    ->setIntegrityCheck(false)
                    ->from($rName_groups, array('photo_id', 'title as sitegroup_title'))
                    ->join($rName, $rName . '.group_id = ' . $rName_groups . '.group_id')
                    ->where($rName . '.status = ?', '1')
                    ->where($rName .'.search = ?', 1);

    $select = $select
                    ->where($rName_groups . '.closed = ?', '0')
                    ->where($rName_groups . '.approved = ?', '1')
                    ->where($rName_groups . '.search = ?', '1')
                    ->where($rName_groups . '.declined = ?', '0')
                    ->where($rName_groups . '.draft = ?', '1');
    if (Engine_Api::_()->sitegroup()->hasPackageEnable()) {
      $select->where($rName_groups . '.expiration_date  > ?', date("Y-m-d H:i:s"));
    }
    $row = $table->fetchAll($select);
    $count = count($row);
    if (empty($count)) {
      return false;
    }
    return true;
  }

  //SITEMOBILE GROUP VIDEO MENUS
  public function onMenuInitialize_SitegroupvideoAdd($row) {
    $subject = Engine_Api::_()->core()->getSubject();

    $video_id = $subject->getIdentity();

    $sitegroupvideo = Engine_Api::_()->getItem('sitegroupvideo_video', $video_id);
    $group_id = $sitegroupvideo->group_id;
    if (empty($sitegroupvideo)) {
      return false;
    }
    $sitegroup = Engine_Api::_()->getItem('sitegroup_group', $group_id);
    //START MANAGE-ADMIN CHECK
    $isManageAdmin = Engine_Api::_()->sitegroup()->isManageAdmin($sitegroup, 'svcreate');
    if (empty($isManageAdmin)) {
      $can_create = 0;
    } else {
      $can_create = 1;
    }

    if (empty($can_create)) {
      return false;
    }
    return array(
        'label' => 'Add Video',
        'route' => 'sitegroupvideo_create',
        'class' => 'ui-btn-action',
        'params' => array(
            'group_id' => $group_id,
            'tab' => Zend_Controller_Front::getInstance()->getRequest()->getParam('tab')
        )
    );
  }

  public function onMenuInitialize_SitegroupvideoEdit($row) {
    $subject = Engine_Api::_()->core()->getSubject();

    $video_id = $subject->getIdentity();

    $sitegroupvideo = Engine_Api::_()->getItem('sitegroupvideo_video', $video_id);
    $group_id = $sitegroupvideo->group_id;
    if (empty($sitegroupvideo)) {
     return false;
    }

    $check = $this->commonChecks();
    if (empty($check)) {
      return false;
    }
    return array(
        'label' => 'Edit Video',
        'route' => 'sitegroupvideo_edit',
        'class' => 'ui-btn-action',
        'params' => array(
            'video_id' => $video_id,
            'group_id' => $group_id,
            'tab' => Zend_Controller_Front::getInstance()->getRequest()->getParam('tab')
        )
    );
  }

  public function onMenuInitialize_SitegroupvideoDelete($row) {
    $subject = Engine_Api::_()->core()->getSubject();

    $video_id = $subject->getIdentity();

    $sitegroupvideo = Engine_Api::_()->getItem('sitegroupvideo_video', $video_id);
    $group_id = $sitegroupvideo->group_id;
    if (empty($sitegroupvideo)) {
      return false;
    }

    $check = $this->commonChecks();
    if (empty($check)) {
      return false;
    }
    return array(
        'label' => 'Delete Video',
        'route' => 'sitegroupvideo_delete',
        'class' => 'ui-btn-danger',
        'params' => array(
            'video_id' => $video_id,
            'group_id' => $group_id,
            'tab' => Zend_Controller_Front::getInstance()->getRequest()->getParam('tab')
        )
    );
  }

  public function commonChecks() {
    //GET LOGGED IN USER INFORMATION
    $viewer = Engine_Api::_()->user()->getViewer();
    $viewer_id = $viewer->getIdentity();

    $subject = Engine_Api::_()->core()->getSubject();

    $video_id = $subject->getIdentity();

    $sitegroupvideo = Engine_Api::_()->getItem('sitegroupvideo_video', $video_id);
    $group_id = $sitegroupvideo->group_id;
    if (empty($sitegroupvideo)) {
      return false;
    }
    $getPackagevideoView = Engine_Api::_()->sitegroup()->getPackageAuthInfo('sitegroupvideo');
    $video = empty($getPackagevideoView) ? null : $sitegroupvideo;

    $owner_id = $video->owner_id;
    $sitegroup = Engine_Api::_()->getItem('sitegroup_group', $group_id);
    $isManageAdmin = Engine_Api::_()->sitegroup()->isManageAdmin($sitegroup, 'edit');
    if (empty($isManageAdmin)) {
      $can_edit = 0;
    } else {
      $can_edit = 1;
    }

    if ($owner_id != $viewer_id && empty($can_edit)) {
      return false;
    } else {
      return true;
    }
  }
  
  public function onMenuInitialize_SitegroupvideoReport(){
    $viewer_id = Engine_Api::_()->user()->getViewer()->getIdentity();
    if(!$viewer_id){
     return false;    
    }
    $subject = Engine_Api::_()->core()->getSubject();
    if ($subject->getType() !== 'sitegroupvideo_video') {
      throw new Video_Model_Exception('Whoops, not a video!');
    }

    return array(
        'label' => 'Report',
        'route' => 'default',
        'params' => array(
            'controller' => 'report',
            'action' => 'create',
            'subject' => $subject->getGuid(),
            'module' => 'core',
            'format' => 'smoothbox'
        )
    );
  }
  
  public function onMenuInitialize_SitegroupvideoShare(){
    $viewer_id = Engine_Api::_()->user()->getViewer()->getIdentity();
    if(!$viewer_id){
     return false;
    }
    $subject = Engine_Api::_()->core()->getSubject();
    if ($subject->getType() !== 'sitegroupvideo_video') {
      throw new Video_Model_Exception('Whoops, not a video!');
    }

    return array(
        'label' => 'Share',
        //'icon' => 'application/modules/Video/externals/images/delete.png',
        'route' => 'default',
        'params' => array(
            'controller' => 'index',
            'action' => 'share',
            'id' => $subject->getIdentity(),
            'type' => 'sitegroupvideo_video',
            'module' => 'activity',
            'format' => 'smoothbox'
        )
    );
  }
}
?>