<?php

class Siteimageoptimizer_Service_S3 extends Storage_Service_S3
{

  public function storeDirectOnBucket($path, $file)
  {
    // Prefix path with bucket?
    //$path = $this->_bucket . '/' . $path;
    // Copy file
    try {
      $return = $this->_internalService->putFile($file, $this->_bucket . '/' . $path, array(
        Zend_Service_Amazon_S3::S3_ACL_HEADER => Zend_Service_Amazon_S3::S3_ACL_PUBLIC_READ,
        'Cache-Control' => 'max-age=864000, public',
      ));
      if( !$return ) {
        throw new Storage_Service_Exception('Unable to store file.');
      }
    } catch( Exception $e ) {
      throw $e;
    }

    return $path;
  }

  public function getObjectsByBucket($prefix)
  {
    $finalList = array();
    $perRequestLimit = 100;
    $params = array(
      'prefix' => $prefix,
      'marker' => 0,
      'max-keys' => $perRequestLimit
    );
    $objects = $this->_internalService->getObjectsByBucket($this->_bucket, $params);

    if( !$objects ) {
      return $finalList;
    }

    while( !empty($objects) ) {
      foreach( $objects as $object ) {
        if( strpos($object, $prefix) === 0 ) {
          $finalList[] = $object;
        }
      }
      if( count($objects) < $perRequestLimit ) {
        break;
      }
      $params['marker'] = $objects[count($objects) - 1];
      $objects = $this->_internalService->getObjectsByBucket($this->_bucket, $params);
    }

    return $finalList;
  }

  /**
   * Returns a url that allows for external access to the file. May point to some
   * adapter which then retrieves the file and outputs it, if desirable
   *
   * @param Storage_Model_DbRow_File The file for operation
   * @return string
   */
  public function mapPath($path)
  {
    if( substr($path, 0, strlen($this->_bucket) + 1) == $this->_bucket . '/' ) {
      $path = ltrim(substr($path, strlen($this->_bucket) + 1), '/');
    }

    // Make url
    if( !$this->_baseUrl ) {
      // Map to S3 bucket directly
      return (_ENGINE_SSL ? 'https://' : 'http://') . $this->_bucket . '.s3.amazonaws.com/' . $path;
    } else {
      // Map to baseUrl (cloudfront)
      return rtrim($this->_baseUrl, '/') . '/' . $path;
    }
  }

  public function s3Path($path)
  {
    return ( 's3://') . $this->_bucket . '/' . $path;
  }

  public function cleanBucket()
  {
    return $this->_internalService->cleanBucket($this->_bucket);
  }

  /**
   * Get metadata information for a given object
   *
   * @param  string $object
   * @return array|false
   */
  public function getInfo($object)
  {
    // return $this->_internalService->getInfo($this->_bucket . '/' . $object);
    $info = array();
    $response = $this->_internalService->_makeRequest('HEAD', $this->_bucket . '/' . $object);
    if( $response->getStatus() == 200 ) {
      $info['type'] = $response->getHeader('Content-type');
      $info['size'] = $response->getHeader('Content-length');
      $info['mtime'] = strtotime($response->getHeader('Last-modified'));
      $info['etag'] = $response->getHeader('ETag');
      $info['img-processed'] = $response->getHeader('X-amz-meta-img-processed');
    } else {
      return false;
    }
    return $info;
  }

  public function removeFromPath($path)
  {
    $this->_remove($path);
  }

  private function _remove($path)
  {
    $finalList = array();
    $params = array(
      'prefix' => $path,
      'marker' => 0,
      'max-keys' => 1000
    );
    $list = $this->_internalService->getObjectsByBucket($this->_bucket, $params);
    foreach( $list as $l ) {
      if( strpos($l, $path) === 0 ) {
        $path = $this->_bucket . '/' . $l;
        $this->_internalService->removeObject($path);
        $finalList[] = $l;
      }
    }
  }

}