<?php

class Siteimageoptimizer_AdminOptimizerController extends Core_Controller_Action_Admin
{

  protected $_baseDir = 'public/siteimageoptimizer';
  protected $_basePath;
  protected $_s3StorageService;
  protected $_s3Config;

  public function init()
  {
    if( !file_exists(APPLICATION_PATH . '/' . $this->_baseDir) ) {
      mkdir(APPLICATION_PATH . '/' . $this->_baseDir, 0777);
    }
    // Check if folder exists and is writable
    if( !file_exists(APPLICATION_PATH . '/' . $this->_baseDir) ||
      !is_writable(APPLICATION_PATH . '/' . $this->_baseDir) ) {
      return $this->_forward('error', null, null, array(
          'message' => 'The public/siteimageoptimizer folder does not exist or is not ' .
          'writable. Please create this folder and set full permissions ' .
          'on it (chmod 0777).',
      ));
    }

    // Set base path
    $this->_basePath = realpath(APPLICATION_PATH . '/' . $this->_baseDir);
    $currentService = Engine_Api::_()->getDbtable('services', 'storage')
      ->getService();
    if( !($currentService instanceof Storage_Service_S3) ) {
      die("Not Supportable");
    }
    $serviceInfo = Engine_Api::_()->getDbtable('services', 'storage')->select()
      ->where('service_id = ?', $currentService->getIdentity())
      ->query()
      ->fetch();
    $config = Zend_Json::decode($serviceInfo['config']);
//    $config['bucket'] = $config['bucket'];
    $this->_s3Config = $config;
    Engine_Loader::loadClass('Siteimageoptimizer_Service_S3');
    $this->_s3StorageService = new Siteimageoptimizer_Service_S3($config);
  }

  public function indexAction()
  {
    // Get path
    $this->view->path = $path = $this->_getPath();
    $this->view->relPath = $relPath = $this->_getRelPath($path);
    // List files
    $files = array();
    $it = new DirectoryIterator($path);
    foreach( $it as $key => $file ) {
      $filename = $file->getFilename();
      if( $file->isDir() || ($it->isDot() && $this->_basePath == $path) || $filename == '.' || ($filename != '..' && $filename[0] == '.') ) {
        continue;
      }
      $relPath = trim(str_replace($this->_basePath, '', realpath($file->getPathname())), '/\\');
      $ext = strtolower(ltrim(strrchr($file->getFilename(), '.'), '.'));
      if( !in_array($ext, array('jpg', 'png', 'gif', 'jpeg')) ) {
        continue;
      }
      $key = trim(str_replace(APPLICATION_PATH, '', realpath($file->getPathname())), '/\\');
      $dat = array(
        'url' => $key,
        'filesize' => round(filesize(realpath($file->getPathname())) / 1024, 2) . ' KB'
      );
      $files[$key] = $dat;
    }
    ksort($files);
    $this->view->localImages = $files;


    $s3Images = $this->_s3StorageService->getObjectsByBucket($this->_baseDir);
    $data = array();
    foreach( $s3Images as $i ) {
      if( empty($files[$i]) ) {
        continue;
      }
      $data[$i]['orignal'] = $files[$i];

      $info = $this->_s3StorageService->getInfo($i);
      $data[$i]['optimized'] = array(
        'url' => $this->_s3StorageService->mapPath($i),
        'filesize' => round($info['size'] / 1024, 2) . ' KB',
        'status' => $info['img-processed']
      );
    }
    $this->view->imagesInfo = $data;
  }

  public function deleteAction()
  {
    $this->_s3StorageService->removeFromPath($this->_baseDir);
    $files = scandir($this->_getPath()); // get all file names
    foreach( $files as $file ) { // iterate files
      if( is_file($file) )
        unlink($file); // delete file
    }
    exec('rm -rf ' . $this->_getPath() . '/*');
    return $this->_helper->redirector->gotoRoute(array('module' => 'siteimageoptimizer', 'controller' => 'optimizer', 'action' => 'index'), 'admin_default', true);
  }

  public function uploadAction()
  {
    $this->view->path = $path = $this->_getPath();
    $this->view->relPath = $relPath = $this->_getRelPath($path);

    // Check method
    if( !$this->getRequest()->isPost() ) {
      return;
    }
    // Prepare
    if( empty($_FILES['Filedata']) ) {
      $this->view->error = 'File failed to upload. Check your server settings (such as php.ini max_upload_filesize).';
      return;
    }

    // Prevent evil files from being uploaded
    $disallowedExtensions = array('php');
    $parts = explode(".", $_FILES['Filedata']['name']);
    $name = end($parts);
    if( is_array($name) && in_array($name, $disallowedExtensions) ) {
      $this->view->error = 'File type or extension forbidden.';
      return;
    }


    $info = $_FILES['Filedata'];
    $targetFile = $path . '/' . $info['name'];
    $vals = array();

    if( file_exists($targetFile) ) {
      $deleteUrl = $this->view->url(array('action' => 'delete')) . '?path=' . $relPath . '/' . $info['name'];
      $deleteUrlLink = '<a href="' . $this->view->escape($deleteUrl) . '">' . Zend_Registry::get('Zend_Translate')->_("delete") . '</a>';
      $this->view->error = Zend_Registry::get('Zend_Translate')->_(sprintf($info['name'] . " : File already exists. Please %s before trying to upload.", $deleteUrlLink));
      return;
    }

    if( !is_writable($path) ) {
      $this->view->error = Zend_Registry::get('Zend_Translate')->_('Path is not writeable. Please CHMOD 0777 the public/admin directory.');
      return;
    }

    // Try to move uploaded file
    $this->_s3StorageService->storeDirectOnBucket($this->_baseDir . '/' . $info['name'], $info['tmp_name']);

    $file = $info['tmp_name'];
    $fileName = $info['name'];
    if( !$fileName ) {
      $fileName = basename($file);
    }
    $image = Engine_Image::factory();
    $image->open($file)
      ->write($targetFile)
      ->destroy();

//    if( !move_uploaded_file($info['tmp_name'], $targetFile) ) {
//      $this->view->error = Zend_Registry::get('Zend_Translate')->_("Unable to move file to upload directory.");
//      return;
//    }
    chmod($targetFile, 0777);
    $this->view->status = 1;
    $this->view->fileName = $_FILES['Filedata']['name'];
  }

  protected function _getPath($key = 'path')
  {
    return $this->_checkPath(urldecode($this->_getParam($key, '')), $this->_basePath);
  }

  protected function _getRelPath($path, $basePath = null)
  {
    if( null === $basePath )
      $basePath = $this->_basePath;
    $path = realpath($path);
    $basePath = realpath($basePath);
    $relPath = trim(str_replace($basePath, '', $path), '/\\');
    return $relPath;
  }

  protected function _checkPath($path, $basePath)
  {
    // Sanitize
    //$path = preg_replace('/^[a-z0-9_.-]/', '', $path);
    $path = preg_replace('/\.{2,}/', '.', $path);
    $path = preg_replace('/[\/\\\\]+/', '/', $path);
    $path = trim($path, './\\');
    $path = $basePath . '/' . $path;

    // Resolve
    $basePath = realpath($basePath);
    $path = realpath($path);

    // Check if this is a parent of the base path
    if( $basePath != $path && strpos($basePath, $path) !== false ) {
      return $this->_helper->redirector->gotoRoute(array());
    }

    return $path;
  }

}