<?php

class Sitelivestreaming_IndexController extends Core_Controller_Action_Standard
{
  public function init()
  {
    $this->view->themeMode = Engine_Api::_()->getApi('settings', 'core')->getSetting('livestreamingvideo.theme.mode', 'dark');
  }

  public function indexAction()
  {
    if( !$this->_helper->requireUser()->isValid() ) return;
    if(!Engine_Api::_()->sitelivestreaming()->hasPackageEnable()) {
      return $this->_forward('requireauth', 'error', 'core');
    }
    $this->view->viewer = $subject = $viewer = Engine_Api::_()->user()->getViewer();

    if( !Engine_Api::_()->core()->hasSubject('user') ) {
      Engine_Api::_()->core()->setSubject($viewer);
    }

    $viewOptions = (array) Engine_Api::_()->authorization()->getAdapter('levels')->getAllowed('livestreamingvideo', $viewer, 'auth_view');
    $availableLabels = array(
      'everyone'  => 'Everyone',
      'networks'  => 'Networks Only',
      'friends'   => 'Friends Only',
      'onlyme'    => 'Only Me',
    );
    $this->view->privacyList = array_intersect_key($availableLabels, array_flip($viewOptions));

    $this->view->isAlreadyBroadcasting = Engine_Api::_()->getDbTable('streams' , 'sitelivestreaming')->isUserBroadcasting($viewer->getIdentity());
    $this->view->current_count = Engine_Api::_()->getDbTable('streams' , 'sitelivestreaming')->getCountOfStreams($viewer->getIdentity());
    $this->view->quota = $quota = Engine_Api::_()->authorization()->getAdapter('levels')->getAllowed('livestreamingvideo', $viewer, 'max_streamings');

	}

  public function broadcastAction()
  {
    if( !$this->_helper->requireUser()->isValid() ) return;
    if(!Engine_Api::_()->sitelivestreaming()->hasPackageEnable()) {
      return $this->_forward('requireauth', 'error', 'core');
    }
    $this->view->viewer = $subject = $viewer = Engine_Api::_()->user()->getViewer();

    if( !Engine_Api::_()->core()->hasSubject('user') ) {
      Engine_Api::_()->core()->setSubject($viewer);
    }

    $stream_id = $this->_getParam("stream_id");
    $this->view->stream = $stream = Engine_Api::_()->getItem('sitelivestreaming_stream', $stream_id);
    $expire_time = new DateTime(date('Y-m-d H:i:s'), new DateTimeZone('UTC'));
    $expire_time = $expire_time->format('Y-m-d H:i:s');

    if(empty($stream->getIdentity()) || $stream->end_time <= $expire_time)
        return $this->_forward('notfound', 'error', 'core');

    $this->view->video = $video = Engine_Api::_()->getItem($stream->subject_type, $stream->subject_id);

    if($viewer->getIdentity() != $video->owner_id || $video->owner_type != 'user') {
      return $this->_forward('requireauth', 'error', 'core');
    }

  }

  public function joinAction()
  {
    if( !$this->_helper->requireUser()->isValid() ) return;
    if(!Engine_Api::_()->sitelivestreaming()->hasPackageEnable(true)) {
      return $this->_forward('requireauth', 'error', 'core');
    }
    $this->view->viewer = $subject = $viewer = Engine_Api::_()->user()->getViewer();

    if( !Engine_Api::_()->core()->hasSubject('user') ) {
      Engine_Api::_()->core()->setSubject($viewer);
    }

    $stream_id = $this->_getParam("stream_id");
    $this->view->stream = $stream = Engine_Api::_()->getItem('sitelivestreaming_stream', $stream_id);
    $expire_time = new DateTime(date('Y-m-d H:i:s'), new DateTimeZone('UTC'));
    $expire_time = $expire_time->format('Y-m-d H:i:s');

    if(!$stream || $stream->end_time <= $expire_time)
        return $this->_forward('notfound', 'error', 'core');

    $this->view->video = $video = Engine_Api::_()->getItem($stream->subject_type, $stream->subject_id);

    if($video->owner_id == $viewer->getIdentity()) {
      return $this->_forward('requireauth', 'error', 'core');
    }

    if( !$this->_helper->requireAuth()->setAuthParams($video, $viewer, 'view')->isValid() ) {
      return;
    }

    $fileId = Engine_Api::_()->getApi('settings', 'core')->getSetting('livestreamingvideo.join.photo', 0);
    $this->view->joinBgImage = $joinBgImage = Engine_Api::_()->sitelivestreaming()->getPhotoUrl($fileId);
  }

  public function completeAction()
  {
    if( !$this->getRequest()->isPost() ) {
      $response['status'] = false;
      $response['error'] = Zend_Registry::get('Zend_Translate')->_('Invalid request method');
      $this->sendJsonResponse($response);
    }
    if(!Engine_Api::_()->getDbtable('modules', 'core')->isModuleEnabled('advancedactivity') || !Engine_Api::_()->getDbtable('modules', 'core')->isModuleEnabled('sitevideo')) {
      $response['status'] = false;
      $response['error'] = Zend_Registry::get('Zend_Translate')->_('Advancedactivity or Advanced video plugin is disabled, please enable them');
      $this->sendJsonResponse($response);
    }
    $response = Seaocore_Service_FancyUpload::upload();
    // Notification work in case of file size exceeds upload_max_filesize limit
    if ($response['error'] == 1) {
      $token = $this->_getParam('token');
      if (!empty($token)) {
        $streamTable = Engine_Api::_()->getDbtable('streams' , 'sitelivestreaming');
        $stream = $streamTable->getstream($token);
        $video = Engine_Api::_()->getItem("sitevideo_video" , $stream->video_id);
        $owner = Engine_Api::_()->getItem("user" , $video->owner_id);

        Engine_Api::_()->getDbtable('notifications', 'activity')->addNotification($owner, $owner, $video, 'sitelivestreaming_failed');
      }
    }
    $this->sendJsonResponse($response);
  }

  public function uploadVideoAction()
  {
    if(!Engine_Api::_()->getDbtable('modules', 'core')->isModuleEnabled('advancedactivity') || !Engine_Api::_()->getDbtable('modules', 'core')->isModuleEnabled('sitevideo')) {
      $response['status'] = false;
      $response['error'] = Zend_Registry::get('Zend_Translate')->_('Advancedactivity or Advanced video plugin is disabled, please enable them');
      $this->sendJsonResponse($response);
    }
    $requestData = json_decode(file_get_contents('php://input'), true);
    $results = $requestData['data'];

    $stream_name = $requestData["stream_name"];

    if(empty($results)) {
      $response['status'] = false;
      $response['error'] = Zend_Registry::get('Zend_Translate')->_('Data is not found');
      $response['stream_name'] = $stream_name;
      $this->sendJsonResponse($response);
    }

    $streamTable = Engine_Api::_()->getDbtable('streams' , 'sitelivestreaming');
    $stream = $streamTable->getstream($stream_name);

    if(!$stream) {
      $response['status'] = false;
      $response['error'] = Zend_Registry::get('Zend_Translate')->_('Invalid stream name');
      $this->sendJsonResponse($response);
    }
    $video = Engine_Api::_()->getItem($stream->subject_type , $stream->subject_id);
    $enableType = array("image", "video");

    foreach($results as $filePath) {
      if(isset($filePath['type']) && in_array($filePath['type'], $enableType)) {
        $fileArrayPath[$filePath['type']] = $filePath['path'];
      } elseif(isset($filePath['duration'])) {
        $duration = $filePath['duration'];
      }
    }

    if(!file_exists($fileArrayPath['video'])) {

      $stream->status = 'normal';
      $stream->end_time = date('Y-m-d H:i:s');
      $stream->save();

      if($video->video_id)
        $video->delete();

      $response['status'] = false;
      $response['error'] = Zend_Registry::get('Zend_Translate')->_('video uploading failed');
      $this->sendJsonResponse($response);
    }

    $viewer = Engine_Api::_()->getItem("user" , $video->owner_id);
    $params = array(
      'name' => $fileArrayPath['video'],
      'owner_type' => 'user',
      'owner_id' => $video->owner_id
    );

    $params['parent_id'] = $video->getIdentity();
    $params['parent_type'] = $video->getType();
    $params["user_id"] = $video->owner_id;

    $db = $streamTable->getAdapter();
    $db->beginTransaction();
    try
    {
      $endType = $stream->status;
      // Get Video Object
      $streamTitle = $stream->title;
      if($endType == 'feed' || $endType == 'both') {
        $file = Engine_Api::_()->storage()->create($fileArrayPath['video'], $params);
        $video->code = 'mp4';
        $video->type = "upload";
        $video->status = 0;
        $video->synchronized = 1;
        $video->file_id = $file->getIdentity();
        $video->duration = $duration;
        $video->save();
        $stream->video_id = $video->getIdentity();
        $stream->save();

        if(file_exists($fileArrayPath['image'])) {
          $fileParams = array(
          'parent_type' => $video->getType(),
          'parent_id' => $video->getIdentity(),
          'user_id' => $video->owner_id
          );
          $filePhoto = Engine_Api::_()->storage()->create($fileArrayPath['image'], $fileParams);
          $video->photo_id = $filePhoto->getIdentity();
          $video->status = 1;
          $video->save();
        }
      } else
        Engine_Api::_()->sitevideo()->deleteVideo($video);

      //story work
      $story_id = 0;
      if(($endType == 'story' || $endType == 'both') && (Engine_Api::_()->getDbtable('modules', 'core')->isModuleEnabled('sitestoriesweb') || Engine_Api::_()->getDbtable('modules', 'core')->isModuleEnabled('sitestories'))) {
        $story = $this->_createStory($streamTitle, $fileArrayPath['video'], $viewer);
        $story->duration = $duration;
        $story_id = $story->getIdentity();
      }
      $db->commit();

      if(isset($story) && !empty($story)) {
        $fileParams = array(
          'parent_type' => $story->getType(),
          'parent_id' => $story->getIdentity(),
          'user_id' => $viewer->getIdentity()
        );
        $storyPhoto = Engine_Api::_()->storage()->create($fileArrayPath['image'], $fileParams);
        $story->photo_id = $storyPhoto->getIdentity();
        $story->save();
      }

      if($endType == 'feed' || $endType == 'both') {
        $actionsTable = Engine_Api::_()->getDbtable('actions', 'advancedactivity');
        $db = $actionsTable->getAdapter();
        $db->beginTransaction();

        try {
          // new action
          $actionType ='sitelivestreaming_video';
          $action = $actionsTable->addActivity($viewer, $video, $actionType);

          if ($action)
            $actionsTable->attachActivity($action, $video);

          $this->checkinAndTagUsers($action);
          $db->commit();
        } catch (Exception $e) {
          $db->rollBack();
          $response['status'] = false;
          $response['error'] = Zend_Registry::get('Zend_Translate')->_('some exception'.$e);
          $response['stream_name'] = $stream_name;
          $this->sendJsonResponse($response);
        }
      }

      @unlink($fileArrayPath['image']);
      @unlink($fileArrayPath['video']);

      $response['status'] = true;
      $response['message'] = Zend_Registry::get('Zend_Translate')->_('Video uploaded sucessfully');
    $this->sendJsonResponse($response);
    } catch (Exception $ex){
      $db->rollBack();
      $response['status'] = false;
      $response['error'] = $ex;
      $response['stream_name'] = $stream_name;
      $this->sendJsonResponse($response);
    }
  }

  protected function _createStory($description ,$fileArrayPath, $viewer)
  {
    $viewer_id = $viewer->getIdentity();

    $values = array();
     if (Engine_Api::_()->getDbtable('modules', 'core')->isModuleEnabled('sitestoriesweb')) {
      $UserPrivacyClass = Engine_Api::_()->getDbtable('userprivacies', 'sitestoriesweb');
      $table = Engine_Api::_()->getDbtable('stories', 'sitestoriesweb');
    } elseif (Engine_Api::_()->getDbtable('modules', 'core')->isModuleEnabled('sitestories')) {
      $UserPrivacyClass = Engine_Api::_()->getDbtable('userprivacies', 'sitestories');
      $table = Engine_Api::_()->getDbtable('stories', 'sitestories');
    }
    $values['privacy'] = $UserPrivacyClass->getUserStoryPrivacyStatus($viewer_id);
    $values['description'] = $description;
    $values = @array_merge($values, array(
      'owner_type' => $viewer->getType(),
      'owner_id' => $viewer->getIdentity(),
    ));

    $createDate = date('Y-m-d H:i:s');
    $days = Engine_Api::_()->getApi('settings', 'core')->getSetting('sitestories_max_allowed_days', 1);
    $pastDate = date('Y-m-d H:i:s', strtotime('+' . $days . ' day', strtotime($createDate)));

    $values['create_date'] = $createDate;
    $values['expiry_date'] = $pastDate;
    $values['type'] = 'video';

    try{
      $story = $table->createRow();
      $story->setFromArray($values);
      $story->save();
      $fileParams = array(
        'parent_type' => $story->getType(),
        'parent_id' => $story->getIdentity(),
        'user_id' => $viewer->getIdentity()
      );
      $file = Engine_Api::_()->storage()->create($fileArrayPath, $fileParams);
      $story->file_id = $file->getIdentity();
      $story->save();
      return $story;
    } catch (Exception $ex) {

    }
  }

  public function checkinAndTagUsers($action)
  {
    if(empty($action))
        return;

    $postData = array();
    $viewer = $action->getSubject();
    $streamTable = Engine_Api::_()->getDbtable('streams' , 'sitelivestreaming');
    $select = $streamTable->select()
                ->where('video_id= ?',$action->object_id);
    $stream =  $streamTable->fetchRow($select);
    if(!empty($stream) && $stream->tovalues){
      $postData['toValues'] = $stream->tovalues;
    }
    if(empty($postData))
      return ;

    // Start the work for tagging
    if ($action && isset($postData['toValues']) && !empty($postData['toValues'])) {

      $actionTag = new Engine_ProxyObject($action, Engine_Api::_()->getDbtable('tags', 'core'));
      $users = array_values(array_unique(explode(",", $postData['toValues'])));

      foreach (Engine_Api::_()->getItemMulti('user', $users) as $tag) {
        $actionTag->addTagMap($viewer, $tag, null);
        // Add notification
        $type_name = str_replace('_', ' ', 'post');
        if (is_array($type_name)) {
            $type_name = $type_name[0];
        } else {
            $type_name = 'post';
        }
        Engine_Api::_()->getDbtable('notifications', 'activity')->addNotification($tag, $viewer, $action, 'tagged', array('object_type_name' => $type_name,'label' => $type_name));
      }
    }
  }

  public function stopStreamAction()
  {
    $uid = $this->_getParam("uid", "");
    if(!empty($uid)){
      Engine_Api::_()->getDbTable('streams' , 'sitelivestreaming')->stopActiveStreams($uid);
      $this->sendJsonResponse(array('flag' => true));
    }
    $this->sendJsonResponse(array('flag' => false));
  }

  private function sendJsonResponse($response)
  {
    echo json_encode($response);
    exit();
  }
}
?>