<?php

/**
 * SocialEngine
 *
 * @category   Application_Extensions
 * @package    Sitemobile
 * @copyright  Copyright 2012-2013 BigStep Technologies Pvt. Ltd.
 * @license    http://www.socialengineaddons.com/license/
 * @version    $Id: Menus.php 6590 2013-06-03 00:00:00Z SocialEngineAddOns $
 * @author     SocialEngineAddOns
 */
class Sitemobile_Api_Menus extends Core_Api_Abstract {

  public function getNavigation($name, array $options = array(), $activeItem = null) {
    $pages = $this->getMenuParams($name, $options, $activeItem);
    $navigation = new Zend_Navigation();
    $navigation->addPages($pages);
    return $navigation;
  }

  public function getMenuParams($name, array $options = array(), $activeItem = null) {
    $menu = $this->getMenu($name);
    $pages = array();

    $enable_type = 'enable';
    if (Engine_Api::_()->sitemobile()->checkMode('tablet-mode')) {
      $enable_type .= '_tablet';
    } elseif (Engine_Api::_()->sitemobile()->checkMode('mobile-mode')) {
      $enable_type .= '_mobile';
    }
    $notAddFileMenu = array("");
    if (Engine_Api::_()->sitemobile()->isApp()) {
      $enable_type .= '_app';
      $infoApp = Engine_Api::_()->sitemobile()->isApp(true);
      if(isset($infoApp['version']) && $infoApp['appOS']=='android' && version_compare($infoApp['version'],'4.4','>=') && version_compare($infoApp['version'],'4.5','<')){
//        $notAddFileMenu = array('album_quick_upload','album_main_upload','album_profile_add','music_main_create','music_quick_create');
         $notAddFileMenu = array('music_main_create','music_quick_create');
      }
    }

    foreach ($menu as $row) {
      if (!isset($row->$enable_type) || !$row->$enable_type || in_array($row->name, $notAddFileMenu)) {
        continue;
      }

      //Plugin
      $page = null;
      $multi = false;
      if (!empty($row->plugin)) {

        //Support overriding the method
        if (strpos($row->plugin, '::') !== false) {
          list($pluginName, $method) = explode('::', $row->plugin);
        } else {
          $pluginName = $row->plugin;
          $method = 'onMenuInitialize_' . $this->_formatMenuName($row->name);
        }

        //Load the plugin
        try {
          $plugin = Engine_Api::_()->loadClass($pluginName);
        } catch (Exception $e) {
          //Silence exceptions
          continue;
        }

        //Run plugin
        try {
          if (method_exists($plugin, $method))
            $result = $plugin->$method($row);
        } catch (Exception $e) {
          //Silence exceptions
          continue;
        }

        if ($result === true) {
          //Just generate normally
        } else if ($result === false) {
          //Don't generate
          continue;
        } else if (is_array($result)) {
          //We got either page params or multiple page params back
          //Single
          if (array_values($result) !== $result) {
            $page = $result;
          }
          //Multi
          else {
            //We have to do this manually
            foreach ($result as $key => $value) {
              if (is_numeric($key)) {
                if (!empty($options)) {
                  $value = array_merge_recursive($value, $options);
                }
                if (!isset($result['label']))
                  $result['label'] = $row->label;
                $pages[] = $value;
              }
            }
            continue;
          }
        } else if ($result instanceof Zend_Db_Table_Row_Abstract && $result->getTable() instanceof Sitemobile_Model_DbTable_MenuItems) {
          //We got the row (or a different row?) back ...
          $row = $result;
        } else {
          //We got a weird data type back
          continue;
        }
      }

      //No page was made, use row
      if (null === $page) {
        $page = (array) $row->params;
      }

      //Add label
      if (!isset($page['label'])) {
        $page['label'] = $row->label;
      }

      //Add custom options
      if (!empty($options)) {
        $page = array_merge_recursive($page, $options);
      }

      //Standardize arguments
      if (!isset($page['reset_params'])) {
        $page['reset_params'] = true;
      }

      //Set page as active, if necessary
      if (!isset($page['active']) && null !== $activeItem && $activeItem == $row->name) {
        $page['active'] = true;
      }

      $page['class'] = (!empty($page['class']) ? $page['class'] . ' ' : '' ) . 'menu_' . $name;
      $page['class'] .= " " . $row->name;

      //Get submenu
      if ($row->submenu) {
        $page['pages'] = $this->getMenuParams($row->submenu);
      }

      //Maintain menu item order 
      $page['order'] = $row->order;

      $pages[] = $page;
    }
    return $pages;
  }

  public function getMenu($name) {
    //Get only enabled modules
    $enabledModuleNames = Engine_Api::_()->getDbtable('modules', 'sitemobile')->getEnabledModuleNames();

    //Get items
    $table = Engine_Api::_()->getDbtable('menuItems', 'sitemobile');
    $select = $table->select()
            ->where('menu = ?', $name)
            ->where('module IN(?)', $enabledModuleNames)
            ->order('order ASC');

    return $table->fetchAll($select);
  }

  protected function _formatMenuName($name) {
    $name = str_replace('_', ' ', $name);
    $name = ucwords($name);
    $name = str_replace(' ', '', $name);
    return $name;
  }

}