<?php

/**
 * SocialEngine
 *
 * @category   Application_Extensions
 * @package    Sitemusic
 * @copyright  Copyright 2017-2022 BigStep Technologies Pvt. Ltd.
 * @license    http://www.socialengineaddons.com/license/
 * @version    $Id: Favourite.php 2017-03-27 9:40:21Z SocialEngineAddOns $
 * @author     SocialEngineAddOns
 */
class Sitemusic_Api_Favourite
{

  public function getFavourite($entityType = '', $info = array())
  {
    $viewer = Engine_Api::_()->user()->getViewer();
    $viewerId = $viewer->getIdentity();

    if( $entityType == 'Playlist' ) {
      $entity = 'userPlaylists';
      $resourceType = 'sitemusic_userpl';
      $entityId = 'userplaylist_id';
    } elseif( $entityType == 'Song' ) {
      $entity = 'playlistSongs';
      $entityId = 'song_id';
      $resourceType = 'sitemusic_playlist_song';
    } elseif( $entityType == 'Artist' ) {
      $entity = 'artists';
      $entityId = 'artist_id';
      $resourceType = 'sitemusic_artist';
    } else {
      $entity = 'playlists';
      $entityId = 'playlist_id';
      $resourceType = 'sitemusic_pl';
    }
    $table = Engine_Api::_()->getDbTable($entity, 'sitemusic');
    $tName = $table->info('name');
    $favouriteTable = Engine_Api::_()->getDbTable('favourites', 'sitemusic');
    $fName = $favouriteTable->info('name');

    $select = $table->select()
      ->from($tName);
    if( isset($info['album_category']) && $info['album_category'] != 'all' ) {
      $select->where('category_id = ?', $info['album_category']);
    }

    if( isset($info['genre_id']) && $info['genre_id'] != 'all' ) {
      $select->where('genre_id = ?', $info['genre_id']);
    }

    $select->joinLeft($fName, "$tName.$entityId = $fName.resource_id", '');
    $select->where('poster_id = ?', $viewerId)
      ->where('resource_type = ?', $resourceType);
    return Zend_Paginator::factory($select);
  }

  /**
   * check the item is favourite or not.
   *
   * @param Stirng $resource_type
   * @param Int $resource_id
   * @return results
   */
  public function hasFavourite($resource_type, $resource_id)
  {

    //GET THE VIEWER.
    $viewer = Engine_Api::_()->user()->getViewer();
    $favouriteTable = Engine_Api::_()->getItemTable('sitemusic_favourite');
    $favouriteTableName = $favouriteTable->info('name');
    $sub_status_select = $favouriteTable->select()
      ->from($favouriteTableName, array('favourite_id'))
      ->where('resource_type = ?', $resource_type)
      ->where('resource_id = ?', $resource_id)
      ->where('poster_type =?', $viewer->getType())
      ->where('poster_id =?', $viewer->getIdentity())
      ->limit(1);
    return $sub_status_select->query()->fetchAll();
  }

  /**
   * Function for showing 'Number of Favourites'.
   *
   * @param Stirng $resource_type
   * @param Int $resource_id
   * @return number of favourites
   */
  public function favouriteCount($resource_type, $resource_id)
  {

    //GET THE VIEWER (POSTER) AND RESOURCE.
    $poster = Engine_Api::_()->user()->getViewer();
    $resource = Engine_Api::_()->getItem($resource_type, $resource_id);
    return Engine_Api::_()->getDbtable('favourites', 'sitemusic')->getFavouriteCount($resource, $poster);
  }

}
