<?php

/**
 * SocialEngine
 *
 * @category   Application_Extensions
 * @package    Sitemusic
 * @copyright  Copyright 2017-2022 BigStep Technologies Pvt. Ltd.
 * @license    http://www.socialengineaddons.com/license/
 * @version    $Id: Liked.php 2017-03-27 9:40:21Z SocialEngineAddOns $
 * @author     SocialEngineAddOns
 */
class Sitemusic_Api_Liked
{

  public function getLiked($entityType = '', $info = array())
  {
    $viewer = Engine_Api::_()->user()->getViewer();
    $viewerId = $viewer->getIdentity();

    if( $entityType == 'Playlist' ) {
      $entity = 'userPlaylists';
      $resourceType = 'sitemusic_userpl';
      $entityId = 'userplaylist_id';
    } elseif( $entityType == 'Song' ) {
      $entity = 'playlistSongs';
      $entityId = 'song_id';
      $resourceType = 'sitemusic_playlist_song';
    } elseif( $entityType == 'Artist' ) {
      $entity = 'artists';
      $entityId = 'artist_id';
      $resourceType = 'sitemusic_artist';
    } else {
      $entity = 'playlists';
      $entityId = 'playlist_id';
      $resourceType = 'sitemusic_pl';
    }

    $table = Engine_Api::_()->getDbTable($entity, 'sitemusic');
    $tName = $table->info('name');
    $likeTable = Engine_Api::_()->getDbTable('likes', 'core');
    $lName = $likeTable->info('name');
    $select = $table->select()
      ->from($tName);

    if( isset($info['album_category']) && $info['album_category'] != 'all' ) {
      $select->where('category_id = ?', $info['album_category']);
    }

    if( isset($info['genre_id']) && $info['genre_id'] != 'all' ) {
      $select->where('genre_id = ?', $info['genre_id']);
    }

    $select->join($lName, "$tName.$entityId = $lName.resource_id", '');
    $select->where('poster_id = ?', $viewerId)
      ->where('resource_type = ?', $resourceType);
    return Zend_Paginator::factory($select);
  }

  public function getPaginator($type)
  {
    $paginator = Zend_Paginator::factory($this->getLiked($type));
    return $paginator;
  }

  public function checkAvailability($resourceType, $resourceId)
  {

    $viewer = Engine_Api::_()->user()->getViewer();
    $sub_status_table = Engine_Api::_()->getItemTable('core_like');
    $sub_status_name = $sub_status_table->info('name');
    $sub_status_select = $sub_status_table->select()
      ->from($sub_status_name, array('like_id'))
      ->where('resource_type = ?', $resourceType)
      ->where('resource_id = ?', $resourceId)
      ->where('poster_type =?', $viewer->getType())
      ->where('poster_id =?', $viewer->getIdentity())
      ->limit(1);
    return $sub_status_select->query()->fetchAll();
  }

  /**
   * check the item is like or not.
   *
   * @param Stirng $resource_type
   * @param Int $resource_id
   * @return results
   */
  public function hasLike($resource_type, $resource_id)
  {

    //GET THE VIEWER.
    $viewer = Engine_Api::_()->user()->getViewer();
    $likeTable = Engine_Api::_()->getItemTable('core_like');
    $likeTableName = $likeTable->info('name');
    $sub_status_select = $likeTable->select()
      ->from($likeTableName, array('like_id'))
      ->where('resource_type = ?', $resource_type)
      ->where('resource_id = ?', $resource_id)
      ->where('poster_type =?', $viewer->getType())
      ->where('poster_id =?', $viewer->getIdentity())
      ->limit(1);
    return $sub_status_select->query()->fetchAll();
  }

}
