<?php

/**
 * SocialEngine
 *
 * @category   Application_Extensions
 * @package    Sitemusic
 * @copyright  Copyright 2017-2022 BigStep Technologies Pvt. Ltd.
 * @license    http://www.socialengineaddons.com/license/
 * @version    $Id: Global.php 2017-03-27 9:40:21Z SocialEngineAddOns $
 * @author     SocialEngineAddOns
 */
class Sitemusic_Form_Admin_Global_Global extends Engine_Form
{

  public function init()
  {
    $url = $this->_attribs['url'];

    $this
      ->setTitle('General Settings')
      ->setDescription('These settings will affect all the member levels of your community.');

    $settings = Engine_Api::_()->getApi('settings', 'core');
    // Get The Value
    $values = $settings->sitemusic;
    // Get available files
    $photoOptions = array('' => '');
    $imageExtensions = array('gif', 'jpg', 'jpeg', 'png');

    $it = new DirectoryIterator(APPLICATION_PATH . '/public/admin/');
    foreach( $it as $file ) {
      if( $file->isDot() || !$file->isFile() )
        continue;
      $basename = basename($file->getFilename());
      if( !($pos = strrpos($basename, '.')) )
        continue;
      $ext = strtolower(ltrim(substr($basename, $pos), '.'));
      if( !in_array($ext, $imageExtensions) )
        continue;
      $photoOptions['public/admin/' . $basename] = $basename;
    }

    $this->addElement('Text', 'sitemusic_manifestUrlP', array(
      'label' => 'Music URL alternate text for "site-musics"',
      'allowEmpty' => false,
      'required' => true,
      'description' => 'Please enter the text below which you want to display in place of "site-musics" in the URLs of this plugin.',
      'value' => $settings->getSetting('sitemusic.manifestUrlP', "site-musics"),
    ));

    $this->addElement('Text', 'sitemusic_manifestUrlS', array(
      'label' => 'Music URL alternate text for "site-music"',
      'allowEmpty' => false,
      'required' => true,
      'description' => 'Please enter the text below which you want to display in place of "site-music" in the URLs of this plugin.',
      'value' => $settings->getSetting('sitemusic.manifestUrlS', "site-music"),
    ));



    $this->addElement('Radio', 'sitemusic_enable_content_basedPrivacy', array(
      'label' => 'Content Based Privacy',
      'description' => 'Do you want to display all content on browse pages even private ones?',
      'multiOptions' => array(
        0 => 'Yes',
        1 => 'No',
      ),
      'value' => $settings->getSetting('sitemusic_enable_content_basedPrivacy', 1),
    ));

    $this->addElement('Radio', 'sitemusic_stats_onzero', array(
      'label' => 'Display Music Statistics',
      'description' => 'Do you want to display music statistics count (eg: like, comment, favourite etc.) when it is zero? [Note: You have to enable / disable statistics to display / hide from a particular block.]',
      'multiOptions' => array(
        1 => 'Yes',
        0 => 'No',
      ),
      'value' => $settings->getSetting('sitemusic.stats.onzero', 1),
    ));


    $this->addElement('Text', 'sitemusic_navigationtabs', array(
      'label' => 'Tabs in Music Navigation bar',
      'allowEmpty' => false,
      'maxlength' => '3',
      'required' => true,
      'description' => 'How many tabs do you want to show on Music main navigation bar by default? (Note: If number of tabs exceeds the limit entered by you then a "More" tab will appear, clicking on which will show the remaining hidden tabs. To choose the tab to be shown in this navigation menu, and their sequence, please visit: "Layout" > "Menu Editor")',
      'value' => $settings->getSetting('sitemusic.navigationtabs', 8),
      'validators' => array(
        array('Int', true),
        array('GreaterThan', true, array(0)),
      ),
    ));

    $this->addElement('Radio', 'sitemusic_multipleextension', array(
      'label' => 'Audio Extension',
      'description' => 'Do you want to support multiple extensions for uploading songs. [Note: Multiple extensions support can increase the time of upload songs process and this will be supported only when FFMPEG is present on your server.]',
      'multiOptions' => array(
        1 => 'Multiple Extensions (mp3, m4a, ogg, flac, wav)',
        0 => 'Only Mp3',
      ),
      'onclick' => 'showFfmpegSetting(this.value)',
      'value' => $settings->getSetting('sitemusic.multipleextension', 0),
    ));

    $this->addElement('Text', 'sitemusic_ffmpeg_path', array(
      'label' => 'Path to FFMPEG',
      'description' => 'Please enter the full path to your FFMPEG installation. (Environment variables are not present)',
      'value' => $settings->getSetting('sitemusic.ffmpeg.path', ''),
    ));

    // Add submit button
    $this->addElement('Button', 'submit', array(
      'label' => 'Save Changes',
      'type' => 'submit',
      'ignore' => true
    ));
  }

}
