<?php

/**
 * SocialEngine
 *
 * @category   Application_Extensions
 * @package    Sitemusic
 * @copyright  Copyright 2017-2022 BigStep Technologies Pvt. Ltd.
 * @license    http://www.socialengineaddons.com/license/
 * @version    $Id: Filter.php 2017-03-27 9:40:21Z SocialEngineAddOns $
 * @author     SocialEngineAddOns
 */
class Sitemusic_Form_Admin_Manage_Filter extends Engine_Form
{

  public function init()
  {
    $this
      ->clearDecorators()
      ->addDecorator('FormElements')
      ->addDecorator('Form')
      ->addDecorator('HtmlTag', array('tag' => 'div', 'class' => 'search'))
      ->addDecorator('HtmlTag2', array('tag' => 'div', 'class' => 'clear'))
    ;

    $this
      ->setAttribs(array(
        'id' => 'filter_form',
        'class' => 'global_form_box',
      ))
      ->setMethod('GET')
    ;

    // Element: query
    $this->addElement('Text', 'title', array(
      'label' => 'Title',
      'decorators' => array(
        'ViewHelper',
        array('Label', array('tag' => null, 'placement' => 'PREPEND')),
        array('HtmlTag', array('tag' => 'div')),
      ),
    ));

    $this->addElement('Text', 'ownerName', array(
      'label' => 'Owner Name',
      'decorators' => array(
        'ViewHelper',
        array('Label', array('tag' => null, 'placement' => 'PREPEND')),
        array('HtmlTag', array('tag' => 'div')),
      ),
    ));

    $labelTable = Engine_Api::_()->getDbtable('labels', 'sitemusic');
    $labelType = $labelTable->getCategoriesAssoc();
    $labelOption = array("all" => "All");
    if( !empty($labelType) ) {
      $labelOption = $labelOption + $labelType;
    }
    $this->addElement('Select', 'labelType', array(
      'label' => 'Label',
      'multiOptions' => $labelOption,
      'decorators' => array(
        'ViewHelper',
        array('Label', array('tag' => null, 'placement' => 'PREPEND')),
        array('HtmlTag', array('tag' => 'div')),
      ),
    ));

    $this->addElement('Text', 'item_title', array(
      'decorators' => array(array('ViewScript', array(
            'viewScript' => '/application/modules/Sitemusic/views/scripts/auto-suggest/artist.tpl')))
    ));

    $this->addElement('text', 'artist_id', array());

    $songCategoryTable = Engine_Api::_()->getDbtable('songcategories', 'sitemusic');
    $genreType = $songCategoryTable->getCategoriesAssoc();
    if( !empty($genreType) ) {
      $subType = $songCategoryTable->getSubCategoriesAssoc($genreType);
    }
    $genreOption = array("all" => "All");
    if( !empty($subType) ) {
      $genreOption = array_merge($genreOption, $subType);
      $this->addElement('Select', 'genreId', array(
        'label' => 'Genre',
        'multiOptions' => $genreOption,
        'decorators' => array(
          'ViewHelper',
          array('Label', array('tag' => null, 'placement' => 'PREPEND')),
          array('HtmlTag', array('tag' => 'div')),
        ),
      ));
    }

    $albumCategoryTable = Engine_Api::_()->getDbtable('albumcategories', 'sitemusic');
    $albumType = $albumCategoryTable->getCategoriesAssoc();
    $albumOption = array("all" => "All");
    if( !empty($albumType) ) {
      $albumOption = $albumOption + $albumType;
    }
    $this->addElement('Select', 'albumType', array(
      'label' => 'Category',
      'multiOptions' => $albumOption,
      'decorators' => array(
        'ViewHelper',
        array('Label', array('tag' => null, 'placement' => 'PREPEND')),
        array('HtmlTag', array('tag' => 'div')),
      ),
    ));

    $integratedModules = Engine_Api::_()->getDbtable('modules', 'sitemusic')->getIntegratedModulesArray();
    if( count($integratedModules) > 1 ) {
      $this->addElement('Select', 'parent_type', array(
        'label' => 'Others Module',
        'multiOptions' => $integratedModules,
        'decorators' => array(
          'ViewHelper',
          array('Label', array('tag' => null, 'placement' => 'PREPEND')),
          array('HtmlTag', array('tag' => 'div')),
        ),
      ));
    }

    $creationOptions = array(
      'anytime' => 'Anytime',
      'last week' => 'Last week',
      'last month' => 'Last month',
      'last 6 month' => 'Last 6 months',
      'last 12 month' => 'Last 12 months'
    );
    $this->addElement('Select', 'creationDate', array(
      'label' => 'Creation Time',
      'multiOptions' => $creationOptions,
      'decorators' => array(
        'ViewHelper',
        array('Label', array('tag' => null, 'placement' => 'PREPEND')),
        array('HtmlTag', array('tag' => 'div')),
      ),
    ));

    $this->addElement('Hidden', 'order', array(
      'order' => 10001,
    ));

    $this->addElement('Hidden', 'order_direction', array(
      'order' => 10002,
    ));
    // Element: execute
    $this->addElement('Button', 'execute', array(
      'label' => 'Search',
      'type' => 'submit',
      'decorators' => array(
        'ViewHelper',
        array('HtmlTag', array('tag' => 'div', 'class' => 'buttons')),
        array('HtmlTag2', array('tag' => 'div')),
      ),
    ));
  }

}
