<?php

/**
 * SocialEngine
 *
 * @category   Application_Extensions
 * @package    Sitemusic
 * @copyright  Copyright 2017-2022 BigStep Technologies Pvt. Ltd.
 * @license    http://www.socialengineaddons.com/license/
 * @version    $Id: Level.php 2017-03-27 9:40:21Z SocialEngineAddOns $
 * @author     SocialEngineAddOns
 */
class Sitemusic_Form_Admin_Settings_Level extends Authorization_Form_Admin_Level_Abstract
{

  public function init()
  {
    parent::init();

    // My stuff
    $this
      ->setTitle('Member Level Settings')
      ->setDescription('SITEMUSIC_FORM_ADMIN_LEVEL_DESCRIPTION');

    // Element: view
    $this->addElement('Radio', 'album_view', array(
      'label' => 'Allow Viewing of Music Albums?',
      'description' => 'SITEMUSIC_FORM_ADMIN_LEVEL_ALBUMVIEW_DESCRIPTION',
      'multiOptions' => array(
        2 => 'Yes, allow viewing of all album, even private ones.',
        1 => 'Yes, allow viewing of album.',
        0 => 'No, do not allow album to be viewed.',
      ),
      'value' => ( $this->isModerator() ? 2 : 1 ),
    ));
    if( !$this->isModerator() ) {
      unset($this->album_view->options[2]);
    }
    $isPlaylistEnable = Engine_Api::_()->getApi('settings', 'core')->getSetting('sitemusic.enable.playlist', 1);
    if( $isPlaylistEnable ) {
      $this->addElement('Radio', 'playlist_view', array(
        'label' => 'Allow Viewing of Playlists?',
        'description' => 'SITEMUSIC_FORM_ADMIN_LEVEL_VIEW_DESCRIPTION',
        'multiOptions' => array(
          2 => 'Yes, allow viewing of all playlists, even private ones.',
          1 => 'Yes, allow viewing of playlists.',
          0 => 'No, do not allow playlists to be viewed.',
        ),
        'value' => ( $this->isModerator() ? 2 : 1 ),
      ));
      if( !$this->isModerator() ) {
        unset($this->playlist_view->options[2]);
      }
    }

    $isArtistEnable = Engine_Api::_()->getApi('settings', 'core')->getSetting('sitemusic.enable.artist', 1);
    if( $isArtistEnable ) {
      $this->addElement('Radio', 'artist_view', array(
        'label' => 'Allow Viewing of Artists?',
        'description' => 'SITEMUSIC_FORM_ADMIN_LEVEL_ARTISTVIEW_DESCRIPTION',
        'multiOptions' => array(
          2 => 'Yes, allow viewing of all artist, even private ones.',
          1 => 'Yes, allow viewing of artist.',
          0 => 'No, do not allow artist to be viewed.',
        ),
        'value' => ( $this->isModerator() ? 2 : 1 ),
      ));
      if( !$this->isModerator() ) {
        unset($this->artist_view->options[2]);
      }
    }
    if( !$this->isPublic() ) {

      // Element: create
      $this->addElement('Radio', 'album_create', array(
        'label' => 'Allow Music Album Creation?',
        'description' => 'Do you want to allow members to create music albums?',
        'multiOptions' => array(
          1 => 'Yes, allow creation of music albums.',
          0 => 'No, do not allow creation of music albums.',
        ),
        'value' => 1,
      ));

      if( $isPlaylistEnable ) {
        $this->addElement('Radio', 'playlist_create', array(
          'label' => 'Allow Playlist Creation?',
          'description' => 'Do you want to allow members to create playlists?',
          'multiOptions' => array(
            1 => 'Yes, allow creation of playlists.',
            0 => 'No, do not allow creation of playlists.',
          ),
          'value' => 1,
        ));
      }
      // Element: edit
      $this->addElement('Radio', 'album_edit', array(
        'label' => 'Allow Editing of Music Albums?',
        'description' => 'SITEMUSIC_FORM_ADMIN_LEVEL_ALBUMEDIT_DESCRIPTION',
        'multiOptions' => array(
          2 => 'Yes, allow members to edit all Album.',
          1 => 'Yes, allow members to edit their own music albums.',
          0 => 'No, do not allow members to edit their music albums.',
        ),
        'value' => ( $this->isModerator() ? 2 : 1 ),
      ));
      if( !$this->isModerator() ) {
        unset($this->album_edit->options[2]);
      }


      if( $isPlaylistEnable ) {
        $this->addElement('Radio', 'playlist_edit', array(
          'label' => 'Allow Editing of Playlists?',
          'description' => 'SITEMUSIC_FORM_ADMIN_LEVEL_EDIT_DESCRIPTION',
          'multiOptions' => array(
            2 => 'Yes, allow members to edit all playlists.',
            1 => 'Yes, allow members to edit their own playlists.',
            0 => 'No, do not allow members to edit their playlists.',
          ),
          'value' => ( $this->isModerator() ? 2 : 1 ),
        ));
        if( !$this->isModerator() ) {
          unset($this->playlist_edit->options[2]);
        }
      }

      if( $isArtistEnable ) {
        $this->addElement('Radio', 'artist_edit', array(
          'label' => 'Allow Editing of Artists?',
          'description' => 'Do you want to let members to edit the artists added by them?',
          'multiOptions' => array(
            2 => 'Yes, allow members to edit all artists.',
            1 => 'Yes, allow members to edit their own added artists.',
            0 => 'No, do not allow members to edit their own added artists.',
          ),
          'value' => ( $this->isModerator() ? 2 : 1 ),
        ));
        if( !$this->isModerator() ) {
          unset($this->artist_edit->options[2]);
        }
      }
      // Element: delete
      $this->addElement('Radio', 'album_delete', array(
        'label' => 'Allow Deletion of Music Albums?',
        'description' => 'SITEMUSIC_FORM_ADMIN_LEVEL_ALBUMDELETE_DESCRIPTION',
        'multiOptions' => array(
          2 => 'Yes, allow members to delete all album.',
          1 => 'Yes, allow members to delete their own music albums.',
          0 => 'No, do not allow members to delete their music albums.',
        ),
        'value' => ( $this->isModerator() ? 2 : 1 ),
      ));
      if( !$this->isModerator() ) {
        unset($this->album_delete->options[2]);
      }
      if( $isPlaylistEnable ) {
        $this->addElement('Radio', 'playlist_delete', array(
          'label' => 'Allow Deletion of Playlists?',
          'description' => 'SITEMUSIC_FORM_ADMIN_LEVEL_DELETE_DESCRIPTION',
          'multiOptions' => array(
            2 => 'Yes, allow members to delete all playlists.',
            1 => 'Yes, allow members to delete their own playlists.',
            0 => 'No, do not allow members to delete their playlists.',
          ),
          'value' => ( $this->isModerator() ? 2 : 1 ),
        ));
        if( !$this->isModerator() ) {
          unset($this->playlist_delete->options[2]);
        }
      }
      $this->addElement('Radio', 'approved_album', array(
        'label' => 'Music Album Approval Moderation',
        'description' => 'Do you want to automatically approve new music albums created by members of this level?',
        'multiOptions' => array(
          1 => 'Yes, automatically approve.',
          0 => 'No, new music albums require site admin approval before getting visible on website.',
        ),
        'value' => 1,
      ));

      if( $isPlaylistEnable ) {
        // Element: max allowed playlist
        $this->addElement('Text', 'sm_max_playlist', array(
          'label' => 'Maximum Allowed Playlists',
          'description' => 'Enter the maximum number of playlists which member can create. This field must contain an integer between 1 and 999, or 0 for unlimited.',
          'validators' => array(
            array('Int', true),
            new Engine_Validate_AtLeast(0),
          ),
        ));
      }

      // Element: max allowed song in album
      $this->addElement('Text', 'sm_max_albumSong', array(
        'label' => 'Maximum Allowed Songs in a Music Album',
        'description' => 'Enter the maximum number of songs that are allowed to be uploaded in a music album. This field must contain an integer between 1 and 999, or 0 for unlimited.',
        'validators' => array(
          array('Int', true),
          new Engine_Validate_AtLeast(0),
        ),
      ));

      if( $isPlaylistEnable ) {
        // Element: max allowed song in playlist
        $this->addElement('Text', 'sm_max_plSong', array(
          'label' => 'Maximum Allowed Songs in a Playlist',
          'description' => 'Enter the maximum number of songs that are allowed to be added in a playlist. This field must contain an integer between 1 and 999, or 0 for unlimited.',
          'validators' => array(
            array('Int', true),
            new Engine_Validate_AtLeast(0),
          ),
        ));
      }

      // Element: comment
      $this->addElement('Radio', 'album_comment', array(
        'label' => 'Allow Commenting on Music Albums?',
        'description' => 'Do you want to let members of this level to comment on music albums?',
        'multiOptions' => array(
          2 => 'Yes, allow members to comments on all album, including private ones.',
          1 => 'Yes, allow members to comment on music albums.',
          0 => 'No, do not allow members to comment on music albums.',
        ),
        'value' => ( $this->isModerator() ? 2 : 1 ),
      ));
      if( !$this->isModerator() ) {
        unset($this->album_comment->options[2]);
      }

      if( $isPlaylistEnable ) {
        // Element: comment
        $this->addElement('Radio', 'playlist_comment', array(
          'label' => 'Allow Commenting on Playlists?',
          'description' => 'Do you want to let members of this level to comment on playlists?',
          'multiOptions' => array(
            2 => 'Yes, allow members to comments on all playlist, including private ones.',
            1 => 'Yes, allow members to comment on playlists.',
            0 => 'No, do not allow members to comment on playlists.',
          ),
          'value' => ( $this->isModerator() ? 2 : 1 ),
        ));
        if( !$this->isModerator() ) {
          unset($this->playlist_comment->options[2]);
        }
      }

      if( $isArtistEnable ) {
        // Element: comment
        $this->addElement('Radio', 'artist_comment', array(
          'label' => 'Allow Commenting on Artists?',
          'description' => 'Do you want to let members of this level to comment on Artists?',
          'multiOptions' => array(
            2 => 'Yes, allow members to comments on artists, including private ones.',
            1 => 'Yes, allow members to comment on artists.',
            0 => 'No, do not allow members to comment on artists.',
          ),
          'value' => ( $this->isModerator() ? 2 : 1 ),
        ));
      }
      // Element: upload song
      $this->addElement('Radio', 'upload_song', array(
        'label' => "Allow user to upload song in other user’s Album?",
        'description' => "Do you want to let members of this level to upload song in other user's Album?",
        'multiOptions' => array(
          1 => 'Yes, allow members to upload song in album.',
          0 => 'No, do not allow members to upload song in album.',
        ),
        'value' => 1,
      ));

      // checking url upload is enable or not
      $isUrlEnable = Engine_Api::_()->getApi('settings', 'core')->getSetting('sitemusic_url', 1);

      if( $isUrlEnable ) {
        $this->addElement('Radio', 'url', array(
          'label' => "Allow Song Upload via URL",
          'description' => "Do you want to let members of this level to upload songs via external downloadable URL?",
          'multiOptions' => array(
            1 => 'Yes, allow members to upload songs via external downloadable URL.',
            0 => 'No, do not allow members to upload songs via external downloadable URL.',
          ),
          'value' => 1,
        ));
      }

      // setting for redirect page
      $this->addElement('Radio', 'redirect_page', array(
        'label' => "Redirection after Music Album Creation",
        'description' => "Where do you want to redirect members after creating music album and uploading songs in it?",
        'multiOptions' => array(
          'edit-info' => 'Edit Song Info Page (where member can edit meta-information of songs being uploaded)',
          'edit-album' => 'Music Album Dashboard',
          'view' => 'Music Album Profile Page',
          'manage' => 'Manage Music Page (My Music)'
        ),
        'value' => 1,
      ));


      // Element: auth_album_view
      $this->addElement('MultiCheckbox', 'auth_view_album', array(
        'label' => 'Music Album Privacy',
        'description' => 'SITEMUSIC_FORM_ADMIN_LEVEL_AUTHALBUMVIEW_DESCRIPTION',
        'multiOptions' => array(
          'everyone' => 'Everyone',
          'registered' => 'All Registered Members',
          'owner_network' => 'Friends and Networks',
          'owner_member_member' => 'Friends of Friends',
          'owner_member' => 'Friends Only',
          'owner' => 'Just Me'
        ),
        'value' => array('everyone', 'owner_network', 'owner_member_member', 'owner_member', 'owner'),
      ));

      if( $isPlaylistEnable ) {
        // Element: auth_view_pl
        $this->addElement('MultiCheckbox', 'auth_view_pl', array(
          'label' => 'Playlist Privacy',
          'description' => 'SITEMUSIC_FORM_ADMIN_LEVEL_AUTHPLAYLISTVIEW_DESCRIPTION',
          'multiOptions' => array(
            'everyone' => 'Everyone',
            'registered' => 'All Registered Members',
            'owner_network' => 'Friends and Networks',
            'owner_member_member' => 'Friends of Friends',
            'owner_member' => 'Friends Only',
            'owner' => 'Just Me'
          ),
          'value' => array('everyone', 'owner_network', 'owner_member_member', 'owner_member', 'owner'),
        ));
      }

      // Element: auth_coment_albm
      $this->addElement('MultiCheckbox', 'auth_coment_albm', array(
        'label' => 'Music Album Comment Options',
        'description' => 'SITEMUSIC_FORM_ADMIN_LEVEL_ALBUMAUTHCOMMENT_DESCRIPTION',
        'multiOptions' => array(
          'everyone' => 'Everyone',
          'registered' => 'All Registered Members',
          'owner_network' => 'Friends and Networks',
          'owner_member_member' => 'Friends of Friends',
          'owner_member' => 'Friends Only',
          'owner' => 'Just Me'
        ),
        'value' => array('everyone', 'owner_network', 'owner_member_member', 'owner_member', 'owner'),
      ));

      if( $isPlaylistEnable ) {
        // Element: auth_comment
        $this->addElement('MultiCheckbox', 'auth_comment_pl', array(
          'label' => 'Playlist Comment Options',
          'description' => 'SITEMUSIC_FORM_ADMIN_LEVEL_AUTHCOMMENT_DESCRIPTION',
          'multiOptions' => array(
            'everyone' => 'Everyone',
            'registered' => 'All Registered Members',
            'owner_network' => 'Friends and Networks',
            'owner_member_member' => 'Friends of Friends',
            'owner_member' => 'Friends Only',
            'owner' => 'Just Me'
          ),
          'value' => array('everyone', 'owner_network', 'owner_member_member', 'owner_member', 'owner'),
        ));
      }

      // Element: upload song in album privacy
      $this->addElement('MultiCheckbox', 'auth_upload_song', array(
        'label' => 'Upload Songs In Music Album',
        'description' => 'SITEMUSIC_FORM_ADMIN_LEVEL_AUTHDOWNLOAD_DESCRIPTION',
        'multiOptions' => array(
          'registered' => 'All Registered Members',
          'owner_network' => 'Friends and Networks',
          'owner_member_member' => 'Friends of Friends',
          'owner_member' => 'Friends Only',
          'owner' => 'Just Me'
        ),
        'value' => array('everyone', 'owner_network', 'owner_member_member', 'owner_member', 'owner'),
      ));
    }
    $this->addElement('Radio', 'download', array(
      'label' => "Allow  user to download song?",
      'description' => "Do you want to let members of this level download song?",
      'multiOptions' => array(
        1 => 'Yes, allow members to download song.',
        0 => 'No, do not allow members to download song.',
      ),
      'value' => 1,
    ));
    if( !$this->isPublic() ) {
      if( Engine_Api::_()->getApi('settings', 'core')->getSetting('sitemusic_enable_download', 1) ) {
        // Element: album_download privacy
        $this->addElement('MultiCheckbox', 'auth_dload_album', array(
          'label' => 'Songs Download Options',
          'description' => 'SITEMUSIC_FORM_ADMIN_LEVEL_AUTHDOWNLOAD_DESCRIPTION',
          'multiOptions' => array(
            'everyone' => 'Everyone',
            'registered' => 'All Registered Members',
            'owner_network' => 'Friends and Networks',
            'owner_member_member' => 'Friends of Friends',
            'owner_member' => 'Friends Only',
            'owner' => 'Just Me'
          ),
          'value' => array('everyone', 'owner_network', 'owner_member_member', 'owner_member', 'owner'),
        ));
      }
    }
  }

}
