<?php

/**
 * SocialEngine
 *
 * @category   Application_Extensions
 * @package    Sitemusic
 * @copyright  Copyright 2017-2022 BigStep Technologies Pvt. Ltd.
 * @license    http://www.socialengineaddons.com/license/
 * @version    $Id: ArtistGeneral.php 2017-03-27 9:40:21Z SocialEngineAddOns $
 * @author     SocialEngineAddOns
 */
class Sitemusic_Form_Admin_Widget_Browse_Artist extends Core_Form_Admin_Widget_Standard
{

  public function init()
  {
    parent::init();

    $labelTable = Engine_Api::_()->getDbtable('labels', 'sitemusic');
    $labelType = $labelTable->getCategoriesAssoc();
    $labelOption = array("all" => "All");
    if( !empty($labelType) ) {
      $labelOption = $labelOption + $labelType;
      $this->addElement('Select', 'label_category', array(
        'label' => 'Label',
        'multiOptions' => $labelOption,
      ));
    }

    $this->addElement('MultiCheckbox', 'artist_layout_views', array(
      'label' => 'Select the view types for artists.',
      'required' => true,
      'multiOptions' => array(
        "gridZZZview" => "Grid View",
        "thumbnailZZZview" => "Mini List View"
      ),
      'onclick' => 'onLayoutSelect()',
    ));

    $this->addElement('Radio', 'artistDefaultLayout', array(
      'label' => 'Select a default view type for artists.',
      'multiOptions' => array(
        "gridZZZview" => "Grid View",
        "thumbnailZZZview" => "Mini List View"
      ),
      'value' => "gridZZZview",
    ));

    $this->addElement('Text', 'gridViewWidth', array(
      'label' => 'Column Width for Grid View.',
      'value' => '167',
    ));

    $this->addElement('Text', 'gridViewHeight', array(
      'label' => 'Column height for Grid View Image.',
    ));


    $artistOptions = Engine_Api::_()->getApi('core', 'sitemusic')->getArtistOptions();
    $this->addElement('MultiCheckbox', 'showOptions', array(
      'label' => 'Choose the option that you want to be available for the artists in this block.',
      'multiOptions' => $artistOptions
    ));

    $this->addElement('Radio', 'default_sort', array(
      'label' => 'Default ordering in browse artist',
      'multiOptions' => array(
        'creationDate' => 'All artists in descending order of creation',
        'ascendingOrder' => 'All artists in ascending order of creation',
        'alphabetic' => 'All artists in alphabetical order'),
      'value' => 'ascending_order'
    ));

    $this->addElement('Text', 'thumbnailTitleTruncationLimit', array(
      'label' => 'Title Truncation Limit for Mini List View',
      'value' => '100',
      'validators' => array(
        array('Int', true),
        array('GreaterThan', true, array(0))),
    ));

    $this->addElement('Text', 'gridTitleTruncationLimit', array(
      'label' => 'Title Truncation Limit for Grid View',
      'value' => '100',
      'validators' => array(
        array('Int', true),
        array('GreaterThan', true, array(0))),
    ));

//    $this->addElement('Text', 'gridViewHeight', array(
//      'label' => 'Column Height For Grid View.',
//      'value' => '328',
//    ));

    $this->addElement('Radio', 'showViewMore', array(
      'label' => 'Show “View More”',
      'description' => '',
      'multiOptions' => array(
        '1' => 'Yes',
        '0' => 'No'),
      'value' => 1,
    ));


    $this->addElement('Text', 'limit', array(
      'label' => 'Count',
      'description' => '(number of items to show)',
      'value' => 5,
    ));
  }

}
?>
<script>
  en4.core.runonce.add(function () {
    onLayoutSelect();

  });
  function onLayoutSelect()
  {
    if ($('artist_layout_views-gridZZZview').checked) {
      $('artistDefaultLayout-gridZZZview').disabled = false;
    } else {
      $('artistDefaultLayout-gridZZZview').disabled = true;
    }
    if ($('artist_layout_views-thumbnailZZZview').checked) {
      $('artistDefaultLayout-thumbnailZZZview').disabled = false;
    } else {
      $('artistDefaultLayout-thumbnailZZZview').disabled = true;
    }
  }
</script>