<?php

/**
 * SocialEngine
 *
 * @category   Application_Extensions
 * @package    Sitemusic
 * @copyright  Copyright 2017-2022 BigStep Technologies Pvt. Ltd.
 * @license    http://www.socialengineaddons.com/license/
 * @version    $Id: PlaylistGeneral.php 2017-03-27 9:40:21Z SocialEngineAddOns $
 * @author     SocialEngineAddOns
 */
class Sitemusic_Form_Admin_Widget_Browse_Playlist extends Sitemusic_Form_Admin_Widget_Script_Playlist
{

  public function init()
  {
    parent::init();

    $labelTable = Engine_Api::_()->getDbtable('labels', 'sitemusic');
    $labelType = $labelTable->getCategoriesAssoc();
    $labelOption = array("all" => "All");
    if( !empty($labelType) ) {
      $labelOption = $labelOption + $labelType;
      $this->addElement('Select', 'label_category', array(
        'label' => 'Label',
        'multiOptions' => $labelOption,
      ));
    }

    $this->addElement('MultiCheckbox', 'playlist_layout_views', array(
      'label' => 'Select the view types for playlists.',
      'required' => true,
      'multiOptions' => array(
        "listZZZview" => "Player View",
        "cardZZZview" => "Card View",
        "gridZZZview" => "Grid View",
        "thumbnailZZZview" => "Mini List View"
      ),
      'onclick' => 'onLayoutSelect()'
    ));

    $this->addElement('Radio', 'playlistDefaultLayout', array(
      'label' => 'Select a default view type for playlists.',
      'multiOptions' => array(
        "listZZZview" => "Player View",
        "cardZZZview" => "Card View",
        "gridZZZview" => "Grid View",
        "thumbnailZZZview" => "Mini List View"
      ),
      'value' => 'list_view',
    ));

    $coreApi = Engine_Api::_()->getApi('core', 'sitemusic');
    $playlistOptions = $coreApi->getPlaylistOptions();
    $playlistViewOptions = $coreApi->getUserPlaylistViewOptions();
    $this->addElement('MultiCheckbox', 'showOptions', array(
      'label' => 'Choose the option that you want to be available for the playlists in this block.',
      'multiOptions' => $playlistOptions
    ));

    $this->addElement('MultiCheckbox', 'showSongOptions', array(
      'label' => 'Choose the option that you want to be available for the songs displaying in list view/card view of playlists in this block.',
      'multiOptions' => $playlistViewOptions
    ));

    $this->addElement('Text', 'gridViewWidth', array(
      'label' => 'Column width for Grid View.',
      'value' => '167',
    ));

    $this->addElement('Text', 'gridViewHeight', array(
      'label' => 'Column height for Grid View Image.',
    ));

    $this->addElement('Text', 'cardViewWidth', array(
      'label' => 'Column width for Card View.',
      'value' => '371',
    ));

    $this->addElement('Text', 'cardViewHeight', array(
      'label' => 'Column height for Card View.',
      'value' => '402',
    ));

    $this->addElement('Text', 'listTitleTruncationLimit', array(
      'label' => 'Title truncation limit for Player View',
      'value' => '100',
      'validators' => array(
        array('Int', true),
        array('GreaterThan', true, array(0))),
    ));

    $this->addElement('Text', 'cardTitleTruncationLimit', array(
      'label' => 'Title truncation limit for Card View',
      'value' => '100',
      'validators' => array(
        array('Int', true),
        array('GreaterThan', true, array(0))),
    ));

    $this->addElement('Text', 'gridTitleTruncationLimit', array(
      'label' => 'Title truncation limit for Grid View',
      'value' => '100',
      'validators' => array(
        array('Int', true),
        array('GreaterThan', true, array(0))),
    ));

    $this->addElement('Text', 'thumbnailTitleTruncationLimit', array(
      'label' => 'Title truncation limit for Mini List View',
      'value' => '100',
      'validators' => array(
        array('Int', true),
        array('GreaterThan', true, array(0))),
    ));



    $this->addElement('Radio', 'default_sort', array(
      'label' => 'Default ordering in browse playlist',
      'multiOptions' => array(
        'creationDate' => 'All playlists in descending order of creation',
        'ascendingOrder' => 'All playlists in ascending order of creation',
        'alphabetic' => 'All playlists in alphabetical order'),
      'value' => 'creationDate'
    ));

    $this->addElement('Radio', 'showViewMore', array(
      'label' => 'Show “View More”',
      'description' => '',
      'multiOptions' => array(
        '1' => 'Yes',
        '0' => 'No'),
      'value' => 1,
    ));


    $this->addElement('Text', 'limit', array(
      'label' => 'Count',
      'description' => '(number of items to show)',
      'value' => 5,
    ));
  }

}
?>

<script>
  en4.core.runonce.add(function () {
    window.setTimeout(onLayoutSelect, 1000);
  });

  function onLayoutSelect()
  {
    var listView = $('playlist_layout_views-listZZZview');
    var cardView = $('playlist_layout_views-cardZZZview');
    var thumbnailView = $('playlist_layout_views-thumbnailZZZview');

    if ($('playlist_layout_views-listZZZview').checked) {
      $('playlistDefaultLayout-listZZZview').disabled = false;
    } else {
      $('playlistDefaultLayout-listZZZview').disabled = true;
    }
    if ($('playlist_layout_views-gridZZZview').checked) {
      $('playlistDefaultLayout-gridZZZview').disabled = false;
    } else {
      $('playlistDefaultLayout-gridZZZview').disabled = true;
    }
    if ($('playlist_layout_views-cardZZZview').checked) {
      $('playlistDefaultLayout-cardZZZview').disabled = false;
    } else {
      $('playlistDefaultLayout-cardZZZview').disabled = true;
    }
    if ($('playlist_layout_views-thumbnailZZZview').checked) {
      $('playlistDefaultLayout-thumbnailZZZview').disabled = false;
    } else {
      $('playlistDefaultLayout-thumbnailZZZview').disabled = true;
    }

    if ($('playlist_layout_views-listZZZview').checked || $('playlist_layout_views-cardZZZview').checked) {
      $('showSongOptions-wrapper').style.display = 'block';
    } else {
      $('showSongOptions-wrapper').style.display = 'none';
    }
  }
</script>