<?php

/**
 * SocialEngine
 *
 * @category   Application_Extensions
 * @package    Sitemusic
 * @copyright  Copyright 2017-2022 BigStep Technologies Pvt. Ltd.
 * @license    http://www.socialengineaddons.com/license/
 * @version    $Id: SongGeneral.php 2017-03-27 9:40:21Z SocialEngineAddOns $
 * @author     SocialEngineAddOns
 */
class Sitemusic_Form_Admin_Widget_Browse_Song extends Sitemusic_Form_Admin_Widget_Script_Song
{

  public function init()
  {
    parent::init();

    $labelTable = Engine_Api::_()->getDbtable('labels', 'sitemusic');
    $labelType = $labelTable->getCategoriesAssoc();
    $labelOption = array("all" => "All");
    if( !empty($labelType) ) {
      $labelOption = $labelOption + $labelType;
      $this->addElement('Select', 'label_category', array(
        'label' => 'Label',
        'multiOptions' => $labelOption,
      ));
    }

    if( count($genreType) > 0 ) {
      $this->addElement('Select', 'genre_id', array(
        'label' => 'Genre',
        'multiOptions' => $genreOption,
      ));
    }

    $songCategoryTable = Engine_Api::_()->getDbtable('songcategories', 'sitemusic');
    $genreType = $songCategoryTable->getCategoriesAssoc();
    if( !empty($genreType) ) {
      $subType = $songCategoryTable->getSubCategoriesAssoc($genreType);
    }
    $genreOption = array("All" => "All");
    if( !empty($subType) ) {
      $genreOption = $genreOption + $subType;
    }

    $this->addElement('MultiCheckbox', 'song_layout_views', array(
      'label' => 'Select the view types for songs.',
      'required' => true,
      'multiOptions' => array(
        "listZZZview" => "List View",
        "gridZZZview" => "Grid View",
        "thumbnailZZZview" => "Mini List View",
      ),
      'onclick' => 'onLayoutSelect()'
    ));

    $this->addElement('Radio', 'songDefaultLayout', array(
      'label' => 'Select a default view type for songs.',
      'multiOptions' => array(
        "listZZZview" => "List View",
        "cardZZZview" => "Card View",
        "thumbnailZZZview" => "Mini List View",
      )
    ));

    $this->addElement('Text', 'gridViewWidth', array(
      'label' => 'Column width for Grid View.',
      'value' => '167',
    ));

    $this->addElement('Text', 'gridViewHeight', array(
      'label' => 'Column height for Grid View Image.',
    ));

    $songOptions = Engine_Api::_()->getApi('core', 'sitemusic')->getSongOptions();
    $this->addElement('MultiCheckbox', 'showOptions', array(
      'label' => 'Choose the option that you want to be available for the songs in this block.',
      'multiOptions' => $songOptions
    ));

    $this->addElement('Text', 'listTitleTruncationLimit', array(
      'label' => 'Title truncation limit for List View',
      'value' => '100',
      'validators' => array(
        array('Int', true),
        array('GreaterThan', true, array(0))),
    ));

    $this->addElement('Text', 'gridTitleTruncationLimit', array(
      'label' => 'Title truncation limit for Grid View',
      'value' => '100',
      'validators' => array(
        array('Int', true),
        array('GreaterThan', true, array(0))),
    ));

    $this->addElement('Text', 'thumbnailTitleTruncationLimit', array(
      'label' => 'Title truncation limit for Mini List View',
      'value' => '100',
      'validators' => array(
        array('Int', true),
        array('GreaterThan', true, array(0))),
    ));

    $this->addElement('Radio', 'default_sort', array(
      'label' => 'Default ordering in browse songs',
      'multiOptions' => array(
        'creationDate' => 'All songs in descending order of upload time',
        'ascendingOrder' => 'All songs in asceding order of upload time',
        'alphabetic' => 'All songs in alphabetic order'),
      'value' => 'creationDate'
    ));

    $this->addElement('Radio', 'showViewMore', array(
      'label' => 'Show “View More”',
      'description' => '',
      'multiOptions' => array(
        '1' => 'Yes',
        '0' => 'No'),
      'value' => 1,
    ));


    $this->addElement('Text', 'limit', array(
      'label' => 'Count',
      'description' => '(number of items to show)',
      'value' => 5,
    ));
  }

}
?>
<script>
  en4.core.runonce.add(function () {
    window.setTimeout(onLayoutSelect, 1000);
  });

  function onLayoutSelect()
  {
    var listView = $('song_layout_views-listZZZview');
    var gridView = $('song_layout_views-gridZZZview');
    var thumbnailView = $('song_layout_views-thumbnailZZZview');

    if ($('song_layout_views-listZZZview').checked) {
      $('songDefaultLayout-listZZZview').disabled = false;
    } else {
      $('songDefaultLayout-listZZZview').disabled = true;
    }
    if ($('song_layout_views-gridZZZview').checked) {
      $('songDefaultLayout-gridZZZview').disabled = false;
    } else {
      $('songDefaultLayout-gridZZZview').disabled = true;
    }
    if ($('song_layout_views-thumbnailZZZview').checked) {
      $('songDefaultLayout-thumbnailZZZview').disabled = false;
    } else {
      $('songDefaultLayout-thumbnailZZZview').disabled = true;
    }

    if (!(listView.checked) && !(gridView.checked) && !(thumbnailView.checked)) {
      $('showOptions-songLike').parentElement.style.display = 'block';
      $('showOptions-songShare').parentElement.style.display = 'block';
    }

    if (listView.checked) {
      $('showOptions-songLike').parentElement.style.display = 'block';
      $('showOptions-songShare').parentElement.style.display = 'block';
    }

    if (thumbnailView.checked && !(listView.checked)) {
      $('showOptions-songLike').parentElement.style.display = 'none';
      $('showOptions-songShare').parentElement.style.display = 'none';
    }

    if (gridView.checked && !(listView.checked)) {
      $('showOptions-songLike').parentElement.style.display = 'block';
      $('showOptions-songShare').parentElement.style.display = 'none';
    }
  }
</script>