<?php

/**
 * SocialEngine
 *
 * @category   Application_Extensions
 * @package    Sitemusic
 * @copyright  Copyright 2017-2022 BigStep Technologies Pvt. Ltd.
 * @license    http://www.socialengineaddons.com/license/
 * @version    $Id: PlaylistGeneral.php 2017-03-27 9:40:21Z SocialEngineAddOns $
 * @author     SocialEngineAddOns
 */
class Sitemusic_Form_Admin_Widget_PlaylistGeneral extends Sitemusic_Form_Admin_Widget_Script_Playlist
{

  public function init()
  {
    parent::init();

    $labelTable = Engine_Api::_()->getDbtable('labels', 'sitemusic');
    $labelType = $labelTable->getCategoriesAssoc();
    $labelOption = array("all" => "All");
    if( !empty($labelType) ) {
      $labelOption = $labelOption + $labelType;
      $this->addElement('Select', 'label_category', array(
        'label' => 'Labels',
        'multiOptions' => $labelOption,
      ));
    }

    $this->addElement('MultiCheckbox', 'playlist_layout_views', array(
      'label' => 'Select the view types for playlists.',
      'required' => true,
      'multiOptions' => array(
        "listZZZview" => "Player View",
        "cardZZZview" => "Card View",
        "gridZZZview" => "Grid View",
        "thumbnailZZZview" => "Mini List View"
      ),
      'onclick' => 'onLayoutSelect()',
    ));

    $this->addElement('Radio', 'playlistDefaultLayout', array(
      'label' => 'Select a default view type for playlists.',
      'multiOptions' => array(
        "listZZZview" => "Player View",
        "cardZZZview" => "Card View",
        "gridZZZview" => "Grid View",
        "thumbnailZZZview" => "Mini List View"
      )
    ));

    $this->addElement('Text', 'gridViewWidth', array(
      'label' => 'Column width For Grid View.',
      'value' => '180',
    ));

    $this->addElement('Text', 'gridViewHeight', array(
      'label' => 'Column height for Grid View Image.',
    ));

    $this->addElement('Text', 'cardViewWidth', array(
      'label' => 'Column width for Card View.',
      'value' => '371',
    ));

    $this->addElement('Text', 'cardViewHeight', array(
      'label' => 'Column height For Card View.',
      'value' => '402',
    ));

    $coreApi = Engine_Api::_()->getApi('core', 'sitemusic');
    $playlistOptions = $coreApi->getPlaylistOptions();
    $playlistViewOptions = $coreApi->getUserPlaylistViewOptions();
    $this->addElement('MultiCheckbox', 'showOptions', array(
      'label' => 'Choose the option that you want to be available for the playlists in this block.',
      'multiOptions' => $playlistOptions
    ));

    $this->addElement('MultiCheckbox', 'showSongOptions', array(
      'label' => 'Choose the option that you want to be available for the songs displaying in list view/card view of playlists in this block.',
      'multiOptions' => $playlistViewOptions
    ));

    $this->addElement('MultiCheckbox', 'ajaxTabs', array(
      'label' => 'Select the tabs that you want to be available in this block.',
      'required' => true,
      'multiOptions' => array(
        'Trending' => 'Trending',
        'Latest' => 'Latest',
        'MostZZZLiked' => 'Most Liked',
        'MostZZZPopular' => 'Most Popular',
        'MostZZZFavourite' => 'Most Favourite',
        'MostZZZRated' => 'Most Rated'
      ),
      'onclick' => 'onMultiCheckBoxSelect()',
      'value' => array('Trending', 'Latest', 'Most_Liked', 'Most_Popular')
    ));

    $this->addElement('Select', 'trendingType', array(
      'label' => 'Trending Criteria',
      'multiOptions' => array(
        "like" => "Like",
        "comment" => "Comment",
      ),
      'value' => 'like',
    ));

    $this->addElement('Select', 'trendingSort', array(
      'label' => 'Trending Duration',
      'multiOptions' => array(
        "last_week" => "Last Week",
        "last_twoweek" => "Last Two Weeks",
        "last_month" => "Last Month",
      ),
      'value' => 'last_week',
    ));

    $this->addElement('Select', 'latestSort', array(
      'label' => 'Latest By',
      'multiOptions' => array(
        "creation_date" => "Creation Date",
        "modified_date" => "Modified Date",
      ),
      'value' => 'creation_date',
    ));

    $this->addElement('Select', 'popularType', array(
      'label' => 'Popular Criteria',
      'multiOptions' => array(
        "like_count" => "Like Count",
        "comment_count" => "Comment Count",
      ),
      'value' => 'like_count',
    ));

    $this->addElement('Text', 'listTitleTruncationLimit', array(
      'label' => 'Title Truncation Limit for Player View',
      'value' => '100',
      'validators' => array(
        array('Int', true),
        array('GreaterThan', true, array(0))),
    ));

    $this->addElement('Text', 'cardTitleTruncationLimit', array(
      'label' => 'Title Truncation Limit for Card View',
      'value' => '100',
      'validators' => array(
        array('Int', true),
        array('GreaterThan', true, array(0))),
    ));

    $this->addElement('Text', 'gridTitleTruncationLimit', array(
      'label' => 'Title Truncation Limit for Grid View',
      'value' => '100',
      'validators' => array(
        array('Int', true),
        array('GreaterThan', true, array(0))),
    ));

    $this->addElement('Text', 'thumbnailTitleTruncationLimit', array(
      'label' => 'Title Truncation Limit for Mini List View',
      'value' => '100',
      'validators' => array(
        array('Int', true),
        array('GreaterThan', true, array(0))),
    ));

    $this->addElement('Text', 'Trending', array(
      'label' => 'Trending Tab (order)',
      'value' => 1,
    ));

    $this->addElement('Text', 'Latest', array(
      'label' => 'Latest Tab (order)',
      'value' => 2,
    ));

    $this->addElement('Text', 'MostZZZPopular', array(
      'label' => 'Most Popular Tab (order)',
      'value' => 3,
    ));

    $this->addElement('Text', 'MostZZZLiked', array(
      'label' => 'Most Liked Tab (order)',
      'value' => 4,
    ));

    $this->addElement('Text', 'MostZZZFavourite', array(
      'label' => 'Most Favourite Tab (order)',
      'value' => 5,
    ));

    $this->addElement('Text', 'MostZZZRated', array(
      'label' => 'Most Rated Tab (order)',
      'value' => 6,
    ));

    $this->addElement('Radio', 'Show “View More”', array(
      'label' => 'Show view more',
      'description' => '',
      'multiOptions' => array(
        '1' => 'Yes',
        '0' => 'No'),
      'value' => 1,
    ));


    $this->addElement('Text', 'limit', array(
      'label' => 'Count',
      'description' => '(number of items to show)',
      'value' => 5,
    ));
  }

}
?>
<script type="text/javascript">

  en4.core.runonce.add(function () {
    onMultiCheckBoxSelect();
    onLayoutSelect();

  });
  function onMultiCheckBoxSelect()
  {
    if ($('ajaxTabs-Trending').checked)
    {
      $('trendingType-wrapper').style.display = 'block';
      $('trendingSort-wrapper').style.display = 'block';
    } else {
      $('trendingType-wrapper').style.display = 'none';
      $('trendingSort-wrapper').style.display = 'none';
    }

    if ($('ajaxTabs-Latest').checked)
    {
      $('latestSort-wrapper').style.display = 'block';
    } else {
      $('latestSort-wrapper').style.display = 'none';
    }

    if ($('ajaxTabs-MostZZZPopular').checked)
    {
      $('popularType-wrapper').style.display = 'block';
    } else {
      $('popularType-wrapper').style.display = 'none';
    }
  }


  function onLayoutSelect()
  {
    if ($('playlist_layout_views-listZZZview').checked) {
      $('playlistDefaultLayout-listZZZview').disabled = false;
    } else {
      $('playlistDefaultLayout-listZZZview').disabled = true;
    }
    if ($('playlist_layout_views-gridZZZview').checked) {
      $('playlistDefaultLayout-gridZZZview').disabled = false;
    } else {
      $('playlistDefaultLayout-gridZZZview').disabled = true;
    }
    if ($('playlist_layout_views-cardZZZview').checked) {
      $('playlistDefaultLayout-cardZZZview').disabled = false;
    } else {
      $('playlistDefaultLayout-cardZZZview').disabled = true;
    }
    if ($('playlist_layout_views-thumbnailZZZview').checked) {
      $('playlistDefaultLayout-thumbnailZZZview').disabled = false;
    } else {
      $('playlistDefaultLayout-thumbnailZZZview').disabled = true;
    }

    if ($('playlist_layout_views-listZZZview').checked || $('playlist_layout_views-cardZZZview').checked) {
      $('showSongOptions-wrapper').style.display = 'block';
    } else {
      $('showSongOptions-wrapper').style.display = 'none';
    }
  }

</script>