<?php

/**
 * SocialEngine
 *
 * @category   Application_Extensions
 * @package    Sitemusic
 * @copyright  Copyright 2017-2022 BigStep Technologies Pvt. Ltd.
 * @license    http://www.socialengineaddons.com/license/
 * @version    $Id: Album.php 2017-03-27 9:40:21Z SocialEngineAddOns $
 * @author     SocialEngineAddOns
 */
class Sitemusic_Form_Admin_Widget_User_Album extends Sitemusic_Form_Admin_Widget_Script_Album
{

  public function init()
  {
    parent::init();

    $this->addElement('MultiCheckbox', 'album_layout_views', array(
      'label' => 'Choose the view types for album that you want to be available for the widget.',
      'required' => true,
      'multiOptions' => array(
        "listZZZview" => "Player View",
        "gridZZZview" => "Grid View",
        "cardZZZview" => "Card View",
        "thumbnailZZZview" => "Thumbnail View",
      ),
      'onclick' => 'onLayoutSelect()'
    ));

    $this->addElement('Radio', 'albumDefaultLayout', array(
      'label' => 'Choose the default view types for album that you want to be available for the widget.',
      'multiOptions' => array(
        "listZZZview" => "Player View",
        "gridZZZview" => "Grid View",
        "cardZZZview" => "Card View",
        "thumbnailZZZview" => "Thumbnail View",
      )
    ));

    $coreApi = Engine_Api::_()->getApi('core', 'sitemusic');
    $albumOptions = $coreApi->getAlbumOptions();
    $albumViewOptions = $coreApi->getAlbumListViewOptions();

    $this->addElement('MultiCheckbox', 'showOptions', array(
      'label' => 'Choose the option that you want to be available for the block.',
      'multiOptions' => $albumOptions
    ));

    $this->addElement('MultiCheckbox', 'showSongOptions', array(
      'label' => 'Choose the option that you want to be available for the songs displaying in list view/card view of music albums in this block.',
      'multiOptions' => $albumViewOptions
    ));

    $this->addElement('Text', 'gridViewWidth', array(
      'label' => 'Column width For Grid View.',
      'value' => '180',
    ));

    $this->addElement('Text', 'gridViewHeight', array(
      'label' => 'Column height for Grid View Image.',
    ));

//    $this->addElement('Text', 'gridViewHeight', array(
//      'label' => 'Column Height For Grid View.',
//      'value' => '328',
//    ));

    $this->addElement('Text', 'cardViewWidth', array(
      'label' => 'Column width for Card View.',
      'value' => '279',
    ));

//    $this->addElement('Text', 'cardViewHeight', array(
//      'label' => 'Column Height For Card View.',
//      'value' => '328',
//    ));

    $this->addElement('Text', 'titleTruncationLimit', array(
      'label' => 'Title Truncation Limit',
      'value' => '100',
      'validators' => array(
        array('Int', true),
        array('GreaterThan', true, array(0))),
    ));

    $this->addElement('Text', 'gridTitleTruncationLimit', array(
      'label' => 'Title truncation limit for Grid View.',
      'value' => '100',
      'validators' => array(
        array('Int', true),
        array('GreaterThan', true, array(0))),
    ));

    $this->addElement('Radio', 'default_sort', array(
      'label' => 'Default ordering of music album',
      'multiOptions' => array(
        'creationDate' => 'All music albums in descending order of creation',
        'ascendingOrder' => 'All music album in ascending order of creation',
        'alphabetic' => 'All music album in alphabetical order'),
      'value' => 'creationDate'
    ));

    $this->addElement('Radio', 'showViewMore', array(
      'label' => 'Show “View More”',
      'description' => '',
      'multiOptions' => array(
        '1' => 'Yes',
        '0' => 'No'),
      'value' => 1,
    ));


    $this->addElement('Text', 'limit', array(
      'label' => 'Count',
      'description' => '(number of items to show)',
      'value' => 5,
    ));
  }

}
?>
<script>
  en4.core.runonce.add(function () {
    window.setTimeout(onLayoutSelect, 1000);
  });

  function onLayoutSelect()
  {
    var listView = $('album_layout_views-listZZZview');
    var gridView = $('album_layout_views-gridZZZview');
    var cardView = $('album_layout_views-cardZZZview');
    var thumbnailView = $('album_layout_views-thumbnailZZZview');


    if ($('album_layout_views-listZZZview').checked) {
      $('albumDefaultLayout-listZZZview').disabled = false;
    } else {
      $('albumDefaultLayout-listZZZview').disabled = true;
    }
    if ($('album_layout_views-gridZZZview').checked) {
      $('albumDefaultLayout-gridZZZview').disabled = false;
    } else {
      $('albumDefaultLayout-gridZZZview').disabled = true;
    }
    if ($('album_layout_views-cardZZZview').checked) {
      $('albumDefaultLayout-cardZZZview').disabled = false;
    } else {
      $('albumDefaultLayout-cardZZZview').disabled = true;
    }
    if ($('album_layout_views-thumbnailZZZview').checked) {
      $('albumDefaultLayout-thumbnailZZZview').disabled = false;
    } else {
      $('albumDefaultLayout-thumbnailZZZview').disabled = true;
    }

    if (thumbnailView.checked || cardView.checked) {
      if ($('showOptions-songDownload')) {
        $('showOptions-songDownload').parentElement.style.display = 'block';
      }
    }

    if ($('album_layout_views-listZZZview').checked || $('album_layout_views-cardZZZview').checked) {
      $('showSongOptions-wrapper').style.display = 'block';
    } else {
      $('showSongOptions-wrapper').style.display = 'none';
    }
  }
</script>