<?php

/**
 * SocialEngine
 *
 * @category   Application_Extensions
 * @package    Sitemusic
 * @copyright  Copyright 2017-2022 BigStep Technologies Pvt. Ltd.
 * @license    http://www.socialengineaddons.com/license/
 * @version    $Id: Edit.php 2017-03-27 9:40:21Z SocialEngineAddOns $
 * @author     SocialEngineAddOns
 */
class Sitemusic_Form_Edit extends Sitemusic_Form_Create
{

  public function init()
  {
    // Init form
    parent::init();
    $this
      ->setDescription('')
      ->setAttrib('id', 'form-upload-sitemusic')
      ->setAttrib('name', 'playlist_edit')
      ->setAttrib('enctype', 'multipart/form-data')
      ->setAction(Zend_Controller_Front::getInstance()->getRouter()->assemble(array()))
    ;
    $playlist = $this->_attribs['playlist'];
    // Pre-fill form values
    $this->addElement('Hidden', 'playlist_id', array(
      'order' => 4
    ));
    $songs = $playlist->getSongs();
    $songsData = array();
    $i = 0;
    foreach( $songs as $song ) {
      $songsData = array('id' => $song->getIdentity(), 'name' => $song->getTitle());
      $populateFiles[$i] = $songsData;
      $i++;
    }

    $data = array(
      'fileIdsElement' => 'fancyuploadfileids',
      'populateFiles' => $populateFiles,
    );

    $uploadUrl = Zend_Controller_Front::getInstance()->getRouter()->assemble(array()) . '?ul=1';
    $deleteUrl = $this->getView()->url(array('module' => 'sitemusic', 'controller' => 'songs', 'action' => 'delete', 'playlist_id' => $playlist->getIdentity()), 'sitemusic_general');
    $this->addElement('SeaoFancyUpload', 'file', array(
      'url' => $uploadUrl,
      'fileType' => 'audio',
      'deleteUrl' => $deleteUrl,
      'data' => $data
    ));

    // Override submit button
    $this->removeElement('submit');
    $this->addElement('Button', 'save', array(
      'label' => 'Save Changes',
      'type' => 'submit',
    ));
  }

  public function populateWithObject($playlist)
  {
    $this->setTitle('Edit Album');
    if( $this->getElement('album_option') ) {
    $this->removeElement('album_option');
    }
    $this->removeElement('published');

    foreach( array(
    'playlist_id' => $playlist->getIdentity(),
    'title' => $playlist->getTitle(),
    'description' => $playlist->description,
    'search' => $playlist->search,
    'category_id' => $playlist->category_id,
    ) as $key => $value ) {
      $this->getElement($key)->setValue($value);
    }

    // AUTHORIZATIONS
    $auth = Engine_Api::_()->authorization()->context;


    $authViewAlbum = $this->getElement('auth_view_album');
    if( $authViewAlbum ) {
      $roles = array_keys($this->_roles);
      $lowestViewer = array_pop($roles);
      foreach( array_reverse(array_keys($this->_roles)) as $role ) {
        if( $auth->isAllowed($playlist, $role, 'view') ) {
          $lowestViewer = $role;
        }
      }

      $authViewAlbum->setValue($lowestViewer);
    }

    $authCommentAlbum = $this->getElement('auth_coment_albm');
    if( $authCommentAlbum ) {
      $roles = array_keys($this->_roles);
      $lowestCommenter = array_pop($roles);
      foreach( array_reverse(array_keys($this->_roles)) as $role ) {
        if( $auth->isAllowed($playlist, $role, 'comment') ) {
          $lowestCommenter = $role;
        }
      }
      $authCommentAlbum->setValue($lowestCommenter);
    }

    $authDownload = $this->getElement('auth_download');
    if( $authDownload ) {
      $roles = array_keys($this->_roles);
      $lowestDownloader = array_pop($roles);
      foreach( array_reverse(array_keys($this->_roles)) as $role ) {
        if( $auth->isAllowed($playlist, $role, 'download') ) {
          $lowestDownloader = $role;
        }
      }
      $authDownload->setValue($lowestCommenter);
    }

    $authUploadSong = $this->getElement('auth_upload_song');
    if( $authUploadSong ) {
      $roles = array_keys($this->_roles);
      $lowestUploader = array_pop($roles);
      foreach( array_reverse(array_keys($this->_roles)) as $role ) {
        if( $auth->isAllowed($playlist, $role, 'upload_song') ) {
          $lowestUploader = $role;
        }
      }
      $authUploadSong->setValue($lowestUploader);
    }
  }

  public function saveValues()
  {
    $values = parent::saveValues();
    $playlist = $this->_attribs['playlist'];
    $songIds = $values['songIds'];
    $values = $this->getValues();
    if( $playlist && $playlist->isEditable() ) {
      $playlist->title = $values['title'];
      $playlist->description = $values['description'];
      $playlist->search = $values['search'];
      $playlist->view_privacy = $values['auth_view_album'];
      $playlist->category_id = $values['category_id'];
      $playlist->save();

      // Authorizations
      $auth = Engine_Api::_()->authorization()->context;
      $prev_allow_comment = $prev_allow_view = $prev_allow_upload =$prev_allow_download = false;
      foreach( $this->_roles as $role => $role_label ) {
        // allow viewers
        if( $values['auth_view_album'] == $role || $prev_allow_view ) {
          $auth->setAllowed($playlist, $role, 'view', true);
          $prev_allow_view = true;
        } else
          $auth->setAllowed($playlist, $role, 'view', 0);

        // allow comments
        if( $values['auth_coment_albm'] == $role || $prev_allow_comment ) {
          $auth->setAllowed($playlist, $role, 'comment', true);
          $prev_allow_comment = true;
        } else
          $auth->setAllowed($playlist, $role, 'comment', 0);

        if( isset($values['auth_download']) ) {
          // allow download
          if( $values['auth_download'] == $role || $prev_allow_download ) {
            $auth->setAllowed($playlist, $role, 'download', true);
            $prev_allow_download = true;
          } else
            $auth->setAllowed($playlist, $role, 'download', 0);
        }
        // allow upload song
        if( $values['auth_upload_song'] == $role || $prev_allow_upload ) {
          $auth->setAllowed($playlist, $role, 'upload_song', true);
          $prev_allow_upload = true;
        } else
          $auth->setAllowed($playlist, $role, 'upload_song', 0);
      }

      // Rebuild privacy
      $actionTable = Engine_Api::_()->getDbtable('actions', 'activity');
      foreach( $actionTable->getActionsByObject($playlist) as $action ) {
        $actionTable->resetActivityBindings($action);
      }
      $values = array();
      $values['songIds'] = $songIds;
      $values['playlist'] = $playlist;
      return $values;
    } else {
      return false;
    }
  }

}
