<?php

/**
 * SocialEngine
 *
 * @category   Application_Extensions
 * @package    Sitemusic
 * @copyright  Copyright 2017-2022 BigStep Technologies Pvt. Ltd.
 * @license    http://www.socialengineaddons.com/license/
 * @version    $Id: Append.php 2017-03-27 9:40:21Z SocialEngineAddOns $
 * @author     SocialEngineAddOns
 */
class Sitemusic_Form_UserPlaylist_Append extends Engine_Form
{

  protected $_roles = array(
    'everyone' => 'Everyone',
    'registered' => 'All Registered Members',
    'owner_network' => 'Friends and Networks',
    'owner_member_member' => 'Friends of Friends',
    'owner_member' => 'Friends Only',
    'owner' => 'Just Me'
  );

  public function init()
  {
    $user = Engine_Api::_()->user()->getViewer();
    // Init form
    $this
      ->setTitle('Add Song To Playlist')
      ->setAttrib('id', 'form-playlist-append')
      ->setAttrib('name', 'playlist_add')
      ->setAttrib('class', 'global_form')
      ->setAction($_SERVER['REQUEST_URI'])
    ;

    // Init playlist
    $playlists = array();
    $playlists[0] = Zend_Registry::get('Zend_Translate')->_('Create New Playlist');
    $this->addElement('Select', 'userplaylist_id', array(
      'label' => 'Choose Playlist',
      'multiOptions' => $playlists,
      'onchange' => "updateTextFields()",
    ));


    // Init new playlist field
    $this->addElement('Text', 'title', array(
      'label' => 'Playlist Name',
      'style' => '',
      'filters' => array(
        new Engine_Filter_Censor(),
      ),
    ));

    $this->addElement('File', 'photo', array(
      'label' => 'Upload Photo',
    ));
    $this->photo->addValidator('Extension', false, 'jpg,png,gif,jpeg');

    // AUTHORIZATIONS
    $availableLabels = $this->_roles;

    // Element: view privacy

    $viewOptions = (array) Engine_Api::_()->authorization()->getAdapter('levels')->getAllowed('sitemusic_userpl', $user, 'auth_view_pl');
    $viewOptions = array_intersect_key($availableLabels, array_flip($viewOptions));
    if( !empty($viewOptions) && count($viewOptions) >= 1 ) {
      // Make a hidden field
      if( count($viewOptions) == 1 ) {
        $this->addElement('hidden', 'auth_view_pl', array('value' => key($viewOptions)));
        // Make select box
      } else {
        $this->addElement('Select', 'auth_view_pl', array(
          'label' => 'View Privacy',
          'description' => 'Who may see this playlist?',
          'multiOptions' => $viewOptions,
          'value' => key($viewOptions),
        ));
        $this->auth_view_pl->getDecorator('Description')->setOption('placement', 'append');
      }
    }

    // Element: comment privacy
    $commentOption = (array) Engine_Api::_()->authorization()->getAdapter('levels')->getAllowed('sitemusic_userpl', $user, 'auth_comment_pl');
    $commentOption = array_intersect_key($availableLabels, array_flip($commentOption));
    if( !empty($commentOption) && count($commentOption) >= 1 ) {
      // Make a hidden field
      if( count($commentOption) == 1 ) {
        $this->addElement('hidden', 'auth_comment_pl', array('value' => key($commentOption)));
        // Make select box
      } else {
        $this->addElement('Select', 'auth_comment_pl', array(
          'label' => 'Comment Privacy',
          'description' => 'Who may comment on this playlist?',
          'multiOptions' => $commentOption,
          'value' => key($commentOption),
        ));
        $this->auth_comment_pl->getDecorator('Description')->setOption('placement', 'append');
      }
    }

    // Element: execute
    $this->addElement('Button', 'execute', array(
      'label' => 'Add Song',
      'type' => 'submit',
      'ignore' => true,
      'decorators' => array(
        'ViewHelper',
      ),
    ));

    // Element: cancel
    $this->addElement('Cancel', 'cancel', array(
      'label' => 'cancel',
      'link' => true,
      'prependText' => ' or ',
      'onclick' => 'parent.Smoothbox.close();',
      'decorators' => array(
        'ViewHelper',
      ),
    ));

    // DisplayGroup: buttons
    $this->addDisplayGroup(array(
      'execute',
      'cancel',
      ), 'buttons', array(
      'decorators' => array(
        'FormElements',
        'DivDivDivWrapper'
      ),
    ));
  }

}
