<?php

/**
 * SocialEngine
 *
 * @category   Application_Extensions
 * @package    Sitemusic
 * @copyright  Copyright 2017-2022 BigStep Technologies Pvt. Ltd.
 * @license    http://www.socialengineaddons.com/license/
 * @version    Albumcategories.php 2017-03-27 9:40:21Z SocialEngineAddOns $
 * @author     SocialEngineAddOns
 */
class Sitemusic_Model_DbTable_Albumcategories extends Engine_Db_Table
{

  protected $_rowClass = 'Sitemusic_Model_Albumcategory';
  protected $_categories = array();

  /**
   * Return subcaregories
   *
   * @param int category_id
   * @return all sub categories
   */
  public function getSubCategories($category_id, $fetchColumns = array())
  {

    //RETURN IF CATEGORY ID IS EMPTY
    if( empty($category_id) ) {
      return;
    }

    //MAKE QUERY
    $select = $this->select();

    if( !empty($fetchColumns) ) {
      $select->from($this->info('name'), $fetchColumns);
    }

    $select->where('cat_dependency = ?', $category_id)
      ->order('cat_order');
    //RETURN RESULTS
    return $this->fetchAll($select);
  }

  public function getCategoriesAssoc()
  {
    $stmt = $this->select()
      ->from($this, array('albumcategory_id', 'category_name'))
      ->order('category_name ASC')
      ->query();

    $data = array();
    foreach( $stmt->fetchAll() as $category ) {
      $data[$category['albumcategory_id']] = $category['category_name'];
    }
    return $data;
  }

  /**
   * Get category object
   * @param int $category_id : category id
   * @return category object
   */
  public function getCategory($category_id)
  {
    if( empty($category_id) )
      return;
    if( !array_key_exists($category_id, $this->_categories) ) {
      $this->_categories[$category_id] = $this->find($category_id)->current();
    }
    return $this->_categories[$category_id];
  }

  /**
   * Return categories
   *
   * @param array $category_ids
   * @return all categories
   */
  public function getCategories($category_ids = null, $count_only = 0, $listingtype_id = 0, $sponsored = 0, $cat_depandancy = 0, $limit = 0, $orderBy = 'cat_order', $visibility = 0, $fetchColumns = array())
  {

    //MAKE QUERY
    $select = $this->select();

    //GET CATEGORY TABLE NAME
    $categoryTableName = $this->info('name');

    //GET LISTING TYPE TABLE
    $listingTypeTable = Engine_Api::_()->getDbTable('albumcategories', 'sitemusic');
    $listingTypeTableName = $listingTypeTable->info('name');

    if( $orderBy == 'category_name' ) {
      $select->order('category_name');
    } else {
      $select->order('cat_order');
    }

    if( !empty($count_only) ) {
      $select->from($this->info('name'), 'category_id');
    } elseif( !empty($fetchColumns) ) {
      $select->from($categoryTableName, $fetchColumns);
    }

    if( !empty($count_only) ) {
      return $select->query()->fetchColumn();
    }
    //RETURN DATA
    return $this->fetchAll($select);
  }

  public function setDefaultImages($toPath, $fromPath, $columnName)
  {
    @mkdir(APPLICATION_PATH . $toPath, 0777);
    $dir = APPLICATION_PATH . $fromPath;
    $public_dir = APPLICATION_PATH . $toPath;
    $fieArr = array();
    if( is_dir($dir) && is_dir($public_dir) ) {
      $files = scandir($dir);
      foreach( $files as $file ) {
        if( strstr($file, '.png') || strstr($file, '.jpg') || strstr($file, '.gif') ) {
          $fieArr[] = $file;
          @copy(APPLICATION_PATH . "$fromPath/$file", APPLICATION_PATH . "$toPath/$file");
        }
      }
      @chmod(APPLICATION_PATH . $toPath, 0777);
    }
    //MAKE QUERY
    $select = $this->select()->from($this->info('name'), array('albumcategory_id', 'category_name', $columnName));
    $categories = $this->fetchAll($select);
    //UPLOAD DEFAULT ICONS
    foreach( $categories as $category ) {
      $categoryName = Engine_Api::_()->sitemusic()->getSlug($category->category_name, 225);
      $iconName = false;
      foreach( $fieArr as $f ) {
        if( strstr($f, $categoryName) ) {
          $iconName = $f;
          break;
        }
      }

      if( $iconName == false )
        continue;
      @chmod(APPLICATION_PATH . $toPath, 0777);
      $file = array();
      if( $columnName == 'photo_id' && !empty($category->photo_id) ) {
        continue;
      } else if( $columnName == 'file_id' && !empty($category->file_id) ) {
        continue;
      } else if( $columnName == 'banner_id' && !empty($category->banner_id) ) {
        continue;
      }

      $file['tmp_name'] = APPLICATION_PATH . "$toPath/$iconName";
      $file['name'] = $iconName;
      if( file_exists($file['tmp_name']) ) {
        $name = basename($file['tmp_name']);
        $path = dirname($file['tmp_name']);
        $mainName = $path . '/' . $file['name'];

        @chmod($mainName, 0777);

        $photo_params = array(
          'parent_id' => $category->albumcategory_id,
          'parent_type' => "sitemusic_albumcategory",
        );

        $extension = ltrim(strrchr(basename($name), '.'), '.');
        // Resize image (main)
        $bigBannerPath = $path . DIRECTORY_SEPARATOR . $name . '_b-i.' . $extension;
        $image = Engine_Image::factory();
        $image->open($file['tmp_name'])
          ->resize(1200, 700)
          ->write($bigBannerPath)
          ->destroy();

        // Resize image (profile)
        $smallBannerPath = $path . DIRECTORY_SEPARATOR . $name . '_s-i.' . $extension;
        $image = Engine_Image::factory();
        $image->open($file['tmp_name'])
          ->resize(350, 200)
          ->write($smallBannerPath)
          ->destroy();

       // Save
        $filesTable = Engine_Api::_()->getDbtable('files', 'storage');

        // Store
        $bigBanner = $filesTable->createSystemFile($bigBannerPath);
        $smallBanner = $filesTable->createSystemFile($smallBannerPath);
        $bigBanner->bridge($smallBanner, 'thumb.normal');

        // Remove temp files
        @unlink($bigBannerPath);
        @unlink($smallBannerPath);

//        $photoFile = Engine_Api::_()->storage()->create($mainName, $photo_params);
        //UPDATE FILE ID IN CATEGORY TABLE
        if( !empty($bigBanner->file_id) ) {
          if( $columnName == 'photo_id' ) {
            $category->photo_id = $bigBanner->file_id;
          }
          $category->save();
        }
      }
    }
    //REMOVE THE CREATED PUBLIC DIRECTORY
    if( is_dir(APPLICATION_PATH . $toPath) ) {
      $files = scandir(APPLICATION_PATH . $toPath);
      foreach( $files as $file ) {
        $is_exist = file_exists(APPLICATION_PATH . "$toPath/$file");
        if( $is_exist ) {
          @unlink(APPLICATION_PATH . "$toPath/$file");
        }
      }
      @rmdir(APPLICATION_PATH . $toPath);
    }
  }

  public function uploadDefaultImages()
  {
    $categoryImagesToPath = "/temporary/music-album-categories_images";
    $categoryImagesfromPath = "/application/modules/Sitemusic/externals/images/music-album-categories";
    $this->setDefaultImages($categoryImagesToPath, $categoryImagesfromPath, 'photo_id');
  }

}
