<?php

/**
 * SocialEngine
 *
 * @category   Application_Extensions
 * @package    Sitemusic
 * @copyright  Copyright 2017-2022 BigStep Technologies Pvt. Ltd.
 * @license    http://www.socialengineaddons.com/license/
 * @version    Artists.php 2017-03-27 9:40:21Z SocialEngineAddOns $
 * @author     SocialEngineAddOns
 */
class Sitemusic_Model_DbTable_Artists extends Engine_Db_Table
{

  protected $_rowClass = 'Sitemusic_Model_Artist';

  public function getCategoriesAssoc()
  {
    $stmt = $this->select()
      ->from($this, array('artist_id', 'title'))
      ->order('title ASC')
      ->query();

    $data = array();
    foreach( $stmt->fetchAll() as $category ) {
      $data[$category['artist_id']] = $category['title'];
    }
    return $data;
  }

  public function setPhoto($photo)
  {
    $viewer = Engine_Api::_()->user()->getViewer();
    $identity = $viewer->getIdentity();
    if( $photo instanceof Zend_Form_Element_File ) {
      $file = $photo->getFileName();
      $fileName = $file;
    } else if( $photo instanceof Storage_Model_File ) {
      $file = $photo->temporary();
      $fileName = $photo->name;
    } else if( $photo instanceof Core_Model_Item_Abstract && !empty($photo->file_id) ) {
      $tmpRow = Engine_Api::_()->getItem('storage_file', $photo->file_id);
      $file = $tmpRow->temporary();
      $fileName = $tmpRow->name;
    } else if( is_array($photo) && !empty($photo['tmp_name']) ) {
      $file = $photo['tmp_name'];
      $fileName = $photo['name'];
    } else if( is_string($photo) && file_exists($photo) ) {
      $file = $photo;
      $fileName = $photo;
    } else {
      throw new User_Model_Exception('invalid argument passed to setPhoto');
    }

    if( !$fileName ) {
      $fileName = $file;
    }

    $name = basename($file);
    $extension = ltrim(strrchr($fileName, '.'), '.');
    $base = rtrim(substr(basename($fileName), 0, strrpos(basename($fileName), '.')), '.');
    $path = APPLICATION_PATH . DIRECTORY_SEPARATOR . 'temporary';
    $params = array(
      'parent_type' => 'sitemusic_artists',
      'parent_id' => $identity,
    );

    // Save
    $filesTable = Engine_Api::_()->getDbtable('files', 'storage');
    // Resize image (main)
    $mainPath = $path . DIRECTORY_SEPARATOR . $base . '_m.' . $extension;
    $image = Engine_Image::factory();
    $image->open($file)
      ->autoRotate()
      ->resize(720, 720)
      ->write($mainPath)
      ->destroy();

    // Resize image (normal)
    $normalPath = $path . DIRECTORY_SEPARATOR . $base . '_in.' . $extension;
    $image = Engine_Image::factory();
    $image->open($file)
      ->autoRotate()
      ->resize(320, 240)
      ->write($normalPath)
      ->destroy();

    // Store
    try {
      $iMain = $filesTable->createFile($mainPath, $params);
      $iIconNormal = $filesTable->createFile($normalPath, $params);

      $iMain->bridge($iIconNormal, 'thumb.normal');
    } catch( Exception $e ) {
      // Remove temp files
      @unlink($mainPath);
      @unlink($normalPath);
      // Throw
      if( $e->getCode() == Storage_Model_DbTable_Files::SPACE_LIMIT_REACHED_CODE ) {
        throw new Album_Model_Exception($e->getMessage(), $e->getCode());
      } else {
        throw $e;
      }
    }

    // Remove temp files
    @unlink($mainPath);
    @unlink($normalPath);

    $table = Engine_Api::_()->getDbtable('artists', 'sitemusic');
    $db = $table->getAdapter();
    $db->beginTransaction();
    // Update row
    try {

      $table->modified_date = date('Y-m-d H:i:s');
      $table->photo_id = $iMain->getIdentity();

      $db->commit();
    } catch( Exception $e ) {
      $db->rollBack();
      throw $e;
    }
    return $this;
  }

  public function getArtistSelect($params = array())
  {
    $labelMapTable = Engine_Api::_()->getDbTable('labelMaps', 'sitemusic');
    $lmName = $labelMapTable->info('name');
    $playlistSongTable = Engine_Api::_()->getDbTable('playlistSongs', 'sitemusic');
    $psName = $playlistSongTable->info('name');
    $songArtistTable = Engine_Api::_()->getDbTable('songartists', 'sitemusic');
    //songartist table name
    $saName = $songArtistTable->info('name');
    $aName = $this->info('name');

    if( !empty($params['genreId']) && $params['genreId'] != 'all' ) {
      $songArtist = $songArtistTable->select()
        ->from($saName);
      $songArtist->join($psName, "$saName.song_id = $psName.song_id", '');
      $songArtist->where('genre_id = ?', $params['genreId']);
      $songArtist->group('artist_id');
      $result = $songArtist->query()->fetchAll();
      if( $result ) {
        foreach( $result as $row ) {
          $artist_id[] = $row['artist_id'];
        }
      }
    }

    $select = $this->select()
      ->from($aName);
    if( !isset($params['notCheckApprove']) && empty($params['notCheckApprove']) ) {
      $select->where('approved = ?', 1);
    }

    //albumIds
    if( !empty($params['artistIds']) ) {
      $select->where('artist_id IN(?)', $params['artistIds']);
    }


    if( !empty($params['creater_id']) ) {
      $select->where('owner_id = ?', $params['creater_id']);
    }

    if( !empty($params['artist_id']) ) {
      $select->where('artist_id IN(?)', $params['artist_id']);
    }

    if( !empty($params['search']) ) {
      $select->where('title LIKE ?', "%{$params['search']}%");
    }
    // alphabet search
    if( !empty($params['alphabet']) && $params['alphabet'] != 'ViewAll' ) {
      if( $params['alphabet'] != '#' ) {
        $select->where('title LIKE ?', "{$params['alphabet']}%");
      } else {
        $select->
          WHERE("title LIKE '%0%'
    OR title LIKE '%1%'
    OR title LIKE '%2%'
    OR title LIKE '%3%'
    OR title LIKE '%4%'
    OR title LIKE '%5%'
    OR title LIKE '%6%'
    OR title LIKE '%7%'
    OR title LIKE '%8%'
    OR title LIKE '%9%'
  ");
      }
    }
    if( !empty($params['genreId']) && $params['genreId'] != 'all' && !empty($artist_id) ) {
      $artistid = implode(',', $artist_id);
      $select->where('artist_id IN(?)', $artistid);
    }
    if( !empty($params['labelType']) && $params['labelType'] != 'all' ) {
      $select->join($lmName, "$aName.artist_id = $lmName.resource_id", '');
      $select->where('label_id = ?', $params['labelType'])
        ->where('resource_type = ?', $params['type']);
    }
    // SORT
    if( !empty($params['sort']) ) {
      $sort = $params['sort'];
      if( 'recent' == $sort ) {
        $select->order('creation_date DESC');
      } else if( 'popular' == $sort ) {
        $select->order("follow_count DESC");
      } else if( 'liked' == $sort ) {
        $select->order("like_count DESC");
      } else if( 'favourite' == $sort ) {
        $select->order("favourite_count DESC");
      } else if( 'alphabetic' == $sort ) {
        $select->order('title ASC');
      } else if( $sort == 'creationDate' ) {
        $select->order('creation_date DESC');
      } else if( $sort == 'ascendingOrder' ) {
        $select->order('creation_date ASC');
      }
    } else {
      $select->order('creation_date DESC');
    }
    return $select;
  }

  public function getPaginator(array $params)
  {
    return Zend_Paginator::factory($this->getArtistSelect($params));
  }

}
