<?php

/**
 * SocialEngine
 *
 * @category   Application_Extensions
 * @package    Sitemusic
 * @copyright  Copyright 2017-2021 BigStep Technologies Pvt. Ltd.
 * @license    http://www.socialengineaddons.com/license/
 * @version    $Id: Modules.php 2017-03-27 9:40:21Z SocialEngineAddOns $
 * @author     SocialEngineAddOns
 */
class Sitemusic_Model_DbTable_Favourites extends Engine_Db_Table
{

  protected $_name = 'sitemusic_favourites';
  protected $_rowClass = 'Sitemusic_Model_Favourite';
  protected $_custom = false;

  public function addFavourite(Core_Model_Item_Abstract $resource, Core_Model_Item_Abstract $poster)
  {
    $row = $this->getFavourite($resource, $poster);
    if( null !== $row ) {
      throw new Core_Model_Exception('Already favourited');
    }

    $table = $this->getFavouriteTable();
    $row = $table->createRow();
    if( isset($row->resource_type) ) {
      $row->resource_type = $resource->getType();
    }

    $row->resource_id = $resource->getIdentity();
    $row->poster_type = $poster->getType();
    $row->poster_id = $poster->getIdentity();
    $row->save();

    if( isset($resource->favourite_count) ) {
      $resource->favourite_count++;
      $resource->save();
    }

    return $row;
  }

  public function getFavourite(Core_Model_Item_Abstract $resource, Core_Model_Item_Abstract $poster)
  {
    $table = $this->getFavouriteTable();
    $select = $this->getFavouriteSelect($resource)
      ->where('poster_type = ?', $poster->getType())
      ->where('poster_id = ?', $poster->getIdentity())
      ->limit(1);
    return $table->fetchRow($select);
  }

  public function getFavouriteSelect(Core_Model_Item_Abstract $resource)
  {
    $select = $this->getFavouriteTable()->select();

    if( !$this->_custom ) {
      $select->where('resource_type = ?', $resource->getType());
    }

    $select
      ->where('resource_id = ?', $resource->getIdentity())
      ->order('favourite_id ASC');

    return $select;
  }

  public function getFavouriteTable()
  {
    return $this;
  }

  public function getFavouriteCount(Core_Model_Item_Abstract $resource)
  {
    if( isset($resource->favourite_count) ) {
      return $resource->favourite_count;
    }

    $select = new Zend_Db_Select($this->getFavouriteTable()->getAdapter());
    $select
      ->from($this->getFavouriteTable()->info('name'), new Zend_Db_Expr('COUNT(1) as count'));

    if( !$this->_custom ) {
      $select->where('resource_type = ?', $resource->getType());
    }

    $select->where('resource_id = ?', $resource->getIdentity());

    $data = $select->query()->fetchAll();
    return (int) $data[0]['count'];
  }

}
