<?php

/**
 * SocialEngine
 *
 * @category   Application_Extensions
 * @package    Sitemusic
 * @copyright  Copyright 2017-2021 BigStep Technologies Pvt. Ltd.
 * @license    http://www.socialengineaddons.com/license/
 * @version    $Id: Modules.php 2017-03-27 9:40:21Z SocialEngineAddOns $
 * @author     SocialEngineAddOns
 */
class Sitemusic_Model_DbTable_Follows extends Engine_Db_Table
{

  protected $_rowClass = 'Sitemusic_Model_Follow';
  protected $_custom = false;

  public function isFollow(Core_Model_Item_Abstract $resource, Core_Model_Item_Abstract $poster)
  {
    return ( null !== $this->getFollow($resource, $poster) );
  }

  /**
   * Function for showing 'Number of Follows'.
   *
   * @param Stirng $resource_type
   * @param Int $resource_id
   * @return number of follows
   */
  public function numberOfFollow($resource_type, $resource_id)
  {

    //RETURN FOLLOW COUNT
    return Engine_Api::_()->getItem($resource_type, $resource_id)->follow_count;
  }

  public function getFollow(Core_Model_Item_Abstract $resource, Core_Model_Item_Abstract $poster)
  {
    // START WORK ON FOLLOW USER CUSTOMIZATION
    $followEnabled = Engine_Api::_()->getApi("settings", "core")->getSetting('user.friends.direction', 1) && Engine_Api::_()->getApi("settings", "core")->getSetting('sitemember.user.follow.enable', 1);
    $hasAdvancedactivity = Engine_Api::_()->hasModuleBootstrap('advancedactivity');
    if( $resource->getType() === 'user' && $poster->getType() === 'user' && $this->isFriend($resource, $poster) && $followEnabled && $hasAdvancedactivity ) {
      $id = $resource->getIdentity();
      $poster_id = $poster->getIdentity();
      $type = 'user';
      $hideTable = Engine_Api::_()->getDbtable('hide', 'advancedactivity');
      $isHide = $hideTable->select()->from($hideTable->info('name'), array('count(user_id)'))
          ->where('user_id = ?', $poster_id)
          ->where('hide_resource_type =? ', $type)
          ->where('hide_resource_id =? ', $id)->query()->fetchColumn();
      $isHide = $isHide ? null : $isHide;
      return $isHide;
    }
    // END WORK ON FOLLOW USER CUSTOMIZATION
    $table = $this->getFollowTable();
    $select = $this->getFollowSelect($resource)
      ->where('poster_type = ?', $poster->getType())
      ->where('poster_id = ?', $poster->getIdentity())
      ->limit(1);

    return $table->fetchRow($select);
  }

  public function getFollowTable()
  {
    return $this;
  }

  public function getFollowSelect(Core_Model_Item_Abstract $resource)
  {
    $select = $this->getFollowTable()->select();

    if( !$this->_custom ) {
      $select->where('resource_type = ?', $resource->getType());
    }

    $select
      ->where('resource_id = ?', $resource->getIdentity())
      ->order('follow_id ASC');
    return $select;
  }

  public function getFollowers($resource_type, $resource_id, $owner_id)
  {

    $followTableName = $this->info('name');
    $select = $this->select()
      ->from($followTableName, 'poster_id')
      ->where('poster_id != ?', $owner_id)
      ->where('poster_type = ?', 'user')
      ->where('resource_type = ?', $resource_type)
      ->where('resource_id = ?', $resource_id)
    ;
    return $this->fetchAll($select);
  }

  public function removeFollow(Core_Model_Item_Abstract $resource, Core_Model_Item_Abstract $poster)
  {
    // START WORK ON FOLLOW USER CUSTOMIZATION
    $followEnabled = Engine_Api::_()->getApi("settings", "core")->getSetting('user.friends.direction', 1) && Engine_Api::_()->getApi("settings", "core")->getSetting('sitemember.user.follow.enable', 1);
    $hasAdvancedactivity = Engine_Api::_()->hasModuleBootstrap('advancedactivity');
    if( $resource->getType() === 'user' && $poster->getType() === 'user' && $this->isFriend($resource, $poster) && $followEnabled && $hasAdvancedactivity ) {
      $id = $resource->getIdentity();
      $poster_id = $poster->getIdentity();
      $type = 'user';
      Engine_Api::_()->getDbtable('hide', 'advancedactivity')->insert(array(
        'user_id' => $poster_id,
        'hide_resource_type' => $type,
        'hide_resource_id' => $id
      ));
      return $id;
    }
    // END WORK ON FOLLOW USER CUSTOMIZATION

    $row = $this->getFollow($resource, $poster);
    if( null === $row ) {
      throw new Core_Model_Exception('No follow to remove');
    }

    $row->delete();

    if( isset($resource->follow_count) ) {
      $resource->follow_count--;
      $resource->save();
    }

    return $this;
  }

  public function isFriend($resource, $poster)
  {

    //GET THE VIEWER ID.
    $resource_id = $resource->getIdentity();
    $poster_id = $poster->getIdentity();
    $isFriend = false;

    //FETCH FRIEND ID FROM DATABASE.
    $memberTable = Engine_Api::_()->getDbtable('membership', 'user');
    $memberTableName = $memberTable->info('name');

    $select = $memberTable->select()
      ->where($memberTableName . '.active = ?', 1)
      ->where($memberTableName . '.resource_id = ?', $resource_id)
      ->where($memberTableName . '.user_id = ?', $poster_id);

    $fetch = $select->query()->fetchAll();
    if( !empty($fetch) ) {
      $isFriend = true;
    }
    return $isFriend;
  }

}
