<?php

/**
 * SocialEngine
 *
 * @category   Application_Extensions
 * @package    Sitemusic
 * @copyright  Copyright 2017-2022 BigStep Technologies Pvt. Ltd.
 * @license    http://www.socialengineaddons.com/license/
 * @version    $Id: PlaylistSongs.php 2017-03-27 9:40:21Z SocialEngineAddOns $
 * @author     SocialEngineAddOns
 */
class Sitemusic_Model_DbTable_PlaylistSongs extends Engine_Db_Table
{

  protected $_name = 'sitemusic_playlist_songs';
  //protected $_primary  = array('playlist_id', 'file_id');
  protected $_primary = 'song_id';
  protected $_rowClass = 'Sitemusic_Model_PlaylistSong';

  public function getCategoriesAssoc()
  {
    $stmt = $this->select()
      ->from($this, array('song_id', 'title'))
      ->order('title ASC')
      ->query();

    $data = array();
    foreach( $stmt->fetchAll() as $category ) {
      $data[$category['song_id']] = $category['title'];
    }
    return $data;
  }

  public function getPaginator(array $params)
  {
    return Zend_Paginator::factory($this->getSongSelect($params));
  }

  public function getSongSelect($params = array())
  {
    if( empty($params['type']) ) {
      $select = $this->select();
      if( count($params['song_id']) > 1 ) {
        $song_ids = implode(',', $params['song_id']);
        $select->where('song_id in (' . $song_ids . ')');
      } elseif( isset($params['song_id']) ) {
        $select->where('song_id = ?', $params['song_id']);
      }
      if( !empty($params['playlist_id']) && is_numeric($params['playlist_id']) ) {
        $select->where('playlist_id = ?', $params['playlist_id']);
      }
      if( !isset($params['is_admin']) ) {
        $viewer = Engine_Api::_()->user()->getViewer();
        $select->where('owner_id = ?', $viewer->getIdentity());
      }
      if( !isset($params['order']) ) {
        $select->order('order ASC');
      } else if( is_string($params['order']) ) {
        $select->order($params['order']);
      }
    } else {
      $songArtistTable = Engine_Api::_()->getItemTable('sitemusic_songartist');
      $labelMapTable = Engine_Api::_()->getDbTable('labelMaps', 'sitemusic');
      $playlistTable = Engine_Api::_()->getDbTable('playlists', 'sitemusic');
      $lmName = $labelMapTable->info('name');
      $saName = $songArtistTable->info('name');
      $pName = $playlistTable->info('name');
      $psName = $this->info('name');
      $select = $this->select()
        ->from($psName);

      //albumIds
      if( !empty($params['songIds']) ) {
        $select->where('song_id IN(?)', $params['songIds']);
      }


      //GET TAGMAP TABLE NAME
      $tagMapTableName = Engine_Api::_()->getDbtable('TagMaps', 'core')->info('name');
      $tagName = Engine_Api::_()->getDbtable('Tags', 'core')->info('name');
      $isTagIdSearch = false;
      if( isset($params['tag_id']) && !empty($params['tag_id']) ) {
        $select
          ->setIntegrityCheck(false)
          ->joinLeft($tagMapTableName, "$tagMapTableName.resource_id = $psName.song_id", array('tagmap_id', 'resource_type', 'resource_id', $tagMapTableName . '.tag_id'))
          ->where($tagMapTableName . '.resource_type = ?', 'sitemusic_playlist_song')
          ->where($tagMapTableName . '.tag_id = ?', $params['tag_id']);
        $isTagIdSearch = true;
      }
      //For Search
      if( !empty($params['search']) ) {
        $select->where($psName . '.title LIKE ?', "%{$params['search']}%");
      }

      if( !empty($params['alphabet']) && $params['alphabet'] != 'ViewAll' ) {
        if( $params['alphabet'] != '#' ) {
          $select->where($psName . '.title LIKE ?', "{$params['alphabet']}%");
        } else {
          $select->
            WHERE($psName . ".title LIKE '%0%'
    OR " . $psName . ".title LIKE '%1%'
    OR " . $psName . ".title LIKE '%2%'
    OR " . $psName . ".title LIKE '%3%'
    OR " . $psName . ".title LIKE '%4%'
    OR " . $psName . ".title LIKE '%5%'
    OR " . $psName . ".title LIKE '%6%'
    OR " . $psName . ".title LIKE '%7%'
    OR " . $psName . ".title LIKE '%8%'
    OR " . $psName . ".title LIKE '%9%'
  ");
        }
      }

      // show options for mymusic section
      if( !empty($params['songShowOptions']) ) {
        if( $params['songShowOptions'] == 1 && isset($params['albumIds']) ) {
          $select->where($psName . '.playlist_id IN (?)', $params['albumIds']);
        } elseif( $params['songShowOptions'] == 2 && isset($params['albumIds']) ) {
          $select->where($psName . '.owner_id = ?', $params['viewerId']);
          $select->where($psName . '.playlist_id IN (?)', $params['albumIds']);
        } elseif( $params['songShowOptions'] == 3 && isset($params['albumIds']) ) {
          $select->where($psName . '.owner_id != ?', $params['viewerId']);
          $select->where('playlist_id IN (?)', $params['albumIds']);
        } elseif( $params['songShowOptions'] == 4 && $params['albumIds'] ) {
          $select->where($psName . '.owner_id = ?', $params['viewerId']);
          $select->where('playlist_id NOT IN (?)', $params['albumIds']);
        } elseif( $params['songShowOptions'] == 5 && isset($params['albumIds']) ) {
          $select->where($psName . '.approved = ?', 0);
          $select->where($psName . '.owner_id != ?', $params['viewerId']);
          $select->where($psName . '.playlist_id IN (?)', $params['albumIds']);
        } elseif( $params['songShowOptions'] == 6 && isset($params['albumIds']) ) {
          $select->where($psName . '.approved = ?', 0);
          $select->where($psName . '.owner_id = ?', $params['viewerId']);
          $select->where($psName . '.playlist_id NOT IN (?)', $params['albumIds']);
        } elseif( $params['songShowOptions'] == 7 ) {
          $select->where($psName . '.owner_id = ?', $params['viewerId']);
        } elseif( $params['songShowOptions'] == 8 && isset($params['albumIds']) ) {
          $select->where($psName . '.owner_id = ?', $params['viewerId']);
          $select->orWhere($psName . '.playlist_id IN(?)', $params['albumIds']);
        }
      }

      // SORT
      if( !empty($params['sort']) ) {
        $sort = $params['sort'];
        if( 'recent' == $sort ) {
          $select->order('creation_date DESC');
        } else if( 'popular' == $sort ) {
          $select->order($psName . ".play_count DESC");
        } else if( 'liked' == $sort ) {
          $select->order($psName . ".like_count DESC");
        } else if( 'downloaded' == $sort ) {
          $select->order($psName . ".download_count DESC");
        } else if( 'favourite' == $sort ) {
          $select->order("favourite_count DESC");
        } else if( 'alphabetic' == $sort ) {
          $select->order($psName . '.title ASC');
        } else if( $sort == 'creationDate' ) {
          $select->order($psName . '.creation_date DESC');
        } else if( $sort == 'ascendingOrder' ) {
          $select->order($psName . '.creation_date ASC');
        }
      } else if( !empty($params['order']) && !empty($params['order_direction']) ) {
        $select->order($psName . $params['order'] . ' ' . $params['order_direction']);
      } else
        $select->order($psName . '.creation_date DESC');
      // USER SEARCH
      if( !empty($params['user']) ) {
        if( is_object($params['user']) ) {
          $select->where($psName . '.owner_id = ?', $params['user']->getIdentity());
        } elseif( is_numeric($params['user']) ) {
          $select->where($psName . '.owner_id = ?', $params['user']);
        }
//        if( !empty($params['searchBit']) ) {
//          $select->where('search = 1');
//        }
      } else if( isset($params['users']) && is_array($params['users']) ) {
        if( empty($params['users']) ) {
          return $select->where('1 != 1');
        }
        $select->join($pName, "$psName.playlist_id = $pName.playlist_id", '');
        $select->where($psName . '.owner_id IN(?)', $params['users']);
        if( !empty($params['searchBit']) ) {
          $select->where('search = 1');
        }
      } else if( !empty($params['adminView']) ) {
        $select->joinLeft($pName, "$psName.playlist_id = $pName.playlist_id", '');
      } else if( !empty($params['only_my']) ) {
        $select->join($pName, "$psName.playlist_id = $pName.playlist_id", '');
        $select->where($psName . '.owner_id = ?', $params['only_my']);
      }
      //For Manage
      if( !empty($params['title']) ) {
        $select->where($psName . '.title LIKE ?', "%{$params['title']}%");
      }
      if( !empty($params['ownerName']) ) {
        $select->where($psName . '.owner_id = ?', $params['owner_id']);
      }
      if( !empty($params['genreId']) && $params['genreId'] != 'all' ) {
        $select->where('genre_id = ?', $params['genreId']);
      }
      if( !empty($params['labelType']) && $params['labelType'] != 'all' ) {
        $select->join($lmName, "$psName.song_id = $lmName.resource_id", '');
        $select->where('label_id = ?', $params['labelType'])
          ->where('resource_type = ?', $params['type']);
      }

      if( !empty($params['artist']) && $params['artist'] != 'all' ) {
        $db = Engine_Db_Table::getDefaultAdapter();
        $query = $db->select()
          ->from($saName)
          ->where('artist_id = ?', $params['artist']);
        $row = $query->query()->fetchAll();
        foreach( $row as $result ) {
          $song_id[] = $result['song_id'];
        }
        if( isset($song_id) ) {
          $song_id = implode(',', $song_id);
          $select->where($psName . '.song_id IN(?)',$song_id);
        } else {
          $dummyArray = array('***');
          $select->where($psName . '.song_id IN(?)',$dummyArray);
        }
      }
      if( !empty($params['creationDate']) ) {
        $week = date('Y-m-d H:i:s', time() - (7 * 86400));
        $month = date('Y-m-d H:i:s', time() - (30 * 86400));
        $sixMonth = date('Y-m-d H:i:s', time() - (30 * 6 * 86400));
        $year = date('Y-m-d H:i:s', time() - (365 * 86400));
        if( $params['creationDate'] == 'last week' ) {
          $select->where($psName . '.creation_date >= ?', $week);
        } elseif( $params['creationDate'] == 'last month' ) {
          $select->where('creation_date >= ?', $month);
        } elseif( $params['creationDate'] == 'last 6 month' ) {
          $select->where($psName . '.creation_date >= ?', $sixMonth);
        } elseif( $params['creationDate'] == 'last 12 month' ) {
          $select->where($psName . '.creation_date >= ?', $year);
        }
      }
    }
    if( !isset($params['notCheckApprove']) && empty($params['notCheckApprove']) ) {
      $select->join($pName, "$psName.playlist_id = $pName.playlist_id", '');
      $select->where($psName . '.approved = ?', 1);
      $select->where($psName . '.status = ?', 1);
      $select->where($pName . '.published = ?', 1);
      $select->where($pName . '.search = ?', 1);
      $param = array();
      //privacy related work
      $select = Engine_Api::_()->getApi('generalWidget', 'sitemusic')->getItemsSelect($select, $param, $pName);
    }
    $select->distinct(true);
    return $select;
  }

  public function oldSongIds($playlist_id)
  {
    $select = $this->select()
      ->where('playlist_id = ?', $playlist_id);

    $query = $select->query()->fetchAll();
    foreach( $query as $q ) {
      $song_id[] = $q['song_id'];
    }
    return $song_id;
  }

  public function getTotalSongIds($playlist_id)
  {
    $select = $this->select()
      ->where('playlist_id = ?', $playlist_id);

    $query = $select->query()->fetchAll();
    foreach( $query as $q ) {
      $song_id[] = $q['song_id'];
    }
    return $song_id;
  }

  public function getMinInfoViewOptions()
  {
    $multiOptions = array();
    $multiOptions = array(
      "songLike" => "Song Like",
      "songShare" => "Song Share",
      "songDownload" => "Song Download",
      "songQueue" => "Song Queue",
      "songRating" => "Song Rating",
      "songFavourite" => "Song Favourite",
      "addToPlaylist" => "Add To Playlist",
      "songPlay" => "Play Song",
      "albumName" => "Album Name",
    );
    return $multiOptions;
  }

}
