<?php

/**
 * SocialEngine
 *
 * @category   Application_Extensions
 * @package    Sitemusic
 * @copyright  Copyright 2017-2022 BigStep Technologies Pvt. Ltd.
 * @license    http://www.socialengineaddons.com/license/
 * @version    $Id: core.php 2017-03-27 9:40:21Z SocialEngineAddOns $
 * @author     SocialEngineAddOns
 */
class Sitemusic_Plugin_Core extends Zend_Controller_Plugin_Abstract
{

  public function onStatistics($event)
  {
    $table = Engine_Api::_()->getDbTable('playlists', 'sitemusic');
    $select = new Zend_Db_Table_Select($table);
    $select->from($table->info('name'), array('COUNT(*) AS count'));
    $event->addResponse($select->query()->fetchColumn(0), 'album');

    $table = Engine_Api::_()->getDbTable('playlistSongs', 'sitemusic');
    $select = new Zend_Db_Table_Select($table);
    $select->from($table->info('name'), array('COUNT(*) AS count'));
    $event->addResponse($select->query()->fetchColumn(0), 'song');
  }

  public function onUserDeleteBefore($event)
  {
    $payload = $event->getPayload();
    if( $payload instanceof User_Model_User ) {
      $UserPlaylistTable = Engine_Api::_()->getDbtable('playlists', 'sitemusic');
      $playlistSelect = $UserPlaylistTable->select()->where('owner_id = ?', $payload->getIdentity());
      foreach( $UserPlaylistTable->fetchAll($playlistSelect) as $playlist ) {
        if($playlist->getSongs()) {
          foreach( $playlist->getSongs() as $song ) {
            $song->deleteUnused();
          }
        }
        $playlist->delete();
      }
    }
  }

  public function onSitemusicPlDeleteBefore($event)
  {
    $payload = $event->getPayload();
    if( $payload instanceof Sitemusic_Model_Playlist ) {
      $playlistTable = Engine_Api::_()->getDbtable('playlists', 'sitemusic');
      $playlistSelect = $playlistTable->select()->where('playlist_id = ?', $payload->getIdentity());
      foreach( $playlistTable->fetchAll($playlistSelect) as $playlist ) {
        foreach( $playlist->getAllSongs() as $song )
          $song->deleteUnused();
      }
    }
  }

  public function onSitemusicUserplDeleteBefore($event)
  {
    $payload = $event->getPayload();
    $db = Zend_Db_Table::getDefaultAdapter();
    $table = Engine_Api::_()->getDbTable('userPlaylistSongs', 'sitemusic');
    $name = $table->info('name');
    if( $payload instanceof Sitemusic_Model_UserPlaylist ) {
      $UserPlaylistTable = Engine_Api::_()->getDbtable('userPlaylists', 'sitemusic');
      $playlistSelect = $UserPlaylistTable->select()->where('userplaylist_id = ?', $payload->getIdentity());
      foreach( $UserPlaylistTable->fetchAll($playlistSelect) as $playlist ) {
        if($playlist->getSongs()) {
          foreach( $playlist->getSongs() as $song ) {
            try {
              $db->delete($name, array(
                'song_id = ?' => $song->getIdentity(),
                'userplaylist_id = ?' => $payload->getIdentity()
              ));
            } catch( Exception $e ) {
              echo $e->getErrors();
            }
          }
        }
      }
    }
  }

  public function onSitemusicLabelDeleteBefore($event)
  {
    $payload = $event->getPayload();
    $db = Zend_Db_Table::getDefaultAdapter();
    $labelMapTable = Engine_Api::_()->getDbtable('labelMaps', 'sitemusic');
    $lmName = $labelMapTable->info('name');
    if( $payload instanceof Sitemusic_Model_Label ) {
      $labelTable = Engine_Api::_()->getDbtable('labels', 'sitemusic');
//      $labelSelect = $labelTable->select()->where('label_id = ?', $payload->getIdentity());
      try {
        $db->delete($lmName, array(
          'label_id = ?' => $payload->getIdentity()
        ));
      } catch( Exception $e ) {
        echo $e->getErrors();
      }
    }
  }

  public function onSitemusicPlCreateAfter($event)
  {
    $payload = $event->getPayload();
    $viewer = Engine_Api::_()->user()->getViewer();
    $resource_type = $viewer->getType();
    $resource_id = Engine_Api::_()->user()->getViewer()->getIdentity();
    $followTable = Engine_Api::_()->getDbTable('follows', 'sitemusic');
    $followers = $followTable->getFollowers($resource_type, $resource_id, $resource_id);
    if( $followers ) {
      foreach( $followers as $result ) {
        $id = $result['poster_id'];
        $user = Engine_Api::_()->getItem('user', $id);
        Engine_Api::_()->getDbtable('notifications', 'activity')->addNotification($user, $viewer, $payload, 'album_new');
      }
    }
  }

//  public function onSitemusicPlUpdateAfter($event)
//  {
//    $payload = $event->getPayload();
//    $resource_type = $payload->getType();
//    $resource_id = $payload->getIdentity();
//    $viewer = Engine_Api::_()->user()->getViewer();
//    $viewerId = $viewer->getIdentity();
//    $followTable = Engine_Api::_()->getDbTable('follows', 'sitemusic');
//    $followers = $followTable->getFollowers($resource_type, $resource_id, $viewerId);
//    if( $followers ) {
//      foreach( $followers as $result ) {
//        $id = $result['poster_id'];
//        $user = Engine_Api::_()->getItem('user', $id);
//        Engine_Api::_()->getDbtable('notifications', 'activity')->addNotification($user, $viewer, $payload, 'album_new');
//      }
//    }
//  }

}
