<?php

/**
 * SocialEngine
 *
 * @category   Application_Extensions
 * @package    Sitemusic
 * @copyright  Copyright 2015-2016 BigStep Technologies Pvt. Ltd.
 * @license    http://www.socialengineaddons.com/license/
 * @version    $Id: Encode.php 6590 2016-3-3 00:00:00Z SocialEngineAddOns $
 * @author     SocialEngineAddOns
 */
class Sitemusic_Plugin_Job_Encode extends Core_Plugin_Job_Abstract
{

  protected function _execute()
  {
    // Get job and params
    $job = $this->getJob();
    set_time_limit(0);
    // No song id?
    if( !($song_id = $this->getParam('song_id')) ) {
      $this->_setState('failed', 'No song identity provided.');
      $this->_setWasIdle();
      return;
    }

    // Get song object
    $item = Engine_Api::_()->getItem('sitemusic_playlist_song', $song_id);
    if( !$item || !($item instanceof Sitemusic_Model_PlaylistSong) ) {
      $this->_setState('failed', 'Song is missing.');
      $this->_setWasIdle();
      return;
    }

    // Check song status
    if( 0 != $item->status ) {
      $this->_setState('failed', 'Song has already been encoded, or has already failed encoding.');
      $this->_setWasIdle();
      return;
    }

    try {
      $this->_process($item);
      $this->_setIsComplete(true);
      $item->status = 1;
      $item->save();
    } catch( Exception $e ) {
      $this->_setState('failed', 'Exception: ' . $e->getMessage());

      // Attempt to set song state to failed
      try {
        if( 1 != $item->status ) {
          $item->status = 3;
          $item->save();
        }
      } catch( Exception $e ) {
        $this->_addMessage($e->getMessage());
      }
    }
  }

  public function fetchMetaInfo($playlistSongObj)
  {
    include_once('id3/getid3.php');
    $getID3 = new getID3;

    $file_id = $playlistSongObj->file_id;
    if( $file_id instanceof Sitemusic_Model_PlaylistSong ) {
      $file_id = $file_id->file_id;
    }
    if( $file_id instanceof Storage_Model_File ) {
      $file = $file_id;
      $file_id = $file->getIdentity();
    } else {
      $file = Engine_Api::_()->getItem('storage_file', $file_id);
    }
    $dbAdapter = Engine_Db_Table::getDefaultAdapter();
    $query = $dbAdapter->select()
      ->from('engine4_storage_files')
      ->where('file_id = ?', $file_id)
    ;
    $q = $query->query()->fetch();
    $songPath = $q['storage_path'];
    $extension = $q['extension'];

    $ThisFileInfo = $getID3->analyze($songPath);
    $meta = $getID3->analyze($songPath);
    $len = @$ThisFileInfo['playtime_string'];
    if( empty($len) ) {
      $len = 0;
    }

    if( !empty($meta['id3v2']['comments']) ) {
      $songInfo = $meta['id3v2']['comments'];
    }

    if( !empty($songInfo) ) {
      $artist = $songInfo['artist'][0];
      $genere = $songInfo['genre'][0];
      $artistName = (explode(",", $artist));
      $count = count($artistName);
    }

    if( !empty($genere) ) {
      $query1 = $dbAdapter->select()
        ->from('engine4_sitemusic_songcategories', array('songcategory_id', 'category_name'))
        ->where('category_name = ?', $genere)
      ;
      foreach( $query1->query()->fetchAll() as $q ) {
        $songCategoryId = $q['songcategory_id'];
        $category_name = $q['category_name'];
      }
    }

    if( $file ) {
      $songTitleWithKey = preg_replace('/\.(mp3|m4a|aac|mp4)$/i', '', $file->name);
      $songTitle = substr($songTitleWithKey, strpos($songTitleWithKey, "-") + 1);
      $playlistSongObj->song_length = $len;

//      if( $songInfo['lyricist'][0] ) {
//        $playlistSongObj->lyrics = $songInfo['lyricist'][0];
//      }
      if( !isset($songCategoryId) ) {
        $metaInfo['genre'] = $songInfo['genre'][0];
      } elseif( isset($songCategoryId) && !$playlistSongObj->genre_id ) {
        $playlistSongObj->genre_id = $songCategoryId;
      }
      if( isset($artistName) ) {
        foreach( $artistName as $artist ) {
          if( !empty($artistTitleString) ) {
            $artistTitleString .= ',';
          }
          $artistParamArray[] = $artist;
          $artistTitleString .= $artist;
        }
        //   $metaInfo['artist'] = $artistTitleString;
      }

      if( !empty($metaInfo) ) {
        $info = Zend_Json::encode($metaInfo);
        $playlistSongObj->params = $info;
      }
      $songId = $playlistSongObj->save();
    }

    $playlistId = $playlistSongObj->playlist_id;
    $songArtistTable = Engine_Api::_()->getItemTable('sitemusic_songartist');
    $newArtistId = $songArtistTable->checkArtistMapping($artistParamArray, $songId, $playlistId);
// Storing song artwork image from id3
// Check the music temporary directory
    $tmpDir = APPLICATION_PATH . DIRECTORY_SEPARATOR . 'temporary' . DIRECTORY_SEPARATOR . 'music';
    if( !is_dir($tmpDir) ) {
      if( !mkdir($tmpDir, 0777, true) ) {
        throw new Sitemusic_Model_Exception('Music temporary directory did not exist and could not be created.');
      }
    }
    if( !is_writable($tmpDir) ) {
      throw new Sitemusic_Model_Exception('Music temporary directory is not writable.');
    }

    if( !empty($meta['id3v2']['APIC'][0]['data']) ) {
      $imgName = "song_$songId.jpg";
      $imgPath = $tmpDir . $imgName;
      $artwork = $meta['id3v2']['APIC'][0]['data'];

      if( isset($artwork) ) {
        file_put_contents($imgPath, $artwork);
      }
      $this->setPhoto($playlistSongObj, $imgPath);
      @unlink($imgPath);
    }

    return $playlistSongObj;
  }

  public function setPhoto($resource, $photo)
  {
    if( $photo instanceof Zend_Form_Element_File ) {
      $file = $photo->getFileName();
      $fileName = $file;
    } else if( $photo instanceof Storage_Model_File ) {
      $file = $photo->temporary();
      $fileName = $photo->name;
    } else if( $photo instanceof Core_Model_Item_Abstract && !empty($photo->file_id) ) {
      $tmpRow = Engine_Api::_()->getItem('storage_file', $photo->file_id);
      $file = $tmpRow->temporary();
      $fileName = $tmpRow->name;
    } else if( is_array($photo) && !empty($photo['tmp_name']) ) {
      $file = $photo['tmp_name'];
      $fileName = $photo['name'];
    } else if( is_string($photo) && file_exists($photo) ) {
      $file = $photo;
      $fileName = $photo;
    } else {
      throw new User_Model_Exception('invalid argument passed to setPhoto');
    }

    if( !$fileName ) {
      $fileName = $file;
    }
    $name = basename($file);
    $extension = ltrim(strrchr($fileName, '.'), '.');
    $base = rtrim(substr(basename($fileName), 0, strrpos(basename($fileName), '.')), '.');
    $path = APPLICATION_PATH . DIRECTORY_SEPARATOR . 'temporary';
    $params = array(
      'parent_type' => $resource->getType(),
      'parent_id' => $resource->getIdentity(),
      'name' => $fileName,
    );

    // Save
    $filesTable = Engine_Api::_()->getDbtable('files', 'storage');

    // Resize image (main)
    $mainPath = $path . DIRECTORY_SEPARATOR . $base . '_m.' . $extension;
    $image = Engine_Image::factory();
    $image->open($file)
      ->autoRotate()
      ->resize(720, 720)
      ->write($mainPath)
      ->destroy();

    // Resize image (normal)
    $normalPath = $path . DIRECTORY_SEPARATOR . $base . '_in.' . $extension;
    $image = Engine_Image::factory();
    $image->open($file)
      ->autoRotate()
      ->resize(320, 240)
      ->write($normalPath)
      ->destroy();

    // Store
    try {
      $iMain = $filesTable->createFile($mainPath, $params);
      $iIconNormal = $filesTable->createFile($normalPath, $params);

      $iMain->bridge($iIconNormal, 'thumb.normal');
    } catch( Exception $e ) {
      // Remove temp files
      @unlink($mainPath);
      @unlink($normalPath);
      // Throw
      if( $e->getCode() == Storage_Model_DbTable_Files::SPACE_LIMIT_REACHED_CODE ) {
        throw new Album_Model_Exception($e->getMessage(), $e->getCode());
      } else {
        throw $e;
      }
    }

    // Remove temp files
    @unlink($mainPath);
    @unlink($normalPath);

    // Update row
    $resource->modified_date = date('Y-m-d H:i:s');
    $resource->photo_id = $iMain->file_id;
    $resource->save();

    // Delete the old file?
    if( !empty($tmpRow) ) {
      $tmpRow->delete();
    }

    return $resource;
  }

  protected function _process($item, $compatibilityMode = false)
  {

    // Update to encoding status
    $item->status = 2;
    $item->save();

    $file = Engine_Api::_()->getItem('storage_file', $item->file_id);

    $ffmpeg_path = Engine_Api::_()->getApi('settings', 'core')->sitemusic_ffmpeg_path;
    $checkFfmpeg = $this->checkFfmpeg($ffmpeg_path);
    $tmp = APPLICATION_PATH . DIRECTORY_SEPARATOR . 'temporary' . DIRECTORY_SEPARATOR . rand(0, 1000000) . '_vconverted.mp3';
    $song = $path . $file->storage_path;
    $output = null;
    $return = null;
    $output = exec("$ffmpeg_path -i $song -acodec libmp3lame $tmp", $output, $return);
    $oldFile = Engine_Api::_()->getItem('storage_file', $file->getIdentity());

    $file->store($tmp);
    @unlink($tmp);
    $this->fetchMetaInfo($item);
  }

  public function checkFfmpeg($ffmpeg_path)
  {
    if( !$ffmpeg_path )
      return false;
    if( !function_exists('shell_exec') ) {
      return false;
    }
    if( !function_exists('exec') ) {
      return false;
    }
    if( !@file_exists($ffmpeg_path) || !@is_executable($ffmpeg_path) ) {
      $output = null;
      $return = null;
      exec($ffmpeg_path . ' -version', $output, $return);
      if( $return > 0 ) {
        return false;
      }
    }
    return true;
  }

}
