<?php

/**
 * SocialEngine
 *
 * @category   Application_Extensions
 * @package    Sitemusic
 * @copyright  Copyright 2009-2010 BigStep Technologies Pvt. Ltd.
 * @license    http://www.Seaocores.com/license/
 * @version    $Id: Mooupload.php 2010-11-18 9:40:21Z Seaocores $
 * @author     SocialEngineAddOns
 */
class Sitemusic_Service_FancyUpload extends Seaocore_Service_FancyUpload
{

  /**
   * Detect the upload method and process the files uploaded
   * @param		string	Directory destination path
   * @param		boolean	Return response to the script
   * @return	array		Response
   */
  public static function upload($destpath = APPLICATION_PATH . DS . 'temporary' . DS)
  {
    return self::HTML5_upload($destpath);
  }

  public static function HTML5_upload($destpath)
  {
    // Normalize path
    $destpath = self::_normalize_path($destpath);
    // Check if path exist
    if( !file_exists($destpath) )
      throw new Exception('Destination Path do not exist!');

    $fileType = $_GET['accept'] ?: 'default';
    $limit = self::getMaximumUploadSize($fileType);

    // Read headers
    $response = array();
    $headers = self::_read_headers();
    $response['id'] = $_GET['X-File-Id'];
    $response['name'] = basename($_GET['X-File-Name']);
    $response['size'] = $headers['Content-Length'];
    $response['error'] = UPLOAD_ERR_OK;
    $response['finish'] = FALSE;

    // Detect upload errors
    if( $response['size'] > $limit && $response['size'] != -1 )
      $response['error'] = UPLOAD_ERR_INI_SIZE;

    // Firefox 4 sometimes sends a empty packet as last packet
    // else if ($headers['Content-Length'] == 0)
    // $response['error'] = UPLOAD_ERR_NO_FILE;
    // Is resume?
    // $flag = (bool) $_GET['X-File-Resume'] ? FILE_APPEND : 0;
    $flag = $_GET['X-File-Resume'] ? FILE_APPEND : FILE_USE_INCLUDE_PATH;
    $filePath = $destpath . $response['id'] . '-' . $response['name'];

    // Write file
    $content = file_get_contents('php://input');
    if( !empty($_GET['is_url']) ) {
      $content = file_get_contents($content);
    }

    if( file_put_contents($filePath, $content, $flag) === FALSE ) {
      $response['error'] = UPLOAD_ERR_CANT_WRITE;
    } else if( isset($_GET['X-File-Size']) && (filesize($filePath) >= $_GET['X-File-Size']) ) {
      $response['finish'] = TRUE;
    }

    $view = Zend_Registry::isRegistered('Zend_View') ? Zend_Registry::get('Zend_View') : null;
    $view->assign($response);
    if( empty($response['finish']) ) {
      self::sendJson($response);
    }

    if( empty(self::isValid($filePath)) ) {
      $response['error'] = 'Invalid File Type';
      @unlink($filePath);
      self::sendJson($response);
    }

    @chmod($filePath, 0777);
    $response['path'] = $filePath;
    return $response;
  }

  protected function isValid($filePath)
  {
    if( empty($_GET['accept']) )
      return true;

    $isSprtMulExtension = Engine_Api::_()->getApi('settings', 'core')->sitemusic_multipleextension;
    if( $isSprtMulExtension ) {
      $extension = array('audio/mpeg', 'audio/ogg', 'audio/aac', 'video/ogg', 'video/mp4', 'audio/x-flac', 'audio/x-wav', 'application/octet-stream', 'audio/mpeg3', 'audio/x-mpeg-3');
    } else {
      $extension = array('audio/mpeg', 'application/octet-stream', 'audio/mpeg3', 'audio/x-mpeg-3' ,'audio/x-wav');
    }
    $extensionType = mime_content_type($filePath);
    if( in_array($extensionType, $extension) ) {
      return true;
    } else {
      return false;
    }
  }

}
