<?php

/**
 * SocialEngine
 *
 * @category   Application_Extensions
 * @package    Sitemusic
 * @copyright  Copyright 2017-2022 BigStep Technologies Pvt. Ltd.
 * @license    http://www.socialengineaddons.com/license/
 * @version    ArtistController.php 2017-03-27 9:40:21Z SocialEngineAddOns $
 * @author     SocialEngineAddOns
 */
class Sitemusic_PlaylistsController extends Core_Controller_Action_Standard
{

  public function init()
  {
    if( !$this->_helper->requireAuth()->setAuthParams('sitemusic_pl', null, 'view')->isValid() ) {
      return $this->_forwardCustom('notfound', 'error', 'core');
    }
  }

  public function indexAction()
  {
    // Check auth
    if( !$this->_helper->requireAuth()->setAuthParams('sitemusic_userpl', null, 'view')->isValid() ) {
      return;
    }
    $pageTable = Engine_Api::_()->getDbtable('pages', 'core');
    $pageSelect = $pageTable->select()->where('name = ?', "sitemusic_playlists_index");
    $pageObject = $pageTable->fetchRow($pageSelect);
    if( Engine_API::_()->sitemusic()->checkSitemobileMode('fullsite-mode') ) {
      $this->_helper->content
        ->setContentName($pageObject->page_id)
        ->setNoRender()
        ->setEnabled();
    } else {
      $this->_helper->content
        ->setNoRender()
        ->setEnabled();
    }
  }

  public function viewAction()
  {
    // Check permission
    $viewer = Engine_Api::_()->user()->getViewer();
    $userPlaylist = Engine_Api::_()->getItem('sitemusic_userpl', $this->_getParam('item_id'));
    if( $userPlaylist ) {
      Engine_Api::_()->core()->setSubject($userPlaylist);
    }
    if( !$this->_helper->requireSubject()->isValid() ) {
      return;
    }
    if( !$this->_helper->requireAuth()->setAuthParams('sitemusic_userpl', $viewer, 'view')->isValid() ) {
      return;
    }
    // Prepare data
    $userPlaylistTable = Engine_Api::_()->getDbtable('userPlaylists', 'sitemusic');

    $this->view->owner = $owner = $userPlaylist->getOwner();
    $this->view->viewer = $viewer;
    $this->view->viewer_id = $viewer->getIdentity();
    $this->view->rating_count = Engine_Api::_()->sitemusic()->ratingCount($userPlaylist->getIdentity(), $userPlaylist->getType());
    $this->view->playlist = $userPlaylist;
    $this->view->rated = Engine_Api::_()->sitemusic()->checkRated($userPlaylist->getIdentity(), $viewer->getIdentity(), $userPlaylist->getType());
    // Get styles
    $table = Engine_Api::_()->getDbtable('styles', 'core');
    $style = $table->select()
      ->from($table, 'style')
      ->where('type = ?', 'user_blog')
      ->where('id = ?', $owner->getIdentity())
      ->limit(1)
      ->query()
      ->fetchColumn();
    if( !empty($style) ) {
      try {
        $this->view->headStyle()->appendStyle($style);
      }
      // silence any exception, exceptin in development mode
      catch( Exception $e ) {
        if( APPLICATION_ENV === 'development' ) {
          throw $e;
        }
      }
    }

    // Render
    $this->_helper->content
      //->setNoRender()
      ->setEnabled()
    ;
  }

  public function appendAction()
  {
    // Check auth
    if( !$this->_helper->requireUser()->isValid() ) {
      return;
    }
    if( !$this->_helper->requireAuth()->setAuthParams('sitemusic_userpl', null, 'create')->isValid() ) {
      return;
    }
    $userPlaylistId = null;
    $songId = $this->_getParam('item_id');
    $userPlaylistSong = Engine_Api::_()->getDbtable('userPlaylistSongs', 'sitemusic');
    $songs = $userPlaylistSong->select()
      ->from($userPlaylistSong)
      ->where('song_id = ?', $songId)
      ->query()
      ->fetchAll();
    if( $songs ) {
      foreach( $songs as $row ) {
        $userPlaylistId = $row['userplaylist_id'];
      }
    }
    $viewer = Engine_Api::_()->user()->getViewer();

    // Get form
    $this->view->form = $form = new Sitemusic_Form_UserPlaylist_Append();
    $userPlaylistTable = Engine_Api::_()->getDbtable('userPlaylists', 'sitemusic');
    $playlists = $userPlaylistTable->select()
      ->from($userPlaylistTable, array('userplaylist_id', 'title'))
      ->where('owner_type = ?', 'user')
      ->where('owner_id = ?', $viewer->getIdentity())
      ->query()
      ->fetchAll();
    foreach( $playlists as $playlist ) {
      if( isset($playlist['userplaylist_id']) && $playlist['userplaylist_id'] != $userPlaylistId ) {
        $form->userplaylist_id->addMultiOption($playlist['userplaylist_id'], html_entity_decode($playlist['title']));
      }
    }

    // Check method/data
    if( !$this->getRequest()->isPost() ) {
      return;
    }

    if( !$form->isValid($this->getRequest()->getPost()) ) {
      return;
    }

    // Get values
    $values = $form->getValues();

    if( empty($values['userplaylist_id']) && empty($values['title']) ) {
      return $form->addError('Please enter a title or select a playlist.');
    }


    // Process
    $db = $userPlaylistTable->getAdapter();
    $db->beginTransaction();

    try {
      // Existing playlist
      if( !empty($values['userplaylist_id']) ) {
        $userPlaylist = Engine_Api::_()->getItem('sitemusic_userpl', $values['userplaylist_id']);
        $upId = $values['userplaylist_id'];

        $upSongTable = Engine_Api::_()->getDbtable('userPlaylistSongs', 'sitemusic');
        $select = $upSongTable->select()->from($upSongTable->info('name'), array('count(*)'));
        $select->where('userplaylist_id =?', $values['userplaylist_id']);
        $this->view->songCurrentCount = $totalExistingSong = $select->query()->fetchColumn();
        $this->view->songQuota = $quota = Engine_Api::_()->authorization()->getPermission($viewer->level_id, 'sitemusic_userpl', 'sm_max_plSong');
        if( !empty($_FILES['photo']['name']) ) {
          $photo = Engine_Api::_()->getApi('core', 'sitemusic')->setPhoto($userPlaylist, $form->photo);
          $userPlaylist->photo_id = $photo->photo_id;
        }
        // already exists in playlist
        $alreadyExists = $userPlaylistSong->select()
          ->from($userPlaylistSong, 'song_id')
          ->where('userplaylist_id = ?', $userPlaylist->getIdentity())
          ->where('song_id = ?', $songId)
          ->limit(1)
          ->query()
          ->fetchColumn()
        ;
        if( $alreadyExists ) {
          return $form->addError('This playlist already has this song.');
        }
        $userPlaylist->save();
      } else {
        // New playlist
        // max playlist allow
        $userPlaylist = Engine_Api::_()->getItemTable('sitemusic_userpl');
        $maxPlaylistAllow = Engine_Api::_()->authorization()->getPermission($viewer->level_id, 'sitemusic_userpl', 'sm_max_playlist');
        $select = $userPlaylist->select()->from($userPlaylist->info('name'), array('count(*) as totalMyPlaylist'))->where('owner_id = ?', $viewer->getIdentity());
        $result = $select->query()->fetch();

        if( !empty($result['totalMyPlaylist']) && isset($result['totalMyPlaylist']) ) {
          $totalExistingPlaylist = $result['totalMyPlaylist'];

          if( $totalExistingPlaylist && $maxPlaylistAllow ) {
            if( ($totalExistingPlaylist + 1) > $maxPlaylistAllow ) {
              $this->view->maximumPlaylistExist = true;
              return;
            }
          }
        }

        $param = array();
        $paginator = $userPlaylist->getPaginator($param);
        $this->view->newPlaylist = 1;
//        $this->view->quota = $quota = Engine_Api::_()->authorization()->getPermission($viewer->level_id, 'sitemusic_userpl', 'sm_max_playlist');
//        $this->view->current_count = $totalExistingPlaylist+1;
        $alreadyExists = $userPlaylistTable->select()
          ->from($userPlaylistTable)
          ->where('title = ?', trim($values['title']))
          ->limit(1)
          ->query()
          ->fetchColumn()
        ;
        if( $alreadyExists ) {
          return $form->addError('This playlist already has this same name.');
        }
        $userPlaylist = $userPlaylistTable->createRow();
        $userPlaylist->title = trim($values['title']);
        if( isset($values['auth_view_pl']) ) {
          $userPlaylist->view_privacy = $values['auth_view_pl'];
        }
        $userPlaylist->owner_type = 'user';
        $userPlaylist->owner_id = $viewer->getIdentity();
        $userPlaylist->search = 1;
        try {
          if( !empty($_FILES['photo']['name']) ) {
            $photo = Engine_Api::_()->getApi('core', 'sitemusic')->setPhoto($userPlaylist, $form->photo);
            $userPlaylist->photo_id = $photo->photo_id;
          }
          $upId = $userPlaylist->save();
        } catch( Exception $e ) {
          echo $e->getMessage();
        }
        // Add action and attachments
        $auth = Engine_Api::_()->authorization()->context;
        foreach( array('everyone', 'registered', 'member') as $role ) {
          $auth->setAllowed($userPlaylist, $role, 'view', true);
        }
        if( $userPlaylist->search ) {
          $activity = Engine_Api::_()->getDbtable('actions', 'activity');
          $action = $activity->addActivity(Engine_Api::_()->user()->getViewer(), $userPlaylist, 'sitemusic_user_playlist_new');
          if( $action ) {
            $activity->attachActivity($action, $userPlaylist);
          }
        }

        $roles = array(
          'everyone' => 'Everyone',
          'registered' => 'All Registered Members',
          'owner_network' => 'Friends and Networks',
          'owner_member_member' => 'Friends of Friends',
          'owner_member' => 'Friends Only',
          'owner' => 'Just Me'
        );

        // Authorizations
        $auth = Engine_Api::_()->authorization()->context;
        $prev_allow_comment = $prev_allow_view = false;
        foreach( $roles as $role => $role_label ) {
          // allow viewers
          if( isset($values['auth_view_pl']) && ($values['auth_view_pl'] == $role) || $prev_allow_view ) {
            $auth->setAllowed($userPlaylist, $role, 'view', true);
            $prev_allow_view = true;
          } else
            $auth->setAllowed($userPlaylist, $role, 'view', 0);

          // allow comments
          if( isset($values['auth_comment_pl']) && ($values['auth_comment_pl'] == $role) || $prev_allow_comment ) {
            $auth->setAllowed($userPlaylist, $role, 'comment', true);
            $prev_allow_comment = true;
          } else
            $auth->setAllowed($userPlaylist, $role, 'comment', 0);
        }
      }
      $params['song_id'] = $songId;
      $params['userplaylist_id'] = $upId;
//      // Add song
      $userPlaylist->addSong($params);



//      // Response
      $this->view->success = true;
      $this->view->message = $this->view->translate('Your changes have been saved.');
      $this->view->playlist = $userPlaylist;

      $db->commit();
    } catch( Sitemusic_Model_Exception $e ) {
      $this->view->success = false;
      $this->view->error = $this->view->translate($e->getMessage());
      $form->addError($e->getMessage());

      $db->rollback();
    } catch( Exception $e ) {
      $this->view->success = false;
      $db->rollback();
    }
  }

  public function addQueueToPlaylistAction()
  {
    // Check auth
    if( !$this->_helper->requireUser()->isValid() ) {
      return;
    }

    if( !$this->_helper->requireAuth()->setAuthParams('sitemusic_userpl', null, 'create')->isValid() ) {
      return;
    }

    $this->view->form = $form = new Sitemusic_Form_UserPlaylist_Append();

    $songIds = $this->_getParam('item_id');
    $songIds = explode(',', $songIds);

    // Check method/data
    if( !$this->getRequest()->isPost() ) {
      return;
    }

    if( !$form->isValid($this->getRequest()->getPost()) ) {
      return;
    }

    // Get values
    $values = $form->getValues();
    if( empty($values['userplaylist_id']) && empty($values['title']) ) {
      return $form->addError('Please enter a title or select a playlist.');
    }

    $viewer = Engine_Api::_()->user()->getViewer();
    $userPlaylistTable = Engine_Api::_()->getDbtable('userPlaylists', 'sitemusic');

    $alreadyExistName = $userPlaylistTable->select()
      ->where('title = ?', trim($values['title']))
      ->limit(1)
      ->query()
      ->fetchColumn()
    ;

    if( $alreadyExistName ) {
      return $form->addError('This playlist already has this same name.');
    }
    // Process
    $db = $userPlaylistTable->getAdapter();
    $db->beginTransaction();
    $upId = null;
    try {

      // Existing playlist
      if( !empty($values['userplaylist_id']) ) {
        $userPlaylist = Engine_Api::_()->getItem('sitemusic_userpl', $values['userplaylist_id']);
        $upId = $values['userplaylist_id'];

        $upSongTable = Engine_Api::_()->getDbtable('userPlaylistSongs', 'sitemusic');
        $select = $upSongTable->select()->from($upSongTable->info('name'), array('count(*)'));
        $select->where('userplaylist_id =?', $values['userplaylist_id']);
        $this->view->current_count = $totalExistingSong = $select->query()->fetchColumn();
        $this->view->quota = $quota = Engine_Api::_()->authorization()->getPermission($viewer->level_id, 'sitemusic_userpl', 'sm_max_playlist');

        if( !empty($_FILES['photo']['name']) ) {
          $photo = Engine_Api::_()->getApi('core', 'sitemusic')->setPhoto($userPlaylist, $form->photo);
          $userPlaylist->photo_id = $photo->photo_id;
        }
      }

      // New playlist
      else {
        $param = array();
        $paginator = Engine_Api::_()->getItemTable('sitemusic_userpl')->getPaginator($param);
        $this->view->quota = $quota = Engine_Api::_()->authorization()->getPermission($viewer->level_id, 'sitemusic_userpl', 'sm_max_playlist');
        $this->view->current_count = $paginator->getTotalItemCount();
        $userPlaylist = $userPlaylistTable->createRow();
        $userPlaylist->title = trim($values['title']);
        if( isset($values['auth_view_pl']) ) {
          $userPlaylist->view_privacy = $values['auth_view_pl'];
        }
        $userPlaylist->owner_type = 'user';
        $userPlaylist->owner_id = $viewer->getIdentity();
        $userPlaylist->search = 1;
        try {
          if( !empty($_FILES['photo']['name']) ) {
            $photo = Engine_Api::_()->getApi('core', 'sitemusic')->setPhoto($userPlaylist, $form->photo);
            $userPlaylist->photo_id = $photo->photo_id;
          }
          $upId = $userPlaylist->save();
        } catch( Exception $e ) {
          echo $e->getMessage();
        }
        // Add action and attachments
        $auth = Engine_Api::_()->authorization()->context;
        $auth->setAllowed($userPlaylist, 'registered', 'comment', true);
        foreach( array('everyone', 'registered', 'member') as $role ) {
          $auth->setAllowed($userPlaylist, $role, 'view', true);
        }
 
        if( $userPlaylist->search ) {
          $activity = Engine_Api::_()->getDbtable('actions', 'activity');
          $action = $activity->addActivity(Engine_Api::_()->user()->getViewer(), $userPlaylist, 'sitemusic_user_playlist_new');
          if( $action ) {
            $activity->attachActivity($action, $userPlaylist);
          }
        }
      }
//
//      // Response

      $this->view->playlist = $userPlaylist;

      $db->commit();
    } catch( Sitemusic_Model_Exception $e ) {
      $this->view->success = false;
      $this->view->error = $this->view->translate($e->getMessage());
      $form->addError($e->getMessage());

      $db->rollback();
    }

    // max song allow in playlist
    $quota = Engine_Api::_()->authorization()->getPermission($viewer->level_id, 'sitemusic_userpl', 'sm_max_plSong');
    $len = count($songIds);
    $i = 0;
    foreach( $songIds as $songId ) {
      if( $i > 1 ) {
        $isCheck = false;
      } else {
        $isCheck = true;
      }
      if( !empty($upId) ) {
        $userPlaylistSong = Engine_Api::_()->getDbtable('userPlaylistSongs', 'sitemusic');
        $count = $userPlaylistSong->select()->from($userPlaylistSong->info('name'), array('count(*) as totalSongs'))
            ->where('userplaylist_id = ?', $upId)->query()->fetch();
      }
      if( $quota && $quota < $i ) {
        $this->view->songQuota = $quota;
        $this->view->songCurrentCount = $count['totalSongs'];
      }
      $i++;
      if( $i == $len ) {
        $msg = true;
      } else {
        $msg = false;
      }
      $this->savePlaylist($values, $form, $songId, $upId, $isCheck, $msg);
    }
  }

  public function savePlaylist($values, $form, $songId, $upId, $isCheck, $msg)
  {
    $userPlaylistSong = Engine_Api::_()->getDbtable('userPlaylistSongs', 'sitemusic');
    // already exists in playlist
    $alreadyExistSong = $userPlaylistSong->select()
      ->from($userPlaylistSong, 'song_id')
      ->where('userplaylist_id = ?', $upId)
      ->where('song_id = ?', $songId)
      ->limit(1)
      ->query()
      ->fetchColumn()
    ;
    if( $alreadyExistSong ) {
      return $form->addError('This playlist already has this song.');
    }
    $userPlaylistTable = Engine_Api::_()->getDbtable('userPlaylists', 'sitemusic');

    $params['song_id'] = $songId;
    $params['userplaylist_id'] = $upId;
    $userPlaylist = Engine_Api::_()->getItem('sitemusic_userpl', $upId);
//      // Add song
    $userPlaylist->addSong($params);

    if( $msg ) {
      $this->view->success = true;
      $this->view->message = $this->view->translate('Your changes have been saved.');
    }
  }

  public function deleteAction()
  {
    $this->_helper->layout->setLayout('default-simple');
    // In smoothbox
    $id = $this->_getParam('id');
    $this->view->playlist_id = $id;

    // Check post
    if( $this->getRequest()->isPost() ) {
      $db = Engine_Db_Table::getDefaultAdapter();
      $db->beginTransaction();

      try {
        $table = Engine_Api::_()->getItem('sitemusic_userpl', $id);
        // delete the playlist into the database
        $table->delete();
        $db->commit();
      } catch( Exception $e ) {
        $db->rollBack();
        throw $e;
      }

      $this->view->status = true;
      $this->view->message = Zend_Registry::get('Zend_Translate')->_('playlist has been successfully deleted.');
      $this->_forward('success', 'utility', 'core', array(
        'smoothboxClose' => true,
        'parentRedirect' => Zend_Controller_Front::getInstance()->getRouter()->assemble(array('controller' => 'playlists'), "sitemusic_general", true),
        'parentRedirectTime' => '2',
        'format' => 'smoothbox',
        'messages' => array($this->view->message)
      ));
    }
  }

  public function editAction()
  {
    $this->_helper->layout->setLayout('default-simple');
    // In smoothbox
    $id = $this->_getParam('item_id');
    $table = Engine_Api::_()->getDbtable('userPlaylists', 'sitemusic');
    $userPlaylist = $table->find($id)->current();

    if( empty($userPlaylist) ) {
      $this->view->message = 'playlist entry does not exist ';
      $this->view->error = true;
      return;
    }


    $songs = $userPlaylist->getSongAssoc();
    $oldSongIds = array_keys($songs);
    // Generate and assign form
    $this->view->form = $form = new Sitemusic_Form_UserPlaylist_EditPlaylist(array('songs' => $songs));
    $form->removeElement('userplaylist_id');
    $form->setTitle('Edit Playlist');
    $form->setAction($this->view->url(array()));

    if( $userPlaylist ) {
      $form->populate($userPlaylist->toArray());
    }
    $roles = array('owner', 'owner_member', 'owner_member_member', 'owner_network', 'registered', 'everyone');
    $authCommentPlaylist = $form->getElement('comment_privacy');
    $auth = Engine_Api::_()->authorization()->context;
    if( $authCommentPlaylist ) {
      $lowestCommenter = array_pop($roles);
      foreach( $roles as $role ) {
        if( $auth->isAllowed($userPlaylist, $role, 'comment') ) {
          $lowestCommenter = $role;
        }
      }
      $authCommentPlaylist->setValue($lowestCommenter);
    }


    // Check post
    if( !$this->getRequest()->isPost() ) {
      return;
    }
    if( !$form->isValid($this->getRequest()->getPost()) ) {
      return;
    }

    // Process
    $values = $form->getValues();

    $viewer = Engine_Api::_()->user()->getViewer();
//    // Update row
    $db = $table->getAdapter();
    $db->beginTransaction();

    try {
      $upSong = Engine_Api::_()->getDbtable('userPlaylistSongs', 'sitemusic');
      $songIds = $values['song_id'];
      if( empty($songIds) ) {
//        foreach( $oldSongIds as $osId ) {
//          $this->deleteSongAction($osId, $id);
//        }

        $upSong->delete(array('userplaylist_id = ?' => $id));
        $userPlaylist->song_count = 0;
        $userPlaylist->save();
      } else {
        $songCount = $userPlaylist->song_count;
        $commonSongIds = array_intersect($oldSongIds, $songIds);
        $diffSongIds = array_diff($oldSongIds, $commonSongIds);

        if( !empty($diffSongIds) ) {
          foreach( $diffSongIds as $sId ) {
            $upSong->delete(array('userplaylist_id = ?' => $id, 'song_id = ?' => $sId));
            $songCount--;
          }
        }
        $userPlaylist->song_count = $songCount;
        $userPlaylist->save();
      }
      $userPlaylist->title = $values['title'];
      if( !empty($_FILES['photo']['name']) ) {
        $photo = Engine_Api::_()->getApi('core', 'sitemusic')->setPhoto($userPlaylist, $form->photo);
        $userPlaylist->photo_id = $photo->photo_id;
      }

      $userPlaylist->view_privacy = $values['view_privacy'];
      $userPlaylist->save();
      // Auth
      $auth = Engine_Api::_()->authorization()->context;
      $roles = array('owner', 'owner_member', 'owner_member_member', 'owner_network', 'registered', 'everyone');

      if( empty($values['comment_privacy']) ) {
        $values['comment_privacy'] = 'everyone';
      }

      $commentMax = array_search($values['comment_privacy'], $roles);
      foreach( $roles as $i => $role ) {
        $auth->setAllowed($userPlaylist, $role, 'comment', ($i <= $commentMax));
      }


      $db->commit();
    } catch( Exception $e ) {
      $db->rollBack();
      throw $e;
    }

    return $this->_forward('success', 'utility', 'core', array(
        'parentRefresh' => 15,
        'messages' => array('playlist has been successfully edited')
    ));
  }

  public function deleteSongAction($id = null, $userPlaylistId = null)
  {
    $this->_helper->layout->setLayout('default-simple');
    // if( empty($id) ) {
    // In smoothbox
    if( empty($id) ) {
      $id = $this->_getParam('id');
    }
    //print_r($id);
    //die;
    if( empty($userPlaylistId) ) {
      $userPlaylistId = $this->_getParam('userplaylist_id');
    }
    $userPlaylist = Engine_Api::_()->getItem('sitemusic_userpl', $userPlaylistId);
    if( empty($userPlaylist) ) {
      return;
    }
    $this->view->song_id = $id;
    $table = Engine_Api::_()->getDbtable('userPlaylistSongs', 'sitemusic');
    if( $this->getRequest()->isPost() ) {
      $db = Engine_Db_Table::getDefaultAdapter();
      $db->beginTransaction();

      try {
        // delete the playlist into the database
        $table->delete(array('song_id = ?' => $id));
        $db->commit();
      } catch( Exception $e ) {
        $db->rollBack();
        throw $e;
      }
      $songCount = $userPlaylist->song_count;
      $userPlaylist->song_count = --$songCount;
      $userPlaylist->save();

      $this->view->status = true;
      $this->view->message = Zend_Registry::get('Zend_Translate')->_('Your entry has been deleted.');
      return $this->_forward('success', 'utility', 'core', array(
        'smoothboxClose' => 15,
        'parentRefresh' => 15,
//  'parentRedirect' => Zend_Controller_Front::getInstance()->getRouter()->assemble(array('controller' => 'playlists', 'action' => 'index'), 'sitemusic_general', true),
          'messages' => Array($this->view->message)
      ));

//      $this->_forward('success', 'utility', 'core', array(
//        'smoothboxClose' => 10,
//        'parentRefresh' => 10,
//        'messages' => array('')
//      ));
    }

    // Output
    $this->renderScript('playlists/delete-song.tpl');
  }

  public function favouriteAction()
  {

    //GET THE VIEWER.
    $viewer = Engine_Api::_()->user()->getViewer();

    //GET THE VALUE OF RESOURCE ID AND RESOURCE TYPE AND FAVOURITE ID.
    $this->view->resource_id = $resource_id = $this->_getParam('resource_id');
    $this->view->resource_type = $resource_type = $this->_getParam('resource_type');
    $favourite_id = $this->_getParam('favourite_id');
    $status = $this->_getParam('smoothbox', 1);
    $this->view->status = true;
    //GET THE FAVOURITE BUTTON SETTINGS.
    $this->view->favourite_setting_button = Engine_Api::_()->getApi('settings', 'core')->getSetting('favourite.setting.button');

    //GET THE CURRENT UESRID AND SETTINGS.
    $this->view->viewer_id = $loggedin_user_id = Engine_Api::_()->user()->getViewer()->getIdentity();
    if( (empty($loggedin_user_id) ) ) {
      return;
    }
    //CHECK THE FAVOURITE ID.
    if( empty($favourite_id) ) {

      //CHECKING IF USER HAS MAKING DUPLICATE ENTRY OF FAVOURITING AN APPLICATION.
      $favourite_id_temp = Engine_Api::_()->getApi('favourite', 'sitemusic')->hasFavourite($resource_type, $resource_id);
      //CHECK THE THE ITEM IS FAVOURITED OR NOT.
      if( empty($favourite_id_temp[0]['favourite_id']) ) {

        $favouriteTable = Engine_Api::_()->getItemTable('sitemusic_favourite');
        $notify_table = Engine_Api::_()->getDbtable('notifications', 'activity');
        $db = $favouriteTable->getAdapter();
        $db->beginTransaction();
        try {
//            //ADD FAVOURITE
          $favourite_id = $favouriteTable->addFavourite($resource, $viewer)->favourite_id;
          //PASS THE FAVOURITE ID VALUE.
          $this->view->favourite_id = $favourite_id;
          $db->commit();
        } catch( Exception $e ) {
          $db->rollBack();
          throw $e;
        }
        $favourite_msg = Zend_Registry::get('Zend_Translate')->_('Successfully Favourited.');
      } else {
        $this->view->favourite_id = $favourite_id_temp[0]['favourite_id'];
      }
    } else {

      //START DELETE NOTIFICATION
      Engine_Api::_()->getDbtable('notifications', 'activity')->delete(array('type = ?' => 'favourited', 'subject_id = ?' => $viewer->getIdentity(), 'subject_type = ?' => $viewer->getType(), 'object_type = ?' => $resource_type, 'object_id = ?' => $resource_id));
      //END DELETE NOTIFICATION
      ////START UNFAVOURITE WORK.
      //HERE 'PAGE OR LIST PLUGIN' CHECK WHEN UNFAVOURITE
      if( !empty($resource) && isset($resource->favourite_count) ) {
        $resource->favourite_count--;
        $resource->save();
      }
      $contentTable = Engine_Api::_()->getDbTable('favourites', 'sitemusic')->delete(array('favourite_id =?' => $favourite_id));
      //END UNFAVOURITE WORK.
      $favourite_msg = Zend_Registry::get('Zend_Translate')->_('Successfully Unfavourited.');
    }
    if( empty($status) ) {
      $this->_forward('success', 'utility', 'core', array(
        'smoothboxClose' => true,
        'parentRefresh' => true,
        'messages' => array($favourite_msg)
        )
      );
    }
    //HERE THE CONTENT TYPE MEANS MODULE NAME
    $num_of_contenttype = Engine_Api::_()->getApi('favourite', 'sitemusic')->favouriteCount($resource_type, $resource_id);
    $favourites_number = $this->view->translate(array('%s favourite', '%s favourites', $num_of_contenttype), $this->view->locale()->toNumber($num_of_contenttype));
    $this->view->num_of_favourite = "<a href='javascript:void(0);' onclick='showSmoothBox(); return false;' >" . $favourites_number . "</a>";
  }

  public function rateAction()
  {
    $viewer = Engine_Api::_()->user()->getViewer();
    $user_id = $viewer->getIdentity();
    $resourceType = 'sitemusic_userpl';
    $rating = $this->_getParam('rating');
    $item_id = $this->_getParam('item_id');

    $table = Engine_Api::_()->getDbtable('ratings', 'sitemusic');
    $db = $table->getAdapter();
    $db->beginTransaction();

    try {
      Engine_Api::_()->sitemusic()->setRating($item_id, $user_id, $rating, $resourceType);

      $userPlaylist = Engine_Api::_()->getItem('sitemusic_userpl', $item_id);
      $userPlaylist->rating_count = $result = Engine_Api::_()->sitemusic()->getRating($userPlaylist->getIdentity(), $resourceType);
      $userPlaylist->save();

      $db->commit();
    } catch( Exception $e ) {
      $db->rollBack();
      throw $e;
    }

    $total = Engine_Api::_()->sitemusic()->ratingCount($userPlaylist->getIdentity(), $resourceType);

    $data = array();
    $data[] = array(
      'total' => $total,
      'rating' => $rating,
    );
    return $this->_helper->json($data);
  }

  public function getPlaylistOfTheDayAction()
  {
    $data = array();
    $userplaylistTable = Engine_Api::_()->getDbtable('userPlaylists', 'sitemusic');
    $select = $userplaylistTable->select()
        ->where('title  LIKE ? ', '%' . $this->_getParam('text') . '%')
        ->order('title ASC')->limit('10');
    $playlists = $userplaylistTable->fetchAll($select);

    foreach( $playlists as $playlist ) {
      $playlistPhoto = $this->view->itemPhoto($playlist, 'thumb.normal');
      $data[] = array(
        'id' => $playlist->userplaylist_id,
        'label' => $playlist->title,
        'photo' => $playlistPhoto
      );
    }
    return $this->_helper->json($data);
  }

  protected function _forwardCustom($action, $controller = null, $module = null, array $params = null)
  {
    // Parent
    $request = $this->getRequest();

    if( null !== $params ) {
      $request->setParams($params);
    }

    if( null !== $controller ) {
      $request->setControllerName($controller);

      // Module should only be reset if controller has been specified
      if( null !== $module ) {
        $request->setModuleName($module);
      }
    }

    $request->setActionName($action);
    if( Engine_API::_()->seaocore()->isSiteMobileModeEnabled() ) {
      $sr_response = Engine_Api::_()->sitemobile()->setupRequest($request);
    }
    $request->setDispatched(false);
  }

}
