<?php

/**
 * SocialEngine
 *
 * @category   Application_Extensions
 * @package    Sitemusic
 * @copyright  Copyright 2017-2022 BigStep Technologies Pvt. Ltd.
 * @license    http://www.socialengineaddons.com/license/
 * @version    $Id: Controller.php 2017-03-27 9:40:21Z SocialEngineAddOns $
 * @author     SocialEngineAddOns
 */
class Sitemusic_Widget_AlbumBrowseController extends Engine_Content_Widget_Abstract
{

  public function indexAction()
  {
    // Can create?
    $this->view->canCreate = $canCreate = Engine_Api::_()->authorization()->isAllowed('sitemusic_pl', null, 'create');
    $this->view->viewer = $viewer = Engine_Api::_()->user()->getViewer();
    $this->view->viewer_id = $viewerId = $viewer->getIdentity();
    $limit = $this->_getParam('limit', 5);
// Get browse params
    $this->view->formFilter = $formFilter = new Sitemusic_Form_Search();
    if( $formFilter->isValid($this->_getAllParams()) ) {
      $values = $formFilter->getValues();
    } else {
      $values = array();
    }
    // only published album display
    $values['published'] = 1;

    $allParam = Zend_Controller_Front::getInstance()->getRequest()->getParams();
    $this->view->value = $allParam;
    if( !isset($allParam['page']) ) {
      $page = 1;
    } else {
      $page = $allParam['page'];
    }
    if( $this->_getParam('randomNum') ) {
      $this->view->randomNumber = $this->_getParam('randomNum');
    } else {
      $this->view->randomNumber = $params['randomNum'] = rand();
    }
    $this->view->enableStatsCountOnZero = Engine_Api::_()->sitemusic()->enableStatsCountOnZero();
    $this->view->enablePlaylist = $enablePlaylist = Engine_Api::_()->sitemusic()->isPlaylistEnabled();
    $this->view->enableAlbumFavourite = $enableAlbumFavourite = Engine_Api::_()->sitemusic()->enableAlbumFavourite();
    $this->view->isRatingEnable = $enableAlbumRating = Engine_Api::_()->sitemusic()->enableAlbumRating();
    $this->view->isAlbumShareEnable = $enableAlbumShare = Engine_Api::_()->sitemusic()->enableAlbumShare();

    $this->view->formValues = array_filter($values);

    $showOptions = $params['showOptions'] = $this->_getParam('showOptions');
    $showViewOptions = $params['showOptions'] = $this->_getParam('showSongOptions');
    if( isset($showViewOptions) && !empty($showViewOptions) ) {
      $options = array_merge($showViewOptions, $showOptions);
    } else {
      $options = $showOptions;
    }
    $this->view->albumShowOptions = $options;
    $this->view->gridViewWidth = $this->_getParam('gridViewWidth');
    $this->view->gridViewHeight = $this->_getParam('gridViewHeight');
    $this->view->cardViewWidth = $this->_getParam('cardViewWidth');
    $this->view->cardViewHeight = $this->_getParam('cardViewHeight');

    $albumLayoutViews = $params['album_layout_views'] = $this->_getParam('album_layout_views', array("list_view", "grid_view", "card_view"));
    sort($albumLayoutViews);
    foreach( $albumLayoutViews as $key => $value )
      $albumLayoutViews[$key] = str_replace("ZZZ", "_", $value);

    $this->view->album_layout_views = $albumLayoutViews;
    $this->view->albumDefaultLayout = $albumDefaultLayout = str_replace("ZZZ", "_", $this->_getParam('albumDefaultLayout', 'list_view'));
    if( count($albumLayoutViews) == 1 ) {
      $this->view->albumDefaultLayout = $albumDefaultLayout = $albumLayoutViews[0];
    }
    $this->view->list_title_truncation = $this->_getParam('listTitleTruncationLimit', 25);
    $this->view->grid_title_truncation = $this->_getParam('gridTitleTruncationLimit', 25);
    $this->view->card_title_truncation = $this->_getParam('cardTitleTruncationLimit', 25);
    $this->view->thumbnail_title_truncation = $this->_getParam('thumbnailTitleTruncationLimit', 20);
    $this->view->gridViewWidth = $this->_getParam('gridViewWidth', 167);
    $this->view->gridViewHeight = $this->_getParam('gridViewHeight', 140);
    $values['sort'] = $this->_getParam('default_sort', 'creationDate');
    if( empty($values['albumcategory_id']) && !isset($values['albumcategory_id']) ) {
      $values['albumcategory_id'] = $this->_getParam('albumcategory_id');
    }

    $values['labelType'] = $this->_getParam('label_category');
    $values['type'] = 'sitemusic_pl';

    // Show
    if( isset($allParam['show']) ) {
      if( $allParam['show'] == 2 && $viewer->getIdentity() ) {
        // Get an array of friend ids
        $values['users'] = $viewer->membership()->getMembershipsOfIds();
        $values['searchBit'] = 1;
      } elseif( $allParam['show'] == 3 && $viewerId ) {
        $values['only_my'] = $viewerId;
      }
    }

    if( isset($allParam['search']) ) {
      $values['title'] = $allParam['search'];
    }
    if( isset($allParam['alphabet']) ) {
      $values['alphabet'] = $allParam['alphabet'];
      $values['title'] = null;
    }
    if( isset($allParam['albumcategory_id']) ) {
      $values['albumcategory_id'] = $allParam['albumcategory_id'];
    }
    if( isset($allParam['sort']) ) {
      $values['sort'] = $allParam['sort'];
    }
//    if( isset($allParam['labelType']) ) {
//      $values['labelType'] = $allParam['labelType'];
//    }

    $url = $this->view->htmlLink(array('route' => 'sitemusic_general', 'module' => 'sitemusic', 'controller' => 'albums', 'action' => 'create'), ' clicking here.');
    if( isset($values['albumcategory_id']) && !empty($values['albumcategory_id']) ) {
      $message = 'Nobody has created any music album under this category. Get started by creating a music album now by';
      if( $canCreate ) {
        $message = $message . $url;
      }
      $this->view->message = $message;
    } else {
      $message = 'Nobody has created any music album yet. Get started by creating a music album now by';
      if( $canCreate ) {
        $message = $message . $url;
      }
      $this->view->message = $message;
    }

    $element = $this->getElement();
    $widgetTitle = $this->view->heading = $element->getTitle();
    if( !empty($widgetTitle) ) {
      $element->setTitle("");
    } else {
      $this->view->heading = "";
    }

    // for others plugin
    $values['parent_type'] = $this->_getParam('item_type');
    $playlistTable = Engine_Api::_()->getDbTable('playlists', 'sitemusic');
// Get paginator
    $this->view->paginator = $paginator = $playlistTable->getPaginator($values);
    $this->view->totalCount = $paginator->getTotalItemCount();
    $paginator->setItemCountPerPage($limit);
    $this->view->params = array('page' => $page);
    $this->view->paginator = $paginator->setCurrentPageNumber($page);
  }

}
