<?php

/**
 * SocialEngine
 *
 * @category   Application_Extensions
 * @package    Sitemusic
 * @copyright  Copyright 2017-2022 BigStep Technologies Pvt. Ltd.
 * @license    http://www.socialengineaddons.com/license/
 * @version    $Id: Controller.php 2017-03-27 9:40:21Z SocialEngineAddOns $
 * @author     SocialEngineAddOns
 */
class Sitemusic_Widget_UserAlbumController extends Engine_Content_Widget_Abstract
{
  
  protected $_childCount;

  public function indexAction()
  {
    $this->view->viewer = $viewer = Engine_Api::_()->user()->getViewer();
    $this->view->viewer_id = $viewerId = $viewer->getIdentity();
    // Can create?
    $this->view->canCreate = $canCreate = Engine_Api::_()->authorization()->isAllowed('sitemusic_pl', null, 'create');

    $this->view->enablePlaylist = $enablePlaylist = Engine_Api::_()->sitemusic()->isPlaylistEnabled();
    // get all params including search
    $allParam = Zend_Controller_Front::getInstance()->getRequest()->getParams();
    $this->view->value = $allParam;
    if( !isset($allParam['page']) ) {
      $page = 1;
    } else {
      $page = $allParam['page'];
    }
    $values['sort'] = $this->_getParam('default_sort');

    $showOptions = $params['showOptions'] = $this->_getParam('showOptions');
    $showViewOptions = $params['showOptions'] = $this->_getParam('showSongOptions');
    if( isset($showViewOptions) && !empty($showViewOptions) ) {
      $options = array_merge($showViewOptions, $showOptions);
    } else {
      $options = $showOptions;
    }
    $this->view->albumShowOptions = $options;
    $albumLayoutViews = $params['album_layout_views'] = $this->_getParam('album_layout_views', array("list_view", "grid_view", "card_view"));
    foreach( $albumLayoutViews as $key => $paramValue )
      $albumLayoutViews[$key] = str_replace("ZZZ", "_", $paramValue);
    sort($albumLayoutViews);
    $this->view->album_layout_views = $albumLayoutViews;

    $this->view->showViewMore = $this->_getParam('showViewMore', 1);
    //for my album
    $values['notCheckApprove'] = true;
    $this->view->albumDefaultLayout = $albumDefaultLayout = str_replace("ZZZ", "_", $this->_getParam('albumDefaultLayout', 'list_view'));
    if( count($albumLayoutViews) == 1 ) {
      $this->view->albumDefaultLayout = $albumDefaultLayout = $albumLayoutViews[0];
    }

    $this->view->gridViewWidth = $this->_getParam('gridViewWidth', '167');
    $this->view->gridViewHeight = $this->_getParam('gridViewHeight', '290');
    $this->view->cardViewWidth = $this->_getParam('cardViewWidth', '279');
    $this->view->cardViewHeight = $this->_getParam('cardViewHeight', '290');

    $this->view->enableStatsCountOnZero = Engine_Api::_()->sitemusic()->enableStatsCountOnZero();
    $this->view->enableAlbumFavourite  = $enableAlbumFavourite  = Engine_Api::_()->sitemusic()->enableAlbumFavourite();
    $this->view->isRatingEnable = $enableAlbumRating = Engine_Api::_()->sitemusic()->enableAlbumRating();
    $this->view->isAlbumShareEnable = $enableAlbumShare = Engine_Api::_()->sitemusic()->enableAlbumShare();

    $this->view->list_title_truncation = $this->_getParam('listTitleTruncationLimit', 25);
    $this->view->grid_title_truncation = $this->_getParam('gridTitleTruncationLimit', 25);
    $this->view->card_title_truncation = $this->_getParam('cardTitleTruncationLimit', 25);
    $this->view->thumbnail_title_truncation = $this->_getParam('thumbnailTitleTruncationLimit', 20);
    $values['albumcategory_id'] = $this->_getParam('albumcategory_id');
    $values['labelType'] = $this->_getParam('label_category');
    $values['type'] = 'sitemusic_pl';
    $this->view->message = 'There is no album uploaded yet.';
    $this->view->mymusic = 1;

    if( $this->_getParam('randomNum') ) {
      $this->view->randomNumber = $this->_getParam('randomNum');
    } else {
      $this->view->randomNumber = $values['randomNum'] = rand();
    }


    // for search
    if( isset($allParam['albumcategory_id']) ) {
      $values['albumcategory_id'] = $allParam['albumcategory_id'];
    }

    $url = $this->view->htmlLink(array('route' => 'sitemusic_general', 'module' => 'sitemusic', 'controller' => 'albums', 'action' => 'create'), ' Click here.');

    if( isset($allParam['albumcategory_id']) && !empty($allParam['albumcategory_id']) ) {
      $message = 'You have not created any music album under this category. Get started by creating a music album now.';
      if( $canCreate ) {
        $message = $message . $url . ' to create one';
      }
      $this->view->message = $message;
    } else {
      $message = 'You have not created any music album under this category. Get started by creating a music album now.';

      if( $canCreate ) {
        $message = $message . $url . ' to create one';
      }
      $this->view->message = $message;
    }

    if( isset($allParam['sort']) ) {
      $values['sort'] = $allParam['sort'];
    }

    if( isset($allParam['search']) ) {
      $values['search'] = $allParam['search'];
    }


    if (!Engine_Api::_()->core()->hasSubject()) {
      $user = $viewer;
    } else {
      $subject = Engine_Api::_()->core()->getSubject();
      $user = $subject->getOwner();
    }
    $values['user'] = $user;
    $playlistTable = Engine_Api::_()->getDbTable('playlists', 'sitemusic');
// Get paginator
    $this->view->paginator = $paginator = $playlistTable->getPaginator($values);
    $limit = $this->_getParam('limit', 5);
    $values['page'] = $page;
    $this->view->params = $values;
    $paginator->setItemCountPerPage($limit);
    $this->view->totalCount = $paginator->getTotalItemCount();
    $this->view->paginator = $paginator->setCurrentPageNumber($page);
    $this->view->paginator = $paginator;

    // Add count to title if configured
    if( $this->_getParam('titleCount', false) && $paginator->getTotalItemCount() > 0 ) {
      $this->_childCount = $paginator->getTotalItemCount();
    }
  }

  public function getChildCount()
  {
    return $this->_childCount;
  }

}
