<?php

/**
 * SocialEngine
 *
 * @category   Application_Extensions
 * @package    Sitenews
 * @copyright  Copyright 2016-2017 BigStep Technologies Pvt. Ltd.
 * @license    http://www.socialengineaddons.com/license/
 * @version    $Id: Core.php 2017-01-01 9:40:21Z SocialEngineAddOns $
 * @author     SocialEngineAddOns
 */
class Sitenews_Api_Core extends Core_Api_Abstract {

    public function deleteSuggestion($viewer_id, $entity, $entity_id, $entity_type, $notifications_type) {
        $is_moduleEnabled = Engine_Api::_()->getDbtable('modules', 'core')->isModuleEnabled('suggestion');
        if (!empty($is_moduleEnabled)) {
            $suggestion_table = Engine_Api::_()->getItemTable('suggestion');
            $suggestion_table_name = $suggestion_table->info('name');
            $suggestion_select = $suggestion_table->select()
                    ->from($suggestion_table_name, array('suggestion_id'))
                    ->where('owner_id = ?', $viewer_id)
                    ->where('entity = ?', $entity)
                    ->where('entity_id = ?', $entity_id);
            $suggestion_array = $suggestion_select->query()->fetchAll();
            if (!empty($suggestion_array)) {
                foreach ($suggestion_array as $sugg_id) {
                    Engine_Api::_()->getItem('suggestion', $sugg_id['suggestion_id'])->delete();
                    Engine_Api::_()->getDbtable('notifications', 'activity')->delete(array('object_id = ?' => $entity_id, 'object_type = ?' => $entity_type, 'type = ?' => $notifications_type));
                }
            }
        }
    }

    public function removeFeeds() {
        $remove_feeds = Engine_Api::_()->getApi('settings', 'core')->getSetting('remove.oldfeeds', 60);
        $relDate = new Zend_Date();
        $relDate->sub((int) $remove_feeds, Zend_Date::DAY);
        $dateInterval = date("Y-m-d H:i:s", $relDate->toValue());

        $db = Zend_Db_Table_Abstract::getDefaultAdapter();
        $db->beginTransaction();
        try {
            $newsTable = Engine_Api::_()->getDbtable('news', 'sitenews');
            $rssTable = Engine_Api::_()->getDbtable('rss', 'sitenews');
            $rssList = $rssTable->fetchAll()->toArray();
            $db->delete($newsTable->info('name'), array(
                'type = ?' => 'feed',
                'publish_date <= ?' => $dateInterval,
            ));
            $db->delete($newsTable->info('name'), array(
                'type = ?' => 'news',
                'creation_date <= ?' => $dateInterval,
            ));
            $db->commit();
            foreach ($rssList as $rss) {
                $rssItem = Engine_API::_()->getItem('sitenews_rss', $rss['rss_id']);
                $rssItem->feeds_count = $rssItem->feedsCount();
                $rssItem->save();
            }
        } catch (Exception $e) {
            $db->rollback();
            echo $e;
        }
    }

    public function updateFeeds() {

        $db = Zend_Db_Table_Abstract::getDefaultAdapter();
        $db->beginTransaction();
        $debug = Engine_Api::_()->getApi('settings', 'core')->getSetting('sitenews.debug', 0);
        if($debug){
            
            $file = APPLICATION_PATH.'/temporary/log/newsDebug.log';
            if(!file_exists($file)){

                $fileObject = fopen($file, 'w');
                fwrite($fileObject, ' ### News / RSS Importer and Aggregator Plugin - Debug ### '.PHP_EOL);
                fclose($fileObject);
                chmod($file, 0777); 
            }            
            $content = file_get_contents($file);
            $content .='updateFeeds started'.PHP_EOL;
            file_put_contents($file, $content);        

        }

        try {
            $latestFeedInterval = Engine_Api::_()->getApi('settings', 'core')->getSetting('sitenews.feed.latest.update', 'first_run');

            if($latestFeedInterval != 'first_run'){
                
                $cronjob_schedule = Engine_Api::_()->getApi('settings', 'core')->getSetting('cronjob.schedule', 1);
                $next_running_date = strtotime(date('Y-m-d H:i:s', date(strtotime("+$cronjob_schedule day", strtotime($latestFeedInterval)))));
            }
            if($latestFeedInterval == 'first_run'){
                //execute
            }elseif ($next_running_date > strtotime(date('Y-m-d'))) {
                
                if($debug){
                    
                    $content .='update-date-not-reached'.PHP_EOL;
                    $status = file_put_contents($file, $content);
                }    
                return false;
            }
            if($debug){
                
                $content .='valid-update-run'.PHP_EOL;
                $status = file_put_contents($file, $content);
            }
            $rssTable = Engine_Api::_()->getDbtable('rss', 'sitenews');
            $select = $rssTable->select()
                    ->from($rssTable->info('name'))
                    ->where('published = ?', 1)
                    ->order('creation_date');
            $rssList = $rssTable->fetchAll($select);
            $savedNews = 0;
            foreach ($rssList as $rss) {
                
                if ($rss->cron_update) {

                    if($debug){
                        $content.='(cron_enabled) RSS ID:'.$rss->rss_id.PHP_EOL;
                    }
                    $savedNews = Engine_Api::_()->getItemTable('sitenews_news')->saveNews($rss, false);
                    if($debug){
                        $content = file_get_contents($file);
                        $content.='(RSS ID:'.$rss->rss_id.') Total NEWS inserted : '.$savedNews.PHP_EOL;
                        file_put_contents($file, $content);
                    }
                    if($savedNews>0){
                        
                        //Send Notification
                        Engine_Api::_()->getDbtable('rsssubscriptions', 'sitenews')->sendNotifications(null, $rss, 'sitenews_subscribed_rss_updated');
                        // Send Email Notification
                        Engine_Api::_()->getApi('core', 'sitenews')->sendEmailNotification(null, $rss, 'sitenews_subscribed_rss_updated', 'SITENEWS_RSSUPDATED_EMAIL');
                    }    
                }
            }
            if($latestFeedInterval=='first_run'){
                
                Engine_Api::_()->getApi('settings','core')->setSetting('sitenews.feed.latest.update', date("Y-m-d H:i:s"));
            }else{

                Engine_Api::_()->getDbTable('settings','core')->update(array('value'=>date("Y-m-d H:i:s")), array(' name = ? '=>'sitenews.feed.latest.update'));
            }
            $db->commit();
            if($debug){

                $content.='Commited Transaction'.PHP_EOL;
                file_put_contents($file, $content);
            }
        } catch (Exception $e) {

            if($debug){
                
                $content.='(RSS ID:'.$rss->rss_id.')Exception thrown :-'.PHP_EOL;
                $content.=$e->getMessage().PHP_EOL;
                file_put_contents($file, $content);
            }
             
            $db->rollback();
            // echo $e;
        }
        if($debug){
            
            $content.='Update Feed Successfully finished.'.PHP_EOL;
            file_put_contents($file, $content);
        }
    }

    public function sendEmailNotification($object, $rss, $notificationType = null, $emailType = null) {

        $view = Zend_Registry::isRegistered('Zend_View') ? Zend_Registry::get('Zend_View') : null;
        $subscriptionTable = Engine_Api::_()->getDbtable('rsssubscriptions', 'sitenews');
        $viewer = Engine_Api::_()->user()->getViewer();
        $viewer_id = $viewer->getIdentity();

        if (!$rss)
            return false;

        $subject = $rss;
        $owner = $subject->getOwner();

        //GET PAGE TITLE AND RSS TITLE.
        $rsstitle = $subject->getTitle();
        $host = $_SERVER['HTTP_HOST'];
        $rssLink = $view->htmlLink($host . $subject->getHref(), $subject->getTitle());
        $posterLink = $view->htmlLink($host . $viewer->getHref(), $viewer->getTitle());
        //ITEM TITLE.
        if (!empty($object)) {
            $item_title = $object->getTitle();
        }

        //POSTER TITLE AND PHOTO WITH LINK
        $poster_title = $viewer->getTitle();
        $post = $notification = ' ';
        if ($notificationType == 'sitenews_rss_post') {
            $notification = "email.posted";
            $post = $posterLink . ' posted a new feed into this RSS: ' . $rssLink;
        } else if ($notificationType == 'sitenews_news_new') {
            $notification = "email.created";
            $newsLink = $view->htmlLink($host . $object->getHref(), $view->translate('news'));
            $post = $posterLink . ' posted a new ' . $newsLink . ' into this RSS: ' . $rssLink;
        } elseif ($notificationType == 'sitenews_subscribed_rss_updated') {

            $notification = "email.rss_updated";
            $post = $rssLink . ' your subscribed RSS, have been updated with latest news.';
        }
        if (empty($notification))
            return false;
        //FETCH DATA
        $subscribedUsersId = $subscriptionTable->getSubscribedUser($subject->rss_id);

        if (!empty($item_title)) {
            $params = array('rss_title' => $rsstitle, 'item_title' => $item_title, 'body_content' => $post);
        } else {
            $params = array('rss_title' => $rsstitle, 'body_content' => $post);
        }

        foreach ($subscribedUsersId as $value) {
            $user_subject = Engine_Api::_()->user()->getUser($value['subscriber_user_id']);
            //EMAIL SEND TO ALL SUBSCRIBERS.
            $email = json_decode($value['notification'], true);
            if (isset($email['email']) && !empty($email['email'])) {

                Engine_Api::_()->getApi('mail', 'core')->sendSystem($user_subject->email, "$emailType", $params);
            }
        }
    }

    public function publishNews() {

        $db = Zend_Db_Table_Abstract::getDefaultAdapter();
        $db->beginTransaction();
        try {
            $newsTable = Engine_Api::_()->getDbtable('news', 'sitenews');
            $rssTable = Engine_Api::_()->getDbtable('rss', 'sitenews');
            $where = 'published = 0';
            $news = $newsTable->fetchAll($where);
            $rss = $rssTable->fetchAll($where);
            foreach ($rss as $r) {
                $owner = $r->getOwner();
                $permission = Engine_Api::_()->getDbtable('permissions', 'authorization');
                $value = $permission->select()
                        ->from($permission->info('name'), 'value')
                        ->where('type = ?', 'sitenews_rss')
                        ->where('name = ?', 'rss_approval')
                        ->where('level_id = ?', $owner->level_id)
                        ->query()
                        ->fetchColumn();
                date_default_timezone_get($owner->timezone);
                if ($value == 0 && $r->published == 0 && $r->publish_date <= date('Y-m-d h-i a')) {
                    $select = $newsTable->select()
                            ->from($newsTable->info('name'))
                            ->where('rss=?', $r->rss_id);
                    $newsItems = $newsTable->fetchAll($select);
                    $r->published = 1;
                    foreach ($newsItems as $item) {
                        $newsTable->update(array(
                            'published' => 1,
                                ), array(
                            'rss =?' => $r->rss_id,
                        ));
                    }
                    $r->save();
                }
            }
            $where = 'published = 0';
            $news = $newsTable->fetchAll($where);
            foreach ($news as $new) {
                $owner = $new->getOwner();
                $permission = Engine_Api::_()->getDbtable('permissions', 'authorization');
                $value = $permission->select()
                        ->from($permission->info('name'), 'value')
                        ->where('type = ?', 'sitenews_news')
                        ->where('name = ?', 'news_approval')
                        ->where('level_id = ?', $owner->level_id)
                        ->query()
                        ->fetchColumn();
                date_default_timezone_get($owner->timezone);
                if ($value == 0 && $new->published == 0 && $new->publish_date <= date('Y-m-d h-i a')) {
                    $new->published = 1;
                    $new->save();
                    // insert new activity if news is just getting published
                    $action = Engine_Api::_()->getDbtable('actions', 'activity')->getActionsByObject($new);
                    if (count($action->toArray()) <= 0 && $new->draft == '0') {
                        
                        $viewer = Engine_Api::_()->user()->getViewer();
                        $viewer_id = $viewer->getIdentity();
                        
                        if(empty($viewer_id)){

                            $subject = Engine_Api::_()->seaocore()->getSuperAdmin();
                        }else{

                            $subject = $viewer;
                        }
                        
                        if ($new->rss) {
                            $action = Engine_Api::_()->getDbtable('actions', 'activity')->addActivity($subject, $r, 'sitenews_news_new_in_rss', null, array('child_id' => $new->getIdentity()));
                        } else {
                            $action = Engine_Api::_()->getDbtable('actions', 'activity')->addActivity($viewer, $new, 'sitenews_news_new');
                        }

                        // make sure action exists before attaching the news to the activity
                        if ($action) {
                            Engine_Api::_()->getDbtable('actions', 'activity')->attachActivity($action, $new);
                        }
                    }

                    // Rebuild privacy
                    $actionTable = Engine_Api::_()->getDbtable('actions', 'activity');
                    foreach ($actionTable->getActionsByObject($new) as $action) {
                        $actionTable->resetActivityBindings($action);
                    }

                    // Send notifications for subscribers
                    if($new->getRss()) {
                        Engine_Api::_()->getDbtable('rsssubscriptions', 'sitenews')
                                ->sendNotifications($new, $new->getRss(),null);
                    }
                }
            }

            $db->commit();
        } catch (Exception $e) {
            $db->rollback();
            echo $e;
        }
    }

    /**
     * Get sitenews_rss tags created by users
     * @param int $owner_id : sitenews owner id
     * @param int $total_tags : number tags to show
     */
    public function getTags($owner_id = 0, $total_tags = 100, $count_only = 0, $params = array()) {
        //GET DOCUMENT TABLE
        $tableSitenews = Engine_Api::_()->getDbtable('rss', 'sitenews');
        $tableSitenewsName = $tableSitenews->info('name');

        //MAKE QUERY
        $select = $tableSitenews->select()
                ->setIntegrityCheck(false)
                ->from($tableSitenewsName, array("rss_id", 'view_count'));

        if (!empty($owner_id)) {
            $select->where($tableSitenewsName . '.owner_id = ?', $owner_id);
        }

        $select->distinct(true);
        $rssIds = $select
                ->query()
                ->fetchAll(Zend_Db::FETCH_COLUMN);

        if (empty($rssIds)) {
            return;
        }

        $tableTagMaps = Engine_Api::_()->getDbtable('tagMaps', 'core');
        $tableTagMapsName = $tableTagMaps->info('name');
        $rssTable = Engine_Api::_()->getDbtable('rss', 'sitenews');
        $rssTableName = $rssTable->info('name');

        //GET TAG TABLE NAME
        $tableTags = 'engine4_core_tags';

        //MAKE QUERY
        $select = $tableTagMaps->select()
                ->setIntegrityCheck(false)
                ->from($tableTagMapsName, array("COUNT($tableTagMapsName.resource_id) AS Frequency", 'resource_id'))
                ->joinInner($tableTags, "$tableTags.tag_id = $tableTagMapsName.tag_id", array('text', 'tag_id'));
        if ($params['rsstype'] == 0) {
            $select->joinInner($rssTableName, "$rssTableName.rss_id = $tableTagMapsName.resource_id", array('view_count'));
        }
        $select->where($tableTagMapsName . '.resource_type = ?', 'sitenews_rss');
        $select->where($tableTagMapsName . '.resource_id IN(?)', (array) $rssIds);
        if ($params['rsstype'] == 0) {
            $select->order("view_count DESC");
        }
        $select->group("$tableTags.text");

        if (isset($params['orderingType']) && !empty($params['orderingType']))
            $select->order("$tableTags.text");
        else
            $select->order("Frequency DESC");

        if (!empty($total_tags)) {
            $select = $select->limit($total_tags);
        }

        if (!empty($count_only)) {
            $total_results = $select->query()->fetchAll(Zend_Db::FETCH_COLUMN);
            return Count($total_results);
        }

        //RETURN RESULTS
        return $select->query()->fetchAll();
    }

    /**
     * Get Sitenews tags created by users
     * @param int $owner_id : sitenews owner id
     * @param int $total_tags : number tags to show
     */
    public function getNewsTags($owner_id = 0, $total_tags = 100, $count_only = 0, $params = array()) {
        //GET DOCUMENT TABLE
        $tableSitenews = Engine_Api::_()->getDbtable('news', 'sitenews');
        $tableSitenewsName = $tableSitenews->info('name');
        //MAKE QUERY
        $select = $tableSitenews->select()
                ->setIntegrityCheck(false)
                ->from($tableSitenewsName, array("news_id"))
                ->where($tableSitenewsName . ".search = ?", 1);
        if ($params['newstype'] == 0) {
            $select->order("view_count DESC");
        }
        if (!empty($owner_id)) {
            $select->where($tableSitenewsName . '.owner_id = ?', $owner_id);
        }

        $select->distinct(true);
        $newsIds = $select
                ->query()
                ->fetchAll(Zend_Db::FETCH_COLUMN);

        if (empty($newsIds)) {
            return;
        }

        $tableTagMaps = Engine_Api::_()->getDbtable('tagMaps', 'core');
        $tableTagMapsName = $tableTagMaps->info('name');
        //GET TAG TABLE NAME
        $tableTags = 'engine4_core_tags';
        $newsTable = Engine_Api::_()->getDbtable('news', 'sitenews');
        $newsTableName = $newsTable->info('name');

        $select = $tableTagMaps->select()
                ->setIntegrityCheck(false)
                ->from($tableTagMapsName, array("COUNT($tableTagMapsName.resource_id) AS Frequency", 'resource_id'))
                ->joinInner($tableTags, "$tableTags.tag_id = $tableTagMapsName.tag_id", array('text', 'tag_id'));
        if ($params['newstype'] == 0) {
            $select->joinInner($newsTableName, "$newsTableName.news_id = $tableTagMapsName.resource_id", array('view_count'));
        }
        $select->where($tableTagMapsName . '.resource_type = ?', 'sitenews_news');
        $select->where($tableTagMapsName . '.resource_id IN(?)', (array) $newsIds);
        if ($params['newstype'] == 0) {
            $select->order("view_count DESC");
        }
        $select->group("$tableTags.text");

        if (isset($params['orderingType']) && !empty($params['orderingType']))
            $select->order("$tableTags.text");
        else
            $select->order("Frequency DESC");

        if (!empty($total_tags)) {
            $select = $select->limit($total_tags);
        }
        if (!empty($count_only)) {
            $total_results = $select->query()->fetchAll(Zend_Db::FETCH_COLUMN);
            return Count($total_results);
        }

        //RETURN RESULTS
        return $select->query()->fetchAll();
    }

    /**
     * Rss base network enable
     *
     * @return bool
     */
    public function rssBaseNetworkEnable() {

        return (bool) ( Engine_Api::_()->getApi('settings', 'core')->getSetting('sitenews.networks.type', 0) && (Engine_Api::_()->getApi('settings', 'core')->getSetting('sitenews.network', 0) || Engine_Api::_()->getApi('settings', 'core')->getSetting('sitenews.default.show', 0)));
    }

    /**
     * News base network enable
     *
     * @return bool
     */
    public function newsBaseNetworkEnable() {

        return (bool) ( Engine_Api::_()->getApi('settings', 'core')->getSetting('sitenews.news.networks.type', 0) && (Engine_Api::_()->getApi('settings', 'core')->getSetting('sitenews.news.network', 0) || Engine_Api::_()->getApi('settings', 'core')->getSetting('sitenews.news.default.show', 0)));
    }

    /**
     * Set Meta Titles
     *
     * @param array $params
     */
    public function setMetaDescriptionsBrowse($params = array()) {

        $view = Zend_Registry::isRegistered('Zend_View') ? Zend_Registry::get('Zend_View') : null;
        $siteinfo = $view->layout()->siteinfo;
        $descriptions = '';
        if (isset($params['description'])) {
            if (!empty($descriptions))
                $descriptions .= ' - ';
            $descriptions .= $params['description'];
        }

        $siteinfo['description'] = $descriptions;
        $view->layout()->siteinfo = $siteinfo;
    }

    /**
     * Set Meta Keywords
     *
     * @param array $params
     */
    public function setMetaKeywords($params = array()) {

        $view = Zend_Registry::isRegistered('Zend_View') ? Zend_Registry::get('Zend_View') : null;
        $siteinfo = $view->layout()->siteinfo;
        $keywords = "";

        if (isset($params['subcategoryname_keywords']) && !empty($params['subcategoryname_keywords'])) {
            if (!empty($keywords))
                $keywords .= ', ';
            $keywords .= $params['subcategoryname_keywords'];
        }

        if (isset($params['categoryname_keywords']) && !empty($params['categoryname_keywords'])) {
            if (!empty($keywords))
                $keywords .= ', ';
            $keywords .= $params['categoryname_keywords'];
        }

        if (isset($params['location']) && !empty($params['location'])) {
            if (!empty($keywords))
                $keywords .= ', ';
            $keywords .= $params['location'];
        }

        if (isset($params['tag']) && !empty($params['tag'])) {
            if (!empty($keywords))
                $keywords .= ', ';
            $keywords .= $params['tag'];
        }

        if (isset($params['search'])) {
            if (!empty($keywords))
                $keywords .= ', ';
            $keywords .= $params['search'];
        }

        if (isset($params['keywords'])) {
            if (!empty($keywords))
                $keywords .= ', ';
            $keywords .= $params['keywords'];
        }

        if (isset($params['rss_type_title'])) {
            if (!empty($keywords))
                $keywords .= ', ';
            $keywords .= $params['rss_type_title'];
        }

        $siteinfo['keywords'] = $keywords;
        $view->layout()->siteinfo = $siteinfo;
    }

    /**
     * Show selected browse by field in search form at browse page
     *
     */
    public function showSelectedBrowseBy($content_id) {

        //GET CORE CONTENT TABLE
        $coreContentTable = Engine_Api::_()->getDbTable('content', 'core');
        $coreContentTableName = $coreContentTable->info('name');

        $page_id = $coreContentTable->select()
                ->from($coreContentTableName, array('page_id'))
                ->where('content_id = ?', $content_id)
                ->query()
                ->fetchColumn();

        if (empty($page_id)) {
            return 0;
        }

        //GET DATA
        $params = $coreContentTable->select()
                ->from($coreContentTableName, array('params'))
                ->where($coreContentTableName . '.page_id = ?', $page_id)
                ->where($coreContentTableName . '.name = ?', 'sitenews.browse-rss-sitenews')
                ->query()
                ->fetchColumn();

        $paramsArray = !empty($params) ? Zend_Json::decode($params) : array();

        if (isset($paramsArray['orderby']) && !empty($paramsArray['orderby'])) {
            return $paramsArray['orderby'];
        } else {
            return 0;
        }
    }

    public function showSelectedNewsBrowseBy($content_id) {

        //GET CORE CONTENT TABLE
        $coreContentTable = Engine_Api::_()->getDbTable('content', 'core');
        $coreContentTableName = $coreContentTable->info('name');

        $page_id = $coreContentTable->select()
                ->from($coreContentTableName, array('page_id'))
                ->where('content_id = ?', $content_id)
                ->query()
                ->fetchColumn();

        if (empty($page_id)) {
            return 0;
        }

        //GET DATA
        $params = $coreContentTable->select()
                ->from($coreContentTableName, array('params'))
                ->where($coreContentTableName . '.page_id = ?', $page_id)
                ->where($coreContentTableName . '.name = ?', 'sitenews.browse-news-sitenews')
                ->query()
                ->fetchColumn();

        $paramsArray = !empty($params) ? Zend_Json::decode($params) : array();

        if (isset($paramsArray['orderby']) && !empty($paramsArray['orderby'])) {
            return $paramsArray['orderby'];
        } else {
            return 0;
        }
    }

    public function categoriesPageCreate($categoryIds = array()) {

        //GET DATABASE
        $db = Zend_Db_Table_Abstract::getDefaultAdapter();

        foreach ($categoryIds as $categoryId) {
            $containerCount = 0;
            $widgetCount = 0;

            $category = Engine_Api::_()->getItem('sitenews_category', $categoryId);

            if ($category->cat_dependency || $category->subcat_dependency || empty($category)) {
                continue;
            }

            $categoryName = $category->getTitle(true);

            $page_id = $db->select()
                    ->from('engine4_core_pages', 'page_id')
                    ->where('name = ?', "sitenews_news_categories-home_category_" . $categoryId)
                    ->limit(1)
                    ->query()
                    ->fetchColumn();

            if (empty($page_id)) {
                $db->insert('engine4_core_pages', array(
                    'name' => 'sitenews_news_categories-home_category_' . $categoryId,
                    'displayname' => 'News - Category - ' . $categoryName,
                    'title' => 'News - Category ' . $categoryName . ' Home',
                    'description' => 'This is the News - Category ' . $categoryName . ' home page.',
                    'custom' => 0,
                ));
                $page_id = $db->lastInsertId();

                //TOP CONTAINER
                $db->insert('engine4_core_content', array('type' => 'container',
                    'name' => 'top',
                    'page_id' => $page_id,
                    'order' => $containerCount++,
                ));
                $top_container_id = $db->lastInsertId();

                //MAIN CONTAINER
                $db->insert('engine4_core_content', array
                    (
                    'type' => 'container',
                    'name' => 'main',
                    'page_id' => $page_id,
                    'order' => $containerCount++,
                ));
                $main_container_id = $db->lastInsertId();

                //INSERT TOP-MIDDLE
                $db->insert('engine4_core_content', array('type' => 'container',
                    'name' => 'middle',
                    'page_id' => $page_id,
                    'parent_content_id' => $top_container_id,
                    'order' => $containerCount++,
                ));
                $top_middle_id = $db->lastInsertId();

                // Top Middle
                $db->insert('engine4_core_content', array(
                    'page_id' =>
                    $page_id,
                    'type' => 'widget',
                    'name' => 'sitenews.browse-menu',
                    'parent_content_id' => $top_middle_id,
                    'order' => $widgetCount++,
                    'params' => '',
                ));

                //RIGHT CONTAINER
                $db->insert('engine4_core_content', array(
                    'type' => 'container',
                    'name' => 'left',
                    'page_id' => $page_id,
                    'parent_content_id' => $main_container_id,
                    'order' => $containerCount++,
                ));
                $left_container_id = $db->lastInsertId();

                //MAIN-MIDDLE CONTAINER
                $db->insert('engine4_core_content', array(
                    'type' => 'container',
                    'name' => 'middle',
                    'page_id' => $page_id,
                    'parent_content_id' => $main_container_id,
                    'order' => $containerCount++,
                ));
                $main_middle_id = $db->lastInsertId();
                $db->insert('engine4_core_content', array(
                    'page_id' => $page_id,
                    'type' => 'widget',
                    'name' => 'sitenews.news-categories-navigation',
                    'parent_content_id' => $left_container_id,
                    'order' => $widgetCount++,
                    'params' => '{"orderBy":"cat_order","viewDisplayHR":"0","title":"Categories","nomobile":"0","name":"sitenews.news-categories-navigation"}',
                ));
                $db->insert('engine4_core_content', array(
                    'page_id' => $page_id,
                    'type' => 'widget',
                    'name' => 'sitenews.tagcloud-sitenews-news',
                    'parent_content_id' => $left_container_id,
                    'order' => $widgetCount++,
                    'params' => '{"title":"Popular News Tags","titleCount":true,"orderingType":"1","itemCount":"25","loaded_by_ajax":"1","nomobile":"0","name":"sitenews.tagcloud-sitenews-news"}',
                ));
                $rss = '';
                if($categoryId == 1)  {
                    $rss = 1;
                } elseif($categoryId == 2) {
                    $rss = 2;
                }
                $db->insert('engine4_core_content', array('page_id' => $page_id,
                    'type' => 'widget',
                    'name' => 'sitenews.popular-news-carousel',
                    'parent_content_id' => $main_middle_id,
                    'order' => $widgetCount++,
                    'params' => '{"title":"' . $categoryName . '","category_id":"' . $categoryId . '","subcategory_id":"0","hidden_news_category_id":"' . $categoryId . '","hidden_news_subcategory_id":"0","hidden_news_subsubcategory_id":"0","rss":"'.$rss.'","showNews":"all_feeds","newsOption":["title","creationDate","view","like","comment","favourite","facebook","twitter","linkedin","googleplus"],"showPagination":"1","carouselType":"horizontal","newsWidth":"905","itemWidth":"0","newsHeight":"250","itemCount":"4","popularType":"featured","interval":"3500","titleTruncation":"42","nomobile":"0","name":"sitenews.popular-news-carousel"}',
                ));

                
                $db->insert('engine4_core_content', array('page_id' => $page_id,
                    'type' => 'widget',
                    'name' => 'sitenews.news-carousel',
                    'parent_content_id' => $main_middle_id,
                    'order' => $widgetCount++,
                    'params' => '{"title":"Recent News","category_id":"0","subcategory_id":"0","hidden_news_category_id":"0","hidden_news_subcategory_id":"0","hidden_news_subsubcategory_id":"0","rss":"","showNews":"all_feeds","newsOption":["title","creationDate","view","comment"],"showPagination":"1","newsWidth":"171","newsHeight":"150","itemCount":"27","popularType":"view","interval":"3500","nomobile":"0","name":"sitenews.news-carousel"}',
                )); 
            } else {

                $pagesTable = Engine_Api::_()->getDbTable('pages', 'core');
                $pagesTable->update(array(
                    'displayname' => 'News - Category - ' . $categoryName,
                    'title' => 'News - Category ' . $categoryName . ' Home',
                    'description' => 'This is the News - Category ' . $categoryName . ' home page.',
                        ), array(
                    'name =?' => "sitenews_news_categories-home_category_" . $categoryId,
                ));
            }
        }
    }

    function findThumbnailType($newsSize, $vWidth) {
        arsort($newsSize);
        $thumbnailType = 'thumb.normal';
        $count = 0;
        $bool = true;
        foreach ($newsSize as $key => $tSize) {
            $newsSizeDup[] = $key;
            if ($key != 'width' && $tSize == $vWidth) {
                $bool = false;
                $thumbnailType = $key;
            }
        }
        if ($bool) {
            foreach ($newsSize as $k => $tSize) {
                if ($k == 'width') {
                    $thumbnailType = isset($newsSizeDup[$count - 1]) ? $newsSizeDup[$count - 1] : $newsSizeDup[$count + 1];
                    break;
                }
                $count++;
            }
        }
        return $thumbnailType;
    }

    public function setLayoutAccordingToTheme() {
        $view = Zend_Registry::isRegistered('Zend_View') ? Zend_Registry::get('Zend_View') : null;
        $theme = '';
        $themeArray = $view->layout()->themes;
        if (isset($themeArray[0])) {
            $theme = $view->layout()->themes[0];
        }
        $file = APPLICATION_PATH . '/application/themes/' . $theme . '/constants.css';
        $width = Engine_Api::_()->seaocore()->getValueOfCssVariables($file, 'theme_content_width');

        if ($width >= 1200) {
            $setLayout = 3;
        } else if (1100 > $width) {
            $setLayout = 1;
        } else if (1100 >= $width && 1200 > $width) {
            $setLayout = 2;
        }

        return $setLayout;
    }

    public function getCategoryHomeRoute() {

        $front = Zend_Controller_Front::getInstance();
        $module = $front->getRequest()->getModuleName();
        $action = $front->getRequest()->getActionName();
        $controller = $front->getRequest()->getControllerName();

        if ($module == 'sitenews' && $controller == 'index' && $action == 'browse')
            return 'sitenews_news_general_category';

        $isCatWidgetizedPageEnabled = 1;
        $routeName = !empty($isCatWidgetizedPageEnabled) ? 'sitenews_category_home' : 'sitenews_news_general_category';

        return $routeName;
    }

    /**
     * Get Widgetized PageId
     * @param $params
     */
    public function getWidgetizedPageId($params = array()) {
        //GET CORE CONTENT TABLE
        $tableNamePages = Engine_Api::_()->getDbtable('pages', 'core');
        $page_id = $tableNamePages->select()
                ->from($tableNamePages->info('name'), 'page_id')
                ->where('name =?', $params['name'])
                ->query()
                ->fetchColumn();
        return $page_id;
    }

}
