<?php

/**
 * SocialEngine
 *
 * @category   Application_Extensions
 * @package    Sitenews
 * @copyright  Copyright 2016-2017 BigStep Technologies Pvt. Ltd.
 * @license    http://www.socialengineaddons.com/license/
 * @version    $Id: RssSettings.php 2017-01-01 9:40:21Z SocialEngineAddOns $
 * @author     SocialEngineAddOns
 */
class Sitenews_Form_Admin_RssSettings extends Engine_Form {

    public function init() {

        $coreSettings = Engine_Api::_()->getApi('settings', 'core');

        $this->setTitle('RSS Settings')
                ->setDescription('These settings affect all members in your community.');

        $this->addElement('Radio', 'sitenews_rss_allow', array(
            'label' => 'RSS',
            'description' => "Do you want to enable the RSS feature on your website?",
            'multiOptions' => array(
                1 => 'Yes',
                0 => 'No'
            ),
            'onclick' => 'checkRssEnable(this.value)',
            'value' => $coreSettings->getSetting('sitenews.rss.allow', 1),
        ));

        $this->addElement('Text', 'sitenews_webparser_endpoint', array(
            'label' => 'Web Parser URL',
            'description' => 'Please enter URL of Web Parser Endpoint for getting the News from the RSS. Please contact us to setup the Web Parser on your server.',
            'required' => 'true',
            'value' => $coreSettings->getSetting('sitenews.webparser.endpoint'),
        ));

        $this->sitenews_webparser_endpoint->getDecorator('Description')->setOptions(array('placement' => 'PREPEND', 'escape' => false));

        $this->addElement('Text', 'feeds_limit', array(
            'label' => 'Maximum Fetched News',
            'description' => 'Enter the maximum number of news to be fetched by a RSS Feed.',
            'value' => Engine_Api::_()->getApi('settings', 'core')->getSetting('feeds.limit', 10),
        ));

        $this->addElement('Text', 'cronjob_schedule', array(
            'label' => 'Cron Job Schedule',
            'description' => 'Enter the time interval in days after which you want to fetch latest news from your active RSS Feeds.',
            'value' => Engine_Api::_()->getApi('settings', 'core')->getSetting('cronjob.schedule', 1),
        ));

        // $this->addElement('Text', 'updatefeed_limit', array(
        //     'label' => 'Update RSS limit',
        //     'description' => 'How many RSS URL you want to update after Cronjob schedule?',
        //     'value' => Engine_Api::_()->getApi('settings', 'core')->getSetting('updatefeed.limit', 10),
        // ));

        $this->addElement('Text', 'remove_oldfeeds', array(
            'label' => 'Remove Old News',
            'description' => 'Mention the number of days after which old news will be removed.',
            'value' => Engine_Api::_()->getApi('settings', 'core')->getSetting('remove.oldfeeds', 60),
        ));

        // $this->addElement('Radio', 'sitenews_rsstags_enabled', array(
        //     'label' => 'Allow Tags',
        //     'description' => 'Do you want the Tags field to be enabled for RSS?',
        //     'multiOptions' => array('1' => 'Yes', '0' => 'No'),
        //     'value' => $coreSettings->getSetting('sitenews.rsstags.enabled', 1)
        // ));

        $this->addElement('Radio', 'sitenews_full_content', array(
            'label' => 'News Content',
            'description' => 'Do you want RSS Feeds to fetch full content of News or just the short description?',
            'multiOptions' => array(
                '1' => 'Yes, fetch full content of News.',
                '0' => 'No, fetch only short description of News.',
            ),
            'value' => $coreSettings->getSetting('sitenews.full.content', 1)
        ));

        $this->addElement('Radio', 'sitenews_rsssubscriptions_enabled', array(
            'label' => 'Subscribe',
            'description' => 'Do you want to enable Subscribe feature for RSS?',
            'multiOptions' => array('1' => 'Yes', '0' => 'No'),
            'value' => $coreSettings->getSetting('sitenews.rsssubscriptions.enabled', 1)
        ));

        // Element: submit
        $this->addElement('Button', 'submit', array(
            'label' => 'Save Changes',
            'type' => 'submit',
            'ignore' => true
        ));
    }

}

?>
