<?php

/**
 * SocialEngine
 *
 * @category   Application_Extensions
 * @package    Sitenews
 * @copyright  Copyright 2016-2017 BigStep Technologies Pvt. Ltd.
 * @license    http://www.socialengineaddons.com/license/
 * @version    $Id: Create.php 2017-01-01 9:40:21Z SocialEngineAddOns $
 * @author     SocialEngineAddOns
 */
class Sitenews_Form_Create extends Engine_Form {

    public $_error = array();

    public function init() {
        
        $viewer = Engine_Api::_()->user()->getViewer();
        $createRss = Engine_Api::_()->authorization()->isAllowed('sitenews_rss', $viewer, 'create');
        $this->setTitle('Add News')
                ->setDescription('Compose your News by filling the below information, then click "Save" to publish the News.')
                ->setAttrib('name', 'sitenews_create');
        $user = Engine_Api::_()->user()->getViewer();
        $user_level = Engine_Api::_()->user()->getViewer()->level_id;
        $view = Zend_Registry::isRegistered('Zend_View') ? Zend_Registry::get('Zend_View') : null;
        $url = "'" . $view->url(array('action' => 'feed', 'from' => 'news'), 'sitenews_general', true) . "'";

        $rssTable = Engine_Api::_()->getItemTable('sitenews_rss');

        $myRss = $rssTable->select()
                ->from($rssTable, array('rss_id', 'title'))
                ->where('owner_type = ?', 'user')
                ->where('owner_id = ?', $user->getIdentity())
                ->query()
                ->fetchAll();
        $rssOptions = array('0' => '');
        foreach ($myRss as $my) {
            $rssOptions[$my['rss_id']] = $my['title'];
        }

        if ($createRss && Engine_Api::_()->getApi('settings', 'core')->getSetting('sitenews.rss.allow', 1)) {
            $this->addElement('Select', 'rss', array(
                'label' => 'Choose RSS',
                'multiOptions' => $rssOptions,
                'style' => 'float:left;',
            ));

            //if ($createRss) {

            $this->addElement('Button', 'createRss', array(
                'label' => 'Add New RSS',
                'type' => 'button',
                'onclick' => "window.location=" . $url,
                'style' => 'float:left;',
                'class' => 'sitenews_blue_button'
            ));
            //}
        }

        $this->addElement('Text', 'title', array(
            'label' => 'News Title',
            'allowEmpty' => false,
            'required' => true,
            'filters' => array(
                new Engine_Filter_Censor(),
                'StripTags',
                new Engine_Filter_StringLength(array('max' => '63'))
            ),
            'autofocus' => 'autofocus',
        ));

        if (Engine_Api::_()->getApi('settings', 'core')->getSetting('sitenews.category.enabled', 1)) {
            // prepare categories
            $categories = Engine_Api::_()->getDbtable('categories', 'sitenews')->getCategories(array('fetchColumns' => array('category_id', 'category_name'), 'sponsored' => 0, 'cat_depandancy' => 1, 'orderBy' => 'category_name'));
            if (count($categories) != 0) {
                $categories_prepared[""] = "";
                foreach ($categories as $category) {
                    $categories_prepared[$category->category_id] = $category->category_name;
                }
            }

            if (Engine_API::_()->seaocore()->checkSitemobileMode('fullsite-mode')) {
                $onChangeEvent = "subcategories(this.value, '', '');";
                $categoryFiles = 'application/modules/Sitenews/views/scripts/_formNewsSubcategory.tpl';
            } else {
                $onChangeEvent = "showSMFields(this.value, 1);sm4.core.category.set(this.value, 'subcategory');";
                $categoryFiles = 'application/modules/Sitenews/views/sitemobile/scripts/_subCategory.tpl';
            }

            $this->addElement('Select', 'category_id', array(
                'label' => 'Category',
                'allowEmpty' => false,
                'required' => true,
                'multiOptions' => $categories_prepared,
                'onchange' => $onChangeEvent,
            ));

            $this->addElement('Select', 'subcategory_id', array(
                'autocomplete' => 'on',
                'RegisterInArrayValidator' => false,
                'allowEmpty' => true,
                'required' => false,
                'decorators' => array(array('ViewScript', array('viewScript' => $categoryFiles, 'class' => 'form element')))
            ));

            $this->addElement('Select', 'subsubcategory_id', array(
                'autocomplete' => 'on',
                'RegisterInArrayValidator' => false,
                'allowEmpty' => true,
                'required' => false,
            ));

            $this->addDisplayGroup(array(
                'subcategory_id',
                'subsubcategory_id',
                    ), 'Select', array(
                'decorators' => array(array('ViewScript', array(
                            'viewScript' => $categoryFiles,
                            'class' => 'form element')))
            ));
        }

        $this->addElement('file', 'photo', array(
            'label' => 'News Photo',
            'description' => 'News thumbnail (Allowed formats: jpg, png, gif, jpeg)',
        ));
        $this->photo->getDecorator("Description")->setOption("placement", "append");
        $this->photo->addValidator('Extension', false, 'jpg,png,gif,jpeg,JPG,PNG,GIF,JPEG');

        $this->addElement('text', 'original_link', array(
            'label' => 'Original Link',
        ));

        if (Engine_Api::_()->getApi('settings', 'core')->getSetting('sitenews.news.tags.enabled', 1)) {
            $this->addElement('Text', 'tags', array(
                'label' => 'Tags (Keywords)',
                'autocomplete' => 'off',
                'description' => 'Separate tags with commas.',
                'filters' => array(
                    new Engine_Filter_Censor(),
                ),
            ));
            $this->tags->getDecorator("Description")->setOption("placement", "append");
        }

        if (Engine_Api::_()->getApi('settings', 'core')->getSetting('sitenews.news.location', 1)) {
            $this->addElement('Text', 'location', array(
                'label' => 'Location',
                'placeholder' => $view->translate('Enter a location'),
                'autocomplete' => 'off',
                'description' => 'Eg: Fairview Park, Berkeley, CA',
                'filters' => array(
                    new Engine_Filter_Censor(),
                ),
            ));
            $this->location->getDecorator("Description")->setOption("placement", "append");
            $this->addElement('Hidden', 'locationParams', array('order' => 800000));

            include_once APPLICATION_PATH . '/application/modules/Seaocore/Form/specificLocationElement.php';
        }

        //NETWORK BASE NEWS
        if (Engine_Api::_()->sitenews()->newsBaseNetworkEnable()) {
            // Make Network List
            $table = Engine_Api::_()->getDbtable('networks', 'network');
            $select = $table->select()
                    ->from($table->info('name'), array('network_id', 'title'))
                    ->order('title');
            $result = $table->fetchAll($select);

            $networksOptions = array('0' => 'Everyone');
            foreach ($result as $value) {
                $networksOptions[$value->network_id] = $value->title;
            }
            if (count($networksOptions) > 0) {
                $viewPricavyEnable = Engine_Api::_()->getApi('settings', 'core')->getSetting('sitenews.news.networkprofile.privacy', 0);
                if ($viewPricavyEnable) {
                    $desc = 'Select the networks, members of which should be able to see your news. (Press Ctrl and click to select multiple networks. Applied privacy will be a combination of the privacy chosen in "View Privacy" and the privacy chosen here.)';
                } else {
                    $desc = 'Select the networks, members of which should be able to see your news in browse and search news. (Press Ctrl and click to select multiple networks. Applied privacy will be a combination of the privacy chosen in "View Privacy" and the privacy chosen here.)';
                }

                $this->addElement('Multiselect', 'networks_privacy', array(
                    'label' => 'Networks Selection',
                    'description' => $desc,
                    'multiOptions' => $networksOptions,
                    'value' => array(0)
                ));
            }
        }

        // tinymce for short description
        $allowed_html = Engine_Api::_()->authorization()->getPermission($user_level, 'sitenews', 'auth_html');
        $upload_url = "";

        if (Engine_Api::_()->authorization()->isAllowed('album', $user, 'create')) {
            $upload_url = Zend_Controller_Front::getInstance()->getRouter()->assemble(array('action' => 'upload-photo'), 'sitenews_general', true);
        }

        $editorOptions = array(
            'upload_url' => $upload_url,
            'html' => (bool) $allowed_html,
        );

        if (!empty($upload_url)) {
            $editorOptions['plugins'] = array(
                'table', 'fullscreen', 'media', 'preview', 'paste',
                'code', 'image', 'textcolor', 'jbimages', 'link'
            );

            $editorOptions['toolbar1'] = array(
                'undo', 'redo', 'removeformat', 'pastetext', '|', 'code',
                'media', 'image', 'jbimages', 'link', 'fullscreen',
                'preview'
            );
        }

        $this->addElement('Textarea', 'shortdescription', array(
            'label' => 'Short Description',
            'required' => true,
            'allowEmpty' => false,
            'filters' => array(
                new Engine_Filter_Censor(),
                new Engine_Filter_Html(array('AllowedTags' => $allowed_html))),
        ));

        if (Engine_Api::_()->getApi('settings', 'core')->getSetting('sitenews.news.description', 1)) {
            $this->addElement('Textarea', 'description', array(
                'label' => 'Description',
                'required' => true,
                'allowEmpty' => false,
                'editorOptions' => $editorOptions,
                'filters' => array(
                    new Engine_Filter_Censor(),
                    new Engine_Filter_Html(array('AllowedTags' => $allowed_html))),
            ));
        }

        $this->addElement('Select', 'draft', array(
            'label' => 'Status',
            'onChange' => 'checkStatus()',
            'multiOptions' => array("0" => "Published", "1" => "Saved As Draft"),
            'description' => 'If this News is published, it cannot be switched back to draft mode.'
        ));
        $this->draft->getDecorator('Description')->setOption('placement', 'append');

        date_default_timezone_get($user->timezone);
        $date = new Engine_Form_Element_CalendarDateTime('publish_date');
        $date->setLabel("Publishing Date");
        $date->setDescription('If you are publishing the news right now, then you do not need to set the publishing date & time.');
        $date->setAllowEmpty(true);
        // $date->addValidator('GreaterThan', true, date('Y-m-d h-i a'));
        $this->addElement($date);
        $this->publish_date->getDecorator('Description')->setOption('placement', 'append');

        $availableLabels = array(
            'everyone' => 'Everyone',
            'registered' => 'All Registered Members',
            'owner_network' => 'Friends and Networks',
            'owner_member_member' => 'Friends of Friends',
            'owner_member' => 'Friends Only',
            'owner' => 'Just Me'
        );

        // Element: auth_view
        $viewOptions = (array) Engine_Api::_()->authorization()->getAdapter('levels')->getAllowed('sitenews_news', $user, 'auth_view');
        $viewOptions = array_intersect_key($availableLabels, array_flip($viewOptions));

        if (!empty($viewOptions) && count($viewOptions) >= 1) {
            // Make a hidden field
            if (count($viewOptions) == 1) {
                $this->addElement('hidden', 'auth_view', array( 'order' => 800001,'value' => key($viewOptions)));
                // Make select box
            } else {
                $this->addElement('Select', 'auth_view', array(
                    'label' => 'Privacy',
                    'description' => 'Who may see this news?',
                    'multiOptions' => $viewOptions,
                    'value' => key($viewOptions),
                ));
                $this->auth_view->getDecorator('Description')->setOption('placement', 'append');
            }
        }

        // Element: auth_comment
        $commentOptions = (array) Engine_Api::_()->authorization()->getAdapter('levels')->getAllowed('sitenews_news', $user, 'auth_comment');
        $commentOptions = array_intersect_key($availableLabels, array_flip($commentOptions));

        if (!empty($commentOptions) && count($commentOptions) >= 1) {
            // Make a hidden field
            if (count($commentOptions) == 1) {
                $this->addElement('hidden', 'auth_comment', array( 'order' => 800002,'value' => key($commentOptions)));
                // Make select box
            } else {
                $this->addElement('Select', 'auth_comment', array(
                    'label' => 'Comment Privacy',
                    'description' => 'Who may post comments on this news?',
                    'multiOptions' => $commentOptions,
                    'value' => key($commentOptions),
                ));
                $this->auth_comment->getDecorator('Description')->setOption('placement', 'append');
            }
        }

        // Element: submit
        $this->addElement('Button', 'submit', array(
            'label' => 'Save',
            'type' => 'submit',
        ));
    }

    public function saveValues() {

        $values = $this->getValues();
        $params = Array();
        if ((empty($values['owner_type'])) || (empty($values['owner_id']))) {
            $params['owner_id'] = Engine_Api::_()->user()->getViewer()->user_id;
            $params['owner_type'] = 'user';
        } else {
            $params['owner_id'] = $values['owner_id'];
            $params['owner_type'] = $values['owner_type'];
            throw new Zend_Exception("Non-user news owners not yet implemented");
        }
        $owner = Engine_Api::_()->getItem('user', $params['owner_id']);
        $params['title'] = $values['title'];
        $params['rss'] = $values['rss'];
        if (isset($values['rss']) && !empty($values['rss'])) {
            $rss = Engine_Api::_()->getItem('sitenews_rss', $values['rss']);
            $old_count = $rss->feeds_count;
            $rss->feeds_count = $old_count + 1;
            $rss->save();
        }
        $params['category_id'] = (int) @$values['category_id'];
        $params['subcategory_id'] = (int) @$values['subcategory_id'];
        $params['subsubcategory_id'] = (int) @$values['subsubcategory_id'];
        $params['description'] = $values['shortdescription'];
        $params['publish_date'] = $values['publish_date'];
        $permission = Engine_Api::_()->getDbtable('permissions', 'authorization');
        $value = $permission->select()
                ->from($permission->info('name'), 'value')
                ->where('type = ?', 'sitenews_news')
                ->where('name = ?', 'news_approval')
                ->where('level_id = ?', $owner->level_id)
                ->query()
                ->fetchColumn();
        date_default_timezone_get($owner->timezone);
        if ($value == 1 || isset($params['publish_date']) && ($params['publish_date'] > date('Y-m-d h-i a'))) {
            $params['published'] = 0;
        }
        $params['original_link'] = $values['original_link'];
        $params['type'] = 'news';
        $params['publish_date'] = date('Y-m-d H-i-s');
        $params['draft'] = $values['draft'];
        $news = Engine_Api::_()->getDbtable('news', 'sitenews')->createRow();
        $news->setFromArray($params);
        $news->save();
        // CREATE AUTH STUFF HERE
        $auth = Engine_Api::_()->authorization()->context;
        $roles = array('owner', 'owner_member', 'owner_member_member', 'owner_network', 'registered', 'everyone');

        if (empty($values['auth_view'])) {
            $values['auth_view'] = 'everyone';
        }
        if (empty($values['auth_comment'])) {
            $values['auth_comment'] = 'owner_member';
        }
        $viewMax = array_search($values['auth_view'], $roles);
        $commentMax = array_search($values['auth_comment'], $roles);
        foreach ($roles as $i => $role) {
            $auth->setAllowed($news, $role, 'view', ($i <= $viewMax));
            $auth->setAllowed($news, $role, 'comment', ($i <= $commentMax));
        }
        $params['content'] = $values['shortdescription'];
        if (Engine_Api::_()->getApi('settings', 'core')->getSetting('sitenews.full.content', 1)) {
            $params['content'] = $values['description'];
        }

        $tableOtherinfo = Engine_Api::_()->getDbTable('newsotherinfo', 'sitenews');
        $db = Engine_Db_Table::getDefaultAdapter();
        $db->beginTransaction();
        try {
            $row = $tableOtherinfo->getOtherinfo($news->getIdentity());
            if (empty($row))
                $tableOtherinfo->insert(array(
                    'news_id' => $news->getIdentity(),
                    'content' => $params['content']
                )); //COMMIT
            $db->commit();
        } catch (Exception $e) {
            $db->rollBack();
            throw $e;
        }

        return $news;
    }

}
