<?php

/**
 * SocialEngine
 *
 * @category   Application_Extensions
 * @package    Sitenews
 * @copyright  Copyright 2016-2017 BigStep Technologies Pvt. Ltd.
 * @license    http://www.socialengineaddons.com/license/
 * @version    $Id: Menus.php 2017-01-01 9:40:21Z SocialEngineAddOns $
 * @author     SocialEngineAddOns
 */
class Sitenews_Plugin_Menus {

    public function onMenuInitialize_SitenewsMainCreate($row) {

        // Must be logged in
        $viewer = Engine_Api::_()->user()->getViewer();
        if (!$viewer || !$viewer->getIdentity()) {
            return false;
        }

        // Must be able to create news
        if (!Engine_Api::_()->authorization()->isAllowed('sitenews_news', $viewer, 'create')) {
            return false;
        }

        $maxAllowedNews = Engine_Api::_()->authorization()->getPermission($viewer->level_id, 'sitenews_news', 'max_allowed');
        $viewerId = $viewer->getIdentity();
        $newsTable = Engine_Api::_()->getDbtable('news', 'sitenews');
        $userNewsCount = $newsTable
                ->select()
                ->from($newsTable->info('name'), new Zend_Db_Expr('COUNT(news_id)'))
                ->where('owner_id = ?', $viewerId)
                ->limit(1)
                ->query()
                ->fetchColumn();

        if ($maxAllowedNews != 0 && $userNewsCount >= $maxAllowedNews) {
            return array(
                'class' => 'smoothbox',
                'route' => 'sitenews_news_general',
                'module' => 'sitenews',
                'controller' => 'news',
                'action' => 'create-barred',
                'title' => 'You can not add more news, as limit has expired.',
            );
        }

        return true;
    }

    public function canCreateNews() {

        // Must be logged in
        $viewer = Engine_Api::_()->user()->getViewer();
        if (!$viewer || !$viewer->getIdentity()) {
            return false;
        }

        // Must be able to create news
        if (!Engine_Api::_()->authorization()->isAllowed('sitenews_news', $viewer, 'create')) {
            return false;
        }

        return true;
    }

    public function canViewRSS() {

        if (!Engine_Api::_()->getApi('settings', 'core')->getSetting('sitenews.rss.allow', 0)) {
            return false;
        }

        $viewer = Engine_Api::_()->user()->getViewer();
        $memberLevelAllow = Engine_Api::_()->authorization()->isAllowed('sitenews_rss', $viewer, 'view');
        if (!$memberLevelAllow) {
            return false;
        }

        return true;
    }

    public function isLocationEnabled() {
        if (Engine_Api::_()->getApi('settings', 'core')->getSetting('sitenews.news.location', 0)) {
            return true;
        } else {
            return false;
        }
    }

    public function canViewNews() {
        $viewer = Engine_Api::_()->user()->getViewer();

        // Must be able to view news
        if (!Engine_Api::_()->authorization()->isAllowed('sitenews_news', $viewer, 'view')) {
            return false;
        }

        return true;
    }

    public function canViewListRss() {

        if (!Engine_Api::_()->getApi('settings', 'core')->getSetting('sitenews.rss.allow', 1)) {
            return false;
        }

        $viewer = Engine_Api::_()->user()->getViewer();

        // Must be able to view RSS
        if (!Engine_Api::_()->authorization()->isAllowed('sitenews_rss', $viewer, 'view')) {
            return false;
        }

        return true;
    }

}
