<?php

/**
 * SocialEngine
 *
 * @category   Application_Extensions
 * @package    Sitenews
 * @copyright  Copyright 2016-2017 BigStep Technologies Pvt. Ltd.
 * @license    http://www.socialengineaddons.com/license/
 * @version    $Id: IndexController.php 2017-01-01 9:40:21Z SocialEngineAddOns $
 * @author     SocialEngineAddOns
 */

class Sitenews_IndexController extends Core_Controller_Action_Standard {

    public function init() {
        // only show to member_level if authorized
        if (!$this->_helper->requireAuth()->setAuthParams('sitenews_rss', null, 'view')->isValid())
            return;
    }

    //ACTION FOR BROWSE PAGE 
    public function browseAction() {

        if (!$this->_helper->requireAuth()->setAuthParams('sitenews_rss', null, 'view')->isValid()) {
            return;
        }

        //GET PAGE OBJECT
        $pageTable = Engine_Api::_()->getDbtable('pages', 'core');
        $pageSelect = $pageTable->select()->where('name = ?', "sitenews_index_browse");
        $pageObject = $pageTable->fetchRow($pageSelect);

        $params = array();
        $channel_type_title = '';
        if (!empty($pageObject->title)) {
            //$params['default_title'] = $title = $pageObject->title;
        } else {
            $params['default_title'] = $title = Zend_Registry::get('Zend_Translate')->_('Browse RSS');
        }

        //GET RSS CATEGORY TABLE
        $tableCategory = Engine_Api::_()->getDbtable('categories', 'sitenews');
        $request = Zend_Controller_Front::getInstance()->getRequest();
        $category_id = $request->getParam('category_id', null);

        if (!empty($category_id)) {
            if ($rss_type_title)
                $params['rss_type_title'] = $title = $rss_type_title;
            $meta_title = $tableCategory->getCategory($category_id)->meta_title;
            if (empty($meta_title)) {
                $params['categoryname'] = Engine_Api::_()->getItem('sitenews_category', $category_id)->getCategorySlug();
            } else {
                $params['categoryname'] = $meta_title;
            }
            $meta_description = $tableCategory->getCategory($category_id)->meta_description;
            if (!empty($meta_description))
                $params['description'] = $meta_description;

            $meta_keywords = $tableCategory->getCategory($category_id)->meta_keywords;
            if (empty($meta_keywords)) {
                $params['categoryname_keywords'] = Engine_Api::_()->getItem('sitenews_category', $category_id)->getCategorySlug();
            } else {
                $params['categoryname_keywords'] = $meta_keywords;
            }

            $subcategory_id = $request->getParam('subcategory_id', null);
            if (!empty($subcategory_id)) {
                $meta_title = $tableCategory->getCategory($subcategory_id)->meta_title;
                if (empty($meta_title)) {
                    $params['subcategoryname'] = Engine_Api::_()->getItem('sitenews_category', $subcategory_id)->getCategorySlug();
                } else {
                    $params['subcategoryname'] = $meta_title;
                }

                $meta_description = $tableCategory->getCategory($subcategory_id)->meta_description;
                if (!empty($meta_description))
                    $params['description'] = $meta_description;

                $meta_keywords = $tableCategory->getCategory($subcategory_id)->meta_keywords;
                if (empty($meta_keywords)) {
                    $params['subcategoryname_keywords'] = Engine_Api::_()->getItem('sitenews_category', $subcategory_id)->getCategorySlug();
                } else {
                    $params['subcategoryname_keywords'] = $meta_keywords;
                }
            }
        }

        //SET META TITLE
        //Engine_Api::_()->sitenews()->setMetaTitles($params);
        //SET META TITLE
        Engine_Api::_()->sitenews()->setMetaDescriptionsBrowse($params);

        //GET LOCATION
        if (isset($_GET['location']) && !empty($_GET['location'])) {
            $params['location'] = $_GET['location'];
        }

        //GET TAG
        if (isset($_GET['tag']) && !empty($_GET['tag'])) {
            $params['tag'] = $_GET['tag'];
        }

        if (isset($_GET['search']) && !empty($_GET['search'])) {
            $params['search'] = $_GET['search'];
        }

        //GET RSS TITLE
        $params['rss_type_title'] = $this->view->translate('RSS');

        //SET META KEYWORDS
        Engine_Api::_()->sitenews()->setMetaKeywords($params);

        $this->_helper->content->setNoRender()->setEnabled();
    }

    // to display all the Rss list from See all link of list-rss widget.
    public function listRssAction() {
        if (!$this->_helper->requireAuth()->setAuthParams('sitenews_rss', null, 'view')->isValid()) {
            return;
        }

        $this->_helper->content->setNoRender()->setEnabled();
    }

    // pinboard action
    public function pinboardAction() {
        if (!$this->_helper->requireAuth()->setAuthParams('sitenews_rss', null, 'view')->isValid()) {
            return;
        }
        $this->_helper->content->setNoRender()->setEnabled();
    }

    //ACTION FOR GETTING THE AUTOSUGGESTED RSS BASED ON SEARCHING
    public function getSearchRssAction() {

        //GET CHANNELS AND MAKE ARRAY
        $usersitenews = Engine_Api::_()->getDbtable('rss', 'sitenews')->getDayItems($this->_getParam('text'), $this->_getParam('limit', 10));
        $data = array();
        $mode = $this->_getParam('struct');
        $count = count($usersitenews);
        if ($mode == 'text') {
            $i = 0;
            foreach ($usersitenews as $sitenews) {
                $sitenews_url = $this->view->url(array('slug' => $sitenews->getSlug(), 'rss_url' => $sitenews->rss_url), "sitenews_entry_view", true);
                $i++;
                $content_news = $this->view->itemPhoto($sitenews, 'thumb.normal');
                $data[] = array(
                    'id' => $sitenews->rss_id,
                    'label' => $sitenews->title,
                    'news' => $content_news,
                    'sitenews_url' => $sitenews_url,
                    'total_count' => $count,
                    'count' => $i
                );
            }
        } else {
            $i = 0;
            foreach ($usersitenews as $sitenews) {
                $sitenews_url = $this->view->url(array('slug' => $sitenews->getSlug(), 'rss_id' => $sitenews->rss_id), "sitenews_rss_view", true);
                // $content_news = $this->view->itemPhoto($sitenews, 'thumb.normal');
                $i++;
                $data[] = array(
                    'id' => $sitenews->rss_id,
                    'label' => $sitenews->title,
                    'news' => $content_news,
                    'sitenews_url' => $sitenews_url,
                    'total_count' => $count,
                    'count' => $i
                );
            }
        }
        if (!empty($data) && $i >= 1) {
            if ($data[--$i]['count'] == $count) {
                $data[$count]['id'] = 'stopevent';
                $data[$count]['label'] = $this->_getParam('text');
                $data[$count]['sitenews_url'] = 'seeMoreLink';
                $data[$count]['total_count'] = $count;
            }
        }
        return $this->_helper->json($data);
    }

    public function rssViewAction() {
        if (!Engine_Api::_()->getApi('settings', 'core')->getSetting('sitenews.rss.allow', 1)) {
            return $this->_forward('notfound', 'error', 'core');
        }
        // Check permission
        $viewer = Engine_Api::_()->user()->getViewer();
        $sitenews = Engine_Api::_()->getItem('sitenews_rss', $this->_getParam('rss_id'));
        if ($sitenews) {
            Engine_Api::_()->core()->setSubject($sitenews);
        }

        if (!$this->_helper->requireSubject()->isValid()) {
            return;
        }
        if (!$this->_helper->requireAuth()->setAuthParams('sitenews_rss', $viewer, 'view')->isValid()) {
            return;
        }
        if (!$sitenews || !$sitenews->getIdentity() ||
                ($sitenews->draft && !$sitenews->isOwner($viewer))) {
            return $this->_helper->requireSubject->forward();
        }

        // Render
        $this->_helper->content
                // ->setNoRender()
                ->setEnabled()
        ;
    }

    // manage action 
    public function manageAction() {
        if (!$this->_helper->requireUser()->isValid())
            return;

        // Render
        $this->_helper->content
                //->setNoRender()
                ->setEnabled()
        ;
    }

    public function deleteAction() {
        $viewer = Engine_Api::_()->user()->getViewer();
        $rss = Engine_Api::_()->getItem('sitenews_rss', $this->getRequest()->getParam('rss_id'));

        if (!$this->_helper->requireAuth()->setAuthParams($rss, $viewer, 'delete')->isValid())
            return;

        $this->_helper->layout->setLayout('default-simple');

        $this->view->form = $form = new Sitenews_Form_Rss_Delete();

        if (!$rss) {
            $this->view->status = false;
            $this->view->error = Zend_Registry::get('Zend_Translate')->_("RSS doesn't exist or not authorized to delete");
            return;
        }

        if (!$this->getRequest()->isPost()) {
            $this->view->status = false;
            $this->view->error = Zend_Registry::get('Zend_Translate')->_('Invalid request method');
            return;
        }

        $db = $rss->getTable()->getAdapter();
        $db->beginTransaction();

        try {
            $db->delete('engine4_sitenews_news', array(
                'rss = ?' => $rss->rss_id,
            ));

            $rss->delete();

            $db->commit();
        } catch (Exception $e) {
            $db->rollBack();
            throw $e;
        }

        $this->view->status = true;
        $this->view->message = Zend_Registry::get('Zend_Translate')->_('Your RSS has been deleted.');
        return $this->_forward('success', 'utility', 'core', array(
                    'parentRedirect' => Zend_Controller_Front::getInstance()->getRouter()->assemble(array('action' => 'manage'), 'sitenews_general', true),
                    'messages' => Array($this->view->message)
        ));
    }

    //ACTION FOR CONSTRUCT TAG CLOUD
    public function tagscloudAction() {

        if (!Engine_Api::_()->getApi('settings', 'core')->getSetting('sitenews.rss.tags.enabled', 1)) {
            return $this->_forward('notfound', 'error', 'core');
        }
        if (!$this->_helper->requireAuth()->setAuthParams('sitenews_rss', null, 'view')->isValid()) {
            return;
        }
        $this->_helper->content
                ->setContentName('sitenews_index_tagscloud')
                ->setNoRender()
                ->setEnabled();
    }

    public function changeStatusAction() {
        $rss = Engine_Api::_()->getItem('sitenews_rss', $this->getParam('rss_id'));
        $newsTable = Engine_Api::_()->getDbtable('news', 'sitenews');
        $where = array('rss=?' => $this->getParam('rss_id'));
        if ($this->getParam('approve') == 1) {
            $rss->published = 1;
            $rss->save();
            $newsTable->update(array('published' => 1), $where);
        } else {
            $rss->published = 0;
            $rss->save();
            $newsTable->update(array('published' => 0), $where);
        }
        $this->_redirect('rss/manage');
    }

    public function feedAction() {

        include_once APPLICATION_PATH .'/application/modules/Sitenews/controllers/license/license2.php';    
        if(empty($sitenews_create_rss) || empty($create_rss)){
            
            $this->_helper->content->setNoRender();
            return;
        }
        
		if (!Engine_Api::_()->getApi('settings', 'core')->getSetting('sitenews.rss.allow', 1)) {
            return $this->_forward('notfound', 'error', 'core');
        }

        if (!$this->_helper->requireAuth()->setAuthParams('sitenews_rss', null, 'create')->isValid()) {
            return;
        }

        // Render
        $this->_helper->content->setEnabled();

        // Get form
        $this->view->form = $form = new Sitenews_Form_Rss();

        $viewer = Engine_Api::_()->user()->getViewer();
        $viewerId = Engine_Api::_()->user()->getViewer()->user_id;
        if (!empty($viewerId)) {
            $level_id = $viewer->level_id;
        } else {
            $level_id = Engine_Api::_()->getDbtable('levels', 'authorization')->fetchRow(array('type = ?' => "public"))->level_id;
        }

        $maxAllowedRss = Engine_Api::_()->authorization()->getPermission($level_id, 'sitenews_rss', 'max_allowed');
        if (!empty($maxAllowedRss)) {
            $rssTable = Engine_Api::_()->getDbtable('rss', 'sitenews');
            $userRssCount = $rssTable
                    ->select()
                    ->from($rssTable->info('name'), new Zend_Db_Expr('COUNT(rss_id)'))
                    ->where('owner_id = ?', $viewerId)
                    ->limit(1)
                    ->query()
                    ->fetchColumn();
            if ($userRssCount >= $maxAllowedRss) {
                $error = sprintf(Zend_Registry::get('Zend_Translate')->_('You have exceeded maximum RSS creation limit. You are allowed to create maximum %s RSS only.'), $maxAllowedRss);
                $form->getDecorator('errors')->setOption('escape', false);
                $form->addError($error);
                return;
            }
        }

        if (!$this->getRequest()->isPost()) {
            if (null !== ($rss_id = $this->_getParam('rss_id'))) {
                $form->populate(array(
                    'rss' => $rss_id
                ));
            }
            return;
        }

        if (!$form->isValid($this->getRequest()->getPost())) {
            return;
        }

        $db = Engine_Db_Table::getDefaultAdapter();
        $db->beginTransaction();
        try {
            $values = $form->getValues();
            
            $rss = $form->saveValues();

            $table = Engine_Api::_()->getItemTable('sitenews_rss');
            $rss_id = $rss->rss_id;
            $category_id = $rss->category_id;
            $subcategory_id = $rss->subcategory_id;
            $subsubcategory_id = $rss->subsubcategory_id;

            //ADDING TAGS
            $keywords = '';
            $tags = $form->getValue('tags');
            if (!empty($tags)) {
                $tags = preg_split('/[,]+/', $tags);
                $tags = array_filter(array_map("trim", $tags));
                $rss->tags()->addTagMaps($viewer, $tags);

                foreach ($tags as $tag) {
                    $keywords .= " $tag";
                }
            }

            $photo = $form->getValue('photo');

            // Set photo
            if (!empty($photo)) {
                $rss->setPhoto($form->photo,array('setRssLogo'=>1));
            }else{
                $feed = Zend_Feed_Reader::import($rss->rss_url);
                $rssImageArray = $feed->getImage();
                $thumbUrl = trim($rssImageArray['uri']);
                if (!empty($thumbUrl)) {
                    // $rssImageArray['tmp_name'] = $rssImageArray['uri'];
                    try {
                            $path = APPLICATION_PATH . '/public/';
                            //                                 (url, dir, dir_type, overite, , debug)
                            $image = Engine_Api::_()->getDbtable('news', 'sitenews')->saveTemporaryImage($thumbUrl, $path , NULL, false, true, true);                    
                            chmod($image,'777');
                            $rss->setPhoto($image,array('setRssLogo'=>1));

                    } catch (Exception $ex) {
                            
                    }
                }                
            }

            $rss->save();


            $action = Engine_Api::_()->getDbtable('actions', 'activity')->addActivity($viewer, $rss, 'sitenews_news_feed');

            // make sure action exists before attaching the news to the activity
            if ($action) {
                Engine_Api::_()->getDbtable('actions', 'activity')->attachActivity($action, $rss);
            }

            //COMMIT
            $db->commit();

            //UPDATE KEYWORDS IN SEARCH TABLE
            if (!empty($keywords)) {
                Engine_Api::_()->getDbTable('search', 'core')->update(array('keywords' => $keywords), array('type = ?' => 'sitenews_rss', 'id = ?' => $rss->rss_id));
            }

            return $this->_helper->redirector->gotoRoute(array('action' => 'manage', 'viewFormat' => 'listView', 'newRSS' => true, 'latest_rss_id' => $rss->rss_id), 'sitenews_general', true);
        } catch (Exception $e) {
            $db->rollBack();
            throw $e;
        }
    }

    //Edit Action
    public function editAction() {

        include_once APPLICATION_PATH .'/application/modules/Sitenews/controllers/license/license2.php';
        if(empty($sitenews_edit_rss)||empty($edit_rss)){
            
            $this->_helper->content->setNoRender();
            return;
        }

        if (!Engine_Api::_()->getApi('settings', 'core')->getSetting('sitenews.rss.allow', 1)) {
            return $this->_forward('notfound', 'error', 'core');
        }

        $viewer = Engine_Api::_()->user()->getViewer();
        $rss = Engine_Api::_()->getItem('sitenews_rss', $this->_getParam('rss_id'));

        if (!Engine_Api::_()->core()->hasSubject('sitenews')) {
            Engine_Api::_()->core()->setSubject($rss);
        }

        if (!$this->_helper->requireSubject()->isValid())
            return;

        if (!$this->_helper->requireAuth()->setAuthParams($rss, $viewer, 'edit')->isValid())
            return;

        $this->_helper->content
                //  ->setNoRender()
                ->setEnabled();

        // Get navigation
        $this->view->navigation = $navigation = Engine_Api::_()->getApi('menus', 'core')
                ->getNavigation('sitenews_main');

        // Get form
        $this->view->form = $form = new Sitenews_Form_RssEdit();
        $this->view->subsubcategory = 0;
        $this->view->subcategory = 0;
        if ($rss['subcategory_id'] != 0) {
            $this->view->subcategory = $rss['subcategory_id'];
            $this->view->category = $rss['category_id'];
            if ($rss['subsubcategory_id'] != 0) {
                $this->view->subsubcategory = $rss['subsubcategory'];
            }
        }

        // Populate form
        $form->populate($rss->toArray());

        $tagStr = '';
        foreach ($rss->tags()->getTagMaps() as $tagMap) {
            $tag = $tagMap->getTag();

            if (!isset($tag->text))
                continue;
            if ('' !== $tagStr)
                $tagStr .= ', ';
            $tagStr .= $tag->text;
        }
        $form->populate(array(
            'tags' => $tagStr,
        ));
        $this->view->tagNamePrepared = $tagStr;

        $auth = Engine_Api::_()->authorization()->context;
        $roles = array('owner', 'owner_member', 'owner_member_member', 'owner_network', 'registered', 'everyone');

        foreach ($roles as $role) {
            if ($form->auth_view) {
                if ($auth->isAllowed($rss, $role, 'view')) {
                    $form->auth_view->setValue($role);
                }
            }

            if ($form->auth_comment) {
                if ($auth->isAllowed($rss, $role, 'comment')) {
                    $form->auth_comment->setValue($role);
                }
            }
        }

        // hide status change if it has been already published
        if ($rss->draft == "0") {
            $form->removeElement('draft');
        }
        date_default_timezone_get($viewer->timezone);
        $form->rss_url->setAttrib('disabled', 'true');
        if ($rss->published == 1) {
            $form->removeElement('publish_date');
        }

        // Check post/form
        if (!$this->getRequest()->isPost()) {
            return;
        }
        if (!$form->isValid($this->getRequest()->getPost())) {
            return;
        }

        // Process
        $db = Engine_Db_Table::getDefaultAdapter();
        $db->beginTransaction();

        try {
            $values = $form->getValues();

            $rss_url = $rss->rss_url;
            $rss->setFromArray($values);

            $rss->modified_date = date('Y-m-d H:i:s');
            $rss->rss_url = $rss_url;
            $photo = $form->getValue('photo');
            // Set photo
            if (!empty($photo)) {
                $rss->setPhoto($form->photo);
            }
            $photo = $rss->save();

            // Auth
            if (empty($values['auth_view'])) {
                $values['auth_view'] = 'everyone';
            }

            if (empty($values['auth_comment'])) {
                $values['auth_comment'] = 'everyone';
            }

            $viewMax = array_search($values['auth_view'], $roles);
            $commentMax = array_search($values['auth_comment'], $roles);

            foreach ($roles as $i => $role) {
                $auth->setAllowed($rss, $role, 'view', ($i <= $viewMax));
                $auth->setAllowed($rss, $role, 'comment', ($i <= $commentMax));
            }
            $newsItems = Engine_Api::_()->getDbtable('news', 'sitenews')->fetchAll()->toArray();
            foreach ($newsItems as $newsItem) {
                $item = Engine_Api::_()->getItem('sitenews_news', $newsItem['news_id']);
                foreach ($roles as $i => $role) {
                    $auth->setAllowed($item, $role, 'view', ($i <= $viewMax));
                    $auth->setAllowed($item, $role, 'comment', ($i <= $commentMax));
                }
            }

            // handle tags
            $tags = preg_split('/[,]+/', $values['tags']);
            $rss->tags()->setTagMaps($viewer, $tags);
            $db->commit();
        } catch (Exception $e) {
            $db->rollBack();
            throw $e;
        }

        return $this->_helper->redirector->gotoRoute(array('action' => 'manage'));
    }

    //ACTION TO GET SUB-CATEGORY
    public function subCategoryAction() {

        //GET CATEGORY ID
        $category_id_temp = $this->_getParam('category_id_temp');
        $showAllCategories = $this->_getParam('showAllCategories', 1);

        //INTIALIZE ARRAY
        $this->view->subcats = $data = array();

        //RETURN IF CATEGORY ID IS EMPTY
        if (empty($category_id_temp))
            return;

        //GET CATEGORY TABLE
        $tableCategory = Engine_Api::_()->getDbtable('categories', 'sitenews');

        //GET CATEGORY
        $category = $tableCategory->getCategory($category_id_temp);
        if (!empty($category->category_name)) {
            $categoryName = Engine_Api::_()->getItem('sitenews_category', $category_id_temp)->getCategorySlug();
        }
        //GET SUB-CATEGORY
        $subCategories = $tableCategory->getSubCategories(array('category_id' => $category_id_temp, 'fetchColumns' => array('category_id', 'category_name', 'category_slug'), 'havingRss' => $showAllCategories));

        foreach ($subCategories as $subCategory) {
            $content_array = array();
            $content_array['category_name'] = $this->view->translate($subCategory->category_name);
            $content_array['category_id'] = $subCategory->category_id;
            $content_array['categoryname_temp'] = $categoryName;
            $content_array['category_slug'] = $subCategory->getCategorySlug();
            $data[] = $content_array;
        }

        $this->view->subcats = $data;
    }

    //ACTION FOR FETCHING SUB-CATEGORY
    public function subsubCategoryAction() {

        //GET SUB-CATEGORY ID
        $subcategory_id_temp = $this->_getParam('subcategory_id_temp');
        $showAllCategories = $this->_getParam('showAllCategories', 1);
        //INTIALIZE ARRAY
        $this->view->subsubcats = $data = array();

        //RETURN IF SUB-CATEGORY ID IS EMPTY
        if (empty($subcategory_id_temp))
            return;

        //GET CATEGORY TABLE
        $tableCategory = Engine_Api::_()->getDbTable('ategories', 'sitenews');

        //GET SUB-CATEGORY
        $subCategory = $tableCategory->getCategory($subcategory_id_temp);
        if (!empty($subCategory->category_name)) {
            $subCategoryName = Engine_Api::_()->getItem('sitenews_category', $subcategory_id_temp)->getCategorySlug();
        }

        //GET 3RD LEVEL CATEGORIES
        $subCategories = $tableCategory->getSubCategories(array('category_id' => $subcategory_id_temp, 'fetchColumns' => array('category_id', 'category_name', 'category_slug'), 'havingRss' => $showAllCategories));
        foreach ($subCategories as $subCategory) {
            $content_array = array();
            $content_array['category_name'] = $this->view->translate($subCategory->category_name);
            $content_array['category_id'] = $subCategory->category_id;
            $content_array['categoryname_temp'] = $subCategoryName;
            $data[] = $content_array;
        }
        $this->view->subsubcats = $data;
    }

    //ACTON FOR CATEGORIES PAGE
    public function categoriesAction() {

        if (!Engine_Api::_()->getApi('settings', 'core')->getSetting('sitenews.category.enabled', 1)) {
            return $this->_forward('notfound', 'error', 'core');
        }

        if (!$this->_helper->requireAuth()->setAuthParams('sitenews_rss', null, 'view')->isValid()) {
            return;
        }

        $siteinfo = $this->view->layout()->siteinfo;
        $titles = $siteinfo['title'];
        $keywords = $siteinfo['keywords'];
        $rss_type_title = 'Rss';

        if (!empty($keywords))
            $keywords .= ' - ';

        $keywords .= $rss_type_title;
        $siteinfo['keywords'] = $keywords;
        $this->view->layout()->siteinfo = $siteinfo;

        $this->_helper->content
                ->setNoRender()
                ->setEnabled();
    }

    public function uploadPhotoAction() {
        $viewer = Engine_Api::_()->user()->getViewer();

        $this->_helper->layout->disableLayout();

        if (!Engine_Api::_()->authorization()->isAllowed('album', $viewer, 'create')) {
            return false;
        }

        if (!$this->_helper->requireAuth()->setAuthParams('album', null, 'create')->isValid())
            return;

        if (!$this->_helper->requireUser()->checkRequire()) {
            $this->view->status = false;
            $this->view->error = Zend_Registry::get('Zend_Translate')->_('Max file size limit exceeded (probably).');
            return;
        }

        if (!$this->getRequest()->isPost()) {
            $this->view->status = false;
            $this->view->error = Zend_Registry::get('Zend_Translate')->_('Invalid request method');
            return;
        }
        if (!isset($_FILES['userfile']) || !is_uploaded_file($_FILES['userfile']['tmp_name'])) {
            $this->view->status = false;
            $this->view->error = Zend_Registry::get('Zend_Translate')->_('Invalid Upload');
            return;
        }

        $db = Engine_Api::_()->getDbtable('photos', 'album')->getAdapter();
        $db->beginTransaction();

        try {
            $viewer = Engine_Api::_()->user()->getViewer();

            $photoTable = Engine_Api::_()->getDbtable('photos', 'album');
            $photo = $photoTable->createRow();
            $photo->setFromArray(array(
                'owner_type' => 'user',
                'owner_id' => $viewer->getIdentity()
            ));
            $photo->save();

            $photo->setPhoto($_FILES['userfile']);

            $this->view->status = true;
            $this->view->name = $_FILES['userfile']['name'];
            $this->view->photo_id = $photo->photo_id;
            $this->view->photo_url = $photo->getPhotoUrl();

            $table = Engine_Api::_()->getDbtable('albums', 'album');
            $album = $table->getSpecialAlbum($viewer, 'news');

            $photo->album_id = $album->album_id;
            $photo->save();

            if (!$album->photo_id) {
                $album->photo_id = $photo->getIdentity();
                $album->save();
            }

            $auth = Engine_Api::_()->authorization()->context;
            $auth->setAllowed($photo, 'everyone', 'view', true);
            $auth->setAllowed($photo, 'everyone', 'comment', true);
            $auth->setAllowed($album, 'everyone', 'view', true);
            $auth->setAllowed($album, 'everyone', 'comment', true);


            $db->commit();
        } catch (Album_Model_Exception $e) {
            $db->rollBack();
            $this->view->status = false;
            $this->view->error = $this->view->translate($e->getMessage());
            throw $e;
            return;
        } catch (Exception $e) {
            $db->rollBack();
            $this->view->status = false;
            $this->view->error = Zend_Registry::get('Zend_Translate')->_('An error occurred.');
            throw $e;
            return;
        }
    }

    public function validateurlAction() {
        $view = Zend_Registry::get('Zend_View');
        $rss_url = $this->_getParam('rss_url');
        $table = Engine_Api::_()->getDbtable('blacklisturls','sitenews');
        $tableName = $table->info('name');
        $error = "";
        try {
            $feeds = Zend_Feed_Reader::import($rss_url);
            $select = $table->select()
                            ->from($tableName,array('blackCount'=>'COUNT(1)'))
                            ->where('blacklisturls_url LIKE ?', "%".$rss_url."%");
            $blacklistedUrl = $table->fetchRow($select);
            if($blacklistedUrl->blackCount>=1){
               $error = "BlacklistFound";
               throw new Exception('This url is blacklisted. Contact Admin, to add this.'); 
            }
            echo Zend_Json::encode(array('success' => 1, 'success_msg' => "<span style='color:green;'><img src='" . $view->layout()->staticBaseUrl . "application/modules/Sitenews/externals/images/tick.png'/> Valid Url</span>", 'title' => $feeds->getTitle(), 'description' => $feeds->getDescription()));
            exit();
        } catch (Exception $e) {
            if($error == 'BlacklistFound'){
                $msg = $e->getMessage();
            }else{
                $msg = "Invalid Url";
            }

            echo Zend_Json::encode(array('success' => 0, 'error_msg' => '<span class="seaocore_txt_red"><img src="' . $view->layout()->staticBaseUrl . 'application/modules/Sitenews/externals/images/cross.png"/> '.$msg.'</span>', 'title' => '', 'description' => ''));
            exit();
        }
    }

    public function fetchNewsFeedAction() {
        $this->view->rss_id = $rss_id = $this->_getParam('rss_id');
    }

    public function fetchAction() {
        
        $rssId = $this->_getParam('rss_id');
        if(empty($rssId)){

            return;
        }

        $count = Engine_Api::_()->getItemTable('sitenews_news')->saveNews(Engine_Api::_()->getItem('sitenews_rss', $rssId), false);
        $this->view->success = true;
        $rssItem = Engine_Api::_()->getItem('sitenews_rss', $rssId);

        if ($count > 0 && !empty($rssId) && !empty($rssItem) && $rssItem->published == 1) {
            //Send Notification
            Engine_Api::_()->getDbtable('rsssubscriptions', 'sitenews')
                    ->sendNotifications(null, $rssItem, 'sitenews_subscribed_rss_updated');

            //Send Email Notification
            Engine_Api::_()->getApi('core', 'sitenews')->sendEmailNotification(null, $rssItem, 'sitenews_subscribed_rss_updated', 'SITENEWS_RSSUPDATED_EMAIL');

            //Generate Activity Feed of a RSS Updated combined all new news.
            // $params = array('count'=>$count);
            // $viewer = Engine_Api::_()->user()->getViewer();
            // $action = Engine_Api::_()->getDbtable('actions', 'activity')->addActivity($viewer, $rssItem, 'sitenews_rss_updated', null, $params);

            // $newsTable = Engine_Api::_()->getDbtable('news','sitenews');
            // $newsTableName = $newsTable->info('name');

            // $select = $newsTable->select()
            //                     ->from($newsTableName,array('news_id'))
            //                     ->where('rss = '.$rssId)
            //                     ->limit($count)
            //                     ->order('news_id DESC');

            // $newsIdentities = $select->query()->fetchAll(Zend_Db::FETCH_COLUMN);
            // $newsData = Engine_Api::_()->getItemMulti('sitenews_news',$newsIdentities);
            // foreach ($newsData as $news) {
                
            //     Engine_Api::_()->getDbtable('actions', 'activity')->attachActivity($action, $news, 2);
            // }
        }        
    }

    public function multiDeleteAction() {
        if ($this->getRequest()->isPost()) {
            $values = $this->getRequest()->getPost();
            $db = Zend_Db_Table_Abstract::getDefaultAdapter();
            try {
                $rssTable = Engine_Api::_()->getDbtable('rss', 'sitenews');
                $newsTable = Engine_Api::_()->getDbtable('news', 'sitenews');
                $db->beginTransaction();
                foreach ($values as $key => $value) {
                    if ($key == 'delete_' . $value) {
                        $newsTable->delete(array('rss = ?' => $value));
                        $rssTable->delete(array('rss_id = ?' => $value));
                    }
                }
                $db->commit();
            } catch (Exception $e) {
                $db->rollback();
                echo $e;
            }
        }
        return $this->_helper->redirector->gotoRoute(array('action' => 'manage', 'viewFormat' => 'listView'));
    }

}
