<?php

/**
 * SocialEngine
 *
 * @category   Application_Extensions
 * @package    Sitenews
 * @copyright  Copyright 2016-2017 BigStep Technologies Pvt. Ltd.
 * @license    http://www.socialengineaddons.com/license/
 * @version    $Id: NewsController.php 2017-01-01 9:40:21Z SocialEngineAddOns $
 * @author     SocialEngineAddOns
 */

class Sitenews_NewsController extends Core_Controller_Action_Standard {

    public function init() {
        // only show to member_level if authorized
        if (!$this->_helper->requireAuth()->setAuthParams('sitenews_news', null, 'view')->isValid())
            return;
    }
    // Cannot create news error message.
    public function createBarredAction(){
        
        $maxAllowedNews = Engine_Api::_()->authorization()->getPermission($viewer->level_id, 'sitenews_news', 'max_allowed');
        $error = sprintf(Zend_Registry::get('Zend_Translate')->_('You have exceeded maximum News creation limit. You are allowed to create maximum %s news only.'), $maxAllowedNews);
        return $this->_forward('success', 'utility', 'core', array(
             // 'parentRedirect' => Zend_Controller_Front::getInstance()->getRouter()->assemble(array('action' => 'manage'), 'sitenews_news_general', true),
             'messages' => $error,
        ));
    }    
    public function indexAction() {
        if (!$this->_helper->requireAuth()->setAuthParams('sitenews_news', null, 'view')->isValid()) {
            return;
        }
        $this->_helper->content->setNoRender()->setEnabled();
    }

    // pinboard action
    public function pinboardAction() {
        if (!$this->_helper->requireAuth()->setAuthParams('sitenews_news', null, 'view')->isValid()) {
            return;
        }
        $this->_helper->content->setNoRender()->setEnabled();
    }

    //ACTION FOR BROWSE LOCATION NEWS.
    public function mapAction() {

        //GET PAGE OBJECT

        $pageTable = Engine_Api::_()->getDbtable('pages', 'core');
        $pageSelect = $pageTable->select()->where('name = ?', "sitenews_news_map");
        $pageObject = $pageTable->fetchRow($pageSelect);

        if (!Engine_Api::_()->getApi('settings', 'core')->getSetting('sitenews.news.location', 0)) {
            return $this->_forwardCustom('notfound', 'error', 'core');
        } else {

            $this->_helper->content->setContentName($pageObject->page_id)->setNoRender()->setEnabled();
        }
    }

    //GET CATEGORIES ACTION
    public function getNewsCategoriesAction() {

        $element_value = $this->_getParam('element_value', 1);
        $element_type = $this->_getParam('element_type', 'category_id');
        $showAllCategories = $this->_getParam('showAllCategories', 1);

        $categoriesTable = Engine_Api::_()->getDbTable('categories', 'sitenews');
        $categoryTableName = $categoriesTable->info('name');
        $select = $categoriesTable->select()
                ->from($categoryTableName, array('category_id', 'category_name'))
                ->where($categoryTableName . ".$element_type = ?", $element_value);

        if ($element_type == 'category_id') {
            $select->where('cat_dependency = ?', 0)->where('subcat_dependency = ?', 0);
        } elseif ($element_type == 'cat_dependency') {
            $select->where('subcat_dependency = ?', 0);
        } elseif ($element_type == 'subcat_dependency') {
            $select->where('cat_dependency = ?', $element_value);
        }

        if (!$showAllCategories) {
            $tableNews = Engine_Api::_()->getDbTable('news', 'sitenews');
            $tableNewsName = $tableNews->info('name');
            $select->setIntegrityCheck();
            if ($element_type == 'subcat_dependency') {
                $select->join($tableNewsName, "$tableNewsName.subcategory_id=$categoryTableName.$element_type", null);
            } else {
                $select->join($tableNewsName, "$tableNewsName.category_id=$categoryTableName.$element_type", null);
            }
            $select->where($tableNewsName . '.approved = ?', 1)->where($tableNewsName . '.draft = ?', 0)->where($tableNewsName . '.search = ?', 1)->where($tableNewsName . '.closed = ?', 0);
            $select = $tableNews->getNetworkBaseSql($select, array('not_groupBy' => 1));
        }

        $select->group($categoryTableName . '.category_id');

        $categoriesData = $categoriesTable->fetchAll($select);

        $categories = array();
        if (Count($categoriesData) > 0) {
            foreach ($categoriesData as $category) {
                $data = array();
                $data['category_name'] = $this->view->translate($category->category_name);
                $data['category_id'] = $category->category_id;
                $data['category_slug'] = $category->getCategorySlug();
                $categories[] = $data;
            }
        }

        $this->view->categories = $categories;
    }

    public function browseAction() {
        if (!$this->_helper->requireAuth()->setAuthParams('sitenews_news', null, 'view')->isValid()) {
            return;
        }
        $this->_helper->content->setNoRender()->setEnabled();
    }

    public function viewAction() {
        $this->view->addHelperPath(APPLICATION_PATH . '/application/modules/Sitenews/View/Helper', 'Sitenews_View_Helper');
        // Check permission
        $viewer = Engine_Api::_()->user()->getViewer();
        if ($_GET['news_id']) {
            $id = $_GET['news_id'];
            $sitenews = Engine_Api::_()->getItem('sitenews_news', $id);
        } else {
            $sitenews = Engine_Api::_()->getItem('sitenews_news', $this->_getParam('news_id'));
        }

        if ($sitenews) {
            Engine_Api::_()->core()->setSubject($sitenews);
        }

        if (!$this->_helper->requireSubject()->isValid()) {
            return;
        }
        if (!$this->_helper->requireAuth()->setAuthParams($sitenews, $viewer, 'view')->isValid()) {
            return;
        }
        if (!$sitenews || !$sitenews->getIdentity()) {
            return $this->_helper->requireSubject->forward();
        }

        // Prepare data
        $sitenewsTable = Engine_Api::_()->getDbtable('news', 'sitenews');
        $owner = $sitenews->getOwner();
        
        // Suggest to Friend link show work
        $is_suggestion_enabled = Engine_Api::_()->getDbtable('modules', 'core')->isModuleEnabled('suggestion');
        $sitenewsView = Zend_Registry::isRegistered('sitenewsView') ? Zend_Registry::get('sitenewsView') : null;
        if(!empty($is_suggestion_enabled)){
            $modContentObj = Engine_Api::_()->suggestion()->getSuggestedFriend('sitenews', $sitenews->news_id,null,null);
            if (!empty($modContentObj)) {
                $contentCreatePopup = @COUNT($modContentObj);
            }

            Engine_Api::_()->sitenews()->deleteSuggestion(Engine_Api::_()->user()->getViewer()->getIdentity(), 'sitenews', $sitenews->news_id, 'sitenews_news', 'sitenews_suggestion');
            if (!empty($contentCreatePopup)) {
                $this->view->newsSuggLink = Engine_Api::_()->suggestion()->getModSettings('sitenews', 'link');
            }
        } else {
            $this->view->newsSuggLink = 0;
          }

        $this->view->sitenews = $sitenews;
        $id = $sitenews->news_id;
        $previous_id = $sitenewsTable->select()
                ->from($sitenewsTable->info('name'), 'max(news_id)')
                ->where('news_id < ?', $id)
                ->query()
                ->fetchColumn();

        $next_id = $sitenewsTable->select()
                ->from($sitenewsTable->info('name'), 'min(news_id)')
                ->where('news_id > ?', $id)
                ->query()
                ->fetchColumn();

        $first_id = $sitenewsTable->select()
                ->from($sitenewsTable->info('name'), 'news_id')
                ->limit(1)
                ->query()
                ->fetchColumn();

        $last_id = $sitenewsTable->select()
                ->from($sitenewsTable->info('name'), 'max(news_id)')
                ->query()
                ->fetchColumn();
        if (empty($previous_id)) {
            $previous_id = 0;
        }
        if (empty($next_id)) {
            $next_id = 0;
        }
        $this->view->previous_id = $previous_id;
        $this->view->next_id = $next_id;

        $this->view->type = $type = $sitenews->type;
        $this->view->owner = $owner;
        $this->view->viewer = $viewer;
        if ($owner != $viewer) {
            $sitenewsTable->update(array(
                'view_count' => new Zend_Db_Expr('view_count + 1'),
                    ), array(
                'news_id = ?' => $sitenews->getIdentity(),
            ));
        }

        // Get tags
        $this->view->sitenewsTags = $sitenews->tags()->getTagMaps();

        // Get category
        if (!empty($sitenews->category_id)) {
            $this->view->category = Engine_Api::_()->getDbtable('categories', 'sitenews')
                            ->find($sitenews->category_id)->current();
        }

        $this->view->newsOption = $newsOption = array(
            'facebook',
            'twitter',
            'linkedin',
            'googleplus'
        );

        // Render
        $this->_helper->content
                //->setNoRender()
                ->setEnabled()
        ;
    }

    //ACTION FOR CONSTRUCT TAG CLOUD
    public function tagscloudAction() {

        if (!Engine_Api::_()->getApi('settings', 'core')->getSetting('sitenews.news.tags.enabled', 1)) {
            return $this->_forward('notfound', 'error', 'core');
        }
        if (!$this->_helper->requireAuth()->setAuthParams('sitenews_news', null, 'view')->isValid()) {
            return;
        }
        $this->_helper->content
                ->setContentName('sitenews_news_tagscloud')
                ->setNoRender()
                ->setEnabled();
    }

    //ACTION TO GET SUB-CATEGORY
    public function subCategoryAction() {

        //GET CATEGORY ID
        $category_id_temp = $this->_getParam('category_id_temp');
        $showAllCategories = $this->_getParam('showAllCategories', 1);

        //INTIALIZE ARRAY
        $this->view->subcats = $data = array();

        //RETURN IF CATEGORY ID IS EMPTY
        if (empty($category_id_temp))
            return;

        //GET CATEGORY TABLE
        $tableCategory = Engine_Api::_()->getDbtable('categories', 'sitenews');

        //GET CATEGORY
        $category = $tableCategory->getCategory($category_id_temp);
        if (!empty($category->category_name)) {
            $categoryName = Engine_Api::_()->getItem('sitenews_category', $category_id_temp)->getCategorySlug();
        }
        //GET SUB-CATEGORY
        $subCategories = $tableCategory->getSubCategories(array('category_id' => $category_id_temp, 'fetchColumns' => array('category_id', 'category_name', 'category_slug'), 'havingNews' => $showAllCategories));

        foreach ($subCategories as $subCategory) {
            $content_array = array();
            $content_array['category_name'] = $this->view->translate($subCategory->category_name);
            $content_array['category_id'] = $subCategory->category_id;
            $content_array['categoryname_temp'] = $categoryName;
            $content_array['category_slug'] = $subCategory->getCategorySlug();
            $data[] = $content_array;
        }

        $this->view->subcats = $data;
    }

    //ACTION FOR FETCHING SUB-CATEGORY
    public function subsubCategoryAction() {

        //GET SUB-CATEGORY ID
        $subcategory_id_temp = $this->_getParam('subcategory_id_temp');
        $showAllCategories = $this->_getParam('showAllCategories', 1);
        //INTIALIZE ARRAY
        $this->view->subsubcats = $data = array();

        //RETURN IF SUB-CATEGORY ID IS EMPTY
        if (empty($subcategory_id_temp))
            return;

        //GET CATEGORY TABLE
        $tableCategory = Engine_Api::_()->getDbTable('categories', 'sitenews');

        //GET SUB-CATEGORY
        $subCategory = $tableCategory->getCategory($subcategory_id_temp);
        if (!empty($subCategory->category_name)) {
            $subCategoryName = Engine_Api::_()->getItem('sitenews_category', $subcategory_id_temp)->getCategorySlug();
        }

        //GET 3RD LEVEL CATEGORIES
        $subCategories = $tableCategory->getSubCategories(array('category_id' => $subcategory_id_temp, 'fetchColumns' => array('category_id', 'category_name', 'category_slug'), 'havingNews' => $showAllCategories));
        foreach ($subCategories as $subCategory) {
            $content_array = array();
            $content_array['category_name'] = $this->view->translate($subCategory->category_name);
            $content_array['category_id'] = $subCategory->category_id;
            $content_array['categoryname_temp'] = $subCategoryName;
            $data[] = $content_array;
        }
        $this->view->subsubcats = $data;
    }

    //ACTION FOR GETTING THE AUTOSUGGESTED NEWS BASED ON SEARCHING
    public function getSearchNewsAction() {

        //GET NEWS AND MAKE ARRAY
        $usersitenews = Engine_Api::_()->getDbtable('news', 'sitenews')->getDayItems($this->_getParam('text'), $this->_getParam('limit', 10));
        $data = array();
        $mode = $this->_getParam('struct');
        $count = count($usersitenews);
        if ($mode == 'text') {
            $i = 0;
            foreach ($usersitenews as $sitenews) {
                $sitenews_url = $sitenews->getHref();
                $i++;
                $content_news = $this->view->itemPhoto($sitenews, 'thumb.normal');
                $data[] = array(
                    'id' => $sitenews->news_id,
                    'label' => $sitenews->title,
                    'news' => $content_news,
                    'sitenews_url' => $sitenews_url,
                    'total_count' => $count,
                    'count' => $i
                );
            }
        } else {
            $i = 0;
            foreach ($usersitenews as $sitenews) {
                $sitenews_url = $sitenews->getHref();
//                 $content_news = $this->view->itemPhoto($sitenews, 'thumb.normal');
                $i++;
                $data[] = array(
                    'id' => $sitenews->news_id,
                    'label' => $sitenews->title,
                    'news' => $content_news,
                    'sitenews_url' => $sitenews_url,
                    'total_count' => $count,
                    'count' => $i
                );
            }
        }
        if (!empty($data) && $i >= 1) {
            if ($data[--$i]['count'] == $count) {
                $data[$count]['id'] = 'stopevent';
                $data[$count]['label'] = $this->_getParam('text');
                $data[$count]['sitenews_url'] = 'seeMoreLink';
                $data[$count]['total_count'] = $count;
            }
        }
        return $this->_helper->json($data);
    }

    //ACTON FOR CATEGORIES PAGE
    public function categoriesAction() {

        if (!Engine_Api::_()->getApi('settings', 'core')->getSetting('sitenews.category.enabled', 1)) {
            return $this->_forward('notfound', 'error', 'core');
        }

        if (!$this->_helper->requireAuth()->setAuthParams('sitenews_news', null, 'view')->isValid()) {
            return;
        }

        $siteinfo = $this->view->layout()->siteinfo;
        $titles = $siteinfo['title'];
        $keywords = $siteinfo['keywords'];
        $news_type_title = 'NEWS';

        if (!empty($keywords))
            $keywords .= ' - ';

        $keywords .= $news_type_title;
        $siteinfo['keywords'] = $keywords;
        $this->view->layout()->siteinfo = $siteinfo;

        $this->_helper->content
                ->setNoRender()
                ->setEnabled();
    }

    public function categoryHomeAction() {
        $request = Zend_Controller_Front::getInstance()->getRequest();
        $category_id = $request->getParam('category_id', null);
        Zend_Registry::set('sitenewsCategoryId', $category_id);

        //GET STORE OBJECT
        $pageTable = Engine_Api::_()->getDbtable('pages', 'core');
        $pageSelect = $pageTable->select()->where('name = ?', "sitenews_news_categories-home_category_$category_id");
        $pageObject = $pageTable->fetchRow($pageSelect);

        $this->_helper->content
                ->setContentName($pageObject->page_id)
                ->setNoRender()
                ->setEnabled();
    }

    // USER SPECIFIC METHODS
    public function manageAction() {
        if (!$this->_helper->requireUser()->isValid())
            return;

        // Render
        $this->_helper->content
                //->setNoRender()
                ->setEnabled()
        ;

        // Prepare data
    }

    public function createAction() {

        include_once APPLICATION_PATH .'/application/modules/Sitenews/controllers/license/license2.php';
        if(empty($sitenews_create_news) || empty($create_news)){
            
            $this->_helper->content->setNoRender();
            return;
        }

        if (!$this->_helper->requireUser()->isValid())
            return;

        if (!$this->_helper->requireAuth()->setAuthParams('sitenews_news', null, 'create')->isValid())
            return;

        $orientation = $this->view->layout()->orientation;
        if ($orientation == 'right-to-left') {
            $this->view->directionality = 'rtl';
        } else {
            $this->view->directionality = 'ltr';
        }

        $local_language = $this->view->locale()->getLocale()->__toString();
        $local_language = explode('_', $local_language);
        $this->view->language = $local_language[0];

        $newRss = '';
        $rssTable = Engine_Api::_()->getItemTable('sitenews_rss');
        if ($this->_getParam('id')) {
            $newRss = $rssTable->select()
                    ->from($rssTable, array('rss_id', 'title'))
                    ->where('rss_id=?', $this->_getParam('id'))
                    ->query()
                    ->fetchAll();
        }
        $this->view->newRss = $newRss;
        if ($this->_getParam('rss')) {
            $this->view->newNewsRss = $this->_getParam('rss');
        }

        // Render
        $this->_helper->content
                //->setNoRender()
                ->setEnabled()
        ;

        // set up data needed to check quota
        $viewer = Engine_Api::_()->user()->getViewer();
        $viewerId = $viewer->user_id;
        $this->view->form = $form = new Sitenews_Form_Create();

        $maxAllowedNews = Engine_Api::_()->authorization()->getPermission($viewer->level_id, 'sitenews_news', 'max_allowed');
        if (!empty($maxAllowedNews)) {
            $newsTable = Engine_Api::_()->getDbtable('news', 'sitenews');
            $userNewsCount = $newsTable
                    ->select()
                    ->from($newsTable->info('name'), new Zend_Db_Expr('COUNT(news_id)'))
                    ->where('owner_id = ?', $viewerId)
                    ->limit(1)
                    ->query()
                    ->fetchColumn();
            if ($userNewsCount >= $maxAllowedNews) {
                $error = sprintf(Zend_Registry::get('Zend_Translate')->_('You have exceeded maximum News creation limit. You are allowed to create maximum %s news only.'), $maxAllowedNews);
                $form->getDecorator('errors')->setOption('escape', false);
                $form->addError($error);
                return;
            }
        }

        // Below URL is to upload photo in the tinymce editor.
        $this->view->upload_url = "";
        if (Engine_Api::_()->authorization()->isAllowed('album', $viewer, 'create')) {
            $this->view->upload_url = Zend_Controller_Front::getInstance()->getRouter()->assemble(array('action' => 'upload-photo'), 'sitenews_general', true);
        }
        
        // If not post or form not valid, return
        if (!$this->getRequest()->isPost()) {
            if (null !== ($news_id = $this->_getParam('news_id'))) {
                $form->populate(array(
                    'news' => $news_id
                ));
            }
            return;
        }

        if (!$form->isValid($this->getRequest()->getPost())) {
            return;
        }

        $values = $form->getValues();
        if(!empty($values['original_link'])){
            
            Zend_Uri::setConfig(array('allow_unwise' => true));
            $validOrignalLink = Zend_Uri::check($values['original_link']);
            Zend_Uri::setConfig(array('allow_unwise' => false));
            
            if(!$validOrignalLink){

                $form->original_link->addError('Orignal Link is invalid.');
                return;
            }        
        }
        // Process
        $table = Engine_Api::_()->getItemTable('sitenews_news');
        $db = $table->getAdapter();
        $db->beginTransaction();

        try {

            $news = $form->saveValues();

            $table = Engine_Api::_()->getItemTable('sitenews_news');

            //ADDING TAGS
            $keywords = '';
            $tags = $form->getValue('tags');
            if (!empty($tags)) {
                $tags = preg_split('/[,]+/', $tags);
                $tags = array_filter(array_map("trim", $tags));
                $news->tags()->addTagMaps($viewer, $tags);

                foreach ($tags as $tag) {
                    $keywords .= " $tag";
                }
            }

            //SAVE LOCATION
            $location = $form->getValue('location');
            if (!empty($location)) {
                $seaoLocationId = Engine_Api::_()->getDbtable('locationitems', 'seaocore')->getLocationItemId($location, '', $news->getType(), $news->getIdentity());
                $news->seao_locationid = $seaoLocationId;
                $news->location = $location;
            }
            $news->save();

            if (Engine_Api::_()->getApi('settings', 'core')->getSetting('sitenews.news.location', 0)) {
                $news->setLocation();
            }

            // Add activity only if news is published
            date_default_timezone_get($viewer->timezone);
            if ($values['draft'] == 0 || isset($values['publish_date']) && $values['publish_date'] <= date('Y-m-d h-i a')) {
                if (isset($values['rss']) && !empty($values['rss'])) {
                    $rss = Engine_Api::_()->getItem('sitenews_rss', $values['rss']);
                    $action = Engine_Api::_()->getDbtable('actions', 'activity')->addActivity($viewer, $rss, 'sitenews_news_new_in_rss', null, array('child_id' => $news->getIdentity()));
                } else {
                    $action = Engine_Api::_()->getDbtable('actions', 'activity')->addActivity($viewer, $news, 'sitenews_news_new');
                }
                // make sure action exists before attaching the news to the activity
                if ($action) {
                    Engine_Api::_()->getDbtable('actions', 'activity')->attachActivity($action, $news);
                }
            }

            $photo = $form->getValue('photo');
            // Set photo
            if (!empty($photo)) {
                $news->setPhoto($form->photo);
            }
            $photo = $news->save();

            // Send notifications for subscribers
            $rss_id = $form->getValue('rss');
            $rss = Engine_Api::_()->getItem('sitenews_rss', $rss_id);
            if (!empty($rss_id) && $rss->published == 1 && $news->published == 1) {
                $rssItem = Engine_Api::_()->getItem('sitenews_rss', $rss_id);
                Engine_Api::_()->getDbtable('rsssubscriptions', 'sitenews')
                        ->sendNotifications($news, $rssItem, 'sitenews_subscribed_rss_post');

                //Send Email Notification
                Engine_Api::_()->getApi('core', 'sitenews')->sendEmailNotification($news, $rssItem, 'sitenews_news_new', 'SITENEWS_CREATENOTIFICATION_EMAIL');
            }

            // Commit
            $db->commit();
        } catch (Exception $e) {
            $db->rollBack();
            die("error" . $e);
            throw $e;
        }
        
        //SENDING ACTIVITY FEED TO FACEBOOK.
        $enable_Facebooksefeed = $enable_fboldversion = Engine_Api::_()->getDbtable('modules', 'core')->isModuleEnabled('facebooksefeed');
        if (!empty($enable_Facebooksefeed)) {

            $sitenews_array = array();
            $sitenews_array['type'] = 'sitenews_news_new';
            $sitenews_array['object'] = $news;

            Engine_Api::_()->facebooksefeed()->sendFacebookFeed($sitenews_array);
        }
        
        return $this->_helper->redirector->gotoRoute(array('action' => 'manage'));
    }

    public function editAction() {
        
        include_once APPLICATION_PATH .'/application/modules/Sitenews/controllers/license/license2.php';
        if(empty($sitenews_edit_news) || empty($edit_news)){
            
            $this->_helper->content->setNoRender();
            return;
        }

        if (!$this->_helper->requireUser()->isValid())
            return;

        $viewer = Engine_Api::_()->user()->getViewer();
        $sitenews = Engine_Api::_()->getItem('sitenews_news', $this->_getParam('news_id'));
        $old_rss = $sitenews->rss;
        if (!Engine_Api::_()->core()->hasSubject('sitenews')) {
            Engine_Api::_()->core()->setSubject($sitenews);
        }
$this->_helper->content
                //  ->setNoRender()
                ->setEnabled();
        $orientation = $this->view->layout()->orientation;
        if ($orientation == 'right-to-left') {
            $this->view->directionality = 'rtl';
        } else {
            $this->view->directionality = 'ltr';
        }

        $local_language = $this->view->locale()->getLocale()->__toString();
        $local_language = explode('_', $local_language);
        $this->view->language = $local_language[0];

        if (!$this->_helper->requireSubject()->isValid())
            return;
        if (!$this->_helper->requireAuth()->setAuthParams($sitenews, $viewer, 'edit')->isValid())
            return;

        // Get navigation
        $this->view->navigation = $navigation = Engine_Api::_()->getApi('menus', 'core')
                ->getNavigation('sitenews_main');

        // Prepare form
        $this->view->subcategory = 0;
        $this->view->subsubcategory = 0;
        $this->view->form = $form = new Sitenews_Form_Edit();
        if ($sitenews['subcategory_id'] != 0) {
            $this->view->subcategory = $sitenews['subcategory_id'];
            $this->view->category = $sitenews['category_id'];
            if ($sitenews['subsubcategory_id'] != 0) {
                $this->view->subsubcategory = $sitenews['subsubcategory_id'];
            }
        }

        if ($form->rss) {
            $form->rss->setAttrib('disabled', 'disabled');
        }

        $siteNewsArray = $sitenews->toArray();
        $tableOtherinfo = Engine_Api::_()->getDbTable('newsotherinfo', 'sitenews');
        $siteNewsArray['shortdescription'] = $siteNewsArray['description'];
        $siteNewsArray['description'] = $tableOtherinfo->getColumnValue($sitenews->getIdentity(), 'content');

        // Populate form
        $form->populate($siteNewsArray);

        $tagStr = '';
        foreach ($sitenews->tags()->getTagMaps() as $tagMap) {
            $tag = $tagMap->getTag();

            if (!isset($tag->text))
                continue;
            if ('' !== $tagStr)
                $tagStr .= ', ';
            $tagStr .= $tag->text;
        }
        $form->populate(array(
            'tags' => $tagStr,
        ));
        $this->view->tagNamePrepared = $tagStr;

        $auth = Engine_Api::_()->authorization()->context;
        $roles = array('owner', 'owner_member', 'owner_member_member', 'owner_network', 'registered', 'everyone');

        foreach ($roles as $role) {
            if ($form->auth_view) {
                if ($auth->isAllowed($sitenews, $role, 'view')) {
                    $form->auth_view->setValue($role);
                }
            }

            if ($form->auth_comment) {
                if ($auth->isAllowed($sitenews, $role, 'comment')) {
                    $form->auth_comment->setValue($role);
                }
            }
        }

        // hide status change if it has been already published
        if ($sitenews->draft == "0") {
            $form->removeElement('draft');
        }
        date_default_timezone_get($viewer->timezone);
        if ($sitenews->published == 1 && $sitenews->publish_date != date('0000-00-00 00:00:00')) {
            $form->removeElement('publish_date');
        }


        // Check post/form
        if (!$this->getRequest()->isPost()) {
            return;
        }
        if (!$form->isValid($this->getRequest()->getPost())) {
            return;
        }


        // Process
        $db = Engine_Db_Table::getDefaultAdapter();
        $db->beginTransaction();

        try {
            $values = $form->getValues();

            $sitenews->setFromArray($values);
            if ($old_rss && $values['rss'] != $old_rss && $values['rss'] != 0) {
                $rss_old = Engine_Api::_()->getItem('sitenews_rss', $old_rss);
                $rss_new = Engine_Api::_()->getItem('sitenews_rss', $values['rss']);
                $old_count = $rss_old->feeds_count;
                $rss_old->feeds_count = $old_count - 1;
                $rss_old->save();
                $old_count = $rss_new->feeds_count;
                $rss_new->feeds_count = $old_count + 1;
                $rss_new->save();
            } elseif ($old_rss && $values['rss'] != $old_rss && $values['rss'] == 0) {
                $rss_old = Engine_Api::_()->getItem('sitenews_rss', $old_rss);
                $old_count = $rss_old->feeds_count;
                $rss_old->feeds_count = $old_count - 1;
                $rss_old->save();
            } elseif ($values['rss'] != 0) {
                $rss_new = Engine_Api::_()->getItem('sitenews_rss', $values['rss']);
                $rss_new->feeds_count = $old_count + 1;
                $rss_new->save();
            }
            $sitenews->description = $values['shortdescription'];
            $sitenews->modified_date = date('Y-m-d H:i:s');
            $photo = $form->getValue('photo');
            // Set photo
            if (!empty($photo)) {
                $sitenews->setPhoto($form->photo);
            }

            if (isset($values['publish_date']) && $values['publish_date']) {
                $permission = Engine_Api::_()->getDbtable('permissions', 'authorization');
                $value = $permission->select()
                        ->from($permission->info('name'), 'value')
                        ->where('type = ?', 'sitenews_news')
                        ->where('name = ?', 'news_approval')
                        ->where('level_id = ?', $viewer->level_id)
                        ->query()
                        ->fetchColumn();
                if ($value == 1 || isset($params['publish_date']) && ($params['publish_date'] > date('Y-m-d h-i a'))) {
                    $sitenews->published = 0;
                } else {
                    $sitenews->published = 1;
                }
                $sitenews->publish_date = date('0000-00-00 00:00:00');
            }
            $photo = $sitenews->save();

            // Auth
            if (empty($values['auth_view'])) {
                $values['auth_view'] = 'everyone';
            }

            if (empty($values['auth_comment'])) {
                $values['auth_comment'] = 'everyone';
            }

            $viewMax = array_search($values['auth_view'], $roles);
            $commentMax = array_search($values['auth_comment'], $roles);

            foreach ($roles as $i => $role) {
                $auth->setAllowed($sitenews, $role, 'view', ($i <= $viewMax));
                $auth->setAllowed($sitenews, $role, 'comment', ($i <= $commentMax));
            }

            // handle tags
            $tags = preg_split('/[,]+/', $values['tags']);
            $sitenews->tags()->setTagMaps($viewer, $tags);

            // insert new activity if news is just getting published
            $action = Engine_Api::_()->getDbtable('actions', 'activity')->getActionsByObject($sitenews);
            if (count($action->toArray()) <= 0 && $values['draft'] == '0') {
                $action = Engine_Api::_()->getDbtable('actions', 'activity')->addActivity($viewer, $sitenews, 'sitenews_news_new');
                // make sure action exists before attaching the news to the activity
                if ($action != null) {
                    Engine_Api::_()->getDbtable('actions', 'activity')->attachActivity($action, $sitenews);
                }
            }

            // Rebuild privacy
            $actionTable = Engine_Api::_()->getDbtable('actions', 'activity');
            foreach ($actionTable->getActionsByObject($sitenews) as $action) {
                $actionTable->resetActivityBindings($action);
            }

            // Send notifications for subscribers
            if ($form->getValue('rss')) {
                $rss_id = $form->getValue('rss');
                $rss = Engine_Api::_()->getItem('sitenews_rss', $rss_id);
                Engine_Api::_()->getDbtable('rsssubscriptions', 'sitenews')
                        ->sendNotifications($sitenews, $rss);
            }

            if (Engine_Api::_()->getApi('settings', 'core')->getSetting('sitenews.full.content', 1)) {
                $newsotherinfocontent = $values['description'];
            } else {
                $newsotherinfocontent = $values['shortdescription'];
            }

            Engine_Api::_()->getDbTable('newsotherinfo', 'sitenews')->update(array('content' => $newsotherinfocontent), array('news_id = ?' => $sitenews->getIdentity()));

            //SAVE LOCATION
            $location = $form->getValue('location');
            if(!empty($location)) {
                $seaoLocationId = Engine_Api::_()->getDbtable('locationitems', 'seaocore')->getLocationItemId($location, '', $sitenews->getType(), $sitenews->getIdentity());
                $sitenews->seao_locationid = $seaoLocationId;
                $sitenews->location = $location;
            }
            $sitenews->save();

            if (Engine_Api::_()->getApi('settings', 'core')->getSetting('sitenews.news.location', 0)) {
                $sitenews->setLocation();
            }

            $db->commit();
        } catch (Exception $e) {
            $db->rollBack();
            throw $e;
        }

        return $this->_helper->redirector->gotoRoute(array('action' => 'manage'));
    }

    public function deleteAction() {
        $viewer = Engine_Api::_()->user()->getViewer();
        $sitenews = Engine_Api::_()->getItem('sitenews_news', $this->getRequest()->getParam('news_id'));
        if (!$this->_helper->requireAuth()->setAuthParams($sitenews, null, 'delete')->isValid())
            return;

        // In smoothbox
        $this->_helper->layout->setLayout('default-simple');

        $this->view->form = $form = new Sitenews_Form_Delete();

        if (!$sitenews) {
            $this->view->status = false;
            $this->view->error = Zend_Registry::get('Zend_Translate')->_("News entry doesn't exist or not authorized to delete");
            return;
        }

        if (!$this->getRequest()->isPost()) {
            $this->view->status = false;
            $this->view->error = Zend_Registry::get('Zend_Translate')->_('Invalid request method');
            return;
        }

        $db = $sitenews->getTable()->getAdapter();
        $db->beginTransaction();

        try {
            $sitenews->delete();
            if ($sitenews->rss != 0) {
                $rss = Engine_Api::_()->getItem('sitenews_rss', $sitenews->rss);
                $old_count = $rss->feeds_count;
                $rss->feeds_count = $old_count - 1;
                $rss->save();
            }

            $db->commit();
        } catch (Exception $e) {
            $db->rollBack();
            throw $e;
        }

        $this->view->status = true;
        $this->view->message = Zend_Registry::get('Zend_Translate')->_('Your news entry has been deleted.');
        return $this->_forward('success', 'utility', 'core', array(
                    'parentRedirect' => Zend_Controller_Front::getInstance()->getRouter()->assemble(array('action' => 'manage'), 'sitenews_news_general', true),
                    'messages' => Array($this->view->message)
        ));
    }

    public function uploadPhotoAction() {
        $viewer = Engine_Api::_()->user()->getViewer();

        $this->_helper->layout->disableLayout();

        if (!Engine_Api::_()->authorization()->isAllowed('album', $viewer, 'create')) {
            return false;
        }

        if (!$this->_helper->requireAuth()->setAuthParams('album', null, 'create')->isValid())
            return;

        if (!$this->_helper->requireUser()->checkRequire()) {
            $this->view->status = false;
            $this->view->error = Zend_Registry::get('Zend_Translate')->_('Max file size limit exceeded (probably).');
            return;
        }

        if (!$this->getRequest()->isPost()) {
            $this->view->status = false;
            $this->view->error = Zend_Registry::get('Zend_Translate')->_('Invalid request method');
            return;
        }
        if (!isset($_FILES['userfile']) || !is_uploaded_file($_FILES['userfile']['tmp_name'])) {
            $this->view->status = false;
            $this->view->error = Zend_Registry::get('Zend_Translate')->_('Invalid Upload');
            return;
        }

        $db = Engine_Api::_()->getDbtable('photos', 'album')->getAdapter();
        $db->beginTransaction();

        try {
            $viewer = Engine_Api::_()->user()->getViewer();

            $photoTable = Engine_Api::_()->getDbtable('photos', 'album');
            $photo = $photoTable->createRow();
            $photo->setFromArray(array(
                'owner_type' => 'user',
                'owner_id' => $viewer->getIdentity()
            ));
            $photo->save();

            $photo->setPhoto($_FILES['userfile']);

            $this->view->status = true;
            $this->view->name = $_FILES['userfile']['name'];
            $this->view->photo_id = $photo->photo_id;
            $this->view->photo_url = $photo->getPhotoUrl();

            $table = Engine_Api::_()->getDbtable('albums', 'album');
            $album = $table->getSpecialAlbum($viewer, 'news');

            $photo->album_id = $album->album_id;
            $photo->save();

            if (!$album->photo_id) {
                $album->photo_id = $photo->getIdentity();
                $album->save();
            }

            $auth = Engine_Api::_()->authorization()->context;
            $auth->setAllowed($photo, 'everyone', 'view', true);
            $auth->setAllowed($photo, 'everyone', 'comment', true);
            $auth->setAllowed($album, 'everyone', 'view', true);
            $auth->setAllowed($album, 'everyone', 'comment', true);


            $db->commit();
        } catch (Album_Model_Exception $e) {
            $db->rollBack();
            $this->view->status = false;
            $this->view->error = $this->view->translate($e->getMessage());
            throw $e;
            return;
        } catch (Exception $e) {
            $db->rollBack();
            $this->view->status = false;
            $this->view->error = Zend_Registry::get('Zend_Translate')->_('An error occurred.');
            throw $e;
            return;
        }
    }

}
