<?php
/**
 * SocialEngine
 *
 * @category   Application_Extensions
 * @package    Sitenewsletter
 * @copyright  Copyright 2010-2011 BigStep Technologies Pvt. Ltd.
 * @license    http://www.socialengineaddons.com/license/
 * @version    $Id: AdminSettingsController.php 2011-05-05 9:40:21Z SocialEngineAddOns $
 * @author     SocialEngineAddOns
 */

class Sitenewsletter_AdminSettingsController extends Core_Controller_Action_Admin
{
  public function indexAction()
  {
    // Get navigation
    $this->view->navigation = $navigation = Engine_Api::_()->getApi('menus', 'core')
      ->getNavigation('sitenewsletter_admin_main', array(), 'sitenewsletter_admin_main_settings');

    $this->view->form  = $form = new Sitenewsletter_Form_Admin_Global();
    
    // check form data is valid or not
    if( $this->getRequest()->isPost() && $form->isValid($this->_getAllParams()) )
    {
      $values = $form->getValues();

      foreach ($values as $key => $value){
        Engine_Api::_()->getApi('settings', 'core')->setSetting($key, $value);
      }
      $form->addNotice('Your changes have been saved.');
    }
  }

  public function categoriesAction()
  {
    // Get navigation
    $this->view->navigation = $navigation = Engine_Api::_()->getApi('menus', 'core')
      ->getNavigation('sitenewsletter_admin_main', array(), 'sitenewsletter_admin_main_category');

    $categories = Engine_Api::_()->getItemTable('sitenewsletter_category');
    $categoriesName = $categories->info('name');
    $select = $categories->select()
            ->from($categoriesName)
            ->order('category_order ASC');

    $this->view->paginator = $paginator = Zend_Paginator::factory($select);
    // Set item count per page and current page number
    $paginator->setItemCountPerPage(10);
    $paginator->setCurrentPageNumber($this->_getParam('page', 1));

    $this->view->enabled = '0';
      if ( empty($this->_getParam('enabled')) && empty($this->_getParam('level_id')) && empty($this->_getParam('signup')) && empty($this->_getParam('query')) ) {
        $this->view->enabled = '1';
      }
  }

  
  public function addCategoryAction()
  {
    // In smoothbox
    $this->_helper->layout->setLayout('admin-simple');

    // Generate and assign form
    $form = $this->view->form = new Sitenewsletter_Form_Admin_Category();
    $form->setAction($this->view->url(array()));
    
    // Check post
    if( !$this->getRequest()->isPost() ) {
      return;
    }
    if( !$form->isValid($this->getRequest()->getPost()) ) {
      return;
    }
    
    // Process
    $values = $form->getValues();

    $categoryTable = Engine_Api::_()->getItemTable('sitenewsletter_category');
    $db = $categoryTable->getAdapter();
    $db->beginTransaction();

    try {
      $category = $categoryTable->insert(array(
        'category_name' => $values['category_name'],
        'auto' => $values['auto'],
        'subscribe_eusers' => $values['subscribe_eusers'],
        'subscribe_gusers' => $values['subscribe_gusers'],
        'visibility' => $values['visibility'],
        'enabled' => $values['enabled'],
      ));
      $category_id = $categoryTable->getAdapter()->lastInsertId();

      $subscriber_type = array('existing' => $values['subscribe_eusers'], 'guest' => $values['subscribe_gusers']);
      Engine_Api::_()->sitenewsletter()->autosubscribe($subscriber_type, $category_id);

      $db->commit();
    } catch( Exception $e ) {
      $db->rollBack();
      throw $e;
    }

    return $this->_forward('success', 'utility', 'core', array(
      'smoothboxClose' => 10,
      'parentRefresh'=> 10,
      'messages' => array('')
    ));
  }

  public function deleteCategoryAction()
  {
    // In smoothbox
    $this->_helper->layout->setLayout('admin-simple');
    $category_id = $this->_getParam('id');
    $this->view->blog_id = $this->view->category_id = $category_id;
    $categoriesTable = Engine_Api::_()->getDbtable('categories', 'sitenewsletter');
    $category = $categoriesTable->find($category_id)->current();
    
    if( !$category ) {
      return $this->_forward('success', 'utility', 'core', array(
        'smoothboxClose' => 10,
        'parentRefresh'=> 10,
        'messages' => array('')
      ));
    } else {
      $category_id = $category->getIdentity();
    }
    
    if( !$this->getRequest()->isPost() ) {
      // Output
      $this->renderScript('admin-settings/delete.tpl');
      return;
    }
    
    // Process
    $db = $categoriesTable->getAdapter();
    $db->beginTransaction();
    
    try {
      
      $subscribeCategoryTable = Engine_Api::_()->getDbtable('subscribecategories', 'sitenewsletter');

      $ids = $subscribeCategoryTable->select()->from($subscribeCategoryTable->info('name'), 'subscribecategory_id')->where('category_id = ?', $category_id)->query()->fetchAll();
      
      foreach ($ids as $key => $value) {
        $subscribecategory = Engine_Api::_()->getItem('sitenewsletter_subscribecategory', $value['subscribecategory_id']);
        $subscribecategory->delete();
      }

      $category->delete();
      $db->commit();
    } catch( Exception $e ) {
      $db->rollBack();
      throw $e;
    }
    
    return $this->_forward('success', 'utility', 'core', array(
      'smoothboxClose' => 1000,
      'parentRefresh'=> 1000,
      'messages' => array('Selected newsletter type has been successfully deleted.')
    ));
  }

  public function editCategoryAction()
  {
    // In smoothbox
    $this->_helper->layout->setLayout('admin-simple');
    $category_id = $this->_getParam('id');
    // $this->view->blog_id = $this->view->category_id = $id;
    $categoriesTable = Engine_Api::_()->getDbtable('categories', 'sitenewsletter');
    $category = $categoriesTable->find($category_id)->current();
    if( !$category ) {
      return $this->_forward('success', 'utility', 'core', array(
        'smoothboxClose' => 10,
        'parentRefresh'=> 10,
        'messages' => array('')
      ));
    } else {
      $category_id = $category->getIdentity();
    }
    
    $form = $this->view->form = new Sitenewsletter_Form_Admin_Category();
    $form->setAction($this->getFrontController()->getRouter()->assemble(array()));
    $form->setField($category);
    
    if( !$this->getRequest()->isPost() ) {
      // Output
      $this->renderScript('admin-settings/add-category.tpl');
      return;
    }
    
    if( !$form->isValid($this->getRequest()->getPost()) ) {
      // Output
      $this->renderScript('admin-settings/add-category.tpl');
      return;
    }
    
    // Process
    $values = $form->getValues();
    
    $db = $categoriesTable->getAdapter();
    $db->beginTransaction();
    
    try {
      $category->category_name = $values['category_name'];
      $category->auto = $values['auto'];
      $category->visibility = $values['visibility'];
      $category->enabled = $values['enabled'];
      $category->save();

      $db->commit();
    } catch( Exception $e ) {
      $db->rollBack();
      throw $e;
    }

    return $this->_forward('success', 'utility', 'core', array(
      'smoothboxClose' => 1000,
      'parentRefresh'=> 1000,
      'messages' => array('Your changes has been saved successfully')
    ));
  }

  public function faqAction()
  {
    $this->view->navigation = $navigation = Engine_Api::_()->getApi('menus', 'core')
      ->getNavigation('sitenewsletter_admin_main', array(), 'sitenewsletter_admin_main_faq');
    $this->view->faq_id = $faq_id = $this->_getParam('faq', 'faq_1');
  }

  // Action for setting order of the categories row. Called via ajax request.
  public function orderItemsAction()
  {
    $data =  $this->getRequest()->getParams();

    if ($data['item'] == 'categories') 
    {
      $orderTable = Engine_Api::_()->getDbtable('categories','sitenewsletter');

      foreach ($data as $category_id => $order) {
        if (substr($category_id,0,8) == 'package_') {
          $id = substr($category_id, 8);
          $db = $orderTable->getAdapter();
          $db->beginTransaction();
          try {
            $orderTable->update(array('category_order' => $order,), array('`category_id` = ?' => $id,));
            $db->commit();
          } catch( Exception $e ) {
              $db->rollBack();
              throw $e;
          }
        }
      }
    }
    exit();
  }
}