<?php

/**
 * SocialEngine
 *
 * @category   Application_Extensions
 * @package    Sitepage
 * @copyright  Copyright 2010-2011 BigStep Technologies Pvt. Ltd.
 * @license    http://www.socialengineaddons.com/license/
 * @version    $Id: Global.php 2011-05-05 9:40:21Z SocialEngineAddOns $
 * @author     SocialEngineAddOns
 */
class Sitepagegeolocation_Form_Admin_Global extends Engine_Form {

  public function init() {

    $this
        ->setTitle('Global Settings')
        ->setDescription('These settings affect all members in your community.');

    $this->addElement('Text', 'sitepagegeolocation_lsettings', array(
            'label' => 'Enter License key',
            'description' => "Please enter your license key that was provided to you when you purchased this plugin. If you do not know your license key, please contact the Support Team of SocialEngineAddOns from the Support section of your Account Area.(Key Format: XXXXXX-XXXXXX-XXXXXX )",
            'value' => Engine_Api::_()->getApi('settings', 'core')->getSetting('sitepagegeolocation.lsettings'),
    ));

    $global_settings_file = APPLICATION_PATH . '/application/settings/general.php';
    if (file_exists($global_settings_file)) {
      $generalConfig = include $global_settings_file;
    } else {
      $generalConfig = array();
    }
    if ($generalConfig['environment_mode'] != 'development') {
      $this->addElement('Checkbox', 'environment_mode', array(
              'label' => 'Your community is currently in "Production Mode". We recommend that you momentarily switch your site to "Development Mode" so that the CSS of this plugin renders fine as soon as the plugin is installed. After completely installing this plugin and visiting few pages of your site, you may again change the System Mode back to "Production Mode" from the Admin Panel Home. (In Production Mode, caching prevents CSS of new plugins to be rendered immediately after installation.)',
              'description' => 'System Mode',
              'value' => 1,
      ));
    } else {
      $this->addElement('Hidden', 'environment_mode', array('order' => 990, 'value' => 0));
    }

    // Add submit button
    $this->addElement('Button', 'submit_lsetting', array(
            'label' => 'Activate Your Plugin Now',
            'type' => 'submit',
            'ignore' => true
    ));


    $this->addElement("Radio", 'sgl_geolocation_api_type', array(
            'Label' => "Geolocation Api Type",
            'description' => 'Select the geolocation api type.',
            'multiOptions' => array(
                    2 => 'Maxmind (Geolite City)',
                    1 => 'Maxmind (GeoIp)',
                    0 => 'W3C',
            ),
            'onchange' => "showMaxmindKey(this.value)",
            'value' => Engine_Api::_()->getApi('core', 'sitepagegeolocation')->getGeoApiType(),
    ));

    $this->addElement('Text', 'socialengineaddon_maxmind_key', array(
            'label' => 'Enter Maxmind License key',
            'description' => "Please enter your maxmind license key that was provided to you when you create account on Maxmind. If you do not know your maxmind license key, please click <a href='https://www.maxmind.com/app/my_license_key' target='blank'>here</a> for it.",
            'value' => Engine_Api::_()->getApi('settings', 'core')->getSetting('socialengineaddon.maxmind.key'),
    ));
    $this->socialengineaddon_maxmind_key
        ->addDecorator('Description', array('placement' => Zend_Form_Decorator_Abstract::PREPEND, 'escape' => false));
    $view = Zend_Registry::isRegistered('Zend_View') ? Zend_Registry::get('Zend_View') : null;
    $this->addElement('Dummy', 'sgl_maxmind_geolitecity_link', array(
            'label' => 'Import Geolite City Data',
            'description' => "<a href='" . $view->url(array('module' => 'socialengineaddon', 'controller' => 'geo-locations','action'=>'import-data'), 'admin_default', true) . "' class='smoothbox'>" . Zend_Registry::get('Zend_Translate')->_('Import a data') . "</a>",           
    ));
    $this->sgl_maxmind_geolitecity_link
        ->addDecorator('Description', array('placement' => Zend_Form_Decorator_Abstract::PREPEND, 'escape' => false));
    $this->addElement("Radio", 'sgl_geolocation_default', array(
            'Label' => "Show Default Geolocation Base",
            'description' => 'show the page according to geolocation base',
            'multiOptions' => array(
                    1 => 'Yes',
                    0 => 'No',
            ),
            'value' => Engine_Api::_()->getApi('settings', 'core')->getSetting('sgl.geolocation.default', 1),
    ));



    $flage = Engine_Api::_()->getApi('settings', 'core')->getSetting('sitepage.proximity.search.kilometer', 0);
    if ($flage) {
      $locationLable = "Range Within Kilometers";
      $locationOption = array(
              '1' => '1 Kilometer',
              '2' => '2 Kilometers',
              '5' => '5 Kilometers',
              '10' => '10 Kilometers',
              '20' => '20 Kilometers',
              '50' => '50 Kilometers',
              '100' => '100 Kilometers',
              '250' => '250 Kilometers',
              '500' => '500 Kilometers',
              '750' => '750 Kilometers',
              '1000' => '1000 Kilometers',
      );
    } else {
      $locationLable = "Range Within Miles";
      $locationOption = array(
              '1' => '1 Mile',
              '2' => '2 Miles',
              '5' => '5 Miles',
              '10' => '10 Miles',
              '20' => '20 Miles',
              '50' => '50 Miles',
              '100' => '100 Miles',
              '250' => '250 Miles',
              '500' => '500 Miles',
              '750' => '750 Miles',
              '1000' => '1000 Miles',
      );
    }
    $this->addElement('Select', 'sgl_geolocation_range', array(
            'label' => $locationLable,
            'multiOptions' => $locationOption,
            'value' => Engine_Api::_()->getApi('settings', 'core')->getSetting('sgl.geolocation.range', 100),
    ));

    // Add submit button
    $this->addElement('Button', 'submit', array(
            'label' => 'Save Changes',
            'type' => 'submit',
            'ignore' => true
    ));
  }

}
?>