<?php

class Sitepoll_Form_Admin_Settings_Global extends Engine_Form{
  public function init(){
    $this
      ->setTitle('Global Settings')
      ->setDescription('These settings affect all members in your community.');

    $this->addElement('Text', 'sitepoll_perpage', array(
      'label' => 'Polls Per Page',
      'description' => 'How many polls will be shown per page? (Enter a number between 1 and 999) Note: This setting works for My Polls Page. ',
      'validators' => array(
        array('Int', true),
        array('LessThan', true, 999),
        new Engine_Validate_AtLeast(1),
      ),
      'required' => true,
      'value' => Engine_Api::_()->getApi('settings', 'core')->getSetting('sitepoll.perpage', 9),
    ));

    $this->addElement('Text', 'sitepoll_maxoptions', array(
      'label' => 'Maximum Poll Options',
      'description' => ' How many possible poll options do you want to allow?(Enter a number between 2 and 6.)',
      'validators' => array(
        array('Int', true),
        array('LessThan', true, 7),
        new Engine_Validate_AtLeast(2),
      ),
      'required' => true,
      'value' => Engine_Api::_()->getApi('settings', 'core')->getSetting('sitepoll.maxoptions', 4)
    ));

    $this->addElement('Radio', 'sitepoll_canchangevote', array(
      'label' => 'Allow to Change Vote',
      'description' => 'Do you want to allow members to change their vote?',
      'multiOptions' => array(
        1 => 'Yes, members can change their vote.',
        0 => 'No, members cannot change their vote.',
      ),
      'value' => Engine_Api::_()->getApi('settings', 'core')->getSetting('sitepoll.canchangevote', 1)
    ));

    $this->addElement('Radio', 'sitepoll_reportinapp', array(
          'label' => ' Report as Inappropriate',
          'description' => ' Do you want to allow logged-in members to report polls as inappropriate? (Members will also be able to mention the reason why they find the poll inappropriate.)',
          'value' => Engine_Api::_()->getApi('settings', 'core')->getSetting('sitepoll_poll.allow.report_inappropriate', 0),
          'multiOptions' => array(
              '1' => 'Yes',
              '0' => 'No',
          ),
          'value' => Engine_Api::_()->getApi('settings', 'core')->getSetting('sitepoll.reportinapp', 1)
      ));

    $this->addElement('Text', 'sitepoll_maxreminder', array(
      'label' => 'Maximum Reminders for Approval',
      'description' => 'Enter the maximum times a user can send reminders for approval to admin.(Enter a number between 1 and 7).',
      'validators' => array(
        array('Int', true),
        new Engine_Validate_AtLeast(1), 
        array('LessThan', true, 7),
      ),
      'required' => true,
      'value' => Engine_Api::_()->getApi('settings', 'core')->getSetting('sitepoll.maxreminder', 4)
    ));

    $this->addElement('Text', 'sitepoll_approvetime', array(
      'label' => 'Duration To Send Next Approval Request',
      'description' => 'Enter the time in which the user can send the next request to approve poll in hours.(Enter a number greater than 2).',
      'validators' => array(
        array('Int', true),
        new Engine_Validate_AtLeast(2),
      ),
      'required' => true,
      'value' => Engine_Api::_()->getApi('settings', 'core')->getSetting('sitepoll.approvetime', 4)
    ));

    // Add submit button
    $this->addElement('Button', 'submit', array(
      'label' => 'Save Changes',
      'type' => 'submit',
      'ignore' => true
    ));
  }
}
