<?php

class SitePoll_Form_Create extends Engine_Form{

    protected $_parent_type;

    protected $_parent_id;

    public function setParent_type($value){
        $this->_parent_type = $value;
    }

    public function setParent_id($value){
        $this->_parent_id = $value;
    }

    public function init(){
        $auth = Engine_Api::_()->authorization()->context;
        $user = Engine_Api::_()->user()->getViewer();

        $this->setTitle('Create Poll')
            ->setDescription('Create your poll below, then click "Create Poll" to start your poll.')
            ->setAttrib('id', 'form-upload')
            ->setAttrib('enctype', 'multipart/form-data');

        $this->addElement('text', 'title', array(
            'label' => 'Poll Title',
            'required' => true,
            'maxlength' => 63,
            'filters' => array(
                'StripTags',
                new Sitepoll_Form_Censor(),
                //new Engine_Filter_Censor(),
                new Engine_Filter_StringLength(array('max' => '63')),
            ),
        ));

        // init to
        $this->addElement('Text', 'tags', array(
            'label'=>'Tags (Keywords)',
            'autocomplete' => 'off',
            'description' => 'Separate tags with commas.',
            'filters' => array(
                'StripTags',
                //new Engine_Filter_Censor(),
                new Sitepoll_Form_Censor(),
            ),
        ));
        $this->tags->getDecorator("Description")->setOption("placement", "append");

        $this->addElement('textarea', 'description', array(
            'label' => 'Description',
            'maxlength' => 350,
            'filters' => array(
                //new Engine_Filter_Censor(),
                new Sitepoll_Form_Censor(),
                new Engine_Filter_StringLength(array('max' => '350')),
                new Engine_Filter_Html(array('AllowedTags'=> array('a'))),
            ),
        ));

        $this->addElement('File', 'photo', array(
            'label' => 'Choose Profile Photo',
        ));

        // Select Catagories
        // prepare categories
        $categories = Engine_Api::_()->getDbtable('categories', 'sitepoll')->getCategoriesAssoc();
        if(count($categories)>0){
            $this->addElement('Select', 'category_id', array(
                'label' => 'Category',
                'multiOptions' => $categories,
                'required'=> true, 
            ));
        }
        
        $pollType = (array) Engine_Api::_()->authorization()->getAdapter('levels')->getAllowed('sitepoll_poll', $user, 'auth_type');
        
        if( $this->_parent_type == 'user' ) {
            $availableLabels = array(
                    '0'       => 'Text',
                    '2'       => 'Photo',
                    '3'       => 'Text with Photo'
            );
            $pollType = array_intersect_key($availableLabels, array_flip($pollType));
         } else if( $this->_parent_type == 'group' ) {
            $availableLabels = array(
                    '0'       => 'Text',
                    '2'       => 'Photo',
                    '3'       => 'Text with Photo'
            );
            $pollType = array_intersect_key($availableLabels, array_flip($pollType));
        }
        $maxOptionsCount = Engine_Api::_()->getApi('settings', 'core')->getSetting('sitepoll.maxoptions', 3);
        if( !empty($pollType) && count($pollType) >= 1 ) {
            // Make a hidden field
            
                $this->addElement('Select', 'auth_type', array(
                    'label' => 'Poll Type',
                    'description' => 'What type of poll you want?',
                    'multiOptions' => $pollType,
                    'value' => key($pollType),

                    'onclick'=>'changetotalfields()',
                    'onchange' => 'isOnline(this.value);',
                ));
        }

        $this->addElement('textarea', 'options', array(
            'label' => ' Poll Options',
            'style' => 'display:none;',
        ));

        if($maxOptionsCount==2)
        {
            $this->addElement('Button', 'add_product_t', array(
            'label' => 'Add Another Option',
            'id'=>'add_product_t',
            'type' => 'button',
            'onclick'=>'addMoreProdElem('.$maxOptionsCount.')',
            'style' => 'display:none;',
        ));
        }else{
            $this->addElement('Button', 'add_product_t', array(
                'label' => 'Add Another Option',
                'id'=>'add_product_t',
                'type' => 'button',
                'onclick'=>'addMoreProdElem('.$maxOptionsCount.')',
            ));
        }

        if($maxOptionsCount==2)
        {
            $this->addElement('Button', 'add_product_p', array(
            'label' => 'Add Another Option',
            'id'=>'add_product_p',
            'type' => 'button',
            'onclick'=>'addMoreProdphoto('.$maxOptionsCount.')',
            'style' => 'display:none;',
        ));
        }else{
            $this->addElement('Button', 'add_product_p', array(
                'label' => 'Add Another Option',
                'id'=>'add_product_p',
                'type' => 'button',
                'onclick'=>'addMoreProdphoto('.$maxOptionsCount.')',
            ));
        }

        if($maxOptionsCount==2)
        {
            $this->addElement('Button', 'add_product_pt', array(
            'label' => 'Add Another Option',
            'id'=>'add_product_tp',
            'type' => 'button',
            'onclick'=>'addMoreProdphototxt('.$maxOptionsCount.')',
            'style' => 'display:none;',
        ));
        }else{
            $this->addElement('Button', 'add_product_pt', array(
                'label' => 'Add Another Option',
                'id'=>'add_product_tp',
                'type' => 'button',
                'onclick'=>'addMoreProdphototxt('.$maxOptionsCount.')',
            ));
        }
        $this->addElement('Select', 'draft', array(
            'label' => 'Poll Duration',
            'description' => 'When this poll will be closed?',
            'multiOptions' => array("0"=>"1 day", "1"=>"3 days", "2"=>"7 days", "3"=>"2 weeks"),
        ));
        $this->draft->getDecorator('Description')->setOption('placement', 'append');

        if (Engine_Api::_()->authorization()->isAllowed('sitepoll', $user, 'allow_network')) {
            $networkOptions = array();
            foreach (Engine_Api::_()->getDbTable('networks', 'network')->fetchAll() as $network) {
                $networkOptions[$network->network_id] = $network->getTitle();
            }
            //Networks
            $this->addElement('Multiselect', 'networks', array(
                'label' => "Networks",
                'description' => 'Choose the Networks to which this Poll will be displayed.',
                'multiOptions' => $networkOptions,
            ));
        }

        // Init profile view
        $viewOptions = (array) Engine_Api::_()->authorization()->getAdapter('levels')->getAllowed('sitepoll_poll', $user, 'auth_view');
        // Comment
        // Init profile comment
        $commentOptions = (array) Engine_Api::_()->authorization()->getAdapter('levels')->getAllowed('sitepoll_poll', $user, 'auth_comment');
        // Privacy
        if( $this->_parent_type == 'user' ) {
            $availableLabels = array(
                'everyone'            => 'Everyone',
                'registered'          => 'All Registered Members',
                'owner_network'       => 'Friends and Networks',
                'owner_member_member' => 'Friends of Friends',
                'owner_member'        => 'Friends Only',
                'owner'               => 'Just Me'
            );
            $viewOptions = array_intersect_key($availableLabels, array_flip($viewOptions));
            $commentOptions = array_intersect_key($availableLabels, array_flip($commentOptions));
         } else if( $this->_parent_type == 'group' ) {
            $availableLabels = array(
                'everyone'      => 'Everyone',
                'registered'    => 'All Registered Members',
                'parent_member' => 'Group Members',
                'member'        => 'Poll Guests Only',
                'owner'         => 'Just Me',
            );
            $viewOptions = array_intersect_key($availableLabels, array_flip($viewOptions));
            $commentOptions = array_intersect_key($availableLabels, array_flip($commentOptions));
        }

        // Init profile Charts
        $styleOptions = (array) Engine_Api::_()->authorization()->getAdapter('levels')->getAllowed('sitepoll_poll', $user, 'auth_style');
        // Stylish 
        if( $this->_parent_type == 'user' ) {
            $availableLabels = array(
                    'pie chart'            => 'Pie Chart',
                    'doughnut'             => 'Doughnut',
                    'progress chart'       => 'Progress Bar Chart'
            );
            $styleOptions = array_intersect_key($availableLabels, array_flip($styleOptions));
         } 

        if( !empty($styleOptions) && count($styleOptions) >= 1 ) {
            // Make a hidden field
            
                $this->addElement('Select', 'auth_style', array(
                    'label' => 'Style',
                    'description' => 'Style of this poll?',
                    'multiOptions' => $styleOptions,
                    'value' => key($styleOptions),
                ));
                $this->auth_style->getDecorator('Description')->setOption('placement', 'append');
            
        }

        if( !empty($viewOptions) && count($viewOptions) >= 1 ) {
            // Make a hidden field
            if(count($viewOptions) == 1) {
                $this->addElement('hidden', 'auth_view', array('order' => 101, 'value' => key($viewOptions)));
                // Make select box
            } else {
                $this->addElement('Select', 'auth_view', array(
                    'label' => 'Privacy',
                    'description' => 'Who may see this poll?',
                    'multiOptions' => $viewOptions,
                    'value' => key($viewOptions),
                ));
                $this->auth_view->getDecorator('Description')->setOption('placement', 'append');
            }
        }

        if( !empty($commentOptions) && count($commentOptions) >= 1 ) {
            // Make a hidden field
            if(count($commentOptions) == 1) {
                $this->addElement('hidden', 'auth_comment', array('order' => 102, 'value' => key($commentOptions)));
                // Make select box
            } else {
                $this->addElement('Select', 'auth_comment', array(
                    'label' => 'Comment Privacy',
                    'description' => 'Who may post comments on this poll?',
                    'multiOptions' => $commentOptions,
                    'value' => key($commentOptions),
                ));
                $this->auth_comment->getDecorator('Description')->setOption('placement', 'append');
            }
        }

        // Search
        $this->addElement('Checkbox', 'search', array(
            'label' => "Show this poll in search results",
            'value' => 1,
        ));

        $this->addElement('hidden', 'hidden', array(
            'label' => 'Hidden',
            'id'=>'hidden',
        ));

        // Submit
        $this->addElement('Button', 'submit', array(
            'label' => 'Create Poll ',
            'ignore' => true,
            'decorators' => array('ViewHelper'),
            'type' => 'submit',
            'onsubmit' => 'event.preventDefault(); formFieldChecks();'
        ));

        $this->addElement('Cancel', 'cancel', array(
            'prependText' => ' or ',
            'label' => 'cancel',
            'link' => true,
            'decorators' => array(
                'ViewHelper'
            ),
        ));

        $this->addDisplayGroup(array(
            'submit',
            'cancel'
        ), 'buttons', array(
            'decorators' => array(
                'FormElements',
                'DivDivDivWrapper',
            ),
        ));
    }
}
