<?php
/**
* SocialEngine
*
* @category Application_Extensions
* @package Sitepoll
* @copyright Copyright 2019-2020 BigStep Technologies Pvt. Ltd.
* @license http://www.socialengineaddons.com/license/
* @version 2019-08-10 9:40:21Z SocialEngineAddOns $
* @author SocialEngineAddOns
*/
class Sitepoll_SitepollController extends Core_Controller_Action_Standard {

    public function editAction(){

        if( !$this->_helper->requireUser()->isValid() ) return;

        $viewer = Engine_Api::_()->user()->getViewer();
        $poll = Engine_Api::_()->getItem('sitepoll_poll', $this->_getParam('poll_id'));
        $polloption = Engine_Api::_()->getItem('sitepoll_option', $this->_getParam('poll_id'));
        if( !Engine_Api::_()->core()->hasSubject('sitepoll') ) {
            Engine_Api::_()->core()->setSubject($poll);
        }

        if( !$this->_helper->requireSubject()->isValid() ) return;

        //GET NAVIGATION
        $this->view->navigation = Engine_Api::_()->getApi('menus', 'core')
        ->getNavigation('sitepoll_main');

        $parent_type = $poll->parent_type;
        $parent_id = $poll->parent_id;

        if( !$this->_helper->requireAuth()->setAuthParams($poll, $viewer, 'edit')->isValid() ) {
            return;
        }

        // Prepare form
        $this->view->form = $form = new Sitepoll_Form_Edit(array(
            'parent_type' => $parent_type,
            'parent_id' => $parent_id
        ));
        
        // REMOVE ADD PRODUCT AS WE CANNOT EDIT THIS
        $form->removeElement('add_product_t');
        $form->removeElement('add_product_p');
        $form->removeElement('add_product_pt');

        // GET ALL OPTIONS
        $options=Engine_Api::_()->getDbtable('options','sitepoll')->getpollOption($this->_getParam('poll_id'));
        
        $img_path=array();
        $text_option=array();

        foreach($options as $option) {
            $text=$option['poll_option'];
            $text_option[]=$text;

            // GET PHOTO OPTION
            if($option['photo_option']!=0) {
                $photo_id=$option['photo_option'];
                $storage_file = Engine_Api::_()->getItem('storage_file', $photo_id);
                $src=$storage_file->map();
                $img_path[]=$src;
            }
        }

        $this->view->text_option=$text_option;
        $this->view->img_path=$img_path;
        $form->populate($poll->toArray());

        $tagStr = '';
        foreach( $poll->tags()->getTagMaps() as $tagMap ) {
            $tag = $tagMap->getTag();
            if( !isset($tag->text) ) continue;
            if( '' !== $tagStr ) $tagStr .= ', ';
            $tagStr .= $tag->text;
        }

        // Populate form 
        $form->populate(array(
            'tags' => $tagStr,
            'networks' => explode(',', $poll->networks),
        ));
        $this->view->tagNamePrepared = $tagStr;

        // UPDATE AUTH IF UPDATED
        $auth = Engine_Api::_()->authorization()->context;
        if( $parent_type == 'group' ) {
            $roles = array('owner', 'member', 'parent_member', 'registered', 'everyone');
        } else {
            $roles = array('owner', 'member', 'owner_member', 'owner_member_member', 'owner_network', 'registered', 'everyone');
        }

        foreach( $roles as $role ) {
            if ($form->auth_view){
                if( $auth->isAllowed($poll, $role, 'view') ) {
                    $form->auth_view->setValue($role);
                }
            }

            if ($form->auth_comment){
                if( $auth->isAllowed($poll, $role, 'comment') ) {
                    $form->auth_comment->setValue($role);
                }
            }
        }

        // Check post/form
        if( !$this->getRequest()->isPost() ) {
            return;
        }
        if( !$form->isValid($this->getRequest()->getPost()) ) {
            return;
        }

        // Process
        $db = Engine_Db_Table::getDefaultAdapter();
        $db->beginTransaction();
        $data=$this->getRequest()->getPost();
        
        try {
            $values = $form->getValues();

            if (isset($values['networks'])) {
                $network_privacy = 'network_'. implode(',network_', $values['networks']);
                $values['networks'] = implode(',', $values['networks']);
            }

            if( empty($values['auth_view']) ) {
                $values['auth_view'] = 'everyone';
            }
            if( empty($values['auth_comment']) ) {
                $values['auth_comment'] = 'everyone';
            }

            $values['view_privacy'] = $values['auth_view'];

            $poll->setFromArray($values);
            $poll->modified_date = date('Y-m-d H:i:s');
            $poll->save();

            // Add photo
            if( !empty($values['photo']) ) {
                $poll->setPhoto($form->photo);
            }

            // Auth
            $viewMax = array_search($values['auth_view'], $roles);
            $commentMax = array_search($values['auth_comment'], $roles);

            foreach( $roles as $i => $role ) {
                $auth->setAllowed($poll, $role, 'view', ($i <= $viewMax));
                $auth->setAllowed($poll, $role, 'comment', ($i <= $commentMax));
            }

            // handle tags
            $tags = preg_split('/[,]+/', $values['tags']);
            $poll->tags()->setTagMaps($viewer, $tags);

            // insert new activity if poll is just getting published
            $action = Engine_Api::_()->getDbtable('actions', 'activity')->getActionsByObject($poll);
            if( count($action->toArray()) <= 0 && $values['draft'] == '0' ) {
                $action = Engine_Api::_()->getDbtable('actions', 'activity')->addActivity($viewer, $poll, 'poll_new', '', array('privacy' => isset($values['networks'])? $network_privacy : null));
                        // make sure action exists before attaching the poll to the activity
                if( $action != null ) {
                    Engine_Api::_()->getDbtable('actions', 'activity')->attachActivity($action, $poll);
                }
            }

            // Rebuild privacy
            $actionTable = Engine_Api::_()->getDbtable('actions', 'activity');
            foreach( $actionTable->getActionsByObject($poll) as $action ) {
                $action->privacy = isset($values['networks'])? $network_privacy : null;
                $action->save();
                $actionTable->resetActivityBindings($action);
            }

            $db->commit();

        }
        catch( Exception $e ) {
            $db->rollBack();
            throw $e;
        }
        return $this->_redirect('poll-item/view/'.$poll->poll_id);
    }

    public function viewAction(){
        
        // Check permission
        $viewer = Engine_Api::_()->user()->getViewer();
        $poll = Engine_Api::_()->getItem('sitepoll_poll', $this->_getParam('poll_id'));
        if( $poll ) {
            Engine_Api::_()->core()->setSubject($poll);
        }

        if( !$this->_helper->requireSubject()->isValid() ) {
            return;
        }
        
        if( !$this->_helper->requireAuth()->setAuthParams($poll, $viewer, 'view')->isValid() )
        {
            return;
        }
        $users = Engine_Api::_()->user()->getSuperAdmins();

        if($viewer!=$poll->getOwner() && !$users)
        {
            if($poll->approved==0)
            {
                $this->_forward('requireauth', 'error', 'core');
            }
        }
    
    
        $this->view->poll = $poll;
        $this->view->owner = $owner = $poll->getOwner();
        $this->view->viewer = $viewer;
        // Get tags
        $this->view->pollTags = $poll->tags()->getTagMaps();

        //$level_id = $viewer->level_id;

        $this->view->viewer = $viewer = Engine_Api::_()->user()->getViewer();
        $this->view->pollOptions = $poll->getOptions();

        $this->view->canVote =$poll->authorization()->isAllowed($viewer,'vote');
        $this->view->canChangeVote = Engine_Api::_()->getApi('settings', 'core')->getSetting('sitepoll.canchangevote', 1);
        $this->view->canDelete = $poll->authorization()->isAllowed($viewer,'delete');
        $this->view->canReport =Engine_Api::_()->getApi('settings', 'core')->getSetting('sitepoll.reportinapp', 3);
        $this->view->canEdit = $poll->authorization()->isAllowed($viewer,'edit');
        $this->view->viewer=$viewer;
        // Prepare data
        $pollTable = Engine_Api::_()->getDbtable('polls', 'sitepoll');
        $this->view->poll = $poll;
        $this->view->owner = $owner = $poll->getOwner();
        $this->view->viewer = $viewer;
        $this->view->title=0;


        if( !$poll->isOwner($viewer) ) {
            $pollTable->update(array(
                'view_count' => new Zend_Db_Expr('view_count + 1'),
            ), array(
                'poll_id = ?' => $poll->getIdentity(),
            ));
        }
        // GET DATA FROM OPTION TABLE
        $options=Engine_Api::_()->getDbtable('options','sitepoll')->getpollOption($this->_getParam('poll_id'));
        
        $img_path=array();
        $text_option=array();
        $votes=array();
        $options_id=array();
        $i=1;
        // Populate form 
        foreach($options as $option) {    
            if(!empty($option['poll_option'])) {
               $text=$option['poll_option'];
               $text_option[]=$text;
            } 
            $votes[]=$option['votes'];
            $options_id[]=$option['option_id'];
            if($option['photo_option']!=0) {
                $photo_id=$option['photo_option'];
                $storage_file = Engine_Api::_()->getItem('storage_file', $photo_id);
                $src=$storage_file->map();
                $img_path[]=$src;
            }
        }
        $max=max($votes);
        $sum=array_sum($votes);
        $optionArray=array();
        $optionSrc=array();
        foreach($votes as $key=>$vote)
        {
          if($vote==$max)
          {
            $optionArray[]=$text_option[$key];
            if(!empty($img_path))
            {
              $optionSrc[]=$img_path[$key];
            }
          }
        }
        $this->view->optionArray=$optionArray;
        $this->view->optionSrc=$optionSrc;
        $this->view->max=$max;
        $this->view->type=$poll->auth_type;
        $this->view->text_option=$text_option;
        $this->view->options_id=$options_id;
        $this->view->img_path=$img_path;
        $this->view->votes=$votes;
        $this->view->sum=$sum;
        $this->view->vote_0=!empty($votes[0])?$votes[0]:0;
        $this->view->vote_1=!empty($votes[1])?$votes[1]:0;
        $this->view->vote_2=!empty($votes[2])?$votes[2]:0;
        $this->view->vote_3=!empty($votes[3])?$votes[3]:0;
        $this->view->vote_4=!empty($votes[4])?$votes[4]:0;
        $this->view->vote_5=!empty($votes[5])?$votes[5]:0;
        try{
        $cal=$votes[0]+$votes[1]+$votes[2]+$votes[3]+$votes[4]+$votes[5];
        if($cal!=0)
        {
            $this->view->cal=$cal;
            $this->view->voteCount_0=round(($votes[0]/$cal)*100);
            $this->view->voteCount_1=round(($votes[1]/$cal)*100);
            $this->view->voteCount_2=round(($votes[2]/$cal)*100);
            $this->view->voteCount_3=round(($votes[3]/$cal)*100);
            $this->view->voteCount_4=round(($votes[4]/$cal)*100);
            $this->view->voteCount_5=round(($votes[5]/$cal)*100);
            $votes_array=array();
            foreach($votes as $vote)
            {
                $votes_array[]=round(($vote/$cal)*100);
            }
            $this->view->votes_array=$votes_array;
        }
        }catch( Exception $e ) {
            $db->rollback();
            throw $e;
        }
        $votesTable = Engine_Api::_()->getDbTable('votes', 'sitepoll');
        $flag=1;

        $this->view->pre_vote_1=0;
        $this->view->key=0;
        if($poll->hasVoted($viewer)){

            // Check for existing vote
            $vote = $votesTable->fetchRow(array(
                'poll_id = ?' => $poll->getIdentity(),
                'user_id = ?' => $viewer->getIdentity(),
            ));
            $v=$vote->option_id;

                $this->view->pre_vote_1=$v;
                $this->view->key=$v;
                $key = array_search($v, $options_id);  
        }
        // Get tags
        $this->view->pollTags = $poll->tags()->getTagMaps();  

                // Render
        $this->_helper->content
                    //->setNoRender()
        ->setEnabled()
        ; 
    }

    //ACTION FOR MAKE THE SITEPOLL FEATURED/UNFEATURED
    public function featuredAction() {
        $poll_id = $this->_getParam('id');
        if (!empty($poll_id)) {
          $sitepoll = Engine_Api::_()->getItem('sitepoll_poll', $poll_id);
          $sitepoll->featured = !$sitepoll->featured;
          $sitepoll->save();

          // SEND NOTIFICATION IF POLL IS FEATURED
          if($sitepoll->featured==1)
          {
            $viewer = Engine_Api::_()->user()->getViewer();
            $owner = Engine_Api::_()->getItem("user" , $sitepoll->user_id);
            if ($sitepoll->approved==1)
            {   
                if($viewer!=$owner)
                {
                Engine_Api::_()->getDbtable('notifications', 'activity')->addNotification($owner, $viewer, $sitepoll, 'sitepoll_poll_featured');
                } 
            }
          }
        }

        //RETURN 
        return $this->_redirect('admin/sitepoll/manage');
    }

    //ACTION FOR MAKE THE SITEPOLL CLOSED
    public function opencloseAction(){
        $poll_id = $this->_getParam('id');
        if (!empty($poll_id)) {
          $sitepoll = Engine_Api::_()->getItem('sitepoll_poll', $poll_id);
          $viewer = Engine_Api::_()->user()->getViewer();
          $owner = Engine_Api::_()->getItem("user" , $sitepoll->user_id);
          if($sitepoll->is_closed==0){
            $sitepoll->is_closed = !$sitepoll->is_closed;
            $sitepoll->end_datetime = date('Y-m-d H:i:s');
            $sitepoll->status="Expired";
            $sitepoll->save();

            //SEND NOTIFICATION IF POLL GET CLOSED BY ADMIN 
            if($viewer!=$owner)
                {
                Engine_Api::_()->getDbtable('notifications', 'activity')->addNotification($owner, $viewer, $sitepoll, 'sitepoll_poll_closed');
                } 
          }
      }
        
      // RETURN 
      return $this->_redirect('admin/sitepoll/manage');
    }

    //ACTION FOR MAKE REQUEST TO APPROVE USER POLL
    public function requestAction(){   
        $poll_id = $this->_getParam('poll_id');
        $viewer = Engine_Api::_()->user()->getViewer();

        // GET APPROVE TIME FROM GLOBAL SETTING
        $max_time = Engine_Api::_()->getApi('settings', 'core')->getSetting('sitepoll.approvetime', 8);

        // GET MAX REMINDER FROM GLOBAL SETTING
        $max_no=Engine_Api::_()->getApi('settings', 'core')->getSetting('sitepoll.maxreminder', 4);

        // PROCESS
        $sitepoll = Engine_Api::_()->getItem('sitepoll_poll', $poll_id);
        if($sitepoll->request_no<$max_no)
        { 
            if ($sitepoll->request==0)
            {   
                $req=$sitepoll->request_no;
                $req++;
                $sitepoll['request'] =1;
                $sitepoll['request_datetime']=date('Y-m-d H:i:s', strtotime(".$max_time hours"));
                $sitepoll['request_no']=$req;
                $sitepoll->save();

                // TO SEND MAIL AND NOTIFICATION TO SUPERADMIN FOR APPROVAL OF POLL
                $users = Engine_Api::_()->user()->getSuperAdmins();

                $defaultParams = array(
                    'ssl' => ( _ENGINE_SSL ? 'https://' : 'http://' ),
                    'host' => $_SERVER['HTTP_HOST'],
                    'email' => '',
                     'title'=>$sitepoll['title'],
                     'object_link'=>Zend_Controller_Front::getInstance()->getRouter()->assemble(array('action'=>'view','poll_id'=>$sitepoll->poll_id), 'sitepoll_view', true),
                 );

                foreach ($users as $user)
                {   
                    $superadmin_id[] = $user->user_id;
                    if(!in_array($viewer->getIdentity(), $superadmin_id)){
                        Engine_Api::_()->getDbtable('notifications', 'activity')->addNotification($user, $viewer, $sitepoll, 'sitepoll_approve_request');
                        $defaultParams['email']=$user->email;
                    Engine_Api::_()->getApi('mail', 'core')->sendSystem($viewer, 'notify_sitepoll_poll_request',$defaultParams);
                    }
                } 

            }
        } else{
            echo "you have send max time request";
        }

        // RETURN
        return $this->_redirect('poll-item/view/'.$poll_id);
    }

    //ACTION FOR MAKE SPONSORED /UNSPONSORED
    public function sponsoredAction() {

        $poll_id = $this->_getParam('id');
        if (!empty($poll_id)) {
          $sitepoll = Engine_Api::_()->getItem('sitepoll_poll', $poll_id);
          $sitepoll->sponsored = !$sitepoll->sponsored;
          $sitepoll->save();
        }

        // SEND NOTIFICATION TO THE CREATER IF THE ADMIN SPONSORED THE POLL
        if($sitepoll->sponsored==1)
        {
            $viewer = Engine_Api::_()->user()->getViewer();
            $owner = Engine_Api::_()->getItem("user" , $sitepoll->user_id);
            if ($sitepoll->approved==1)
            {
                if($viewer!=$owner)
                {
                    Engine_Api::_()->getDbtable('notifications', 'activity')->addNotification($owner, $viewer, $sitepoll, 'sitepoll_poll_sponsored');
                }
            }
        }

        // RETURN 
        return $this->_redirect('admin/sitepoll/manage');
    }

    //ACTION FOR MAKE SITEPOLL APPROVE/DIS-APPROVE
    public function approvedAction() {
        $poll_id = $this->_getParam('id');
        try {
          $sitepoll = Engine_Api::_()->getItem('sitepoll_poll', $poll_id);
          $reports=Engine_Api::_()->getDbtable('reports','sitepoll')->getpollReport($poll_id);
          $report_obj = Engine_Api::_()->getDbtable('reports','sitepoll');
          // POLL IS DISSAPPROVED
          if($sitepoll->approved==1 && $sitepoll->approve_date!=null)
          {
            $sitepoll->approved=0;
            $report_obj->delete(array(
                'poll_id = ?' => $poll_id,
            ));
          }
          
          // POLL IS APPROVED
          if($sitepoll->approved==0 && $sitepoll->approve_date==null)
          {
            $sitepoll->approved=1;
          }

          // SEND NOTIFICATION TO OWNER IF POLL IS DISAPPROVE BY ADMIN
          if($sitepoll->approved==0 && $sitepoll->approve_date!=null)
          {
            $viewer = Engine_Api::_()->user()->getViewer();
            $owner = Engine_Api::_()->getItem("user" , $sitepoll->user_id);
                
            if($viewer!=$owner){
                Engine_Api::_()->getDbtable('notifications', 'activity')->addNotification($owner, $viewer, $sitepoll, 'sitepoll_poll_disapproved');
            }

            // DELETE THE FEED IF THE POLL IS DISAPPROVED
            $sitepoll->postdelete();
          }

          // UPDATEDING THE INFO IN DATABASE IF POLL IS APPROVED
          if ($sitepoll->approved==1) {              
            if (empty($sitepoll->aprrove_date) || empty($sitepoll->start_datetime)){
              $sitepoll['approve_date'] = date('Y-m-d H:i:s');
              $sitepoll['status'] ='Active';
              $sitepoll['start_datetime'] = date('Y-m-d H:i:s');
            }
            if ($sitepoll->draft==0){
                $sitepoll->end_datetime=date('Y-m-d H:i:s', strtotime("+1 day"));
            } else if ($sitepoll->draft==1){
                $sitepoll->end_datetime=date('Y-m-d H:i:s', strtotime("+3 day"));
            } else if($sitepoll->draft==2){
                $sitepoll->end_datetime=date('Y-m-d H:i:s', strtotime("+7 day"));
            } else if($sitepoll->draft==3){
                $sitepoll->end_datetime=date('Y-m-d H:i:s', strtotime("+14 day"));
            }
          }
            $sitepoll->save();

            // SEND NOTIFICATION TO OWNER IF POLL IS APPROVED BY ADMIN
            $viewer = Engine_Api::_()->user()->getViewer();
            $owner = Engine_Api::_()->getItem("user" , $sitepoll->user_id);
            if ($sitepoll->approved==1)
            {    
                if($viewer!=$owner)
                {
                    Engine_Api::_()->getDbtable('notifications', 'activity')->addNotification($owner, $viewer, $sitepoll, 'sitepoll_poll_approved');
                }
                 $action = Engine_Api::_()->getDbtable('actions', 'activity')->addActivity($owner, $sitepoll, 'sitepoll_new','',array('privacy' => isset($sitepoll->view_privacy)? $sitepoll->view_privacy : 'everyone'));
                if( $action ) {
                  Engine_Api::_()->getDbtable('actions', 'activity')->attachActivity($action, $sitepoll);
              }
            }

            // SENDING MAIL OF APPROVE AND DISSAPPROVE
            $viewer = Engine_Api::_()->user()->getViewer();
            $owner = Engine_Api::_()->getItem("user" , $sitepoll->user_id);

            $defaultParams = array(
                            'ssl' => ( _ENGINE_SSL ? 'https://' : 'http://' ),
                            'host' => $_SERVER['HTTP_HOST'],
                            'email' => '',
                             'title'=>$sitepoll['title'],
                             'status'=>"dis-Approved",
                             'object_link'=>Zend_Controller_Front::getInstance()->getRouter()->assemble(array('action'=>'view','poll_id'=>$poll_id), 'sitepoll_view', true)
                         );
            $defaultParams['email']=$owner->email;
                            Engine_Api::_()->getApi('mail', 'core')->sendSystem($viewer, 'notify_sitepoll_poll_status',$defaultParams);
        } catch (Exception $e) {
            throw $e;
        }

        // RETURN 
        return $this->_redirect('admin/sitepoll/manage');
    }

    //ACTION FOR MAKE SITEPOLL DELETE
    public function deleteAction(){
        $viewer = Engine_Api::_()->user()->getViewer();
        $id = $this->_getParam('poll_id');
        $poll = Engine_Api::_()->getItem('sitepoll_poll', $this->getRequest()->getParam('poll_id'));
        $option = Engine_Api::_()->getDbtable('polls', 'sitepoll');
        $report = Engine_Api::_()->getDbtable('reports', 'sitepoll');
        if( !$this->_helper->requireAuth()->setAuthParams($poll, null, 'delete')->isValid()) return;

            // In smoothbox
        $this->_helper->layout->setLayout('default-simple');

        $this->view->form = $form = new Sitepoll_Form_Delete();

        if( !$poll ) {
            $this->view->status = false;
            $this->view->error = Zend_Registry::get('Zend_Translate')->_("Poll doesn't exist or not authorized to delete");
            return;
        }

        if( !$this->getRequest()->isPost() ) {
            $this->view->status = false;
            $this->view->error = Zend_Registry::get('Zend_Translate')->_('Invalid request method');
            return;
        }

        $db = $poll->getTable()->getAdapter();
        $db->beginTransaction();

        try {
            $poll->delete();
            $db->commit();
        } catch( Exception $e ) {
            $db->rollBack();
            throw $e;
        }

        $this->view->status = true;
        $this->view->message = Zend_Registry::get('Zend_Translate')->_('Your poll has been deleted.');

        // RETURN 
        return $this->_forward('success' ,'utility', 'core', array(
            'parentRedirect' => Zend_Controller_Front::getInstance()->getRouter()->assemble(array('action' => 'manage'), 'sitepoll_general', true),
            'messages' => Array($this->view->message)
        ));
    }

    //ACTION FOR MAKE SITEPOLL CLOSE BY OWNER
    public function closeAction(){

        $viewer = Engine_Api::_()->user()->getViewer();
        $poll = Engine_Api::_()->getItem('sitepoll_poll', $this->_getParam('poll_id'));

        if( !$this->_helper->requireUser()->isValid() ) return;

        // In smoothbox
        $this->_helper->layout->setLayout('default-simple');
        $this->view->form = $form = new Sitepoll_Form_Close();

        if( !Engine_Api::_()->core()->hasSubject('poll') ) {
            Engine_Api::_()->core()->setSubject($poll);
        }
        $this->view->poll = $poll;

        if( !$poll ) {
            $this->view->status = false;
            $this->view->error = Zend_Registry::get('Zend_Translate')->_("Poll doesn't exist or not authorized to close");
            return;
        }

        if( !$this->getRequest()->isPost() ) {
            $this->view->status = false;
            $this->view->error = Zend_Registry::get('Zend_Translate')->_('Invalid request method');
            return;
        }
        // Check auth
        if( !$this->_helper->requireSubject()->isValid() ) {
            return;
        }

        // @todo convert this to post only
        $table = $poll->getTable();
        $db = $table->getAdapter();
        $db->beginTransaction();

        try {
            $poll->is_closed = (bool) $this->_getParam('is_closed');
            $poll->end_datetime = date('Y-m-d H:i:s');
            $poll->status="Expired";
            $poll->save();

            $db->commit();
        } catch( Exception $e ) {
            $db->rollBack();
            throw $e;
        }

        $this->view->status = true;
        $this->view->message = Zend_Registry::get('Zend_Translate')->_('Your poll has been closed.');

        // RETURN 
        return $this->_forward('success' ,'utility', 'core', array(
            'parentRedirect' => Zend_Controller_Front::getInstance()->getRouter()->assemble(array('action' => 'manage'), 'sitepoll_general', true),
            'messages' => Array($this->view->message)
        ));
    }

    public function voteAction(){
        $viewer = Engine_Api::_()->user()->getViewer();
        $poll = Engine_Api::_()->getItem('sitepoll_poll', $this->_getParam('poll_id'));
        $this->view->poll_id=$this->_getParam('poll_id');
        // Check auth
        if( !$this->_helper->requireUser()->isValid() ) {
            return;
        }
        if( !$this->_helper->requireAuth()->setAuthParams('sitepoll_poll', $viewer, 'view')->isValid() ) {
            return;
        }
        if( !$this->_helper->requireAuth()->setAuthParams('sitepoll_poll', null, 'vote')->isValid() ) {
            $this->view->notVote=false;
            $this->view->error = Zend_Registry::get('Zend_Translate')->_('You do not have perssion to vote.');
            return;
        }
        $this->view->canChangeVote=$canChangeVote = Engine_Api::_()->getApi('settings', 'core')->getSetting('sitepoll.canchangevote', 1);

        if($poll->approved==0) {
            $this->view->notApproved = false;
            $this->view->error = Zend_Registry::get('Zend_Translate')->_('This poll is not approved by admin.');
            return;
        }
        if( !$poll ) {
            $this->view->success = false;
            $this->view->error = Zend_Registry::get('Zend_Translate')->_('This poll does not seem to exist anymore.');
            return;
        }

        if( $poll->is_closed ) {

            $this->view->success = false;
            $this->view->error = Zend_Registry::get('Zend_Translate')->_('This poll is closed.');
            return;
        }

        if( $poll->hasVoted($viewer) && !$canChangeVote ) {
            $this->view->success = false;
            $this->view->error = Zend_Registry::get('Zend_Translate')->_('You have already voted on this poll, and are not permitted to change your vote.');
            return;
        }

        $viewer = Engine_Api::_()->user()->getViewer();
        $owner = Engine_Api::_()->getItem("user" , $poll->user_id);
        if($viewer!=$owner)
        {
            Engine_Api::_()->getDbtable('notifications', 'activity')->addNotification($owner, $viewer, $poll, 'sitepoll_poll_vote');
        }
        $id=$this->_getParam('id');
        $poll_id=$this->_getParam('poll_id');
        $explode=explode('_', $id);
        $this->view->id=$explode[1];
        $dbTable =  Engine_Api::_()->getDbtable('options','sitepoll');
        $options=Engine_Api::_()->getDbtable('options','sitepoll')->getpollOption($this->_getParam('poll_id'));
        
        $img_path=array();
        $text_option=array();
        $votes=array();
        $options_id=array();
        // Populate form 
        foreach($options as $option)
        {
            $text=$option['poll_option'];
            $text_option[]=$text;
            $votes[]=$option['votes'];
            $options_id[]=$option['option_id'];
            if($option['photo_option']!=0)
            {
                $photo_id=$option['photo_option'];
                $storage_file = Engine_Api::_()->getItem('storage_file', $photo_id);
                $src=$storage_file->map();
                $img_path[]=$src;
            }
        }
        
        $votesTable = Engine_Api::_()->getDbTable('votes', 'sitepoll');
        $optionsTable = Engine_Api::_()->getDbtable('options', 'sitepoll');

        $this->view->text_option=$text_option;
        $this->view->img_path=$img_path;
        $flag=1;

        if($poll->hasVoted($viewer))
        {
        
        // Check for existing vote
            $vote = $votesTable->fetchRow(array(
                'poll_id = ?' => $poll_id,
                'user_id = ?' => $viewer->getIdentity(),
            ));
            $v=$vote->option_id;
            $this->view->pre_vote_1=$v;

        // New vote is the same as old vote, ignore
            if($option_id == $vote->option_id ) {
                $this->view->fl='wjdj';
                $flag=0;
            }else{
                $key = array_search($v, $options_id);
                $key1=array_search($option_id,$options_id);
                $this->view->key=$key;
                $p=$votes[$key]=$votes[$key]-1;
                $votes[$key1]=$votes[$key1]+1;
                $this->view->p=$p;
            }

        }
        $option = $optionsTable->find((int) $explode[1])->current();
        $vote_early=$votes[$explode[1]];
        $this->view->vote_early=$votes[$explode[1]];
        if($flag==1)
            $votes[$explode[1]]=$vote_early+1;
        $this->view->vote=$votes[$explode[1]];
        $this->view->vote_new=$canChangeVote;
        $this->view->vote_0=$votes[0];
        $this->view->vote_1=$votes[1];
        $this->view->vote_2=$votes[2];
        $this->view->vote_3=$votes[3];
        $this->view->vote_4=$votes[4];
        $this->view->vote_5=$votes[5];
        try{
            $cal=$votes[0]+$votes[1]+$votes[2]+$votes[3]+$votes[4]+$votes[5];
            if($cal!=0)
            {
                $this->view->cal=$cal;
                $this->view->voteCount_0=round(($votes[0]/$cal)*100);
                $this->view->voteCount_1=round(($votes[1]/$cal)*100);
                $this->view->voteCount_2=round(($votes[2]/$cal)*100);
                $this->view->voteCount_3=round(($votes[3]/$cal)*100);
                $this->view->voteCount_4=round(($votes[4]/$cal)*100);
                $this->view->voteCount_5=round(($votes[5]/$cal)*100);
            }
        }catch( Exception $e ) {
            $db->rollback();
            throw $e;
        }
        $db = $dbTable->getAdapter();
        $db->beginTransaction();
        try {
           $poll->vote($viewer, $explode[1]);

           $db->commit();

           $db->commit();
        }catch( Exception $e ) {
        $db->rollback();
        throw $e;
        }
    }

    public function voterlistAction() {
        $viewer = Engine_Api::_()->user()->getViewer();
        $poll = Engine_Api::_()->getItem('sitepoll_poll', $this->_getParam('id'));
        $this->view->poll_id=$this->_getParam('id');
        // Check auth
            if( !$this->_helper->requireUser()->isValid() ) {
                return;
            }
            if( !$this->_helper->requireAuth()->setAuthParams('sitepoll_poll', $viewer, 'view')->isValid() ) {
                return;
            }
        $sitepollVoteTable =Engine_Api::_()->getDbtable('votes', 'sitepoll');
        $sitepollOptionTable=Engine_Api::_()->getDbtable('options', 'sitepoll');
        $poll_id= $this->_getParam('id');
        $sitepollVoteSelect = $sitepollVoteTable->fetchAll(array('poll_id=?'=>$poll_id));
        $sitepollOptionSelect = $sitepollOptionTable->fetchAll(array('poll_id=?'=>$poll_id));
        $optionDatas=$sitepollOptionSelect->toArray();
        $votesDatas=$sitepollVoteSelect->toArray();
        $voterNames=array();
        $votersOption=array();
        $optionData=array();
        $votes=array();
        if(!empty($votesDatas))
        { 
            foreach($votesDatas as $voteData)
            {   
                $voterNames[]=$voteData['user_id'];
                $votersOption[]=$voteData['option_id'];
            }

            foreach($optionDatas as $options)
            {   
                $optionData[$options['option_id']] = array('text'=>$options['poll_option'],'photo'=>$options['photo_option']);
                $votes[]=$options['votes'];
            }
        }
        $sum=array_sum($votes);
        $this->view->poll=$poll;
        $this->view->sum=$sum;
        $this->view->optionData=$optionData;
        $this->view->votesDatas=$votesDatas;
        $this->view->voterNames=$voterNames;
        $this->view->votersOption=$votersOption;
         
    }
}
