<?php

require_once realpath(dirname(__FILE__)) . '/sitemodule_install.php';

class Sitepoll_Installer extends SiteModule_Installer{

  protected $_deependencyVersion = array(
    'seaocore' => '4.10.5p8',
  );

  protected $_installConfig = array(
        'sku' => 'sitepoll',
  );

    public function onInstall(){

        if($this->_databaseOperationType != 'upgrade'){
          $this->_addSitepollBrowsePage();
          $this->_addSitepollViewPage();
          
          $this->_addSitepollCreatePage();
          $this->_addSitepollManagePage();
          $this->_addTagsViewPage();
        }
        parent::onInstall();
    }

    protected function _addSitepollManagePage(){
        $db = $this->getDb();

            // profile page
        $pageId = $db->select()
                     ->from('engine4_core_pages', 'page_id')
                     ->where('name = ?', 'sitepoll_index_manage')
                     ->limit(1)
                     ->query()
                     ->fetchColumn();

            // insert if it doesn't exist yet
        if( !$pageId ) {
                // Insert page
            $db->insert('engine4_core_pages', array(
                'name' => 'sitepoll_index_manage',
                'displayname' => ' Ultimate Polls - My Polls Page',
                'title' => 'My Entries',
                'description' => 'This page lists a user\'s sitepoll entries.',
                'custom' => 0,
            ));
            $pageId = $db->lastInsertId();

                // Insert top
            $db->insert('engine4_core_content', array(
                'type' => 'container',
                'name' => 'top',
                'page_id' => $pageId,
                'order' => 1,
            ));
            $topId = $db->lastInsertId();

                // Insert main
            $db->insert('engine4_core_content', array(
                'type' => 'container',
                'name' => 'main',
                'page_id' => $pageId,
                'order' => 2,
            ));
            $mainId = $db->lastInsertId();

                // Insert top-middle
            $db->insert('engine4_core_content', array(
                'type' => 'container',
                'name' => 'middle',
                'page_id' => $pageId,
                'parent_content_id' => $topId,
            ));
            $topMiddleId = $db->lastInsertId();

                // Insert main-middle
            $db->insert('engine4_core_content', array(
                'type' => 'container',
                'name' => 'middle',
                'page_id' => $pageId,
                'parent_content_id' => $mainId,
                'order' => 2,
            ));
            $mainMiddleId = $db->lastInsertId();

                // Insert main-right
            $db->insert('engine4_core_content', array(
                'type' => 'container',
                'name' => 'right',
                'page_id' => $pageId,
                'parent_content_id' => $mainId,
                'order' => 1,
            ));
            $mainRightId = $db->lastInsertId();

                // Insert menu
            $db->insert('engine4_core_content', array(
                'type' => 'widget',
                'name' => 'sitepoll.browse-menu',
                'page_id' => $pageId,
                'parent_content_id' => $topMiddleId,
                'order' => 1,
            ));

                // Insert content
            $db->insert('engine4_core_content', array(
                'type' => 'widget',
                'name' => 'sitepoll.polls-manage',
                'page_id' => $pageId,
                'parent_content_id' => $mainMiddleId,
                'order' => 1,
                'params' =>'{"columnWidth":"272","columnHeight":"370"}',
            ));

                // Insert search
            $db->insert('engine4_core_content', array(
                'type' => 'widget',
                'name' => 'sitepoll.browse-search',
                'page_id' => $pageId,
                'parent_content_id' => $mainRightId,
                'order' => 2,
                'params' =>'{"recentType":"vertical"}',
            ));

                // Insert gutter menu
            $db->insert('engine4_core_content', array(
                'type' => 'widget',
                'name' => 'sitepoll.browse-menu-quick',
                'page_id' => $pageId,
                'parent_content_id' => $mainRightId,
                'order' => 1,
            ));

                // Insert popular polls
            $db->insert('engine4_core_content', array(
                'type' => 'widget',
                'name' => 'sitepoll.list-popular-polls',
                'page_id' => $pageId,
                'parent_content_id' => $mainRightId,
                'order' => 3,
                'params' =>'{"popularType":"1","title":"Popular Polls"}',
            ));

                // Insert popular poll tags
            $db->insert('engine4_core_content', array(
                'type' => 'widget',
                'name' => 'sitepoll.tagcloud-sitepoll',
                'page_id' => $pageId,
                'parent_content_id' => $mainRightId,
                'order' => 4,
                'params' =>'{"postedby":"vote","truncationTitle":"100","itemCount":"3"}',
            ));
        }
    }

    protected function _addSitepollCreatePage() {

        $db = $this->getDb();

        // profile page
        $page_id = $db->select()
        ->from('engine4_core_pages', 'page_id')
        ->where('name = ?', 'sitepoll_index_create')
        ->limit(1)
        ->query()
        ->fetchColumn();

        if( !$page_id ) {

          // Insert page
          $db->insert('engine4_core_pages', array(
            'name' => 'sitepoll_index_create',
            'displayname' => ' Ultimate Polls - Create Poll',
            'title' => 'Create New Poll',
            'description' => 'This page is the poll create page.',
            'custom' => 0,
        ));
          $page_id = $db->lastInsertId();
          
          // Insert top
          $db->insert('engine4_core_content', array(
            'type' => 'container',
            'name' => 'top',
            'page_id' => $page_id,
            'order' => 1,
        ));
          $top_id = $db->lastInsertId();
          
          // Insert main
          $db->insert('engine4_core_content', array(
            'type' => 'container',
            'name' => 'main',
            'page_id' => $page_id,
            'order' => 2,
        ));
          $main_id = $db->lastInsertId();
          
          // Insert top-middle
          $db->insert('engine4_core_content', array(
            'type' => 'container',
            'name' => 'middle',
            'page_id' => $page_id,
            'parent_content_id' => $top_id,
        ));
          $top_middle_id = $db->lastInsertId();
          
          // Insert main-middle
          $db->insert('engine4_core_content', array(
            'type' => 'container',
            'name' => 'middle',
            'page_id' => $page_id,
            'parent_content_id' => $main_id,
            'order' => 2,
        ));
          $main_middle_id = $db->lastInsertId();
          
          // Insert menu
          $db->insert('engine4_core_content', array(
            'type' => 'widget',
            'name' => 'sitepoll.browse-menu',
            'page_id' => $page_id,
            'parent_content_id' => $top_middle_id,
            'order' => 1,
        ));
          
          // Insert content
          $db->insert('engine4_core_content', array(
            'type' => 'widget',
            'name' => 'core.content',
            'page_id' => $page_id,
            'parent_content_id' => $main_middle_id,
            'order' => 1,
        ));
      }
    }

    protected function _addSitepollBrowsePage(){

        $db = $this->getDb();

        // profile page
        $page_id = $db->select()
        ->from('engine4_core_pages', 'page_id')
        ->where('name = ?', 'sitepoll_index_browse')
        ->limit(1)
        ->query()
        ->fetchColumn();
        
        // insert if it doesn't exist yet
        if( !$page_id ) {
          // Insert page
          $db->insert('engine4_core_pages', array(
            'name' => 'sitepoll_index_browse',
            'displayname' => ' Ultimate Polls - Browse Polls Page',
            'title' => 'Poll Browse',
            'description' => 'This page lists polls.',
            'custom' => 0,
        ));
          $page_id = $db->lastInsertId();
          
          // Insert top
          $db->insert('engine4_core_content', array(
            'type' => 'container',
            'name' => 'top',
            'page_id' => $page_id,
            'order' => 1,
        ));
          $top_id = $db->lastInsertId();
          
          // Insert main
          $db->insert('engine4_core_content', array(
            'type' => 'container',
            'name' => 'main',
            'page_id' => $page_id,
            'order' => 2,
        ));
          $main_id = $db->lastInsertId();
          
          // Insert top-middle
          $db->insert('engine4_core_content', array(
            'type' => 'container',
            'name' => 'middle',
            'page_id' => $page_id,
            'parent_content_id' => $top_id,
        ));
          $top_middle_id = $db->lastInsertId();
          
          // Insert main-middle
          $db->insert('engine4_core_content', array(
            'type' => 'container',
            'name' => 'middle',
            'page_id' => $page_id,
            'parent_content_id' => $main_id,
            'order' => 2,
        ));
          $main_middle_id = $db->lastInsertId();
          
          // Insert main-right
          $db->insert('engine4_core_content', array(
            'type' => 'container',
            'name' => 'right',
            'page_id' => $page_id,
            'parent_content_id' => $main_id,
            'order' => 1,
        ));
          $main_right_id = $db->lastInsertId();
          
          // Insert menu
          $db->insert('engine4_core_content', array(
            'type' => 'widget',
            'name' => 'sitepoll.browse-menu',
            'page_id' => $page_id,
            'parent_content_id' => $top_middle_id,
            'order' => 1,
        ));
          
          // Insert content
          $db->insert('engine4_core_content', array(
            'type' => 'widget',
            'name' => 'sitepoll.polls-sitepoll',
            'page_id' => $page_id,
            'parent_content_id' => $main_middle_id,
            'order' => 1,
            'params' =>'{"layouts_views":["1","2"],"columnWidth":"272","columnHeight":"370","defaultordering":"1","truncationDescription":"250","truncationTitle":"100","showoptions":["votecount","owner","creation","feature","sponsored","likecount","viewcount","commentcount"]}',
        ));
          
          // Insert gutter menu
          $db->insert('engine4_core_content', array(
            'type' => 'widget',
            'name' => 'sitepoll.browse-menu-quick',
            'page_id' => $page_id,
            'parent_content_id' => $main_right_id,
            'order' => 1,
        ));

          // Insert search
          $db->insert('engine4_core_content', array(
            'type' => 'widget',
            'name' => 'sitepoll.browse-search',
            'page_id' => $page_id,
            'parent_content_id' => $main_right_id,
            'order' => 1,
            'params' =>'{"recentType":"vertical"}',
        ));

          //Insert categories
          $db->insert('engine4_core_content', array(
            'type' => 'widget',
            'name' => 'sitepoll.categories-polls',
            'page_id' => $page_id,
            'parent_content_id' => $main_right_id,
            'order' => 1,
            'params' =>'{"title":"Categories"}',
        ));

          //Insert recent polls
          $db->insert('engine4_core_content', array(
            'type' => 'widget',
            'name' => 'sitepoll.list-recent-polls',
            'page_id' => $page_id,
            'parent_content_id' => $main_right_id,
            'order' => 1,
            'params' =>'{"truncationDescription":"250","truncationTitle":"100","recentType":["vote","view","featured","sponsored","likes","creation","comment","owner"],"itemCount":"3","category_id":"0","title":"Recent Polls"}',
        )); 

          //Insert popular polls tags
          $db->insert('engine4_core_content', array(
            'type' => 'widget',
            'name' => 'sitepoll.tagcloud-sitepoll',
            'page_id' => $page_id,
            'parent_content_id' => $main_right_id,
            'order' => 1,
            'params' =>'{"postedby":"1"}',
        ));      
      }
    }

    protected function _addSitepollViewPage(){

        $db = $this->getDb();

            // profile page
        $pageId = $db->select()
        ->from('engine4_core_pages', 'page_id')
        ->where('name = ?', 'sitepoll_sitepoll_view')
        ->limit(1)
        ->query()
        ->fetchColumn();

            // insert if it doesn't exist yet
        if( !$pageId ) {
                // Insert page
            $db->insert('engine4_core_pages', array(
                'name' => 'sitepoll_sitepoll_view',
                'displayname' => ' Ultimate Polls - Polls View Page',
                'title' => 'sitepoll View',
                'description' => 'This page displays a sitepoll entry.',
                'provides' => 'subject=sitepoll',
                'custom' => 0,
            ));
            $pageId = $db->lastInsertId();

                // Insert main
            $db->insert('engine4_core_content', array(
                'type' => 'container',
                'name' => 'main',
                'page_id' => $pageId,
            ));
            $mainId = $db->lastInsertId();

                // Insert left
            $db->insert('engine4_core_content', array(
                'type' => 'container',
                'name' => 'left',
                'page_id' => $pageId,
                'parent_content_id' => $mainId,
                'order' => 1,
            ));
            $leftId = $db->lastInsertId();

                // Insert middle
            $db->insert('engine4_core_content', array(
                'type' => 'container',
                'name' => 'middle',
                'page_id' => $pageId,
                'parent_content_id' => $mainId,
                'order' => 2,
            ));
            $middleId = $db->lastInsertId();

                // Insert owner photo
            $db->insert('engine4_core_content', array(
                'type' => 'widget',
                'name' => 'sitepoll.poll-owner-photo',
                'page_id' => $pageId,
                'parent_content_id' => $leftId,
                'order' => 1,
            ));

                // Insert poll status
            $db->insert('engine4_core_content', array(
                'type' => 'widget',
                'name' => 'sitepoll.poll-status',
                'page_id' => $pageId,
                'parent_content_id' => $leftId,
                'order' => 2,
            ));

                // Insert Trending poll
            $db->insert('engine4_core_content', array(
                'type' => 'widget',
                'name' => 'sitepoll.trending-sitepoll',
                'page_id' => $pageId,
                'parent_content_id' => $leftId,
                'order' => 3,
                'params' =>'{"itemCount":"3","sitepoll_item":["owner","host","date","like","vote"],"columnHeight":"328","show_sitepoll":"featured","sort_sitepoll":"vote_count","title":"Trending Polls"}',
            ));

                // Insert breadcrum
            $db->insert('engine4_core_content', array(
                'type' => 'widget',
                'name' => 'sitepoll.poll-profile-breadcrumb',
                'page_id' => $pageId,
                'parent_content_id' => $middleId,
                'order' => 1,
            ));

                // Insert content
            $db->insert('engine4_core_content', array(
                'type' => 'widget',
                'name' => 'core.content',
                'page_id' => $pageId,
                'parent_content_id' => $middleId,
                'order' => 1,
            ));

                // Insert core comments
            $db->insert('engine4_core_content', array(
                'type' => 'widget',
                'name' => 'core.comments',
                'page_id' => $pageId,
                'parent_content_id' => $middleId,
                'order' => 2,
            ));
        }
    }

    protected function _addTagsViewPage(){
        $db = $this->getDb();

            // profile page
        $pageId = $db->select()
        ->from('engine4_core_pages', 'page_id')
        ->where('name = ?', 'sitepoll_index_tagscloud')
        ->limit(1)
        ->query()
        ->fetchColumn();

            // insert if it doesn't exist yet
        if( !$pageId ) {
                // Insert page
            $db->insert('engine4_core_pages', array(
                'name' => 'sitepoll_index_tagscloud',
                'displayname' => 'Tags view Page',
                'title' => 'Tags view',
                'description' => 'This page displays tags.',
                'provides' => 'subject=question',
                'custom' => 0,
            ));
            $pageId = $db->lastInsertId();

                // Insert top
            $db->insert('engine4_core_content', array(
                'type' => 'container',
                'name' => 'top',
                'page_id' => $pageId,
                'order' => 1,
            ));
            $topId = $db->lastInsertId();

                // Insert main
            $db->insert('engine4_core_content', array(
                'type' => 'container',
                'name' => 'main',
                'page_id' => $pageId,
                'order' => 2,
            ));
            $mainId = $db->lastInsertId();

                // Insert top-middle
            $db->insert('engine4_core_content', array(
                'type' => 'container',
                'name' => 'middle',
                'page_id' => $pageId,
                'parent_content_id' => $topId,
            ));
            $topMiddleId = $db->lastInsertId();

                // Insert main-middle
            $db->insert('engine4_core_content', array(
                'type' => 'container',
                'name' => 'middle',
                'page_id' => $pageId,
                'parent_content_id' => $mainId,
                'order' => 2,
            ));
            $mainMiddleId = $db->lastInsertId();

                // Insert main-right
            $db->insert('engine4_core_content', array(
                'type' => 'container',
                'name' => 'right',
                'page_id' => $pageId,
                'parent_content_id' => $mainId,
                'order' => 1,
            ));
            $mainRightId = $db->lastInsertId();

                // Insert menu
            $db->insert('engine4_core_content', array(
                'type' => 'widget',
                'name' => 'sitepoll.browse-menu',
                'page_id' => $pageId,
                'parent_content_id' => $topMiddleId,
                'order' => 1,
            ));

                // Insert content
            $db->insert('engine4_core_content', array(
                'type' => 'widget',
                'name' => 'sitepoll.tagcloud-sitepoll',
                'page_id' => $pageId,
                'parent_content_id' => $mainMiddleId,
                'order' => 2,
            ));
        }
    }
}
