<?php
/**
 * SocialEngine
 *
 * @category   Application_Extensions
 * @package    Sitepushnotification
 * @copyright  Copyright 2015-2016 BigStep Technologies Pvt. Ltd.
 * @license    http://www.socialengineaddons.com/license/
 * @version    $Id: Create.php 6590 2016-3-3 00:00:00Z SocialEngineAddOns $
 * @author     SocialEngineAddOns
 */
class Sitepushnotification_Form_Admin_Create extends Engine_Form {

    public function init() {

        $this
                ->setTitle('Send Push Notification')
                ->setDescription('Using this form, you will be able to send a push notification out to your subscribers by choosing robust targeting options for who should receive your push notification based on "Member Levels" and "Networks", depending on which of these are being used on your site. You can also choose to send push notification to particular subscribers by choosing their names from the auto-suggest box. You can also schedule them on later date, to be sent.
            <br><br>
          <b>Note:</b> To have better visualization, you should keep Push Notification title and message short, and Push Notifications will only be sent to those who have subscribed your website for push notifications.')
                ->setEnctype(Zend_Form::ENCTYPE_MULTIPART)
                ->setAttrib('id', 'new-push');

        $this->loadDefaultDecorators();
        $this->getDecorator('Description')->setOption('escape', false);

        // Set time zone
        $timezone = Engine_Api::_()->getApi('settings', 'core')->core_locale_timezone;
        date_default_timezone_set($timezone);

        // Form field for setting title of notifications
        $this->addElement('Text', 'title', array(
            'label' => 'Title',
            'order' => 6,
            'description' => 'Enter the title for push notification.',
        ));
        $this->title->setRequired(true);

        // Form field for setting url of notifications
        $this->addElement('Select', 'urlprtocol', array(
            'label' => 'Redirecting URL',
            'order' => 9,
            'description' => '',
            'multiOptions' => array('http://' => 'http://', 'https://' => "https://"),
        ));
        $this->addElement('Text', 'url', array(
            'order' => 10,
            'error_msg' => 'Enter the prorper URL'
        ));
        $this->url->addValidator('Regex', false, '/^(https?:\/\/)?([\da-z\.-]+)\.([a-z\.]{2,6})([\/\w \.-]*)*\/?$/');
        $this->url->getDecorator('Description')->setOption('escape', false);

        // Form field for setting body of notifications
        $this->addElement('Textarea', 'body', array(
            'label' => 'Message',
            'order' => 7,
            'description' => 'Enter the message you want to display in push notification.',
        ));
        $this->body->setRequired(true);

        // Form field for setting logo of notifications
        $this->addElement('File', 'logo', array(
            'label' => 'Select Logo',
            'order' => 8,
            'description' => 'Upload the logo you want to be displayed in the push notification.<br> [Note: If your site is not SSL secure then, the logo you have sent us via filing a support ticket will be displayed in the notification. To change the logo in future you need to file us a support ticket again with the same details and new logo.]',
            'value' => 0
        ));
        $this->logo->addValidator('Extension', false, 'jpg,png,gif,jpeg,JPG,PNG,GIF,JPEG');
        $this->logo->getDecorator('Description')->setOption('escape', false);

        // Form field for setting recievers of notifications
        $availableLabels = array(
            'registered' => Engine_Api::_()->getApi('core', 'sitepushnotification')->translateType('registered'),
            'member_level' => Engine_Api::_()->getApi('core', 'sitepushnotification')->translateType('member_level'),
            'network' => Engine_Api::_()->getApi('core', 'sitepushnotification')->translateType('network'),
            'specific_user' => Engine_Api::_()->getApi('core', 'sitepushnotification')->translateType('specific_user'),
            'non_loggedin' => Engine_Api::_()->getApi('core', 'sitepushnotification')->translateType('non_loggedin')
        );

        $this->addElement('Select', 'send_to', array(
            'label' => 'Notification will be sent to?',
            'description' => 'Select the user type to which you want to send Push Notification',
            'order' => 1,
            'multiOptions' => $availableLabels,
            'onchange' => 'javascript:hide_Others(this.value)'
        ));

        // MAKE NETWORK LIST
        $table = Engine_Api::_()->getDbtable('networks', 'network');
        $select = $table->select()
                ->from($table->info('name'), array('network_id', 'title'))
                ->order('title');
        $result = $table->fetchAll($select);

        foreach ($result as $value) {
            $networksOptions[$value->network_id] = $value->title;
        }

        // print_r($networksOptions); die();
        if (count($networksOptions) > 0) {
            $this->addElement('Multiselect', 'network', array(
                'label' => 'Networks Selection',
                'description' => 'Select the networks, to which you want to send push notification. (Press Ctrl and click to select multiple networks.)',
                'multiOptions' => $networksOptions,
                'order' => 2,
                'value' => 1
            ));
        }

        // MAKE MEMBER LEVEL LIST
        $levelTable = Engine_Api::_()->getDbtable('levels', 'authorization');
        $query = $levelTable->select()
                ->from($levelTable->info('name'), array('level_id', 'title'))
                ->order('title');
        $resultArray = $table->fetchAll($query);

        foreach ($resultArray as $value) {
            $levelOptions[$value->level_id] = $value->title;
        }
        if (count($levelOptions) > 0) {
            $this->addElement('Multiselect', 'member_level', array(
                'label' => 'Member Levels Selection',
                'description' => 'Select the member levels, to which you want to send push notification. (Press Ctrl and click to select multiple member levels.)',
                'multiOptions' => $levelOptions,
                'order' => 3,
                'value' => array(0)
            ));
        }

        //SPECIFIC USERS SELECT
        $this->addElement('Text', 'users_data', array(
            'label' => 'Choose Subscribers',
            'description' => 'Enter and choose the names (though auto-suggest) of specific subscribers to whom you want to send push notifications. [<b>Note:</b> You will only be able to choose from those subscribers who have subscribed for your website push notifications]',
            'order' => 4,
            'autocomplete' => 'off'));

        Engine_Form::addDefaultDecorators($this->users_data);
        $this->users_data->getDecorator('Description')->setOption('escape', false);
        // Init to Values
        $this->addElement('Hidden', 'toValues', array(
            'order' => 5,
            'validators' => array(
                'NotEmpty'
            ),
            'filters' => array(
                'HtmlEntities'
            ),
        ));
        Engine_Form::addDefaultDecorators($this->toValues);

        // Form field for setting time of sending notifications
        $this->addElement('Select', 'send_at', array(
            'label' => 'Notification will be send at ',
            'order' => 11,
            'multiOptions' => array(
                1 => 'Send Now',
                0 => 'Send Later'
            ),
            'onclick' => 'showsendtime(this.value)',
            'value' => 1,
        ));

        // Form field for selecting time of sending notifications
        $time = new Engine_Form_Element_CalendarDateTime('scheduled_time');
        $time->useMilitaryTime;
        $time->setLabel("Send At");
        $time->setOrder(12);
        $time->setValue(date("Y-m-d H:i:s"));
        $time->setAllowEmpty(false);
        $this->addElement($time);


        $this->addElement('Button', 'submit', array(
            'label' => 'Send Notification',
            'order' => 13,
            'type' => 'submit',
            'ignore' => true,
        ));
    }

}