<?php

/**
 * SocialEngine
 *
 * @category   Application_Extensions
 * @package    Sitepushnotification
 * @copyright  Copyright 2015-2016 BigStep Technologies Pvt. Ltd.
 * @license    http://www.socialengineaddons.com/license/
 * @version    $Id: General.php 6590 2016-3-3 00:00:00Z SocialEngineAddOns $
 * @author     SocialEngineAddOns
 */
class Sitepushnotification_Form_Admin_General extends Engine_Form {

    // IF YOU WANT TO SHOW CREATED ELEMENT ON PLUGIN ACTIVATION THEN INSERT THAT ELEMENT NAME IN THE BELOW ARRAY.
    public $_SHOWELEMENTSBEFOREACTIVATE = array(
        "submit_lsetting", "environment_mode"
    );

    public function init() {

        $productType = 'sitepushnotification';
        // Set time zone
        $timezone = Engine_Api::_()->getApi('settings', 'core')->core_locale_timezone;
        date_default_timezone_set($timezone);

        $this
                ->setTitle('General Settings')
                ->setDescription('These settings affect all members in your community.');

        $logoId = Engine_Api::_()->getApi('settings', 'core')->getSetting('sitepushnotification.defaultlogo', '');
        $logoValue = "";
        if ($logoId) {
            $url = Engine_Api::_()->storage()->get($logoId, '')->getPhotoUrl();
            $urlArr = explode("/", $url);
            $logo_name = explode("?c=", $urlArr[count($urlArr) - 1]);
            $logoValue = "[ Uploaded file " . $logo_name[0] . " ] &nbsp;&nbsp;<img src='$url' width=70px height=70px />";
        }

        $this->addElement('Text', 'sitepushnotification_sitetitle', array(
            'label' => 'Website Title',
            'description' => 'Enter your website name which will be displayed as title in your push notification.',
            'value' => Engine_Api::_()->getApi('settings', 'core')->getSetting('sitepushnotification.sitetitle', ''),
        ));

        $view = Zend_Registry::isRegistered('Zend_View') ? Zend_Registry::get('Zend_View') : null;
        $baseURL = $view->baseUrl();
        // Form field for setting notification subscription method for users
        $this->addElement('Radio', 'sitepushnotification_subscription_method', array(
            'label' => 'How to Subscribe',
            'description' => 'Select a method for how a user can subscribe for push notifications on your website.',
            'multiOptions' => array(
                1 => "Browser's Default Method [When browsers automatically asks users to allow / disallow for push notifications on page loading / refreshing.]",
                0 => "Subscribe via Bell Widget [Users can only subscribe by clicking on floating bell widget available on your website.]",
            ),
            'value' => Engine_Api::_()->getApi('settings', 'core')->getSetting('sitepushnotification.subscription.method', '1'),
        ));
        $icon_url = $baseURL . '/application/modules/Sitepushnotification/externals/images/Global_Setting_Screenshot.png';
        $icon_view = '<a href="' . $icon_url . '" title="View Screenshot" class="sitepushnotification_icon_view" target="_blank"></a>';

        // Form field for setting logo of notifications
        $this->addElement('File', 'sitepushnotification_defaultlogo', array(
            'label' => 'Select Logo',
            'description' => ' Choose a logo to be displayed in the push notification, with the title and description. Global logo cannot be changed if your site is running on HTTP. ' . $icon_view . ' <br>' . $logoValue,
            'value' => '',
        ));
        $this->sitepushnotification_defaultlogo->addValidator('Extension', false, 'jpg,png,gif,jpeg,JPG,PNG,GIF,JPEG');
        $this->sitepushnotification_defaultlogo->getDecorator('Description')->setOption('escape', false);

        $this->addElement('Text', 'sitepushnotification_cookieduration', array(
            'label' => 'Duration of Cookie',
            'description' => 'Enter the duration of cookie for the users who want to enable push notification sometimes later.',
            'value' => Engine_Api::_()->getApi('settings', 'core')->getSetting('sitepushnotification.cookieduration', 2),
        ));

        $scheme = (Engine_Api::_()->getApi('core', 'sitepushnotification')->isSSL()) ? '' : '1';

        $this->addElement('Select', 'sitepushnotification_protocol', array(
            'label' => 'Website on HTTPS',
            'description' => 'Is your website running on HTTPS ?',
            'multiOptions' => array(
                '' => 'Yes',
                1 => 'No'
            ),
            'onclick' => 'showHideSubdomain()',
            'value' => $scheme,
        ));
        $this->sitepushnotification_protocol->getDecorator('Description')->setOptions(array('placement' =>
            'POSTPEND', 'escape' => false));
        // Extract subdomain name from db entry
        $subdomain_value = Engine_Api::_()->getApi('settings', 'core')->getSetting('sitepushnotification.subdomain', '');

        $subdomain_value = substr($subdomain_value, 8);
        $subdomain = substr($subdomain_value, 0, -12);


        $subdomain_icon_url = $baseURL . '/application/modules/Sitepushnotification/externals/images/Notification_HTTP.png';
        $subdomain_icon_view = '<a href="' . $subdomain_icon_url . '" title="View Screenshot" class="sitepushnotification_icon_view" target="_blank"></a>';

        $this->addElement('Text', 'sitepushnotification_subdomain', array(
            'label' => 'Subdomain name',
            'description' => 'Enter the subdomain of your website for eg, if your website’s URL is: https://www.example.com or https://www.community.example.com, then your subdomain will be <b>“example” or “community-example” </b> <br> <a href="' . $subdomain_icon_url . '" target="_blank">Click here </a> to see how it will be displayed.<br><br> [Note: This sub-domain name displayed in the notification will be the one you provided us via filing a support ticket. To change the subdomain name in future, you need to file us a support ticket again with the same details and new subdomain name.] <br><br>',
            'value' => $subdomain,
        ));
        $this->sitepushnotification_subdomain->getDecorator('Description')->setOption('escape', false);

        $this->addElement('Button', 'submit', array(
            'label' => 'Save Changes',
            'type' => 'submit',
            'ignore' => true
        ));
    }

}
