<?php
/**
 * SocialEngine
 *
 * @category   Application_Extensions
 * @package    Sitepushnotification
 * @copyright  Copyright 2015-2016 BigStep Technologies Pvt. Ltd.
 * @license    http://www.socialengineaddons.com/license/
 * @version    $Id: Users.php 6590 2016-3-3 00:00:00Z SocialEngineAddOns $
 * @author     SocialEngineAddOns
 */
class Sitepushnotification_Model_DbTable_Users extends Engine_Db_Table {

    public function getNotificationUsersSelect($params = array()) {
        $table = Engine_Api::_()->getDbtable('users', 'sitepushnotification');
        $rName = $table->info('name');

        $select = $table->select()
                ->order(!empty($params['orderby']) ? $params['orderby'] . ' DESC' : $rName . '.creation_date DESC' );

        return $select;
    }

    public function getNotificationUsersPaginator($params = array()) {
        $paginator = Zend_Paginator::factory($this->getNotificationUsersSelect($params));
        $page = 1;
        $limit = 50;
        if (!empty($params['page'])) {
            $page = $params['page'];
        }
        if (!empty($params['limit'])) {
            $limit = $params['limit'];
        }
        $paginator->setCurrentPageNumber($page);
        $paginator->setItemCountPerPage($limit);
        return $paginator;
    }

    public function getUserIds() {
        $select = $this
                ->select()
                ->from($this, array('uid'))
                ->group("engine4_sitepushnotification_users.uid")
                ->query();

        $data = array();
        foreach ($select->fetchAll() as $user) {
            $data[] = $user['uid'];
        }

        return $data;
    }

    public function getUsers($text, $limit) {

        $userTable = Engine_Api::_()->getDbtable('users', 'user');
        $select = $userTable->select()
                ->from($userTable->info('name'))
                ->join($this->info('name'), $userTable->info('name') . '.user_id = ' . $this->info('name') . '.uid', null);
        $titleColumn = Engine_Api::_()->getApi('core', 'sitepushnotification')->getUserTitleColumn();
        if (null !== $text)
            $select->where('`' . $userTable->info('name') . "`.`$titleColumn` LIKE ?", '%' . $text . '%');

        if (0 < ($limit))
            $select->limit($limit);

        $select->group($userTable->info('name') . '.user_id');
        return $userTable->fetchAll($select);
    }

    public function getRegisteredUsers() {
        $select = $this->select();
        $select->where('uid is not null AND uid != 0');
        $result = $this->fetchAll($select);
        $users = array();
        foreach ($result as $row) {
            $users[] = array(
                'uid' => $row->uid,
                'browser' => $row->browser,
                'device_id' => $row->device_id);
        }
        return $users;
    }

    public function getUnregisteredUsers() {
        $select = $this->select();
        $select->where('uid is null OR uid = 0');
        $result = $this->fetchAll($select);
        $users = array();
        foreach ($result as $row) {
            $users[] = array(
                'uid' => $row->uid,
                'browser' => $row->browser,
                'device_id' => $row->device_id);
        }
        return $users;
    }

    public function getSpecificUsers($params = null) {
        $params_arr = array();
        $params_arr = array_map('intval', explode(",", json_decode($params)));
        $select = $this->select();
        $select->where('uid IN(?)', $params_arr);
        $result = $this->fetchAll($select);
        $users = array();
        foreach ($result as $row) {
            $users[] = array(
                'uid' => $row->uid,
                'browser' => $row->browser,
                'device_id' => $row->device_id);
        }
        return $users;
    }

    public function getLevelBasedUsers($params = null) {
        $params_arr = array();
        $params_arr = json_decode($params);

        $userTable = Engine_Api::_()->getDbtable('users', 'user');
        $select = $this->select()
                ->from($this->info('name'))
                ->join($userTable->info('name'), $userTable->info('name') . '.user_id = ' . $this->info('name') . '.uid', null)
                ->where($userTable->info('name') . '.level_id IN(?)', $params_arr);

        $result = $this->fetchAll($select);

        $users = array();
        foreach ($result as $row) {
            $users[] = array(
                'uid' => $row->uid,
                'browser' => $row->browser,
                'device_id' => $row->device_id);
        }

        return $users;
    }

    public function getNetworkBasedUsers($params = null) {
        $params_arr = array();
        $params_arr = json_decode($params);

        $networkTable = Engine_Api::_()->getDbtable('membership', 'network');
        $select = $this->select()
                ->from($this->info('name'))
                ->join($networkTable->info('name'), $networkTable->info('name') . '.user_id = ' . $this->info('name') . '.uid', null)
                ->where($networkTable->info('name') . '.resource_id IN(?)', $params_arr);

        $result = $this->fetchAll($select);

        $users = array();
        foreach ($result as $row) {
            $users[] = array(
                'uid' => $row->uid,
                'browser' => $row->browser,
                'device_id' => $row->device_id);
        }
        return $users;
    }

    public function getUserData($params = null) {
        $select = $this->select();
        $select->where('uid = ?', $params);

        $result = $this->fetchAll($select);

        $users = array();
        foreach ($result as $row) {
            $users[] = array(
                'uid' => $row->uid,
                'browser' => $row->browser,
                'device_id' => $row->device_id);
        }

        return $users;
    }

    public function deleteSubscription($device_id = null, $uid = null) {
        $params = array();
        if (!empty($device_id)) {
            $params['device_id = ?'] = $device_id;
        }
        if (!empty($uid)) {
            $params['uid = ?'] = $uid;
        }
        if (count($params) > 0) {
            $this->delete($params);
        }
    }

    public function getUserSubscription($deviceId) {
        $select = $this->select();
        $select->where('device_id = ?', $deviceId);
        $user = $this->fetchRow($select);
        return $user ? true : false;
    }

    public function updateSubscription($params = null) {
        $updateStatus = 1;
        $select = $this->select();
        $select->where('device_id = ?', $params['device_id']);

        $result = $this->fetchRow($select);
        
        if ($result) {
            $this->update(array('uid' => $params['uid']), array('`device_id` = ? ' => $params['device_id']));
            return $updateStatus;
        }

        Engine_Api::_()->getDbtable('users', 'sitepushnotification')->setSubscription($params);
        $updateStatus = 0;
        return $updateStatus;
    }

    public function setSubscription($params) {
        $params['subscription_time'] = date("Y-m-d H:i:s");
        $db = $this->getAdapter();
        $db->beginTransaction();
        try {
            $user = $this->createRow();
            $user->setFromArray($params);
            $user->save();
            $db->commit();
        } catch (Exception $e) {
            $db->rollBack();
            throw $e;
        }
    }

    public function getSubscription($params) {
        $select = $this->select();
        $select->where('device_id = ?', $params['device_id']);
        $result = $this->fetchAll($select);
        $users = array();
        foreach ($result as $row) {
            $users[] = array(
                'uid' => $row->uid,
                'browser' => $row->browser,
                'device_id' => $row->device_id);
        }
        return count($users) > 0 ? 1 : 0;
    }

    public function deleteUserSubscription($uid = null) {
        if (empty($uid)) {
            return;
        }
        $this->delete(array(
            'uid = ?' => $uid
        ));
    }

}
