<?php

/**
 * SocialEngine
 *
 * @category   Application_Extensions
 * @package    Sitepushnotification
 * @copyright  Copyright 2015-2016 BigStep Technologies Pvt. Ltd.
 * @license    http://www.socialengineaddons.com/license/
 * @version    $Id: Pushnotification.php 6590 2016-3-3 00:00:00Z SocialEngineAddOns $
 * @author     SocialEngineAddOns
 */
class Sitepushnotification_Plugin_Pushnotification {

    public $_GOOGLE_API_KEY;

    // Hook called after a user has logged out
    public function onUserLogoutAfter($event) {

        $logoutSession = new Zend_Session_Namespace('logout');
        $logoutSession->uid = Engine_Api::_()->user()->getViewer()->getIdentity();
        $subscription_method = Engine_Api::_()->getApi('settings', 'core')->getSetting('sitepushnotification.subscription.method', '1');
    }

    //  Hook called after user has logged in
    public function onUserLoginAfter($event) {
        $loginSession = new Zend_Session_Namespace('login');
        $loginSession->uid = Engine_Api::_()->user()->getViewer()->getIdentity();
        $subscription_method = Engine_Api::_()->getApi('settings', 'core')->getSetting('sitepushnotification.subscription.method', '1');
        $userPushSetting = Engine_Api::_()->getApi('core', 'sitepushnotification')->getUserPushSetting($loginSession->uid);
    }

    // Hook called after a notification is created
    public function onActivityNotificationCreateAfter($event) {
        $notification = $payload = $event->getPayload();

        $user_model = Engine_Api::_()->user()->getUser($notification->user_id);
        $notificationSetting = Engine_Api::_()->getDbtable('notificationSettings', 'activity')->getEnabledNotifications($user_model);

        if (!in_array($notification->type, $notificationSetting)) {
            return;
        }

        $webTitle = Engine_Api::_()->getApi('settings', 'core')->getSetting('sitepushnotification.sitetitle', $_SERVER['SERVER_NAME']);

        $subject = Engine_Api::_()->user()->getViewer();
        $subjectOwner = $subjectOwner = Engine_Api::_()->getItem('user', $notification->user_id);

        $userPushSetting = Engine_Api::_()->getApi('core', 'sitepushnotification')->getUserPushSetting($notification->user_id);

        if ($userPushSetting != '1')
            return;

        // User could be login in multiple devices that's why we need to send push notification on all devices.
        $users = Engine_Api::_()->getDbtable('users', 'sitepushnotification')->getUserData($notification->user_id);

        foreach ($users as $data) {
            $this->sendDefaultNotification($data, $notification);
        }
    }

    public function getUsers($user_id) {
        $fcmTable = Engine_Api::_()->getDbtable('users', 'sitepushnotification');
        return $fcmTable->getUsers(array('user_id' => $user_id));
    }

    public function sendAdminBasedNotification($data) {
        $GOOGLE_API_KEY = $this->canSendNotification(true);

        if ($data['browser'] == 'chrome' || $data['browser'] == 'mozilla' || $data['browser'] == 'opera') {
            if (!$GOOGLE_API_KEY)
                return;
            return Engine_Api::_()->loadClass('Sitepushnotification_Plugin_Pushnotification')->sendFcmNotification($data, $GOOGLE_API_KEY);
        } else if ($data['browser'] == 'safari') {
            return Engine_Api::_()->loadClass('Sitepushnotification_Plugin_Pushnotification')->sendSafariNotification($data);
        }
    }

    public function sendWelcomeNotification($data = null) {
        if ($data == null) 
            return;

        $data['title'] = Engine_Api::_()->getApi('settings', 'core')->getSetting('sitepushnotification.welcome.title', 'Welcome to Push Notifications !!');
        $data['body'] = Engine_Api::_()->getApi('settings', 'core')->getSetting('sitepushnotification.welcome.body', 'Thanks for subscribing for the browser push notifications :)');
        $data['tag'] = "welcome";
        $welcomeLogo = Engine_Api::_()->getApi('settings', 'core')->getSetting('sitepushnotification.welcome.logo', '');

        // Set welcome notification logo
        $front = Zend_Controller_Front::getInstance();
        if (!empty($welcomeLogo)) {
            $welcomeLogo = Engine_Api::_()->storage()->get($welcomeLogo, '')->getPhotoUrl();
        } else if (empty($welcomeLogo)) {
            $defaultLogo = Engine_Api::_()->getApi('settings', 'core')->getSetting('sitepushnotification.defaultlogo', '');
            if (!empty($defaultLogo))
                $welcomeLogo = Engine_Api::_()->storage()->get($defaultLogo, '')->getPhotoUrl();
            else
                $welcomeLogo = $front->getBaseUrl() . '/application/modules/Sitepushnotification/externals/images/default.jpg';
        }
        $data['logo'] = Engine_Api::_()->getApi('core','sitepushnotification')->getPhotoUrl($welcomeLogo);

        // Set welcome notification url
        $welcomeUrl = Engine_Api::_()->getApi('settings', 'core')->getSetting('sitepushnotification.welcome.url', '');
        if (empty($welcomeUrl)) 
            $welcomeUrl = Engine_Api::_()->getApi('core','sitepushnotification')->getBaseHost();
        
        $data['url'] = $welcomeUrl;

        $GOOGLE_API_KEY = $this->canSendNotification(true);

        if ($data['browser'] == 'chrome' || $data['browser'] == 'mozilla' || $data['browser'] == 'opera') {
            if (!$GOOGLE_API_KEY)
                return;
            return Engine_Api::_()->loadClass('Sitepushnotification_Plugin_Pushnotification')->sendFcmNotification($data, $GOOGLE_API_KEY);
        } else if ($data['browser'] == 'safari') {
            return Engine_Api::_()->loadClass('Sitepushnotification_Plugin_Pushnotification')->sendSafariNotification($data);
        }
    }

    public function sendDefaultNotification($data, $notification) {
	
        // Make data packet extract data from notification object
        // Set logo of default notifications
        $logoId = Engine_Api::_()->getApi('settings', 'core')->getSetting('sitepushnotification.defaultlogo', 0);
	$subject = $notification->getSubject();
        $photoId = 0;
        if ( $subject && $subject->getType()=='user') {
		$photoId = $subject->photo_id;
        }
	
        if (!empty($photoId)) {
		$data['logo'] = $subject->getPhotoUrl('thumb.profile');
        } elseif ($logoId != 0) {
            $data['logo'] = Engine_Api::_()->storage()->get($logoId, '')->getPhotoUrl();
        } else {
            $data['logo'] = DIRECTORY_SEPARATOR . basename(APPLICATION_PATH) . '/application/modules/Sitepushnotification/externals/images/default.jpg';
        }

        $data['logo'] = Engine_Api::_()->getApi('core', 'sitepushnotification')->getPhotoUrl($data['logo']);
        $hrefLinks = explode('href', $notification->__toString());
        $hrefArray = explode('"', $hrefLinks[count($hrefLinks) - 1]);
        if (count($hrefArray) == 1)
            $hrefArray = explode('\'', $hrefArray[0]);
        $data['url'] = $this->addBaseUrl($hrefArray[1]);

        // Url arguments for safari
        $arr = explode("/", $hrefArray[1]);
        unset($arr[0]);
        unset($arr[1]);
        $str = implode('/', $arr);
        $data['args'] = explode('/', $str);


        $notificationObject = $notification->getObject();
        $tempMessage['feed_title'] = $this->getContent($notification);
        $tempMessage['object_params'] = array(
            'type' => $notificationObject->getType(),
            'id' => $notificationObject->getIdentity()
        );

        //push notification work for MLT plugin add listingtype_id in object params & send listing_id in case of sitereview_listing instead of review_id
        if (isset($tempMessage['object_params']['type']) && !empty($tempMessage['object_params']['type']) && isset($tempMessage['object_params']['id']) && !empty($tempMessage['object_params']['id']) && strstr($tempMessage['object_params']['type'], 'sitereview')) {

            if ($tempMessage['object_params']['type'] == 'sitereview_listing') {
                $sitereviewObj = Engine_Api::_()->getItem('sitereview_listing', $tempMessage['object_params']['id']);
                if (isset($sitereviewObj) && !empty($sitereviewObj)) {
                    $tempMessage['object_params']['listingtype_id'] = $sitereviewObj->listingtype_id;
                }
            } else if ($tempMessage['object_params']['type'] == 'sitereview_review') {
                $reviewObj = Engine_Api::_()->getItem('sitereview_review', $tempMessage['object_params']['id']);
                if (isset($reviewObj) && !empty($reviewObj) && !empty($reviewObj->resource_id)) {
                    $sitereviewObj = Engine_Api::_()->getItem('sitereview_listing', $reviewObj->resource_id);
                    if (isset($sitereviewObj) && !empty($sitereviewObj)) {
                        $tempMessage['object_params']['listingtype_id'] = $sitereviewObj->listingtype_id;
                        $tempMessage['object_params']['id'] = $sitereviewObj->listing_id;
                    }
                }
            }
        }
        if (isset($tempMessage['object_params']['id']) && isset($notification->type) && ($notification->type == 'friend_request'))
            $tempMessage['object_params']['id'] = $notification->subject_id;


        $data['body'] = $tempMessage['feed_title'];
        $data['tag'] = $notification['type'];
        $data['title'] = Engine_Api::_()->getApi('settings', 'core')->getSetting('sitepushnotification.sitetitle', 'New Push Notification');

        $GOOGLE_API_KEY = $this->canSendNotification(true);

        if ($data['browser'] == 'chrome' || $data['browser'] == 'mozilla' || $data['browser'] == 'opera') {
            if (!$GOOGLE_API_KEY)
                return;
            $status = Engine_Api::_()->loadClass('Sitepushnotification_Plugin_Pushnotification')->sendFcmNotification($data, $GOOGLE_API_KEY);
        } else if ($data['browser'] == 'safari') {
            $status = Engine_Api::_()->loadClass('Sitepushnotification_Plugin_Pushnotification')->sendSafariNotification($data);
        }
        $data['status'] = $status['sent'];
        // Insterting notifications and their status to notification table
//        if ($status['sent'] == 200 )
//            $data['delivered'] = 1;
//        else if ($status['sent'] == 400 ) {
//            $data['delivered'] = 0;
//            $data['error'] = $status['error'];
//        }
//        Engine_Api::_()->getApi('core', 'sitepushnotification')->saveNotificationData($data);
    }

    public function canSendNotification($returnKey = false) {
        if (!$this->_GOOGLE_API_KEY) {
            $this->_GOOGLE_API_KEY = Engine_Api::_()->getApi('settings', 'core')->getSetting("sitepushnotification.apikey");
        }

        if (!$this->_GOOGLE_API_KEY)
            return false;

        return $returnKey ? $this->_GOOGLE_API_KEY : true;
    }

    //  Sending notifications to chrome based users
    public function sendFcmNotification($data, $GOOGLE_API_KEY) {
        $fcm = new Zend_WebPush_Fcm();
        $fcm->setApiKey($GOOGLE_API_KEY);

        $messageFCM = new Zend_WebPush_Message_Fcm();
        $messageFCMData = array();
        $messageFCM->addToken($data['device_id']);
        $messageFCMData['body'] = $data['body'];
        $messageFCMData['messageType'] = "sitepushnotification";
        // $messageFCMData['sound'] = 'audios/drip.wav';

        $view = new Zend_View();
        $messageFCMData['title'] = isset($data['title']) && $data['title'] ? $data['title'] : $view->translate('new update');
        $messageFCMData['alert'] = 'default';
        $messageFCMData['click_action'] = $data['url'];
        $messageFCMData['icon'] = $data['logo'];

        $messageFCM->setData(
                $messageFCMData
        );
        return $fcm->send($messageFCM);
    }

    //  Sending notifications to safari based users
    public function sendSafariNotification($data) {
        $deviceToken = $data['device_id'];
        // Put your private key's passphrase here:
        //  $passphrase = 'bigstep';

        $cert_pem_path = APPLICATION_PATH . '/' . Engine_Api::_()->getDbtable('settings', 'core')->find('sitepushnotification.apnscertpem')->current()->value;

        if ($cert_pem_path == '0') {
            echo "Cant send notification. Certificate .pem not located ";
            return;
        }

        ////////////////////////////////////////////////////////////////////////////////
        $ctx = stream_context_create();
        stream_context_set_option($ctx, 'ssl', 'local_cert', $cert_pem_path);

        // stream_context_set_option($ctx, 'ssl', 'passphrase', '');
        // Open a connection to the APNS server
        $fp = stream_socket_client(
                'ssl://gateway.push.apple.com:2195', $err, $errstr, 60, STREAM_CLIENT_CONNECT | STREAM_CLIENT_PERSISTENT, $ctx);

        if (!$fp)
            exit("Failed to connect: $err $errstr" . PHP_EOL);

        // Create the payload body
        $body['aps'] = array(
            'alert' => array(
                "title" => $data['title'],
                "body" => $data['body']),
		"messageType" => "sitepushnotification",
            "url-args" => array()
        );

        // Encode the payload as JSON
        $payload = json_encode($body);
        // Build the binary notification
        $msg = chr(0) . pack('n', 32) . pack('H*', $deviceToken) . pack('n', strlen($payload)) . $payload;

        // Send it to the server
        $result = fwrite($fp, $msg, strlen($msg));

        if (!$result) {
            $status = '400';
        } else {
            $status = '200';
        }
        // Close the connection to the server
        fclose($fp);
        return $status;
    }

    public function addBaseUrl($url) {
        if (!preg_match("~^(?:f|ht)tps?://~i", $url)) {
            $url = $this->getHttpHostUrl() . $url;
        }
        return $url;
    }

    public function getHttpHostUrl() {
        $request = Zend_Controller_Front::getInstance()->getRequest();
        if ($request == null) {
            $request = new Zend_Controller_Request_Http();
        }

        return $request->getScheme() . '://' . $request->getHttpHost();
    }

    public function getContent($notification, $flag = false) {
        $params = array_merge(
                $notification->toArray(), (array) $notification->params, array(
            'subject' => $notification->getSubject(),
            'object' => $notification->getObject()
                )
        );

        $params['flag'] = $flag;

        return $this->assemble($notification->getTypeInfo()->body, $params);
    }

    public function assemble($body, array $params = array()) {
        $view = Zend_Registry::isRegistered('Zend_View') ? Zend_Registry::get('Zend_View') : null;
        $body = $view->translate($body);

        // Do other stuff
        preg_match_all('~\{([^{}]+)\}~', $body, $matches, PREG_SET_ORDER);
        $feedParams = array();

        foreach ($matches as $match) {
            $tag = $match[0];
            $args = explode(':', $match[1]);
            $helper = array_shift($args);

            $tempParams = $helperArgs = array();
            $tempLabel = $tempType = $tempId = '';
            foreach ($args as $arg) {
                if (substr($arg, 0, 1) === '$') {
                    $arg = substr($arg, 1);
                    $helperArgs[] = ( isset($params[$arg]) ? $params[$arg] : null );
                } else {
                    $helperArgs[] = $arg;
                    $tempLabel .= $arg;
                }
            }

            try {
                $helper = $this->getHelper($helper);
                $r = new ReflectionMethod($helper, 'direct');
                $content = $r->invokeArgs($helper, $helperArgs);
            } catch (Exception $ex) {
                return $body;
            }

            if (isset($params['flag']) && !empty($params['flag'])) { // Make a feed type body params for dynamic Feed Title
                if (isset($helperArgs[0]) && !empty($helperArgs[0])) {
                    if (is_object($helperArgs[0])) {

                        $tempParams['search'] = $tag;
                        $tempParams['label'] = (isset($helperArgs[1]) && !empty($helperArgs[1]) && is_string($helperArgs[1])) ? $helperArgs[1] : $helperArgs[0]->getTitle();
                        $tempParams['type'] = $helperArgs[0]->getType();
                        $tempParams['id'] = $helperArgs[0]->getIdentity();

                        if (isset($helperArgs[1]) && is_object($helperArgs[1]) && strstr($tag, '{actors:$subject:$object}')) {
                            $tempParams['object']['label'] = $helperArgs[1]->getTitle();
                            $tempParams['object']['type'] = $helperArgs[1]->getType();
                            $tempParams['object']['id'] = $helperArgs[1]->getIdentity();
                        }
                    } else {
                        $tempParams['search'] = $tag;
                        $tempParams['label'] = preg_replace('/<\/?a[^>]*>/', '', $helperArgs[0]);

                        // In case of GUID, create object and send respective array to client.
                        if (isset($helperArgs[0]) && !empty($helperArgs[0]) && is_string($helperArgs[0]) && strstr($helperArgs[0], '_')) {
                            $explodeItemTypes = @explode("_", $helperArgs[0]);
                            $id = @end($explodeItemTypes);
                            array_pop($explodeItemTypes);
                            $type = @implode("_", $explodeItemTypes);
                            if (!empty($type) && !empty($id)) {
                                $getObj = Engine_Api::_()->getItem($type, $id);
                                if (!empty($getObj)) {
                                    $tempParams['search'] = $tag;
                                    $tempParams['label'] = $getObj->getTitle();
                                    $tempParams['type'] = $getObj->getType();
                                    $tempParams['id'] = $getObj->getIdentity();
                                }
                            }
                        }
                    }
                    $feedParams[] = $tempParams;
                }
            } else { // Make a Feed Title
                $content = preg_replace('/\$(\d)/', '\\\\$\1', $content);
                $body = preg_replace("/" . preg_quote($tag) . "/", $content, $body, 1);
            }
        }

        if (isset($params['flag']) && !empty($params['flag'])) {
            return $feedParams;
        } else {
            $body = strip_tags($body);
            return $body;
        }
    }

    public function getHelper($name) {
        $name = $this->_normalizeHelperName($name);
        if (!isset($this->_helpers[$name])) {
            $helper = $this->getPluginLoader()->load($name);
            $this->_helpers[$name] = new $helper;
        }

        return $this->_helpers[$name];
    }

    public function _normalizeHelperName($name) {
        $name = preg_replace('/[^A-Za-z0-9]/', '', $name);
        $name = ucfirst($name);
        return $name;
    }

    public function getPluginLoader() {
        if (null === $this->_pluginLoader) {
            $path = APPLICATION_PATH . DIRECTORY_SEPARATOR . 'application' . DIRECTORY_SEPARATOR
                    . 'modules' . DIRECTORY_SEPARATOR
                    . 'Activity';
            $this->_pluginLoader = new Zend_Loader_PluginLoader(array(
                'Activity_Model_Helper_' => $path . '/Model/Helper/'
            ));
        }

        return $this->_pluginLoader;
    }

}
