<?php

/**
 * SocialEngine
 *
 * @category   Application_Extensions
 * @package    Sitereviewpaidlisting
 * @copyright  Copyright 2013-2014 BigStep Technologies Pvt. Ltd.
 * @license    http://www.socialengineaddons.com/license/
 * @version    $Id: Create.php 2014-05-19 5:40:21Z SocialEngineAddOns $
 * @author     SocialEngineAddOns
 */
class Sitereviewpaidlisting_Form_Admin_Package_Create extends Engine_Form {

  public function init() {

    $this->setTitle('Create Review Package')
            ->setDescription('Create a new listing package over here. Below, you can configure various settings for this package like videos, overview, map, etc. Please note that payment parameters (Price, Duration) cannot be edited after creation. If you wish to change these, you will have to create a new package and disable the existing one.');

    $listingtype_id = Zend_Controller_Front::getInstance()->getRequest()->getParam('listingtype_id', null);

    if (!empty($listingtype_id)) {
      if (!Engine_Api::_()->sitereviewpaidlisting()->hasPackageEnable($listingtype_id)) {
        $this->addElement('Dummy', 'dummy_text', array(
            'description' => '<div class="tip"><span>' . 'Package is not enabled for this listing type.' . '</span></div>',
            'decorators' => array(
                'ViewHelper', array(
                    'description', array('placement' => 'APPEND', 'escape' => false)
            ))
        ));
      }
    }

    $listingTypeTable = Engine_Api::_()->getDbTable('listingtypes', 'sitereview');
    $listingTypeCount = $listingTypeTable->getListingTypeCount();

    if ($listingTypeCount > 1) {
      $multiOptions = array('');
      $listingTypes = $listingTypeTable->getListingTypes();
      foreach ($listingTypes as $listingType) {
        $multiOptions["$listingType->listingtype_id"] = $listingType->title_plural;
      }

      $this->addElement('Select', 'listingtype_id', array(
          'label' => 'Listing Type',
          'description' => '',
          'onchange' => 'javascript:changeListingType(this.value);',
          'multiOptions' => $multiOptions,
      ));
    }

    // Element: title
    $this->addElement('Text', 'title', array(
        'label' => 'Package Name',
        'required' => true,
        'allowEmpty' => false,
        'filters' => array(
            'StringTrim',
        ),
    ));

    // Element: description
    $this->addElement('Textarea', 'description', array(
        'label' => 'Package Description',
        'validators' => array(
            array('StringLength', true, array(0, 250)),
        )
    ));

    // Element: level_id
    $multiOptions = array('0' => 'All Levels');
    foreach (Engine_Api::_()->getDbtable('levels', 'authorization')->fetchAll() as $level) {
      if ($level->type == 'public') {
        continue;
      }
      $multiOptions[$level->getIdentity()] = $level->getTitle();
    }
    $this->addElement('Multiselect', 'level_id', array(
        'label' => 'Member Levels',
        'description' => 'Select the Member Levels to which this Package should be available. Only users belonging to the selected Member Levels will be able to create listing of this package.',
        'attribs' => array('style' => 'max-height:100px; '),
        'multiOptions' => $multiOptions,
        'value' => array('0')
    ));

    // Element: price
    $this->addElement('Text', 'price', array(
        'label' => 'Price',
        'description' => 'The amount to charge from the listing owner. Setting this to zero will make this a free package.',
        'required' => true,
        'allowEmpty' => false,
        'validators' => array(
            array('Float', true),
            new Engine_Validate_AtLeast(0),
        ),
        'value' => '0.00',
    ));

    // Element: recurrence @ todo

    $this->addElement('Duration', 'recurrence', array(
        'label' => 'Billing Cycle',
        'description' => 'How often should Listings of this package be billed? (You can choose the payment for this package to be one-time or recurring.)',
        'required' => true,
        'allowEmpty' => false,
        'value' => array(1, 'month'),
    ));

    // Element: duration
    $this->addElement('Duration', 'duration', array(
        'label' => 'Billing Duration',
        'description' => 'When should this package expire? For one-time packages, the package will expire after the period of time set here. For recurring plans, the user will be billed at the above billing cycle for the period of time specified here.',
        'required' => true,
        'allowEmpty' => false,
        'value' => array('0', 'forever'),
    ));

    // renew
    $this->addElement('Checkbox', 'renew', array(
        'description' => 'Renew Link',
        'label' => 'Listing creators will be able to renew their listings of this package before expiry. (Note: Renewal link after expiry will only be shown for listings of paid packages, i.e., packages having a non-zero value of Price above.)',
        'value' => 0,
        'onclick' => 'javascript:setRenewBefore();',
    ));

    $this->addElement('Text', 'renew_before', array(
        'label' => 'Renewal Frame before Listing Expiry',
        'description' => 'Show listing renewal link these many days before expiry.',
        'required' => true,
        'allowEmpty' => false,
        'validators' => array(
            array('Int', true),
            new Engine_Validate_AtLeast(0),
        ),
        'value' => '0',
    ));

    // auto aprove
    $this->addElement('Checkbox', 'approved', array(
        'description' => "Auto-Approve",
        'label' => 'Auto-Approve listings of this package. These listings will not need admin moderation approval before going live.',
        'value' => 0,
    ));

    // Element:sponsored
    $this->addElement('Checkbox', 'sponsored', array(
        'description' => "Sponsored",
        'label' => 'Make listings of this package as Sponsored. Note: A change in this setting later on will only apply on new listings that are created in this package.',
        'value' => 0,
    ));

    // Element:featured
    $this->addElement('Checkbox', 'featured', array(
        'description' => "Featured",
        'label' => 'Make listings of this package as Featured. Note: A change in this setting later on will only apply on new listings that are created in this package.',
        'value' => 0,
    ));

    // Element: overview
    $this->addElement('Checkbox', 'overview', array(
        'description' => "Overview",
        'label' => 'Enable Overview for listings of this package. (Using this, users will be able to create rich profiles for their listings using WYSIWYG editor. Note: This setting is be dependent on the listing type and will only work if it is enabled from the corresponding listing type and member level setting.)',
        'value' => 0,
    ));

    // Element:map
    $this->addElement('Checkbox', 'map', array(
        'description' => "Location Map",
        'label' => 'Enable Location Map for listings of this package. (Using this, users will be able to specify detailed location for their listings and the corresponding Map will be shown on the Listing Profile. Note: This setting is be dependent on the listing type and will only work if it is enabled from the corresponding listing type.)',
        'value' => 0,
    ));

    // Element:user_review
    $this->addElement('Checkbox', 'user_review', array(
        'description' => "User Review",
        'label' => 'Enable User Review for listings of this package. (Note: This setting is be dependent on the listing type and will only work if it is enabled from the corresponding listing type and member level setting.)',
        'value' => 0,
    ));

    if(Engine_Api::_()->getApi('settings', 'core')->getSetting('sitereview.favourite', 0))
    $wishlistDescription = 'Favourite'; 
    else
    $wishlistDescription = 'Wishlist';
    
    // Element:wishlist
    $this->addElement('Checkbox', 'wishlist', array(
        'description' => $wishlistDescription,
        'label' => 'Enable Wishlist for listings of this package. (Note: This settings work as a “Favourites” if Site Admin allow users to add the listings as their favourites from Global Settings of this plugin. This setting is be dependent on the listing type and will only work if it is enabled from the corresponding listing type.)',
        'value' => 0,
    ));

    // Element : video
    $this->addElement('Radio', 'video', array(
        'label' => 'Videos',
        'description' => 'Enable Videos for listings of this package. (Note: This setting is be dependent on the listing type and will only work if it is enabled from the corresponding listing type member level setting.)',
        'multiOptions' => array(
            '1' => 'Yes',
            '0' => 'No',
        ),
        'value' => 1,
        'onclick' => 'showVideoOption(this.value)',
    ));

    // Element : video_count
    $this->addElement('text', 'video_count', array(
        'label' => 'Maximum Allowed Videos',
        'value' => 10,
        'description' => 'Please enter the number of videos which you want to be uploaded in the listigns of this package. (Note: Enter 0 for unlimited videos.)'
    ));

    // Element : photo
    $this->addElement('Radio', 'photo', array(
        'label' => 'Photos',
        'description' => 'Enable Photos for listings of this package. (Note: This setting is be dependent on the listing type and will only work if it is enabled from the corresponding listing type member level setting.)',
        'multiOptions' => array(
            '1' => 'Yes',
            '0' => 'No',
        ),
        'value' => 1,
        'onclick' => 'showPhotoOption(this.value)',
    ));

    // Element : photo_count
    $this->addElement('text', 'photo_count', array(
        'label' => 'Maximum Allowed Photos',
        'value' => 10,
        'description' => 'Please enter the number of photos which you want to be uploaded in the listigns of this package. (Note: Enter 0 for unlimited photos.)'
    ));


    // Element : profile
    $this->addElement('Radio', 'profile', array(
        'label' => 'Profile Information',
        'description' => '',
        'multiOptions' => array(
            '1' => 'Yes, allow profile information with ALL available fields.',
            '0' => 'No, do not allow profile information for listings of this package.',
            '2' => 'Yes, allow profile information with RESTRICTED fields. (Below, you can choose the profile fields that should be available. With this configuration, you can give access to more profile fields to packages of higher cost.)',
        ),
        'value' => 1,
        'onclick' => 'showprofileOption(this.value)',
    ));

    //Add Dummy element for using the tables
    $this->addElement('Dummy', 'profilefield', array(
        'ignore' => true,
        'decorators' => array(array('ViewScript', array(
                    'viewScript' => '_profilefield.tpl',
                    'class' => 'form element'
            )))
    ));

    $this->addElement('Checkbox', 'update_list', array(
        'description' => 'Show in "Other available Packages" List',
        'label' => "Show this package in the list of 'Other available Packages' which gets displayed to the users for upgrading the package of a Listing at Listing dashboard. (This will be useful in case you are creating a free package or a test package and you want it to be used by the users only once for a limited period of time and do not want to show it during package upgrdation.)",
        'value' => 1,
    ));
    // Element: enabled
    $this->addElement('hidden', 'enabled', array(
        'order' => 6001,
        'value' => 1,
    ));

    // CUSTOM WORK
    $this->addElement('Text', 'max_listing', array(
        'label' => 'Maximum Allowed listing in this package',
        'value' => 0,
        'description' => 'Please enter the maximum number of listing which you want to create in the listings of this package. Enter 0 for unlimited packages.',
    ));
    // CUSTOM WORK

    // Element: execute
    $this->addElement('Button', 'execute', array(
        'label' => 'Create Package',
        'type' => 'submit',
        'ignore' => true,
        'decorators' => array('ViewHelper'),
    ));

    // Element: cancel
    $this->addElement('Cancel', 'cancel', array(
        'label' => 'cancel',
        'prependText' => ' or ',
        'ignore' => true,
        'link' => true,
        'href' => Zend_Controller_Front::getInstance()->getRouter()->assemble(array('action' => 'index', 'package_id' => null)),
        'decorators' => array('ViewHelper'),
    ));

    // DisplayGroup: buttons
    $this->addDisplayGroup(array('execute', 'cancel'), 'buttons', array(
        'decorators' => array(
            'FormElements',
            'DivDivDivWrapper',
        )
    ));

    if (!empty($listingtype_id)) {
      if (!Engine_Api::_()->sitereviewpaidlisting()->hasPackageEnable($listingtype_id)) {
        $this->getElement('execute')
                ->setIgnore(true)
                ->setAttrib('disable', true)
                ->clearValidators()
                ->setRequired(false)
                ->setAllowEmpty(true)
        ;
      }
    }
  }

}