<?php

/**
 * SocialEngine
 *
 * @category   Application_Extensions
 * @package    Sitereviewpaidlisting
 * @copyright  Copyright 2013-2014 BigStep Technologies Pvt. Ltd.
 * @license    http://www.socialengineaddons.com/license/
 * @version    $Id: PaymentController.php 2014-05-19 5:40:21Z SocialEngineAddOns $
 * @author     SocialEngineAddOns
 */
class Sitereviewpaidlisting_PaymentController extends Core_Controller_Action_Standard {

	/**
	 * @var User_Model_User
	 */
	protected $_user;

	/**
	 * @var Zend_Session_Namespace
	 */
	protected $_session;

	/**
	 * @var Payment_Model_Order
	 */
	protected $_order;

	/**
	 * @var Payment_Model_Gateway
	 */
	protected $_gateway;

	/**
	 * @var Sitereview_Model_Listing
	 */
	protected $_listing;

	/**
	 * @var Payment_Model_Package
	 */
	protected $_package;
	protected $_success;
	protected $_listingtypeId;

	public function init() {

		// Get user and session
		$this->_user = Engine_Api::_()->user()->getViewer();

		$this->view->listingtype_id = $this->_listingtypeId = $this->_getParam('listingtype_id', null);
		if ($this->_listingtypeId != -1 && !empty($this->_listingtypeId)) {

			//AUTHORIZATION CHECK
			if (!$this->_helper->requireAuth()->setAuthParams('sitereview_listing', null, "view_listtype_$this->_listingtypeId")->isValid()) {
				return;
			}

		}

		// If no user, redirect to home?
		if (!$this->_user || !$this->_user->getIdentity()) {
			return $this->_helper->redirector->gotoRoute(array('action' => 'manage'), "sitereview_general_listtype_$this->_listingtypeId", true);
		}
		// If there are no enabled gateways or packages, disable
		if (Engine_Api::_()->getDbtable('gateways', 'payment')->getEnabledGatewayCount() <= 0 ||
			Engine_Api::_()->getDbtable('packages', 'sitereviewpaidlisting')->getEnabledNonFreePackageCount() <= 0) {
			return $this->_forward('show-error');
		}
		$this->_session = new Zend_Session_Namespace('Payment_Sitereview');
		$this->_success = new Zend_Session_Namespace('Payment_Sitereview_Success');
	}

	public function indexAction() {
		return $this->_forward('gateway');
	}

	public function showErrorAction() {
		// Get navigation
		$this->view->navigation = $navigation = Engine_Api::_()->getApi('menus', 'core')
			->getNavigation("sitereview_main_listtype_$this->_listingtypeId");
		if (Engine_Api::_()->getDbtable('gateways', 'payment')->getEnabledGatewayCount() <= 0) {
			$this->view->show = 1;
		} else {
			$this->view->show = 0;
		}

		// Hide siteevent navigation in case of webview for native app.
		$this->view->hideNavigation = 0;
		$session = new Zend_Session_Namespace();
		if (isset($session->hideHeaderAndFooter) && !empty($session->hideHeaderAndFooter) && $session->hideHeaderAndFooter == true) {
			$this->view->hideNavigation = 1;
		}
	}

	public function gatewayAction() {
		// Get subscription
		$listingId = $this->_getParam('listing_id', $this->_session->listing_id);
		if (!$listingId ||
			!($listing = Engine_Api::_()->getItem('sitereview_listing', $listingId))) {
			return $this->_helper->redirector->gotoRoute(array('action' => 'manage'), "sitereview_general_listtype_$this->_listingtypeId", true);
		}
		$this->view->listing = $listing;
		$this->view->title_singular = lcfirst(Engine_Api::_()->getDbTable('listingtypes', 'sitereview')->getListingTypeColumn($this->_listingtypeId, 'title_singular'));
		$this->view->title_singular_uc = ucfirst(Engine_Api::_()->getDbTable('listingtypes', 'sitereview')->getListingTypeColumn($this->_listingtypeId, 'title_singular'));
		$this->view->title = Engine_Api::_()->getDbTable('listingtypes', 'sitereview')->getListingTypeColumn($this->_listingtypeId, 'title_plural');

		// Check subscription status
		if ($this->_checkListingStatus($listing)) {
			return;
		}

		// Get subscription
		if (!$this->_user ||
			!($listingId = $this->_getParam('listing_id', $this->_session->listing_id)) ||
			!($listing = Engine_Api::_()->getItem('sitereview_listing', $listingId)) || !($package = Engine_Api::_()->getItem('sitereviewpaidlisting_package', $listing->package_id))) {
			return $this->_helper->redirector->gotoRoute(array('action' => 'manage'), "sitereview_general_listtype_$this->_listingtypeId", true);
		}
		$this->view->listing = $listing;
		$this->view->package = $package;

		// Unset certain keys
		unset($this->_session->gateway_id);
		unset($this->_session->order_id);

		// Hide siteevent navigation in case of webview for native app.
		$this->view->hideNavigation = 0;
		$session = new Zend_Session_Namespace();
		if (isset($session->hideHeaderAndFooter) && !empty($session->hideHeaderAndFooter) && $session->hideHeaderAndFooter == true) {
			$this->view->hideNavigation = 1;
		}

		// Gateways
		$gatewayTable = Engine_Api::_()->getDbtable('gateways', 'payment');
		$gatewaySelect = $gatewayTable->select()
			->where('enabled = ?', 1)
		;
		$gateways = $gatewayTable->fetchAll($gatewaySelect);

		$gatewayPlugins = array();
		foreach ($gateways as $gateway) {
			if ($gateway->plugin == 'Sitegateway_Plugin_Gateway_MangoPay') {
				continue;
			}

			// Check billing cycle support
			if (!$package->isOneTime()) {
				$sbc = $gateway->getGateway()->getSupportedBillingCycles();

				if ($gateway->plugin == 'Payment_Plugin_Gateway_Bank' || $gateway->plugin == 'Payment_Plugin_Gateway_Cheque' || $gateway->plugin == 'Payment_Plugin_Gateway_Cash') {
					continue;
				}
				
				if (!in_array($package->recurrence_type, array_map('strtolower', $sbc))) {
					continue;
				}
			}
			$gatewayPlugins[] = array(
				'gateway' => $gateway,
				'plugin' => $gateway->getGateway(),
			);
		}
		$this->view->gateways = $gatewayPlugins;
		$this->view->navigation = $navigation = Engine_Api::_()->getApi('menus', 'core')
			->getNavigation("sitereview_main_listtype_$this->_listingtypeId");

		$viewer_id = Engine_Api::_()->user()->getViewer()->getIdentity();
		$creditAllow = false;
		$isSitecreditEnabled = Engine_Api::_()->getDbtable("modules", "core")->isModuleEnabled("sitecredit");

		if ($isSitecreditEnabled) {

			if (!empty($viewer_id)) {

				$CreditModuleTable = Engine_Api::_()->getDbtable('modules', 'sitecredit');
				$select = $CreditModuleTable->select()->where('name = ?', 'sitereviewpaidlisting')->where('flag=?', 'package');
				$creditModuleAllow = $CreditModuleTable->fetchRow($select);

				if (!empty($creditModuleAllow->integrated)) {
					$creditAllow = true;
					$creditLimit = $creditModuleAllow->percentage_checkout;
					if (empty($creditLimit)) {
						$creditAllow = false;
					} else {
						$creditValue = Engine_Api::_()->getApi('settings', 'core')->getSetting('sitecredit.value', 0);
						$this->view->maxcredit = @round($creditValue * (($package->price * $creditLimit) / 100));
					}
				}
			}
		}

		$creditSession = new Zend_Session_Namespace('credit_package_payment_' . $package->getType());

		if (!empty($creditSession->packagePaymentCreditDetail)) {
			$creditSession->packagePaymentCreditDetail = null;
		}

		$this->view->creditAllow = $creditAllow;

	}

	public function processAction() {

		//GET GATEWAY
		$gatewayId = $this->_getParam('gateway_id', $this->_session->gateway_id);
		if (!$gatewayId ||
			!($gateway = Engine_Api::_()->getItem('sitereviewpaidlisting_gateway', $gatewayId)) ||
			!($gateway->enabled)) {
			return $this->_helper->redirector->gotoRoute(array('action' => 'gateway'));
		}
		$this->view->gateway = $gateway;

		//GET SUBSCRIPTION
		$listingId = $this->_getParam('listing_id', $this->_session->listing_id);
		if (!$listingId ||
			!($listing = Engine_Api::_()->getItem('sitereview_listing', $listingId))) {
			return $this->_helper->redirector->gotoRoute(array('action' => 'manage'), "sitereview_general_listtype_$this->_listingtypeId", true);
		}
		$this->view->listing = $listing;

		//GET PACKAGE
		$package = $listing->getPackage();
		if (!$package || $package->isFree()) {
			return $this->_helper->redirector->gotoRoute(array('action' => 'manage'), "sitereview_general_listtype_$this->_listingtypeId", true);
		}
		$this->view->package = $package;

		//CHECK SUBSCRIPTION?
		if ($this->_checkListingStatus($listing)) {
			return;
		}
		if (Engine_Api::_()->getDbtable('modules', 'core')->isModuleEnabled('sitecredit')) {
			$creditSession = new Zend_Session_Namespace('credit_package_payment_' . $package->getType());

			if (!empty($creditSession->packagePaymentCreditDetail)) {
				$creditDetail = unserialize($creditSession->packagePaymentCreditDetail);

				$discount_value = $creditDetail['credit_amount'];
				$totalValue = $package->price - $discount_value;
				$package->price = @round($totalValue, 2);
			}

		}
		//PROCESS
		//CREATE ORDER
		$ordersTable = Engine_Api::_()->getDbtable('orders', 'payment');
		if (!empty($this->_session->order_id)) {
			$previousOrder = $ordersTable->find($this->_session->order_id)->current();
			if ($previousOrder && $previousOrder->state == 'pending') {
				$previousOrder->state = 'incomplete';
				$previousOrder->save();
			}
		}
		$ordersTable->insert(array(
			'user_id' => $this->_user->getIdentity(),
			'gateway_id' => $gateway->gateway_id,
			'state' => 'pending',
			'creation_date' => new Zend_Db_Expr('NOW()'),
			'source_type' => 'sitereview_listing',
			'source_id' => $listing->listing_id,
		));
		$this->_session->order_id = $order_id = $ordersTable->getAdapter()->lastInsertId();

		//UNSET CERTAIN KEYS
		unset($this->_session->package_id);
		unset($this->_session->listing_id);
		unset($this->_session->gateway_id);

		//GET GATEWAY PLUGIN
		$this->view->gatewayPlugin = $gatewayPlugin = $gateway->getGateway();
		$plugin = $gateway->getPlugin();

		//PREPARE HOST INFO
		$schema = 'http://';
		if (!empty($_ENV["HTTPS"]) && 'on' == strtolower($_ENV["HTTPS"])) {
			$schema = 'https://';
		}
		$host = $_SERVER['HTTP_HOST'];

		//PREPARE TRANSACTION
		$sitereviewlistingTypeTable = Engine_Api::_()->getDbtable('listingtypes', 'sitereview');
		$listingTypeTitle = $sitereviewlistingTypeTable->select()
			->from($sitereviewlistingTypeTable->info('name'), 'title_singular')
			->where('listingtype_id = ?', $listing->listingtype_id)
			->limit(1)
			->query()
			->fetchColumn();

		if (Engine_Api::_()->hasModuleBootstrap('sitecredit')) {
			//SESSION SET OF CREDITS.
			$creditSession = new Zend_Session_Namespace('credit_package_payment_' . $package->getType());

			if (!empty($creditSession->packagePaymentCreditDetail)) {
				$creditDetail = unserialize($creditSession->packagePaymentCreditDetail);

				if (empty($package->price)) {
					$order = Engine_Api::_()->getItem('payment_order', $order_id);
					$listing_user = $order->getUser();
					$listing_list = $order->getSource();
					$listing_package = $listing_list->getPackage();
					$order->state = 'complete';
					$order->save();
					$listing_list->onPaymentSuccess();
					if ($listing_list->didStatusChange()) {
						// SEND ACTIVE MAIL HERE
						Engine_Api::_()->sitepage()->sendMail("ACTIVE", $listing_list->listing_id);
					}
					$param['type_id'] = $order->order_id;
					$param['credit_point'] = -$creditDetail['credit_points'];
					$param['type'] = strtolower($listing_package->getType());
					$param['reason'] = 'used credits for package purchase';
					$param['resource_type'] = $order->source_type;
					$param['resource_id'] = $order->source_id;
					$credit_table = Engine_Api::_()->getDbtable('credits', 'sitecredit');
					$credit_table->insertCredit($param);
					$creditSession->packagePaymentCreditDetail = null;
					$this->_listing = $listing_list;
					$this->_success->succes_id = $listing_list->listing_id;
					return $this->_finishPayment('active');
				}
			}
		}

		$params = array();
		$params['title_singular'] = $listingTypeTitle;
		$params['language'] = $this->_user->language;
		$localeParts = explode('_', $this->_user->language);
		if (count($localeParts) > 1) {
			$params['region'] = $localeParts[1];
		}
		$params['vendor_order_id'] = $order_id;
		$this->view->returnUrl = $params['return_url'] = $schema . $host
		. $this->view->url(array('action' => 'return', 'controller' => 'payment', 'module' => 'sitereviewpaidlisting'), 'default')
		. '?order_id=' . $order_id
		. '&listingtype_id=' . $this->_listingtypeId
			. '&state=' . 'return';
		$params['cancel_url'] = $schema . $host
		. $this->view->url(array('action' => 'return', 'controller' => 'payment', 'module' => 'sitereviewpaidlisting'), 'default')
		. '?order_id=' . $order_id
		. '&listingtype_id=' . $this->_listingtypeId
			. '&state=' . 'cancel';
		$params['ipn_url'] = $schema . $host
		. $this->view->url(array('action' => 'index', 'controller' => 'ipn', 'module' => 'sitereviewpaidlisting'), 'default')
		. '?listingtype_id=' . $this->_listingtypeId
			. '&order_id=' . $order_id;
		//PROCESS TRANSACTION
		$transaction = $plugin->createListingTransaction($this->_user, $listing, $package, $params);

		//PULL TRANSACTION PARAMS
		$this->view->transactionUrl = $transactionUrl = $gatewayPlugin->getGatewayUrl();
		$this->view->transactionMethod = $transactionMethod = $gatewayPlugin->getGatewayMethod();
		$this->view->transactionData = $transactionData = $transaction->getData();

		//HANDLE REDIRECTION
		if ($transactionMethod == 'GET') {
			$transactionUrl .= '?' . http_build_query($transactionData);
			return $this->_helper->redirector->gotoUrl($transactionUrl, array('prependBase' => false));
		}

		//POST WILL BE HANDLED BY THE VIEW SCRIPT
	}

	public function returnAction() {

		//GET ORDER
		if (!$this->_user ||
			!($orderId = $this->_getParam('order_id', $this->_session->order_id)) ||
			!($order = Engine_Api::_()->getItem('payment_order', $orderId)) ||
			$order->user_id != $this->_user->getIdentity() ||
			$order->source_type != 'sitereview_listing' ||
			!($listing = $order->getSource()) ||
			!($package = $listing->getPackage()) ||
			!($gateway = Engine_Api::_()->getItem('sitereviewpaidlisting_gateway', $order->gateway_id))) {
			return $this->_helper->redirector->gotoRoute(array('action' => 'manage'), "sitereview_general_listtype_$this->_listingtypeId", true);
		}

		$this->_listing = $listing;
		//GET GATEWAY PLUGIN
		$this->view->gatewayPlugin = $gatewayPlugin = $gateway->getGateway();
		$plugin = $gateway->getPlugin();

		//PROCESS RETURN
		unset($this->_session->errorMessage);
		try {
			$status = $plugin->onPageTransactionReturn($order, $this->_getAllParams());
		} catch (Payment_Model_Exception $e) {
			$status = 'failure';
			$this->_session->errorMessage = $e->getMessage();
		}
		$this->_success->succes_id = $listing->listing_id;
		return $this->_finishPayment($status);
	}

	public function finishAction() {

		$this->view->status = $status = $this->_getParam('state');
		$this->view->listingtype_id = $listingtype_id = $this->_listingtypeId;
		$listingTypeTable = Engine_Api::_()->getDbTable('listingtypes', 'sitereview');
		$this->view->title_plural = $listingTypeTable->getListingTypeColumn($listingtype_id, 'title_plural');
		$this->view->title_singular = $listingTypeTable->getListingTypeColumn($listingtype_id, 'title_singular');
		$this->view->title = Engine_Api::_()->getDbTable('listingtypes', 'sitereview')->getListingTypeColumn($listingtype_id, 'title_plural');
		$this->view->error = $this->_session->errorMessage;
		$this->view->navigation = $navigation = Engine_Api::_()->getApi('menus', 'core')
			->getNavigation("sitereview_main_listtype_$this->_listingtypeId");

		// Hide form buttons in case of webview for native app.
		$this->view->hideButtons = false;
		$session = new Zend_Session_Namespace();
		if (isset($session->hideHeaderAndFooter) && !empty($session->hideHeaderAndFooter)) {
			$this->view->hideButtons = true;
		}

		if (isset($this->_success->succes_id)) {
			$this->view->id = $this->_success->succes_id;
			unset($this->_success->succes_id);
		}
	}

	protected function _checkListingStatus(
		Zend_Db_Table_Row_Abstract $listing = null) {
		if (!$this->_user) {
			return false;
		}

		if (null == $listing) {
			$listing = Engine_Api::_()->getItem('sitereview_listing', $this->_session->listing_id);
		}

		if ($listing->getPackage()->isFree()) {
			$this->_finishPayment('free');
			return true;
		}

		return false;
	}

	protected function _finishPayment($state = 'active') {

		$listingtype_id = $this->_listing->listingtype_id;

		//REDIRECT
		if ($state == 'free') {
			return $this->_helper->redirector->gotoRoute(array('action' => 'manage'), "sitereview_general_listtype_$listingtype_id", true);
		} else {
			return $this->_helper->redirector->gotoRoute(array('action' => 'finish', 'controller' => 'payment', 'state' => $state), "sitereviewpaidlisting_extended_listtype_$listingtype_id", true);
		}
	}

}
