<?php

/**
 * SocialEngine
 *
 * @category   Application_Theme
 * @package    Siteshortcut
 * @copyright  Copyright 2017-2018 BigStep Technologies Pvt. Ltd.
 * @license    http://www.socialengineaddons.com/license/
 * @version    $Id: Shortcuts.php 2017-12-15 00:00:00 SocialEngineAddOns $
 * @author     SocialEngineAddOns
 */
class Siteshortcut_Model_DbTable_Shortcuts extends Engine_Db_Table
{
  public function addToShortcut($params = array())
  {
    if( empty($params['resource_type']) && empty($params['resource_id']) && empty($params['user_id']) ) {
      return;
    }
    if( $this->isAdded($params) ) {
      return;
    }
    $this->insert($params);
  }

  public function deleteFromShortcut($params = array())
  {
    if( empty($params['resource_type =?']) && empty($params['resource_id =?']) && empty($params['user_id =?']) ) {
      return;
    }
    $this->delete($params);
  }

  public function isAdded($params = array())
  {
    $shortcut_id = $this->select()->from($this->info('name'), array('shortcut_id'))
      ->where('resource_type =?', $params['resource_type'])
      ->where('resource_id =?', $params['resource_id'])
      ->where('user_id =?', $params['user_id'])
      ->limit(1)
      ->query()
      ->fetchColumn();
    if( empty($shortcut_id) ) {
      return false;
    }
    return ture;
  }

  public function getUserShortcuts($viewer)
  {
    if( empty($viewer->getIdentity()) ) {
      return array();
    }
    $select = $this->select()
      ->where('user_id =?', $viewer->getIdentity());
    return $this->fetchAll($select);
  }

  public function getUserResourceBaseShortcuts($viewer)
  {
    $data = array();
    $settings = Engine_Api::_()->getApi('settings', 'core');
    $max = $settings->getSetting('siteshortcut.item.max', 10);
    if( Engine_Api::_()->authorization()->isAllowed('siteshortcut', null, 'add') ) {
      foreach( $this->getUserShortcuts($viewer) as $row ) {
        if( !empty($data[$row->resource_type]) && count($data[$row->resource_type]['items']) >= $max ) {
          continue;
        }
        if( !Engine_Api::_()->hasItemType($row->resource_type) ) {
          continue;
        }
        $item = Engine_Api::_()->getItem($row->resource_type, $row->resource_id);
        if( empty($item) ) {
          continue;
        }
        $resource_type = $row->resource_type ==  'sitereview_listing' ? $row->resource_type . 'type_' . $row->resource_id :  $row->resource_type;
        $data[$resource_type]['headding'] = $item->getShortType(true);
        $data[$resource_type]['items'][$item->getGuid()] = $item;
        $data[$resource_type]['itemsAdded'][] = $item->getGuid();
      }
    }

    foreach( $this->suggestItemAction($viewer) as $key => $row ) {
      $data[$key]['headding'] = $row['headding'];
      foreach( $row['items'] as $guid => $item ) {
        if( !empty($data[$key]['items']) && count($data[$key]['items']) >= $max ) {
          break;
        }
        if( !empty($data[$key]['items'][$guid]) ) {
          continue;
        }
        $data[$key]['items'][$guid] = $item;
      }
    }
    return $data;
  }

  public function suggestItemAction($viewer)
  {
    $shortcutTypes = Engine_Api::_()->getDbtable('shortcuttypes', 'siteshortcut')->getEnableShortcutTypes();
    $data = array();

    if( !Engine_Api::_()->authorization()->isAllowed('siteshortcut', null, 'auto') ) {
      return $data;
    }
    $settings = Engine_Api::_()->getApi('settings', 'core');
    $max = $settings->getSetting('siteshortcut.item.max', 5);
    foreach( $shortcutTypes as $shortcutType ) {
      $itemType = $shortcutType->type;
      $itemType = stripos($itemType, '_listingtype_') !== false ? 'sitereview_listing' : $itemType;
      $params = $shortcutType->params;

      $itemTable = Engine_Api::_()->getItemTable($itemType);
      $select = $itemTable->select();
      if( $itemType == 'sitereview_listing' ) {
        $select->where("listingtype_id = ? ", str_replace('sitereview_listingtype_', '', $shortcutType->type));
      }
      $shortcutAllow = $shortcutType->shortcut_allow;

      $itemIds = array();
      $primaryInfo = $itemTable->info('primary');
      if( !empty($params['membership']) && $shortcutAllow === 'member' ) {
        $itemIds = Engine_Api::_()->getDbtable('membership', $shortcutType->module_name)->getMembershipsOfIds($viewer);
      } else if( !empty($params['admin']) && $shortcutAllow === 'admin' ) {
        $itemIds = $this->getAdminsContentIds($shortcutType);
      }
      if( !empty($itemIds) ) {
        $select->where("{$params['owner']} = " . $viewer->getIdentity() . " OR {$primaryInfo[1]} IN (?)", (array) $itemIds);
      } else {
        $select->where("{$params['owner']} = ?", $viewer->getIdentity());
      }
      //$select->order($title);
      $select->limit($max);
      $contents = $itemTable->fetchAll($select);
      foreach( $contents as $content ) {
        $data[$shortcutType->type]['headding'] = $shortcutType->title;
        $data[$shortcutType->type]['items'][$content->getGuid()] = $content;
      }
    }
    return $data;
  }

  private function getAdminsContentIds($shortcutType)
  {
    $module = $shortcutType->module_name;
    $type = $shortcutType->type;
    $viewer = Engine_Api::_()->user()->getViewer();
    $manageAdmins = array(
      'sitepage_page' => 'getManageAdminPages',
      'sitegroup_group' => 'getManageAdminGroups',
      'sitestore_store' => 'getManageAdminStores',
      'sitebusiness_business' => 'getManageAdminBusinesses',
    );
    if( in_array($type, array_keys($manageAdmins)) ) {
      $table = Engine_Api::_()->getDbtable('manageadmins', $module);
      $result = call_user_func_array(array(
        $table, $manageAdmins[$type]), array($viewer->getIdentity()));
      $ids = array();
      foreach( $result as $row ) {
        $rowArray = $row->toArray();
        $ids[] = array_shift($rowArray);
      }
      return $ids;
    }
    if( !in_array($type, array('group', 'siteevent_event', 'forum')) ) {
      return array();
    }
    $listTable = Engine_Api::_()->getDbtable('lists', $module);
    $listTableName = $listTable->info('name');
    $list = $listTable->fetchNew();
    $listItemTableName = $list->getListItemTable()->info('name');
    $select = $list->select()
      ->from($listTableName)
      ->join($listItemTableName, "`{$listTableName}`.`list_id` = `{$listItemTableName}`.`list_id`", null)
      ->where('child_id = ?', $viewer->getIdentity());
    $result = $listTable->fetchAll($select);
    $ids = array();
    foreach( $result as $row ) {
      $ids[] = $row->owner_id;
    }
    return $ids;
  }

}
