<?php

class Sitestore_PackageController extends Siteapi_Controller_Action_Standard {

    public function indexAction() {
        if (!Zend_Registry::isRegistered('Zend_Translate'))
            Engine_Api::_()->getApi('Core', 'siteapi')->setTranslate();

        Engine_Api::_()->getApi('Core', 'siteapi')->setView();
        Engine_Api::_()->getApi('Core', 'siteapi')->setLocal();

        //USER VALIDATON
        if (!$this->_helper->requireUser()->isValid())
            $this->respondwitherror('unauthorized');

        //STORE CREATION PRIVACY
        if (!$this->_helper->requireAuth()->setAuthParams('sitestore_store', null, 'create')->isValid())
            $this->respondwitherror('unauthorized');

        if (!Engine_Api::_()->sitestore()->hasPackageEnable()) {
            $this->respondwitherror('unauthorized');
        }

        $viewer = Engine_Api::_()->user()->getViewer();
        $viewer_id = $viewer->getIdentity();

        if (!$viewer_id)
            $this->respondwitherror('unauthorized');

        $bodyParams = array();
        $packageInfoArray = Engine_Api::_()->getApi('settings', 'core')->getSetting('sitestore.package.information', array('price', 'billing_cycle', 'duration', 'featured', 'sponsored', 'tellafriend', 'print', 'overview', 'map', 'insights', 'contactdetails', 'sendanupdate', 'apps', 'description', 'twitterupdates', 'ads'));
        $currency = Engine_Api::_()->getApi('settings', 'core')->getSetting('payment.currency', 'USD');
        $package_id = $this->getRequestParam('package_id', 0);


        try {


            if (Engine_Api::_()->sitestore()->hasPackageEnable()) {
                $packages_select = Engine_Api::_()->getItemtable('sitestore_package')->getPackagesSql(null);
                $paginator = Zend_Paginator::factory($packages_select);
                $getPaginatorCount = $paginator->getTotalItemCount();
                $bodyParams["getTotalItemCount"] = $paginator->getTotalItemCount();
                foreach ($paginator as $package) {
                    $packageShowArray = array();

                    if (isset($package->package_id) && !empty($package->package_id))
                        $packageShowArray['package_id'] = $package->package_id;

                    if (isset($package->title) && !empty($package->title)) {
                        $packageShowArray['title']['label'] = $this->translate('Title');
                        $packageShowArray['title']['value'] = $this->translate($package->title);
                    }

                    if (in_array('price', $packageInfoArray)) {
                        if ($package->price > 0.00) {
                            $packageShowArray['price']['label'] = $this->translate('Price');
                            $packageShowArray['price']['value'] = $package->price;
                            $packageShowArray['price']['currency'] = Engine_Api::_()->getApi('settings', 'core')->getSetting('payment.currency', 'USD');
                        } else {
                            $packageShowArray['price']['label'] = $this->translate('Price');
                            $packageShowArray['price']['value'] = $this->translate('FREE');
                        }
                    }


                    if (in_array('billing_cycle', $packageInfoArray)) {
                        $packageShowArray['billing_cycle']['label'] = $this->translate('Billing Cycle');
                        $packageShowArray['billing_cycle']['value'] = $package->getBillingCycle();
                    }
                    if (in_array('duration', $packageInfoArray)) {
                        $packageShowArray['duration']['label'] = $this->translate("Duration");
                        $packageShowArray['duration']['value'] = $package->getPackageQuantity();
                    }

                    if (in_array('featured', $packageInfoArray)) {
                        if ($package->featured == 1) {
                            $packageShowArray['featured']['label'] = $this->translate('Featured');
                            $packageShowArray['featured']['value'] = $this->translate('Yes');
                        } else {
                            $packageShowArray['featured']['label'] = $this->translate('Featured');
                            $packageShowArray['featured']['value'] = $this->translate('No');
                        }
                    }

                    if (in_array('sponsored', $packageInfoArray)) {
                        if ($package->sponsored == 1) {
                            $packageShowArray['Sponsored']['label'] = $this->translate('Sponsored');
                            $packageShowArray['Sponsored']['value'] = $this->translate('Yes');
                        } else {
                            $packageShowArray['Sponsored']['label'] = $this->translate('Sponsored');
                            $packageShowArray['Sponsored']['value'] = $this->translate('No');
                        }
                    }

                    if (in_array('rich_overview', $packageInfoArray) && ($overview && (empty($level_id) || Engine_Api::_()->authorization()->getPermission($level_id, 'siteevent_event', "overview")))) {
                        if ($package->overview == 1) {
                            $packageShowArray['rich_overview']['label'] = $this->translate('Rich Overview');
                            $packageShowArray['rich_overview']['value'] = $this->translate('Yes');
                        } else {
                            $packageShowArray['rich_overview']['label'] = $this->translate('Rich Overview');
                            $packageShowArray['rich_overview']['value'] = $this->translate('No');
                        }
                    }

                    if (in_array('videos', $packageInfoArray) && (empty($level_id) || Engine_Api::_()->authorization()->getPermission($level_id, 'siteevent_event', "video"))) {
                        if ($package->video == 1) {
                            if ($package->video_count) {
                                $packageShowArray['videos']['label'] = $this->translate('Videos');
                                $packageShowArray['videos']['value'] = $package->video_count;
                            } else {
                                $packageShowArray['videos']['label'] = $this->translate('Videos');
                                $packageShowArray['videos']['value'] = $this->translate("Unlimited");
                            }
                        } else {
                            $packageShowArray['videos']['label'] = $this->translate('Videos');
                            $packageShowArray['videos']['value'] = $this->translate('No');
                        }
                    }

                    if (in_array('photos', $packageInfoArray) && (empty($level_id) || Engine_Api::_()->authorization()->getPermission($level_id, 'siteevent_event', "photo"))) {
                        if ($package->photo == 1) {
                            if ($packagem->photo_count) {
                                $packageShowArray['photos']['label'] = $this->translate('Photos');
                                $packageShowArray['photos']['value'] = $package->photo_count;
                            } else {
                                $packageShowArray['photos']['label'] = $this->translate('Photos');
                                $packageShowArray['photos']['value'] = $this->translate("Unlimited");
                            }
                        } else {
                            $packageShowArray['photos']['label'] = $this->translate('Photos');
                            $packageShowArray['photos']['value'] = $this->translate('No');
                        }
                    }


                    if (in_array('description', $packageInfoArray)) {
                        $packageShowArray['description']['label'] = $this->translate("Description");
                        $packageShowArray['description']['value'] = $this->translate($package->description);
                    }

                    $packageArray["package"] = $packageShowArray;
                    $tempMenu = array();
                    $tempMenu[] = array(
                        'label' => $this->translate('Create Store'),
                        'name' => 'create',
                        'url' => 'sitestore/create',
                        'urlParams' => array(
                            'package_id' => $package->package_id
                        )
                    );
                    $tempMenu[] = array(
                        'label' => $this->translate('Package Info'),
                        'name' => 'package_info',
                        'url' => 'sitestore/package/index',
                        'urlParams' => array(
                            'package_id' => $package->package_id
                        )
                    );

                    $packageArray['menu'] = $tempMenu;
                    $bodyParams['response'][] = $packageArray;
                }

                if (isset($bodyParams) && !empty($bodyParams))
                    $this->respondWithSuccess($bodyParams);
            }
            else {
                $bodyParams['getTotalItemCount'] = 0;
                $this->respondWithSuccess($bodyParams);
            }
        } catch (Exception $ex) {
            $this->respondWithValidationError("internal_server_error", $ex->getMessage());
        }
    }

    public function upgradePackageAction() {
        //USER VALIDATON
        if (!Zend_Registry::isRegistered('Zend_Translate'))
            Engine_Api::_()->getApi('Core', 'siteapi')->setTranslate();

        Engine_Api::_()->getApi('Core', 'siteapi')->setView();
        Engine_Api::_()->getApi('Core', 'siteapi')->setLocal();
        //USER VALIDATON
        if (!$this->_helper->requireUser()->isValid())
            $this->respondwitherror('unauthorized');
        $viewer = Engine_Api::_()->user()->getViewer();

        $viewer_id = $viewer->getIdentity();

        //GET USER LEVEL ID
        if (!empty($viewer_id)) {
            $level_id = $viewer->level_id;
        } else {
            $level_id = Engine_Api::_()->getDbtable('levels', 'authorization')->fetchRow(array('type = ?' => "public"))->level_id;
        }

        //PACKAGE ENABLE VALIDATION
        if (!Engine_Api::_()->sitestore()->hasPackageEnable()) {
            $this->respondWithError('no_record');
        }

        //GET STORE ID STORE OBJECT AND THEN CHECK VALIDATIONS
        $store_id = $this->_getParam('store_id');
        if (empty($store_id)) {
            $this->respondWithError('no_record');
        }
        $sitestore = Engine_Api::_()->getItem('sitestore_store', $store_id);
        if (empty($sitestore)) {
            $this->respondWithError('no_record');
        }

        //START MANAGE-ADMIN CHECK
        $isManageAdmin = Engine_Api::_()->sitestore()->isManageAdmin($sitestore, 'edit');
        if (empty($isManageAdmin)) {
            $this->respondwitherror('unauthorized');
        }
        //END MANAGE-ADMIN CHECK
        //Start Coupon plugin work.
        $couponEnabled = Engine_Api::_()->getDbtable('modules', 'core')->isModuleEnabled('sitecoupon');
        if (!empty($couponEnabled)) {
            $modules_enabled = Engine_Api::_()->getApi('settings', 'core')->getSetting('modules.enabled');
            if (!empty($modules_enabled)) {
                $modules_enabled = unserialize($modules_enabled);
            }
        }
        //End coupon plugin work.

        $package_view = Engine_Api::_()->getApi('settings', 'core')->getSetting('sitestore.package.view', 1);

        if ($this->getRequest()->isGet()) {
            $packageInfoArray = Engine_Api::_()->getApi('settings', 'core')->getSetting('sitestore.package.information', array('price', 'billing_cycle', 'duration', 'featured', 'sponsored', 'tellafriend', 'print', 'overview', 'map', 'insights', 'contactdetails', 'sendanupdate', 'apps', 'description', 'twitterupdates', 'ads'));

            $package = $currentPackage = Engine_Api::_()->getItem('sitestore_package', $sitestore->package_id);
            $table = Engine_Api::_()->getItemtable('sitestore_package');
            $packages_select = $table->getPackagesSql($sitestore->getOwner())
                    ->where("update_list = ?", 1)
                    ->where("enabled = ?", 1)
                    ->where("package_id <> ?", $sitestore->package_id);
            $paginator = Zend_Paginator::factory($packages_select);

            $paginator->setCurrentPageNumber($this->_getParam('page', 1));
            $paginator->setCurrentPageNumber($this->_getParam('limit', 20));
            $bodyParams['getTotalItemCount'] = $paginator->getTotalItemCount();
            if (count($bodyParams['getTotalItemCount']) > 0) {
                $bodyParams['getTotalItemCount'] = $paginator->getTotalItemCount();
                foreach ($paginator as $row => $package) {
                    $packageShowArray = array();
                    $currency = Engine_Api::_()->getApi('settings', 'core')->getSetting('payment.currency', 'USD');

                    if (isset($package->package_id) && !empty($package->package_id))
                        $packageShowArray['package_id'] = $package->package_id;

                    if (isset($package->title) && !empty($package->title)) {
                        $packageShowArray['title']['label'] = $this->translate('Title');
                        $packageShowArray['title']['value'] = $this->translate($package->title);
                    }

                    if (in_array('price', $packageInfoArray)) {
                        if ($package->price > 0.00) {
                            $packageShowArray['price']['label'] = $this->translate('Price');
                            $packageShowArray['price']['value'] = $package->price;
                            $packageShowArray['price']['currency'] = Engine_Api::_()->getApi('settings', 'core')->getSetting('payment.currency', 'USD');
                        } else {
                            $packageShowArray['price']['label'] = $this->translate('Price');
                            $packageShowArray['price']['value'] = $this->translate('FREE');
                        }
                    }

                    if (in_array('billing_cycle', $packageInfoArray)) {
                        $packageShowArray['billing_cycle']['label'] = $this->translate('Billing Cycle');
                        $packageShowArray['billing_cycle']['value'] = $package->getBillingCycle();
                    }

                    if (in_array('contactdetails', $packageInfoArray)) {
                        $packageShowArray['contactdetails']['label'] = $this->translate('Contact details');
                        $packageShowArray['contactdetails']['value'] = $this->translate('No');
                        if ($package->contact_details)
                            $packageShowArray['contactdetails']['value'] = $this->translate("Yes");
                    }

                    if (in_array('sendanupdate', $packageInfoArray)) {
                        $packageShowArray['sendanupdate']['label'] = $this->translate('Send an Updates');
                        $packageShowArray['sendanupdate']['value'] = $this->translate('No');
                        if ($package->sendupdate)
                            $packageShowArray['sendanupdate']['value'] = $this->translate("Yes");
                    }

                    if (in_array('apps', $packageInfoArray)) {
                        $modules = unserialize($package->modules);
                        $submodules = $package->getSubModulesString();
                        $packageShowArray['apps']['label'] = $this->translate('Apps available');
                        $packageShowArray['apps']['value'] = $this->translate('No');
                        if (!empty($modules) && !empty($submodules))
                            $packageShowArray['apps']['value'] = $this->translate("Yes");
                    }

                    if (in_array('adds', $packageInfoArray)) {
                        $packageShowArray['adds']['label'] = $this->translate('Advertisement');
                        $packageShowArray['adds']['value'] = $this->translate('No');
                        if ($package->contact_details)
                            $packageShowArray['adds']['value'] = $this->translate("Yes");
                    }

                    if (in_array('duration', $packageInfoArray)) {
                        $packageShowArray['duration']['label'] = $this->translate("Duration");
                        $packageShowArray['duration']['value'] = $package->getPackageQuantity();
                    }

                    if (in_array('featured', $packageInfoArray)) {
                        if ($package->featured == 1) {
                            $packageShowArray['featured']['label'] = $this->translate('Featured');
                            $packageShowArray['featured']['value'] = $this->translate('Yes');
                        } else {
                            $packageShowArray['featured']['label'] = $this->translate('Featured');
                            $packageShowArray['featured']['value'] = $this->translate('No');
                        }
                    }

                    if (in_array('sponsored', $packageInfoArray)) {
                        if ($package->sponsored == 1) {
                            $packageShowArray['Sponsored']['label'] = $this->translate('Sponsored');
                            $packageShowArray['Sponsored']['value'] = $this->translate('Yes');
                        } else {
                            $packageShowArray['Sponsored']['label'] = $this->translate('Sponsored');
                            $packageShowArray['Sponsored']['value'] = $this->translate('No');
                        }
                    }

                    if (in_array('tellafriend', $packageInfoArray)) {
                        $packageShowArray['tellafriend']['label'] = $this->translate('Tell a friend');
                        $packageShowArray['tellafriend']['value'] = $this->translate('No');
                        if ($package->tellafriend)
                            $packageShowArray['tellafriend']['value'] = $this->translate('Yes');
                    }

                    if (in_array('print', $packageInfoArray)) {
                        $packageShowArray['print']['label'] = $this->translate('Print');
                        $packageShowArray['print']['value'] = $this->translate('No');
                        if ($package->print)
                            $packageShowArray['print']['value'] = $this->translate('Yes');
                    }

                    if (in_array('overview', $packageInfoArray)) {
                        $packageShowArray['overview']['label'] = $this->translate('Overview');
                        $packageShowArray['overview']['value'] = $this->translate('No');
                        if ($package->overview)
                            $packageShowArray['overview']['value'] = $this->translate('Yes');
                    }

                    if (in_array('map', $packageInfoArray)) {
                        $packageShowArray['map']['label'] = $this->translate('Map');
                        $packageShowArray['map']['value'] = $this->translate('No');
                        if ($package->overview)
                            $packageShowArray['map']['value'] = $this->translate('Yes');
                    }

                    if (in_array('insights', $packageInfoArray)) {
                        $packageShowArray['insights']['label'] = $this->translate('Insights');
                        $packageShowArray['insights']['value'] = $this->translate('No');
                        if ($package->insights)
                            $packageShowArray['insights']['value'] = $this->translate('Yes');
                    }

                    if (in_array('rich_overview', $packageInfoArray) && ($overview && (empty($level_id) || Engine_Api::_()->authorization()->getPermission($level_id, 'sitepage_page', "overview")))) {
                        if ($package->overview == 1) {
                            $packageShowArray['rich_overview']['label'] = $this->translate('Rich Overview');
                            $packageShowArray['rich_overview']['value'] = $this->translate('Yes');
                        } else {
                            $packageShowArray['rich_overview']['label'] = $this->translate('Rich Overview');
                            $packageShowArray['rich_overview']['value'] = $this->translate('No');
                        }
                    }

                    if (in_array('videos', $packageInfoArray) && (empty($level_id) || Engine_Api::_()->authorization()->getPermission($level_id, 'sitepage_page', "video"))) {
                        if ($package->video == 1) {
                            if ($package->video_count) {
                                $packageShowArray['videos']['label'] = $this->translate('Videos');
                                $packageShowArray['videos']['value'] = $package->video_count;
                            } else {
                                $packageShowArray['videos']['label'] = $this->translate('Videos');
                                $packageShowArray['videos']['value'] = $this->translate("Unlimited");
                            }
                        } else {
                            $packageShowArray['videos']['label'] = $this->translate('Videos');
                            $packageShowArray['videos']['value'] = $this->translate('No');
                        }
                    }

                    if (in_array('photos', $packageInfoArray) && (empty($level_id) || Engine_Api::_()->authorization()->getPermission($level_id, 'sitepage_page', "photo"))) {
                        if ($package->photo == 1) {
                            if ($packagem->photo_count) {
                                $packageShowArray['photos']['label'] = $this->translate('Photos');
                                $packageShowArray['photos']['value'] = $package->photo_count;
                            } else {
                                $packageShowArray['photos']['label'] = $this->translate('Photos');
                                $packageShowArray['photos']['value'] = $this->translate("Unlimited");
                            }
                        } else {
                            $packageShowArray['photos']['label'] = $this->translate('Photos');
                            $packageShowArray['photos']['value'] = $this->translate('No');
                        }
                    }

                    if (in_array('description', $packageInfoArray)) {
                        $packageShowArray['description']['label'] = $this->translate("Description");
                        $packageShowArray['description']['value'] = $this->translate($package->description);
                    }
                    $packageArray["package"] = $packageShowArray;
                    $tempMenu = array();
                    $tempMenu[] = array(
                        'label' => $this->translate('Upgrade Package'),
                        'name' => 'upgrade_package',
                        'url' => 'sitestore/package/upgrade-package',
                        'urlParams' => array(
                            'package_id' => $package->package_id,
                            'store_id' => $sitestore->getIdentity()
                        )
                    );
                    $tempMenu[] = array(
                        'label' => $this->translate('Package Info'),
                        'name' => 'package_info',
                        'url' => 'sitestore/package/upgrade-package',
                        'urlParams' => array(
                            'package_id' => $package->package_id,
                            'store_id' => $sitestore->getIdentity()
                        )
                    );

                    $packageArray['menu'] = $tempMenu;
                    $bodyParams['response'][] = $packageArray;
                }
                if (isset($currentPackage) && !empty($currentPackage)) {
                    $bodyParams['currentPackage'] = $currentPackage->toArray();
                }
                if (empty($bodyParams))
                    $bodyParams['getTotalItemCount'] = 0;

                $this->respondWithSuccess($bodyParams);
            }
        }
        elseif ($this->getRequest()->getPost()) {
            $package_id = $this->_getParam('package_id');
            $package_chnage = Engine_Api::_()->getItem('sitestore_package', $package_id);
            if (empty($package_chnage) || !$package_chnage->enabled || (!empty($package_chnage->level_id) && !in_array($sitestore->getOwner()->level_id, explode(",", $package_chnage->level_id)))) {
                
            }

            $getPackageAuth = Engine_Api::_()->sitestore()->getPackageAuthInfo('sitestore');

            if (!empty($_POST['package_id'])) {
                $table = $sitestore->getTable();
                $db = $table->getAdapter();
                $db->beginTransaction();

                try {
                    $is_upgrade_package = true;

                    //APPLIED CHECKS BECAUSE CANCEL SHOULD NOT BE CALLED IF ALREADY CANCELLED 
                    if ($sitestore->status == 'active')
                        $sitestore->cancel($is_upgrade_package);

                    $sitestore->package_id = $_POST['package_id'];
                    $package = Engine_Api::_()->getItem('sitestore_package', $sitestore->package_id);

                    $sitestore->featured = $package->featured;
                    $sitestore->sponsored = $package->sponsored;
                    $sitestore->pending = 1;
                    $sitestore->expiration_date = new Zend_Db_Expr('NULL');
                    $sitestore->status = 'initial';
                    if (($package->isFree()) && !empty($getPackageAuth)) {
                        $sitestore->approved = $package->approved;
                    } else {
                        $sitestore->approved = 0;
                    }

                    if (!empty($sitestore->approved)) {
                        $sitestore->pending = 0;
                        $expirationDate = $package->getExpirationDate();
                        if (!empty($expirationDate))
                            $sitestore->expiration_date = date('Y-m-d H:i:s', $expirationDate);
                        else
                            $sitestore->expiration_date = '2250-01-01 00:00:00';

                        if (empty($sitestore->aprrove_date)) {
                            $sitestore->aprrove_date = date('Y-m-d H:i:s');
                            if (!empty($sitestore) && !empty($sitestore->draft) && empty($sitestore->pending)) {
                                Engine_Api::_()->sitestore()->attachStoreActivity($sitestore);
                            }
                        }
                    }
                    $sitestore->save();
                    $db->commit();
                    $this->successResponseNoContent('no_content', true);
                } catch (Exception $e) {
                    $db->rollBack();
                }
            }
        }
    }

}

?>
