<?php

/**
 * SocialEngine
 *
 * @category   Application_Extensions
 * @package    Sitestoreintegration
 * @copyright  Copyright 2011-2012 BigStep Technologies Pvt. Ltd.
 * @license    http://www.socialengineaddons.com/license/
 * @version    $Id: Contents.php 2012-31-12 9:40:21Z SocialEngineAddOns $
 * @author     SocialEngineAddOns
 */
class Sitestoreintegration_Model_DbTable_Contents extends Engine_Db_Table {

  protected $_name = 'sitestoreintegration_contents';
  protected $_rowClass = 'Sitestoreintegration_Model_Content';

  /**
   * Return count results according to intregration modules.
   *
   * @param int $store_id
   */
  public function getCountResults($modNameKey, $listingtype_id = null) {
  
    $count = 0;
    $contentsTableName = $this->info('name');
		$resource_typetable = Engine_Api::_()->getItemTable($modNameKey);

		//GIVE AUTO INCREMENT ID NAME ACCRODING TO RESOURCE TYPE.
		$primaryId = current($resource_typetable->info("primary"));
		$resource_typetableTableName = $resource_typetable->info('name');

		$select = $resource_typetable->select()
						->setIntegrityCheck(false)
						->from($resource_typetableTableName, array('count(*) as count'))
						->joinleft($contentsTableName, $resource_typetableTableName . ".$primaryId = " .                       $contentsTableName . '.resource_id')
						->where($contentsTableName . '.resource_type = ?', $modNameKey);
		if ($modNameKey == 'sitereview_listing') {
			$select->where($resource_typetableTableName . '.listingtype_id = ?', $listingtype_id);
		}
		$row = $select->query()->fetchColumn();
		return $row;
  }
  
  /**
   * Return results according to intregration modules.
   *
   * @param array $params
   */
  public function getResults($params) {

		$contentsTableName = $this->info('name');
		
		$resource_typetable = Engine_Api::_()->getItemTable($params['resource_type']);

		//GIVE AUTO INCREMENT ID NAME ACCRODING TO RESOURCE TYPE.
		$primaryId = current($resource_typetable->info("primary"));
		$resource_typetableTableName = $resource_typetable->info('name');

		$contentSelect = $resource_typetable->select()
						->setIntegrityCheck(false)
						->from($resource_typetableTableName);
		if (isset($params['action']) && $params['action'] == 'index') { 
			$contentSelect->joinleft($contentsTableName, $resource_typetableTableName . ".$primaryId = " .$contentsTableName . '.resource_id'); 
		} else {
			$contentSelect->joinleft($contentsTableName, $resource_typetableTableName . ".$primaryId = " .$contentsTableName . '.resource_id', null); 
		}
		$contentSelect->where($contentsTableName . '.resource_type = ?', $params['resource_type'])
		              ->where($contentsTableName . '.store_id = ?', $params['store_id']);

		if ($params['resource_type'] == 'sitereview_listing') {
			$contentSelect->where($resource_typetableTableName . '.listingtype_id = ?', $params['listingtype_id']);
		}
		
		if($params['resource_type'] == 'sitepage_page' ) {
			$contentSelect->where($resource_typetableTableName . '.approved = ?', '1')
			->where($resource_typetableTableName . '.declined = ?', '0')
			->where($resource_typetableTableName . '.draft = ?', '1')
			->where($resource_typetableTableName . ".search = ?", 1)
			->where($resource_typetableTableName . '.closed = ?', '0');
		}

		if (!empty($params['search'])) {
			$contentSelect->where($resource_typetableTableName . ".title LIKE ? OR " . $resource_typetableTableName . ".body LIKE ?", '%' . $params['search'] . '%');
		}
		
		if (isset($params['orderby']) && !empty($params['orderby'])) {
			$contentSelect->order($resource_typetableTableName . '.' . $params['orderby'] . ' DESC' );
		} else {
			$contentSelect->order($resource_typetableTableName . '.creation_date DESC' );
		}

		$paginator = Zend_Paginator::factory($contentSelect);
		
    return $paginator;
  }
  
  /**
   * Return resource ids array
   *
   * @param int $store_id
   */
	public function getResourceIds($store_id, $resource_type) {

    $select = $this->select()
                    ->from($this->info('name'), 'resource_id')
                    ->where('resource_type = ?', $resource_type)
                    ->where('store_id = ?', $store_id);
    $resource_ids = $select->query()->fetchAll(Zend_Db::FETCH_COLUMN);
    return $resource_ids;
	}
}