<?php

/**
 * SocialEngine
 *
 * @category   Application_Extensions
 * @package    Sitestoreproduct
 * @copyright  Copyright 2012-2013 BigStep Technologies Pvt. Ltd.
 * @license    http://www.socialengineaddons.com/license/
 * @version    $Id: IndexController.php 2013-09-02 00:00:00Z SocialEngineAddOns $
 * @author     SocialEngineAddOns
 */
class Sitestoreproduct_FilesController extends Siteapi_Controller_Action_Standard {

    protected $_filePath;

    public function init() {
        Engine_Api::_()->getApi('Core', 'siteapi')->setView();
        if (!$this->_helper->requireAuth()->setAuthParams('sitestore_store', null, "view")->isValid())
            $this->respondWithError('unauthorized');

        if (!$this->_helper->requireAuth()->setAuthParams('sitestoreproduct_product', null, "view")->isValid())
            $this->respondWithError('unauthorized');

        //ONLY LOGGED IN USER CAN CREATE
        if (!$this->_helper->requireUser()->isValid())
            $this->respondWithError('unauthorized');

        //PAGE ID 
        $product_id = $this->_getParam('product_id', NULL);

        $product = Engine_Api::_()->getItem('sitestoreproduct_product', $product_id);
        if (!empty($product))
            $product_type = $product->product_type;
        else {
            $this->respondWithError('unauthorized');
        }

        if ($product_type != 'downloadable')
            $this->respondWithError('unauthorized');

        $store_id = $product->store_id;
        $authValue = Engine_Api::_()->sitestoreproduct()->isStoreAdmin($store_id);

        //IS USER IS PAGE ADMIN OR NOT
        if (empty($authValue))
            $this->respondWithError('unauthorized');
        else if ($authValue == 1)
            $this->respondWithError('unauthorized');

        $this->_filePath = (string) APPLICATION_PATH . '/public/sitestoreproduct_product/file_' . $product_id;
    }

    public function uploadFileAction() {
        $uploadType = $this->_getParam('type', 'main');
        $product_id = $product_id = $this->_getParam('product_id', null);
        $viewer = Engine_Api::_()->user()->getViewer();

        $sitestoreproduct = Engine_Api::_()->getItem('sitestoreproduct_product', $product_id);
        $sitestore = Engine_Api::_()->getItem('sitestore_store', $sitestoreproduct->store_id);
        $published = $sitestoreproduct->search;

        $path = $relPath = $this->_filePath . '/main';
        if ($uploadType != 'main') {
            $path = $relPath = $this->_filePath . '/sample';
        }

        //VALIDATION REGARDING NUBER OF FILES
        $store_id = $sitestoreproduct->store_id;
        $uploadLimit = Engine_Api::_()->sitestoreproduct()->getUploadLimit($store_id);
        $downloadableFileTable = Engine_Api::_()->getDbtable('downloadablefiles', 'sitestoreproduct');
        $currentUploadStats = $downloadableFileTable->getUploadStatus(array("product_id" => $product_id, "type" => $uploadType));

        if ($uploadType == 'main' && !empty($uploadLimit['sitestoreproduct_main_files'])) {
            if ($currentUploadStats['files'] >= $uploadLimit['sitestoreproduct_main_files']) {
                $this->respondWithError("'unauthorized'", "You will not permitted for uploading file because you already achived the maximum number of uplode " . $uploadLimit['sitestoreproduct_main_files'] . "files.");
            }
        }

        if ($uploadType == 'sample' && !empty($uploadLimit['sitestoreproduct_sample_files'])) {
            if ($currentUploadStats['files'] >= $uploadLimit['sitestoreproduct_sample_files']) {
                $this->respondWithError("'unauthorized'", "You will not permitted for uploading file because you already achived the maximum number of uplode " . $uploadLimit['sitestoreproduct_main_files'] . "files.");
            }
        }
        if ($this->getRequest()->isGet()) {
            $response = Engine_Api::_()->getApi('Siteapi_Core', 'sitestoreproduct')->getDowloadProductForm($uploadType);
            $this->respondWithSuccess($response);
        }




        if ($this->getRequest()->isPost()) {
            // START FILE VALIDATIONS
            if (empty($_FILES['upload_product'])) {
                $this->respondWithError("unauthorized", 'Failed to upload file due to some server settings (such as php.ini max_upload_filesize). Please contact to site administrator for this problem.');
            }

            // Prevent evil files from being uploaded
            $disallowedExtensions = array('php');
            if (in_array(end(explode(".", $_FILES['upload_product']['name'])), $disallowedExtensions)) {
                $this->respondWithError("unauthorized", 'File type or extension forbidden.');
            }

            $info = $_FILES['upload_product'];
            $targetFile = $path . '/' . $info['name'];
            $vals = array();



            $uploadedSize = ($currentUploadStats['size'] + $info['size']) / 1024;
            if ($uploadType == 'main') {
                ;
                // VALIDATE ALLOWING FILE SIZE LIMIT
                if ($uploadedSize > $uploadLimit['filesize_main']) {
                    $this->respondWithError("unauthorized", " You have exceeded the uploading size that's why you will not permitted for uploading this file");
                }
            } else {
                if ($uploadedSize > $uploadLimit['filesize_sample']) {
                    $this->respondWithError("unauthorized", " You have exceeded the uploading size that's why you will not permitted for uploading this file");
                }
            }


            if (file_exists($targetFile)) {
                $file_id = $downloadableFileTable->getFileId(array('type' => $uploadType, 'product_id' => $product_id, 'filename' => $info['name']));
                if (!empty($file_id)) {
                    $this->respondWithError("unauthorized", " This file all ready exist.");
                }
            }
            // END FILE VALIDATIONS
            // START FILE UPLOADING
            if (!file_exists($this->_filePath)) {
                $mask = @umask(0000);
                $directoryPath = $this->_filePath;
                $submaindirectoryPath = $this->_filePath . '/main';
                $subsampledirectoryPath = $this->_filePath . '/sample';
                @mkdir($directoryPath, 0777, true);
                @mkdir($submaindirectoryPath, 0777, true);
                @mkdir($subsampledirectoryPath, 0777, true);
                @umask($mask);
            }

            if (!is_writable($path)) {
                $this->respondWithError("unauthorized", " Path is not writeable. Please give CHMOD 0777 permission to the respective directory or contact to site administrator.");
            }

            if (!move_uploaded_file($info['tmp_name'], $targetFile)) {
                $this->respondWithError("unauthorized", "Unable to move file to upload directory.");
            }
            // END FILE UPLOADING
            // START DATABASE INSERTION
            $formValues = $_REQUEST;
            $values['product_id'] = $product_id;
            $values['title'] = $formValues['title'];
            $values['download_limit'] = isset($formValues['download_limit']) ? $formValues['download_limit'] : 0;
//    $values['status'] = !empty($formValues['status']) ? 1 : 0;
            $values['type'] = $uploadType;
            $values['owner_id'] = $viewer->getIdentity();
            $values['owner_type'] = Engine_Api::_()->getItem('authorization_level', $viewer->level_id)->type;
            $values['filename'] = $info['name'];
            $values['extension'] = strtolower(ltrim(strrchr($info['name'], '.'), '.'));
            $values['size'] = $info['size'];

            if (!empty($info['size'])) {
                $mimeType = explode("/", $info['type']);
                $values['mime_major'] = $mimeType[0];
                $values['mime_minor'] = $mimeType[1];
            }

            $downloadableFileTable = Engine_Api::_()->getDbtable('downloadablefiles', 'sitestoreproduct');
            $db = $downloadableFileTable->getAdapter();
            $db->beginTransaction();

            try {
                $row = $downloadableFileTable->createRow();
                $row->setFromArray($values);
                $row->save();
                $db->commit();
                $this->successResponseNoContent('no_content', true);
            } catch (Exception $e) {
                $db->rollBack();
            }
        }
    }

    public function manageAction() {
        $product_id = $this->_getParam('product_id', NULL);
        $type = $this->_getParam('type', 'main');
        $sitestoreproduct = Engine_Api::_()->getItem('sitestoreproduct_product', $product_id);
        $sitestore = Engine_Api::_()->getItem('sitestore_store', $sitestoreproduct->store_id);

        $published = $sitestoreproduct->search;

        //set item count per page to show all records on a page
        $uploadLimit = Engine_Api::_()->sitestoreproduct()->getUploadLimit($sitestoreproduct->store_id);
        $maxItem = max($uploadLimit['sitestoreproduct_main_files'], $uploadLimit['sitestoreproduct_sample_files']);

        $params = array();
        $params['product_id'] = $product_id;
        $params['type'] = $type;
        $params['limit'] = $maxItem;
        $params['page'] = $this->_getParam('page', 1);

        //PAGINATOR FOR MAIN FILES
        $paginator = Engine_Api::_()->getDbtable('downloadablefiles', 'sitestoreproduct')->getDownloadableFilesPaginator($params);
        foreach ($paginator as $downloadablefile) {
            $methodShowArray = array();
            $methodShowArray['downloadablefile_id'] = $downloadablefile->getIdentity();
            $methodShowArray['title']['label'] = $this->translate('Title');
            $methodShowArray['title']['value'] = $this->translate($downloadablefile->title);
            $methodShowArray['download_limit']['label'] = $this->translate('Max Downloads');
            $methodShowArray['download_limit']['value'] = $this->translate($downloadablefile->download_limit);
            $methodShowArray['extension']['label'] = $this->translate('File Extension');
            $methodShowArray['extension']['value'] = $this->translate($downloadablefile->extension);
            $methodShowArray['status']['label'] = $this->translate('Status');
            $methodShowArray['status']['value'] = $this->translate($downloadablefile->status);



            $menu = array();

            $menu[] = array(
                'name' => 'edit_file',
                'label' => $this->translate('Edit File'),
                'url' => 'sitestore/product/file/edit/' . $sitestoreproduct->getIdentity(),
                'urlParams' => array(
                    "product_id" => $product_id,
                    "downloadablefile_id" => $downloadablefile->getIdentity(),
                    "type" => $type
                )
            );
            $menu[] = array(
                'name' => 'delete_file',
                'label' => $this->translate('Delete File'),
                'url' => 'sitestore/product/file/delete/' . $sitestoreproduct->getIdentity(),
                'urlParams' => array(
                    "product_id" => $product_id,
                    "downloadablefile_id" => $downloadablefile->getIdentity(),
                    "type" =>$type
                )
            );
            if ($downloadablefile->status) {
                $menu[] = array(
                    'name' => 'disable_file',
                    'label' => $this->translate('Disable File'),
                    'url' => 'sitestore/product/file/enable-disable/' . $sitestoreproduct->getIdentity(),
                    'urlParams' => array(
                        "product_id" => $product_id,
                        "downloadablefile_id" => $downloadablefile->getIdentity(),
                        "type" => $type
                    )
                );
            } else {
                $menu[] = array(
                    'name' => 'enable_file',
                    'label' => $this->translate('Enable File'),
                    'url' => 'sitestore/product/file/enable-disable/' . $sitestoreproduct->getIdentity(),
                    'urlParams' => array(
                        "product_id" => $product_id,
                        "downloadablefile_id" => $downloadablefile->getIdentity(),
                        "type" =>$type
                    )
                );
            }
            $view = Zend_Registry::get('Zend_View');
            $downloadUrl = $view->url(array('action' => 'download', 'product_id'=>$sitestoreproduct->getIdentity(), 'downloadablefile_id' => $downloadablefile->getIdentity(), 'type' => $type), 'sitestoreproduct_files', true);
            $menu[] = array(
                    'name' => 'download',
                    'label' => $this->translate('Download'),
                     'downloadUrl'=>$this->getHost.$downloadUrl
                );

            $methodShowArray['menu'] = $menu;



            $bodyBrowse['file'] = $methodShowArray;
            $response['response'][] = $bodyBrowse;
        }
        $response['uploadurl'] = 'sitestore/product/file/upload-file/' . $sitestoreproduct->getIdentity();
        $this->respondWithSuccess($response, true);
    }

    public function enableDisableAction() {
        $downloadablefile_id = $this->_getParam('downloadablefile_id', null);

        if (empty($downloadablefile_id)) {
            $this->respondWithError('no_record');
        }
        $db = Engine_Db_Table::getDefaultAdapter();
        $db->beginTransaction();
        try {
            $downloadablefile = Engine_Api::_()->getItem('sitestoreproduct_downloadablefile', $downloadablefile_id);
            // CHANGING STATUS TO COMPLEMENT OF PRESENT STATUS VALUE
            if(empty($downloadablefile->status)){
                $downloadablefile->status=1;
            }
            else{
                $downloadablefile->status=0;
            }
            
            $downloadablefile->save();
            $db->commit();
            $this->successResponseNoContent('no_content', true);
        } catch (Exception $e) {
            $db->rollBack();
        }
    }

    public function deleteAction() {

        $deleteType = $this->_getParam('type', null);
        $path = $relPath = $this->_filePath . '/' . $deleteType;
        if ($uploadType != 'main') {
            $path = $relPath = $this->_filePath . '/' . $deleteType;
        }

        $downloadablefile_id = $this->_getParam('downloadablefile_id', NULL);


        $db = Engine_Db_Table::getDefaultAdapter();
        $db->beginTransaction();

        try {
            $downloadablefileItem = Engine_Api::_()->getItem('sitestoreproduct_downloadablefile', $downloadablefile_id);
            $downloadablefile_name = $downloadablefileItem->filename;
            $filePath = $path . '/' . $downloadablefile_name;
            if (is_file($filePath)) {

                if (@unlink($filePath)) {
                    $downloadablefileItem->delete();
                }
            }

            $db->commit();
            $this->successResponseNoContent('no_content', true);
        } catch (Exception $e) {
            $db->rollBack();
        }
    }

    public function editAction() {

        $uploadType = $this->_getParam('type', 'main');


        $downloadablefileItem = Engine_Api::_()->getItem('sitestoreproduct_downloadablefile', $this->_getParam('downloadablefile_id', null));

        $downloadablefileArray = $downloadablefileItem->toArray();

        if ($this->getRequest()->isGet()) {
            $form = Engine_Api::_()->getApi('Siteapi_Core', 'sitestoreproduct')->getDowloadProductForm($uploadType,1);
            $form['formValues'] =$downloadablefileArray;
            $this->respondWithSuccess($form, true);
        } else {
            $values = $_REQUEST;

            $db = Engine_Db_Table::getDefaultAdapter();
            $db->beginTransaction();

            try {
                $downloadablefileItem->title = $values['title'];
                $downloadablefileItem->download_limit = $values['download_limit'];

                $downloadablefileItem->save();
                $db->commit();
                 $this->successResponseNoContent('no_content', true);
                
            } catch (Exception $e) {
                $db->rollBack();
               
            }
        }
    }
    
    
      public function downloadAction() {
    $downloadType = $this->_getParam('type', null);
    // Get path
    $path = $relPath = $this->_filePath . '/' . $downloadType;
    if ($uploadType != 'main') {
      $path = $relPath = $this->_filePath . '/' . $downloadType;
    }
    
    $downloadablefileItem = Engine_Api::_()->getItem('sitestoreproduct_downloadablefile', $this->_getParam('downloadablefile_id', NULL));
    $downloadablefile_name = $downloadablefileItem->filename;
    
    $path = $path . '/' . $downloadablefile_name;

    if (file_exists($path) && is_file($path)) {
      
      $isGZIPEnabled = false;
      if (ob_get_level()) {
        $isGZIPEnabled = true;
        @ob_end_clean();
      }

      header("Content-Disposition: attachment; filename=" . urlencode(basename($path)), true);
      header("Content-Transfer-Encoding: Binary", true);
      header("Content-Type: application/force-download", true);
      header("Content-Type: application/octet-stream", true);
      header("Content-Type: application/download", true);
      header("Content-Description: File Transfer", true);
      
      if(empty($isGZIPEnabled)) {
        header("Content-Length: " . filesize($path), true);
        flush();
      }

      $fp = fopen($path, "r");
      while (!feof($fp)) {
        echo fread($fp, 65536);
        if(empty($isGZIPEnabled))
          flush();
      }
      fclose($fp);
    }

    exit();
  }

}

?>
