<?php

/**
 * SocialEngine
 *
 * @category   Application_Extensions
 * @package    Sitestoreproduct
 * @copyright  Copyright 2012-2013 BigStep Technologies Pvt. Ltd.
 * @license    http://www.socialengineaddons.com/license/
 * @version    $Id: IndexController.php 2013-09-02 00:00:00Z SocialEngineAddOns $
 * @author     SocialEngineAddOns
 */
class Sitestoreproduct_IndexController extends Siteapi_Controller_Action_Standard {

    public $_configurableOptions;

    /*
     * Creates the store object 
     */

    public function init() {

        if (!Zend_Registry::isRegistered('Zend_Translate'))
            Engine_Api::_()->getApi('Core', 'siteapi')->setTranslate();

        Engine_Api::_()->getApi('Core', 'siteapi')->setView();
        Engine_Api::_()->getApi('Core', 'siteapi')->setLocal();
        $viewer = Engine_Api::_()->user()->getViewer();

        if ($this->getRequestParam("store_id") && (0 !== ($store_id = (int) $this->getRequestParam("store_id")) &&
                null !== ($store = Engine_Api::_()->getItem('sitestore_store', $store_id)))) {
            Engine_Api::_()->core()->setSubject($store);
        }
        else if ($this->getRequestParam("store_id") && (null !== ($store_url = (string) $this->getRequestParam("store_id")))) {
            $store = Engine_Api::_()->getApi('Core','siteapi')->getSubjectByModuleUrl('sitestore','stores','store_url',$store_url); 
            Engine_Api::_()->core()->setSubject($store);
        }

        // Authorization check
        if (!$this->_helper->requireAuth()->setAuthParams('sitestore_store', $viewer, "view")->isValid())
            $this->respondWithError('unauthorized');
    }

    /*
     * Store product paginator
     */

    //ACTION FOR CREATING A NEW PRODUCT
    public function createAction() {
        //ONLY LOGGED IN USER CAN CREATE
        if (!$this->_helper->requireUser()->isValid())
            $this->respondWithError('unauthorized');
        $viewer = Engine_Api::_()->user()->getViewer();        //GET VIEWER
        $viewer_id = $viewer->getIdentity();
        $store_id = $this->_getParam('store_id', null);

        $page_id = $this->_getParam('page_id', null);
        $authValue = Engine_Api::_()->sitestoreproduct()->isStoreAdmin($store_id);
        //IS USER IS STORE ADMIN OR NOT
        if (empty($authValue))
            $this->respondWithError('unauthorized');
        else if ($authValue == 1)
            $this->respondWithError('unauthorized');


        //GET SITESTORE ITEM
        $sitestore = Engine_Api::_()->getItem('sitestore_store', $store_id);
        $isAdminDrivenStore = Engine_Api::_()->getApi('settings', 'core')->getSetting('is.sitestore.admin.driven', 0);
        $tableLocation = Engine_Api::_()->getDbTable('locations', 'sitestore');

        if (!empty($sitestore->location))
            $locationId = $tableLocation->select()->from($tableLocation->info('name'), 'location_id')->where('store_id = ?', $store_id)->where("location = ?", $sitestore->location)->query()->fetchColumn();
        if (!empty($locationId)) {
            $locationDetails = Engine_Api::_()->getItem('sitestore_location', $locationId);
        }

        if (Engine_Api::_()->getApi('settings', 'core')->getSetting('sitestoreproduct.openclose', 0)) {
            if (empty($sitestore->approved) || !empty($sitestore->closed) || empty($sitestore->search) || empty($sitestore->draft) || !empty($sitestore->declined)) {
                $this->respondWithError('unauthorized', 'Either store is not approved or save as draft ');
            }
        } else {
            if (empty($sitestore->approved) || empty($sitestore->search) || empty($sitestore->draft) || !empty($sitestore->declined)) {

                $this->respondWithError('unauthorized', 'Either store is not approved or save as draft ');
            }
        }

        //FLAG FOR SHOW MARKER IN DATE
        //$showMarkerInDate = $this->showMarkerInDate();
        //CHECK FOR CREATION PRIVACY
        if (!$this->_helper->requireAuth()->setAuthParams('sitestoreproduct_product', null, "create")->isValid()) {
            $this->respondWithError('unauthorized');
        }

        // COUNT PRODUCT CREATED BY THIS STORE AND MAXIMUM PRODUCT CREATION LIMIT
        $current_count = Engine_Api::_()->getDbTable('products', 'sitestoreproduct')->getProductsCountInStore($store_id);
        $quota = $quota = Engine_Api::_()->sitestoreproduct()->getProductLimit($store_id);
        if (!empty($quota) && $current_count >= $quota) {
            $this->respondWithError('unauthorized', "You have exceed maximum create of product ");
        }

        //GET DEFAULT PROFILE TYPE ID
        $defaultProfileId = $defaultProfileId = Engine_Api::_()->getDbTable('metas', 'sitestoreproduct')->defaultProfileId();

        // WORK FOR MULTILANGUAL PRODUCT TITLE STARTS    
        $settings = Engine_Api::_()->getApi('settings', 'core');
        //MULTI LANGUAGE IS ALLOWED OR NOT
        $multiLanguage = $settings->getSetting('sitestoreproduct.multilanguage', 0);

        // Comment Privacy
        $isCommentsAllow = Engine_Api::_()->sitestore()->isCommentsAllow("sitestoreproduct_product");

        //DEFAULT LANGUAGE
        $defaultLanguage = $defaultLanguage = $settings->getSetting('core.locale.locale', 'en');
        // MULTI LANGUAGE WORK
        $languageCount = 0;
        $languageData = array();
        $title_link = 'title';
        $body_link = 'body';
        $overview_link = 'overview';
        if ($multiLanguage) {
            //GET LANGUAGE ARRAY
            $localeMultiOptions = Engine_Api::_()->sitestoreproduct()->getLanguageArray();
            $languages = $settings->getSetting('sitestoreproduct.languages');

            $languageCount = Count($languages);
            $languageData = array();
            if (is_array($languages)) {
                foreach ($languages as $label) {
                    $languageData[] = $label;

                    if ($languageCount >= 2 && $defaultLanguage == $label && $label != 'en') {
                        $title_link = "title_$label";
                        $body_link = "body_$label";
                        $overview_link = "overview_$label";
                    }
                }
            }
            if (!in_array($defaultLanguage, $languageData)) {
                $defaultLanguage = 'en';
            }
        }
        // WORK FOR MULTILANGUAL PRODUCT TITLE ENDS    
        //GET TINYMCE SETTINGS
        $upload_url = "";
        $albumEnabled = Engine_Api::_()->getDbtable('modules', 'core')->isModuleEnabled('album');
        if (Engine_Api::_()->authorization()->isAllowed('album', $viewer, 'create') && $albumEnabled) {
            //$upload_url = Zend_Controller_Front::getInstance()->getRouter()->assemble(array('action' => 'upload-photo'), 'sitestoreproduct_general', true);
        }


        $category_count = Engine_Api::_()->getDbTable('categories', 'sitestoreproduct')->getCategories(null, 1, 0, 1);
        $expiry_setting = Engine_Api::_()->sitestoreproduct()->expirySettings();
        $allowSellingProducts = Engine_Api::_()->sitestoreproduct()->getIsAllowedSellingProducts($store_id, false);

        //PRODUCT FLAG        
        $packageEnable = Engine_Api::_()->getApi('settings', 'core')->getSetting('sitestore.package.enable', 1);

        //GET PRODUCT USING LEVEL OR PACKAGE BASED SETTINGS
        if (!empty($packageEnable)) {
            $packageObj = Engine_Api::_()->getItem('sitestore_package', $sitestore->package_id);
            if (empty($packageObj->store_settings)) {
                $product_types = array('simple', 'configurable', 'virtual', 'grouped', 'bundled', 'downloadable');
            } else {
                $storeSettings = @unserialize($packageObj->store_settings);
                $product_types = $storeSettings['product_type'];
            }
        } else {
            $user = $sitestore->getOwner();
            $product_types = Engine_Api::_()->authorization()->getPermission($user->level_id, "sitestore_store", "product_type");
            $product_types = Zend_Json_Decoder::decode($product_types);
        }
        $countProductTypes = $countProductTypes = count($product_types);

        // CHECK ANY SHIPPING METHOD IS CREATED BY STORE OR NOT
        $shipping_method_exist = Engine_Api::_()->getDbtable('shippingmethods', 'sitestoreproduct')->isAnyShippingMethodExist($store_id);

        // CHECK ANY ENABLE LOCATIONS
        $isAnyCountryEnable = Engine_Api::_()->getDbtable('regions', 'sitestoreproduct')->isAnyCountryEnable();


        $directPayment = $directPayment = Engine_Api::_()->sitestoreproduct()->isDirectPaymentEnable();
        $isDownPaymentEnable = Engine_Api::_()->getApi('settings', 'core')->getSetting('sitestorereservation.downpayment', 0);
        $allowProductCode = Engine_Api::_()->getApi('settings', 'core')->getSetting('sitestoreproduct.productcode', 1);



        //IS ANY SHIPPING METHOD EXIST WITH ENABLE STATUS

        if ($countProductTypes == 0) {
            $productType = 0;
        } else if ($countProductTypes == 1) {
            if (@in_array("bundled", $product_types) || @in_array("grouped", $product_types)) {
                $productCount = Engine_Api::_()->getDbtable('products', 'sitestoreproduct')->getProductAvailability($sitestore->store_id, $productTypeValue['product_type']);
                $lessSimpleProductType = ($productCount <= 1) ? 1 : 0;
            }

            $productTypeName = $product_types[0];
        } else
            $productType = $product_types;


        if ($this->getRequest()->isGet()) {

            //MAKE FORM
            try {
                if (!isset($_REQUEST['product_type']) || empty($_REQUEST['product_type'])) {
                    $product_types_array = array();
                    foreach ($product_types as $key => $product_type_val) {
                        $product_types_array[$product_type_val] = ucfirst($product_type_val);
                    }

                    $current_count = Engine_Api::_()->getDbtable('products', 'sitestoreproduct')->getProductAvailability($sitestore->store_id, 'bundled');
                    if ($current_count < 2) {
                        unset($product_types_array['bundled']);
                    }

                    $current_count = Engine_Api::_()->getDbtable('products', 'sitestoreproduct')->getProductAvailability($sitestore->store_id, 'grouped');
                    if ($current_count < 2) {
                        unset($product_types_array['grouped']);
                    }


                    $createForm[] = array(
                        'name' => 'product_type',
                        'label' => $this->translate('Product Type'),
                        'type' => 'Select',
                        'multiOptions' => $product_types_array,
                        "hasValidator" => true
                    );

                    $createForm[] = array(
                        'name' => 'product_help',
                        'label' => $this->translate('Need help with Product Types ?'),
                        'type' => 'Dummy',
                        "url" => $this->getHost . "/stores/products/product-type-details",
                        "fieldType" => "help"
                    );

                    $response['form'] = $createForm;
                } else {

                    $shipping_method_exist = Engine_Api::_()->getDbtable('shippingmethods', 'sitestoreproduct')->isAnyShippingMethodExist($store_id);
                    if (empty($shipping_method_exist)) {
                        $this->respondWithError('unauthorized', "Please configure a shipping method.");
                    }
                    $response = Engine_Api::_()->getApi('Siteapi_Core', 'sitestoreproduct')->getForm($defaultProfileId, $store_id, $_REQUEST['product_type'], $product_types, 0);
                }
                $this->respondWithSuccess($response);
            } catch (Exception $ex) {
                $this->respondWithError('internal_server_error', $ex->getMessage());
            }
        }


        //CHECK TO SHOW II ND STEP OF PRODUCT CREATION
        if ($this->getRequest()->isPost()) {
            $productTypeValue = $_REQUEST;
            if (empty($productTypeValue['draft'])) {
                $productTypeValue['draft'] = 1;
            } else {
                $productTypeValue['draft'] = 0;
            }
            $productTypeName = $productTypeValue['product_type'];

            if ($productTypeValue['product_type'] == 'grouped' || $productTypeValue['product_type'] == 'bundled') {
                $currentProductCount = Engine_Api::_()->getDbtable('products', 'sitestoreproduct')->getProductAvailability($store_id, $productTypeValue['product_type']);
                if ($currentProductCount < 2) {
                    $this->respondWithError('unauthorized', 'This store has less than two product.');
                }
            }
        }


        if ($productTypeName == 'virtual')
            $showProductInventory = Engine_Api::_()->getApi('settings', 'core')->getSetting('sitestorereservation.productinventory', 1);
        else
            $showProductInventory = true;

        if (isset($productTypeValue['discount']) && !empty($productTypeValue['discount'])) {

            $discount_array = explode("_", $productTypeValue['discount']);
            $count = count($discount_array);
            $productTypeValue['discount'] = $discount_array[$count - 1];
        }
        if (isset($productTypeValue['handling_type']) && !empty($productTypeValue['handling_type'])) {
            $handling_type = explode("_", $productTypeValue['handling_type']);
            $count = count($handling_type);
            $productTypeValue['handling_type'] = $handling_type[$count - 1];
        }

        if (isset($productTypeValue['discount_permanant']) && !empty($productTypeValue['discount_permanant'])) {
            $discount_permanant = explode("_", $productTypeValue['discount_permanant']);
            $count = count($discount_permanant);
            $productTypeValue['discount_permanant'] = $discount_permanant[$count - 1];
        }

        if (isset($productTypeValue['stock_unlimited']) && !empty($productTypeValue['stock_unlimited'])) {
            $stock_unlimited = explode("_", $productTypeValue['stock_unlimited']);
            $count = count($stock_unlimited);
            $productTypeValue['stock_unlimited'] = $stock_unlimited[$count - 1];
        }

        if (isset($productTypeValue['out_of_stock']) && !empty($productTypeValue['out_of_stock'])) {
            $out_of_stock = explode("_", $productTypeValue['out_of_stock']);
            $count = count($out_of_stock);
            $productTypeValue['out_of_stock'] = $out_of_stock[$count - 1];
        }

        if (isset($productTypeValue['end_date_enable']) && !empty($productTypeValue['end_date_enable'])) {
            $end_date_enable = explode("_", $productTypeValue['end_date_enable']);
            $count = count($end_date_enable);
            $productTypeValue['end_date_enable'] = $end_date_enable[$count - 1];
        }


        $params = array();
        $params['store_id'] = $store_id;
        $params['expiry_setting'] = $expiry_setting;
        $this->saveProduct($productTypeValue, $params);
    }

    public function saveProduct($formValues, $params) {
        $store_id = $params['store_id'];
        $viewer = Engine_Api::_()->user()->getViewer();
        $viewer_id = $viewer->getIdentity();
        $sitestore = Engine_Api::_()->getItem('sitestore_store', $store_id);
        $directPayment = Engine_Api::_()->sitestoreproduct()->isDirectPaymentEnable();
        $isDownPaymentEnable = Engine_Api::_()->getApi('settings', 'core')->getSetting('sitestorereservation.downpayment', 0);
        if ($formValues['product_type'] == "grouped" || $formValues['product_type'] == "bundled") {
            if (!empty($formValues['product_ids'])) {
                $productsArray = $tempProductsArray = array();
                $tempMappedIdsStr = $formValues['product_ids'];
                $tempMappedIds = explode(',', $formValues['product_ids']);
                foreach ($tempMappedIds as $product_id) {
                    $tempProductsArray['title'] = Engine_Api::_()->getItem('sitestoreproduct_product', $product_id)->title;
                    $tempProductsArray['id'] = $product_id;
                    $productsArray[] = $tempProductsArray;
                }
                $productArray = $productsArray;
            }
        }
        $isAdminDrivenStore = Engine_Api::_()->getApi('settings', 'core')->getSetting('is.sitestore.admin.driven', 0);

        if ($formValues['product_type'] != "grouped") {
            if (empty($formValues['min_order_quantity']))
                $formValues['min_order_quantity'] = isset($formValues['in_stock']) ? $formValues['in_stock'] : '';

            if (empty($formValues['max_order_quantity']))
                $formValues['max_order_quantity'] = isset($formValues['in_stock']) ? $formValues['in_stock'] : '';
        }

        $validateData = $getPostValuesArray = $formValues;

        if (@array_key_exists('section_id', $getPostValuesArray))
            unset($getPostValuesArray['section_id']);

        if (@array_key_exists('inputsection_id', $getPostValuesArray))
            unset($getPostValuesArray['inputsection_id']);

        $validators = Engine_Api::_()->getApi('Siteapi_FormValidators', 'sitestoreproduct')->getFormValidators();
        $validateData['validators'] = $validators;
        $validationMessage = $this->isValid($validateData);



        //PRODUCT IMAGE VALIDATION
        $isMainPhotoRequired = Engine_Api::_()->getApi('settings', 'core')->getSetting('sitestoreproduct.mainphoto', 1);
        if (!empty($isMainPhotoRequired) && !empty($params['copy_product']) && (!isset($_FILES['photo']) || empty($_FILES['photo']))) {

            $validationMessage = (is_array($validationMessage)) ? $validationMessage : array();
            $validationMessage['photo'] = $this->translate('Please complete this field - it is required.');
        }


        //CATEGORY IS REQUIRED FIELD
        if (empty($formValues['category_id'])) {
            $validationMessage = (is_array($validationMessage)) ? $validationMessage : array();
            $validationMessage['category_id'] = $this->translate('Please complete this field - it is required.');
        }
        $user_level = Engine_Api::_()->user()->getViewer()->level_id;
        $allowed_upload = Engine_Api::_()->authorization()->getPermission($user_level, 'sitestoreproduct_product', "photo");
        $isMainPhotoRequired = Engine_Api::_()->getApi('settings', 'core')->getSetting('sitestoreproduct.mainphoto', 1);
        if (!empty($isMainPhotoRequired) && !empty($allowed_upload) && empty($_FILES['photo'])) {
            $validationMessage = (is_array($validationMessage)) ? $validationMessage : array();
            $validationMessage['photo'] = $this->translate('Please complete this field - it is required.');
        }


        if ($formValues['product_type'] == "simple" && empty($formValues['price'])) {
            $validationMessage = (is_array($validationMessage)) ? $validationMessage : array();
            $validationMessage['price'] = $this->translate('Please complete this field - it is required.');
        }


        if ($formValues['product_type'] != "grouped" && !empty($formValues['discount']) && empty($formValues['discount_permanant']) && empty($formValues['discount_end_date'])) {
            $validationMessage = (is_array($validationMessage)) ? $validationMessage : array();
            $validationMessage['discount_permanant'] = $this->translate('Please complete this field - it is required.');
        }

        //VARIOUS LOGICAL CHECKS BITWEEN DIFFERENT PRODUCT ATTRIBUTES
        if ($formValues['product_type'] != "grouped" && (isset($formValues['stock_unlimited']) && empty($formValues['stock_unlimited'])) && !empty($formValues['min_order_quantity']) && $formValues['min_order_quantity'] > $formValues['in_stock']) {
            $validationMessage = (is_array($validationMessage)) ? $validationMessage : array();
            $validationMessage['min_order_quantity'] = $this->translate('Minimum Order Quantity can not be greater than In Stock value.');
        }

        if ($formValues['product_type'] != "grouped" && empty($formValues['stock_unlimited']) && !empty($formValues['max_order_quantity']) && $formValues['max_order_quantity'] > $formValues['in_stock']) {
            $validationMessage = (is_array($validationMessage)) ? $validationMessage : array();
            $validationMessage['max_order_quantity'] = $this->translate('Maximum Order Quantity can not be greater than In Stock value.');
        }

        if ($formValues['product_type'] != "grouped" && !empty($formValues['max_order_quantity']) && $formValues['max_order_quantity'] < $formValues['min_order_quantity']) {
            $validationMessage = (is_array($validationMessage)) ? $validationMessage : array();
            $validationMessage['min_order_quantity'] = $this->translate('Minimum Order Quantity can not be greater than Maximum Order Quantity.');
        }

        if ($formValues['product_type'] != "grouped" && $formValues['discount'] == 1 && $formValues['handling_type'] == 0 && $formValues['discount_price'] >= $formValues['price']) {
            $validationMessage = (is_array($validationMessage)) ? $validationMessage : array();
            $validationMessage['discount_price'] = $this->translate('Discount can not be more than and equal to actual price.');
        }

        if (($formValues['product_type'] == "grouped" || $formValues['product_type'] == 'bundled') && (empty($formValues['product_ids']) || COUNT(explode(',', $formValues['product_ids'])) <= 1)) {
            $validationMessage = (is_array($validationMessage)) ? $validationMessage : array();
            $validationMessage['product_ids'] = $this->translate('To create this product, you must select at least two products from this store.');
        }

        if ($formValues['product_type'] != 'grouped') {
            $validationMessage = (is_array($validationMessage)) ? $validationMessage : array();
            if (empty($formValues['min_order_quantity']))
                $validationMessage['min_order_quantity'] = $this->translate('Please complete this field - it is required.');
            elseif (!preg_match('/^[0-9]*$/', $formValues['min_order_quantity'])) {
                $validationMessage['min_order_quantity'] = $this->translate('Please enter valid quantity.');
            }
            if (!empty($formValues['max_order_quantity']) && !preg_match('/^[0-9]*$/', $formValues['max_order_quantity']))
                $validationMessage['max_order_quantity'] = $this->translate('Please enter valid quantity.');
        }

        if (!empty($formValues['end_date_enable'])) {
            $validationMessage = (is_array($validationMessage)) ? $validationMessage : array();

            if (strtotime($formValues['start_date']) > strtotime($formValues['end_date'])) {
                $validationMessage['start_date'] = $this->translate('Start Date should be less than End Date.');
            }
        }

        if (!empty($validationMessage) && is_array($validationMessage)) {
            $this->respondWithValidationError('validation_fail', $validationMessage);
        }

        //TAKING VARIOUS VALUES FOR PRODUCT AND OTHERINFO TABLE
        $otherInfoValues = array();
        $sitestoreproduct_values = $formValues;

//      if(empty ($temp_allow_selling)){
//        $sitestoreproduct_values['allow_purchase'] = 0;
//      }


        if ($sitestoreproduct_values['product_type'] != 'grouped') {
            if (empty($sitestoreproduct_values['max_order_quantity']))
                $sitestoreproduct_values['max_order_quantity'] = isset($sitestoreproduct_values['in_stock']) ? $sitestoreproduct_values['in_stock'] : '';

            // START DOWNPAYMENT WORK
            if (!empty($directPayment) && !empty($isDownPaymentEnable)) {
                if (!empty($sitestoreproduct_values['downpayment']))
                    $otherInfoValues['downpayment_value'] = $sitestoreproduct_values['downpaymentvalue'];
                else
                    $otherInfoValues['downpayment_value'] = 0;
                unset($sitestoreproduct_values['downpayment']);
                unset($sitestoreproduct_values['downpaymentvalue']);
            }
            // END DOWNPAYMENT WORK
            // START DISCOUNT WORK
            if (Engine_Api::_()->getDbtable("modules", "core")->isModuleEnabled("sitecredit") && $isAdminDrivenStore && Engine_Api::_()->getApi('settings', 'core')->getSetting('sitecredit.store.credit.redemption', 'all_store') == 'product_wise') {

                if (!empty($sitestoreproduct_values['credit_handling_type'])) {

                    $otherInfoValues['credit_limit'] = @round($sitestoreproduct_values['credit_limit'], 2);
                    $otherInfoValues['credit_handling_type'] = $sitestoreproduct_values['credit_handling_type'];
                } else {
                    if (!empty($sitestoreproduct_values['discount'])) {

                        if (empty($sitestoreproduct_values['handling_type'])) {
                            $otherInfoValues['discount_value'] = $otherInfoValues['discount_amount'] = @round($sitestoreproduct_values['discount_price'], 2);
                            $otherInfoValues['discount_percentage'] = @round($otherInfoValues['discount_value'] * 100 / $sitestoreproduct_values['price'], 2);
                        } else {
                            $otherInfoValues['discount_value'] = @round($sitestoreproduct_values['discount_rate'], 2);
                            $otherInfoValues['discount_percentage'] = @round($sitestoreproduct_values['discount_rate'], 2);
                            $otherInfoValues['discount_amount'] = $sitestoreproduct_values['price'] * $otherInfoValues['discount_value'] / 100;
                        }

                        $otherInfoValues['discount'] = $sitestoreproduct_values['discount'];
                        $otherInfoValues['handling_type'] = $sitestoreproduct_values['handling_type'];
                        $otherInfoValues['discount_start_date'] = $sitestoreproduct_values['discount_start_date'];

                        if (empty($sitestoreproduct_values['discount_permanant']))
                            $otherInfoValues['discount_end_date'] = $sitestoreproduct_values['discount_end_date'];

                        $otherInfoValues['discount_permanant'] = $sitestoreproduct_values['discount_permanant'];
                        $otherInfoValues['user_type'] = $sitestoreproduct_values['user_type'];
                    }
                }
                unset($sitestoreproduct_values['credit_handling_type']);
                unset($sitestoreproduct_values['credit_limit']);
            } else {
                if (!empty($sitestoreproduct_values['discount'])) {

                    if (empty($sitestoreproduct_values['handling_type'])) {
                        $otherInfoValues['discount_value'] = $otherInfoValues['discount_amount'] = @round($sitestoreproduct_values['discount_price'], 2);
                        $otherInfoValues['discount_percentage'] = @round($otherInfoValues['discount_value'] * 100 / $sitestoreproduct_values['price'], 2);
                    } else {
                        $otherInfoValues['discount_value'] = @round($sitestoreproduct_values['discount_rate'], 2);
                        $otherInfoValues['discount_percentage'] = @round($sitestoreproduct_values['discount_rate'], 2);
                        $otherInfoValues['discount_amount'] = $sitestoreproduct_values['price'] * $otherInfoValues['discount_value'] / 100;
                    }

                    $otherInfoValues['discount'] = $sitestoreproduct_values['discount'];
                    $otherInfoValues['handling_type'] = $sitestoreproduct_values['handling_type'];
                    $otherInfoValues['discount_start_date'] = $sitestoreproduct_values['discount_start_date'];

                    if (empty($sitestoreproduct_values['discount_permanant']))
                        $otherInfoValues['discount_end_date'] = $sitestoreproduct_values['discount_end_date'];

                    $otherInfoValues['discount_permanant'] = $sitestoreproduct_values['discount_permanant'];
                    $otherInfoValues['user_type'] = $sitestoreproduct_values['user_type'];
                }
            }

            unset($sitestoreproduct_values['discount']);
            unset($sitestoreproduct_values['handling_type']);
            unset($sitestoreproduct_values['discount_price']);
            unset($sitestoreproduct_values['discount_rate']);
            unset($sitestoreproduct_values['discount_start_date']);
            unset($sitestoreproduct_values['discount_end_date']);
            unset($sitestoreproduct_values['discount_permanant']);
            unset($sitestoreproduct_values['user_type']);
            // END DISCOUNT WORK

            if (isset($sitestoreproduct_values['user_tax']))
                $sitestoreproduct_values['user_tax'] = @serialize($sitestoreproduct_values['user_tax']);

            // START VIRTUAL PRODUCT DATE-CALENDAR AND PRICE BASIS WORK
            if ($sitestoreproduct_values['product_type'] == 'virtual') {
                $tempVirtualProductInfo = array();
                $isDateSelectorEnable = Engine_Api::_()->getApi('settings', 'core')->getSetting('sitestorereservation.dateselector', 0);
                if (!empty($isDateSelectorEnable)) {
                    $tempVirtualProductInfo['virtual_product_date_selector'] = $sitestoreproduct_values['virtual_product_date_selector'];
                    unset($sitestoreproduct_values['virtual_product_date_selector']);
                }

                if (!empty($sitestoreproduct_values['virtual_product_price_range'])) {
                    $tempVirtualProductInfo['virtual_product_price_range'] = $sitestoreproduct_values['virtual_product_price_range'];
                    unset($sitestoreproduct_values['virtual_product_price_range']);
                }

                if (!empty($tempVirtualProductInfo))
                    $otherInfoValues['product_info'] = serialize($tempVirtualProductInfo);
            }
            // END VIRTUAL PRODUCT DATE-CALENDAR AND PRICE BASIS WORK

            if ($sitestoreproduct_values['product_type'] == 'bundled') {

                if (@in_array('configurable', $sitestoreproduct_values['bundle_product_type']) || @in_array('virtual', $sitestoreproduct_values['bundle_product_type']))
                    $isConfigurationTabRequired = true;

                $mappedIdsArray = explode(',', $sitestoreproduct_values['product_ids']);
                $otherInfoValues['mapped_ids'] = Zend_Json_Encoder::encode($mappedIdsArray);
                $otherInfoValues['weight_type'] = $sitestoreproduct_values['weight_type'];

                $otherInfoValues['product_info'] = @serialize(array('enable_shipping' => $sitestoreproduct_values['enable_shipping'], 'bundle_product_type' => $sitestoreproduct_values['bundle_product_type']));

                if (!empty($sitestoreproduct_values['weight_type']))
                    $sitestoreproduct_values['weight'] = '';

                unset($sitestoreproduct_values['bundle_product_type']);
                unset($sitestoreproduct_values['enable_shipping']);
                unset($sitestoreproduct_values['product_name']);
                unset($sitestoreproduct_values['product_ids']);
                unset($sitestoreproduct_values['weight_type']);
            }

            $otherInfoValues['out_of_stock'] = isset($sitestoreproduct_values['out_of_stock']) ? $sitestoreproduct_values['out_of_stock'] : '';
            $otherInfoValues['out_of_stock_action'] = isset($sitestoreproduct_values['out_of_stock_action']) ? $sitestoreproduct_values['out_of_stock_action'] : '';

            // ADDING SPECIAL VAT IN OTHERINFO
            if (Engine_Api::_()->getApi('settings', 'core')->getSetting('sitestoreproduct.vat', 0) && isset($sitestoreproduct_values['special_vat'])) {
                if (empty($sitestoreproduct_values['special_vat']))
                    $otherInfoValues['special_vat'] = null;
                else
                    $otherInfoValues['special_vat'] = $sitestoreproduct_values['special_vat'];
            }

            unset($sitestoreproduct_values['out_of_stock']);
            unset($sitestoreproduct_values['out_of_stock_action']);
            unset($sitestoreproduct_values['special_vat']);
        }else {
            $otherInfoValues['mapped_ids'] = Zend_Json_Encoder::encode(explode(',', $sitestoreproduct_values['product_ids']));

            unset($sitestoreproduct_values['product_name']);
            unset($sitestoreproduct_values['product_ids']);
        }
        $db = Engine_Db_Table::getDefaultAdapter();
        $db->beginTransaction();
        $user_level = $viewer->level_id;
        try {
            //Create sitestoreproduct
            $values = array_merge($sitestoreproduct_values, array(
                'owner_type' => $viewer->getType(),
                'owner_id' => $viewer_id,
                'featured' => Engine_Api::_()->authorization()->getPermission($user_level, 'sitestoreproduct_product', "featured"),
                'sponsored' => Engine_Api::_()->authorization()->getPermission($user_level, 'sitestoreproduct_product', "sponsored"),
                'approved' => Engine_Api::_()->authorization()->getPermission($user_level, 'sitestoreproduct_product', "approved")
            ));

            if (empty($values['subcategory_id'])) {
                $values['subcategory_id'] = 0;
            }

            if (empty($values['subsubcategory_id'])) {
                $values['subsubcategory_id'] = 0;
            }

            if ($params['expiry_setting'] == 1 && $values['end_date_enable'] == 1) {
                // Convert times
                $oldTz = date_default_timezone_get();
                date_default_timezone_set($viewer->timezone);
                $end = strtotime($values['end_date']);
                date_default_timezone_set($oldTz);
                $values['end_date'] = date('Y-m-d H:i:s', $end);
            } elseif (isset($values['end_date'])) {
                unset($values['end_date']);
            }

            // Convert times
            if (isset($values['start_date']) && !empty($values['start_date'])) {
                $oldTz = date_default_timezone_get();
                date_default_timezone_set($viewer->timezone);
                $end = strtotime($values['start_date']);
                date_default_timezone_set($oldTz);
                $values['start_date'] = date('Y-m-d H:i:s', $end);
            }

            if (Engine_Api::_()->sitestoreproduct()->listBaseNetworkEnable()) {
                if (isset($values['networks_privacy']) && !empty($values['networks_privacy'])) {
                    if (in_array(0, $values['networks_privacy'])) {
                        unset($values['networks_privacy']);
                    }
                }
            }

            $sitestoreproduct = Engine_Api::_()->getItemTable('sitestoreproduct_product')->createRow();
            if ($_POST['product_type'] == 'grouped')
                $values['stock_unlimited'] = 1;

            if (@array_key_exists('max_order_quantity', $values) && empty($values['max_order_quantity']))
                unset($values['max_order_quantity']);

            if (empty($values['search'])) {
                $values['search'] = 0;
            }

            $values['store_id'] = $store_id;

            $values['weight'] = @number_format($values['weight'], 2, '.', ',');
            $values['price'] = @number_format($values['price'], 2, '.', '');

            $sitestoreproduct->setFromArray($values);

            if ($sitestoreproduct->approved) {
                $sitestoreproduct->approved_date = date('Y-m-d H:i:s');
            }

            if (!empty($_POST['section_id']) && !empty($_POST['inputsection_id']) && ($_POST['section_id'] == 'new')) {
                $tableSections = Engine_Api::_()->getDbTable('sections', 'sitestoreproduct');
                $tableSectionsName = $tableSections->info('name');

                $row_info = $tableSections->fetchRow($tableSections->select()->from($tableSectionsName, 'max(sec_order) AS sec_order'));
                $sec_order = $row_info['sec_order'] + 1;
                $row = $tableSections->createRow();
                $row->section_name = $_POST['inputsection_id'];
                $row->sec_order = $sec_order;
                $row->store_id = $store_id;
                $newsec_id = $row->save();
                $sitestoreproduct->section_id = $newsec_id;
            }

            if (@array_key_exists("section_id", $_POST) && ($_POST['section_id'] != 'new'))
                $sitestoreproduct->section_id = $_POST['section_id'];

            if (empty($sitestoreproduct->section_id)) {
                unset($sitestoreproduct->section_id);
            }

            $sitestoreproduct->save();
            $product_id = $sitestoreproduct->product_id;

            //START PAGE INTEGRATION WORK
            $page_id = $this->_getParam('page_id');
            if (!empty($page_id)) {
                $moduleEnabled = Engine_Api::_()->getDbtable('modules', 'core')->isModuleEnabled('sitepageintegration');
                if (!empty($moduleEnabled)) {
                    $contentsTable = Engine_Api::_()->getDbtable('contents', 'sitepageintegration');
                    $row = $contentsTable->createRow();
                    $row->owner_id = $viewer_id;
                    $row->resource_owner_id = $sitestoreproduct->owner_id;
                    $row->page_id = $page_id;
                    $row->resource_type = 'sitestoreproduct_product';
                    $row->resource_id = $sitestoreproduct->product_id;
                    $row->save();
                }
            }

            //END PAGE INTEGRATION WORK
            if ($sitestoreproduct->product_type == 'configurable' || $sitestoreproduct->product_type == 'virtual') {
                $sitestoreform = Engine_Api::_()->fields()->getTable('sitestoreproduct_cartproduct', 'options')->createRow();
                $sitestoreform->label = $values['title'];
                $sitestoreform->field_id = 1;
                $option_id = $sitestoreform->save();
                $optionids = Engine_Api::_()->getDbtable('productfields', 'sitestoreproduct')->createRow();
                $optionids->option_id = $option_id;
                $optionids->product_id = $sitestoreproduct->product_id;
                $optionids->save();

                // ENTER THE CATEGORY FIELDS IN PRODUCT ATTRIBUTES TABLE
                $categoryFields = Engine_Api::_()->sitestoreproduct()->getProductCategoryFields($sitestoreproduct);
                if (!empty($categoryFields)) {
                    $order = 1;
                    foreach ($categoryFields as $field) {
                        if ($field['type'] == 'select') {
                            $sitestoremeta = Engine_Api::_()->fields()->getTable('sitestoreproduct_cartproduct', 'meta')->createRow();
                            $sitestoremeta->option_id = $option_id;
                            $sitestoremeta->type = $field['type'];
                            $sitestoremeta->label = $field['lable'];
                            $sitestoremeta->display = 1;
                            $field_id = $sitestoremeta->save();
                            $sitestoremap = Engine_Api::_()->fields()->getTable('sitestoreproduct_cartproduct', 'maps')->createRow();
                            $sitestoremap->field_id = 1;
                            $sitestoremap->option_id = $option_id;
                            $sitestoremap->child_id = $field_id;
                            $sitestoremap->order = $order++;
                            $sitestoremap->save();
                            if (isset($field['multioptions']) && !empty($field['multioptions'])) {
                                foreach ($field['multioptions'] as $option) {
                                    $sitestoreoption = Engine_Api::_()->fields()->getTable('sitestoreproduct_cartproduct', 'options')->createRow();
                                    $sitestoreoption->field_id = $field_id;
                                    $sitestoreoption->label = $option['label'];
                                    $sitestoreoption->order = $option['order'];
                                    $sitestoreoption->save();
                                }
                            }
                        }
                    }
                }
            }

            try {

                //SET PHOTO
                if (empty($params['copy_product']) && !empty($_FILES['photo'])) {
                    $sitestoreproduct = Engine_Api::_()->getApi('Siteapi_Core', 'sitestoreproduct')->setPhoto($_FILES['photo'], $sitestoreproduct);
                    $albumTable = Engine_Api::_()->getDbtable('albums', 'sitestoreproduct');
                    $album_id = $albumTable->update(array('photo_id' => $sitestoreproduct->photo_id), array('product_id = ?' => $sitestoreproduct->product_id));
                }
            } catch (Exception $ex) {
                $this->respondWithValidationError('internal_server_error', $ex->getMessage());
            }
//            if (!empty($params['copy_product']) && (!empty($_FILES['photo']) || !empty($_FILES['photo']))) {
//                    $imageFlag = 0;
//                    if (@count($_FILES['photo']) > 0) {
//                        foreach ($_FILES['photo'] as $file_id) {
//                            $sitestoreproduct->setCopyPhoto($flag = 1, $file_id, $sitestoreproduct, $imageFlag);
//                            $imageFlag++;
//                        }
//                    }
//
//                    if (@count($_FILES['photo']) > 0) {
//                        foreach ($_FILES['photo'] as $file_id) {
//                            $sitestoreproduct->setCopyPhoto($flag = 0, $file_id, $sitestoreproduct, $imageFlag);
//                            $imageFlag++;
//                        }
//                    }
//
//                    if (!empty($sitestoreproduct)) {
//                        $albumTable = Engine_Api::_()->getDbtable('albums', 'sitestoreproduct');
//                        $album_id = $albumTable->update(array('photo_id' => $sitestoreproduct->photo_id), array('product_id = ?' => $sitestoreproduct->product_id));
//                    }
//                }
            //ADDING TAGS
            $keywords = '';
            if (isset($values['tags']) && !empty($values['tags'])) {
                $tags = preg_split('/[,]+/', $values['tags']);
                $tags = array_filter(array_map("trim", $tags));
                $sitestoreproduct->tags()->addTagMaps($viewer, $tags);

                foreach ($tags as $tag) {
                    $keywords .= " $tag";
                }
            }
            $data = $_REQUEST;
            if (empty($data['draft'])) {
                $data['draft'] = 1;
            } else {
                $data['draft'] = 0;
            }
            Engine_Api::_()->getApi('Siteapi_Core', 'sitestore')->setProfileFields($sitestoreproduct, $data);

            //SAVE CUSTOM VALUES AND PROFILE TYPE VALUE
            $categoryIds = array();
            $categoryIds[] = $sitestoreproduct->category_id;
            $categoryIds[] = $sitestoreproduct->subcategory_id;
            $categoryIds[] = $sitestoreproduct->subsubcategory_id;
            try {
                $sitestoreproduct->profile_type = Engine_Api::_()->getDbTable('categories', 'sitestoreproduct')->getProfileType($categoryIds, 0, 'profile_type');
            } catch (Exception $ex) {
                $sitestoreproduct->profile_type = 0;
            }


            //NOT SEARCHABLE IF SAVED IN DRAFT MODE
            if (!empty($sitestoreproduct->draft)) {
                $sitestoreproduct->search = 0;
            }
            $sitestoreproduct->save();

            if (!empty($product_id)) {
                $sitestoreproduct->setLocation();
            }

            //PRIVACY WORK
            $auth = Engine_Api::_()->authorization()->context;

            $roles = array('owner', 'owner_member', 'owner_member_member', 'owner_network', 'registered', 'everyone');

            if (empty($values['auth_view'])) {
                $values['auth_view'] = array("everyone");
            }

            if (empty($values['auth_comment'])) {
                $values['auth_comment'] = array("everyone");
            }

            $viewMax = array_search($values['auth_view'], $roles);
            $commentMax = array_search($values['auth_comment'], $roles);

            foreach ($roles as $i => $role) {
                $auth->setAllowed($sitestoreproduct, $role, "view", ($i <= $viewMax));
                $auth->setAllowed($sitestoreproduct, $role, "comment", ($i <= $commentMax));
            }

            $roles = array('owner', 'owner_member', 'owner_member_member', 'owner_network', 'registered');
            if (empty($values['auth_photo'])) {
                $values['auth_photo'] = array("owner");
            }

            if (!isset($values['auth_video']) && empty($values['auth_video'])) {
                $values['auth_video'] = array("owner");
            }

            $photoMax = array_search($values['auth_photo'], $roles);
            $videoMax = array_search($values['auth_video'], $roles);
            foreach ($roles as $i => $roles) {
                $auth->setAllowed($sitestoreproduct, $roles, "photo", ($i <= $photoMax));
                $auth->setAllowed($sitestoreproduct, $roles, "video", ($i <= $videoMax));
            }

            $tableOtherinfo = Engine_Api::_()->getDbTable('otherinfo', 'sitestoreproduct');

            $row = $tableOtherinfo->getOtherinfo($product_id);
            if (empty($row)) {

                // SAVE MULTILANGUAL OVERVIEW IN OTHERINFO TABLE
                $otherInfoArray = array(
                    'product_id' => $product_id,
                    'overview' => isset($values['overview']) ? $values['overview'] : '',
                    'out_of_stock' => isset($otherInfoValues['out_of_stock']) ? $otherInfoValues['out_of_stock'] : '',
                    'out_of_stock_action' => isset($otherInfoValues['out_of_stock_action']) ? $otherInfoValues['out_of_stock_action'] : '',
                    'mapped_ids' => isset($otherInfoValues['mapped_ids']) ? $otherInfoValues['mapped_ids'] : '',
                    'weight_type' => isset($otherInfoValues['weight_type']) ? $otherInfoValues['weight_type'] : '',
                    'discount' => isset($otherInfoValues['discount']) ? $otherInfoValues['discount'] : '',
                    'handling_type' => isset($otherInfoValues['handling_type']) ? $otherInfoValues['handling_type'] : '',
                    'discount_value' => isset($otherInfoValues['discount_value']) ? $otherInfoValues['discount_value'] : '',
                    'discount_start_date' => isset($otherInfoValues['discount_start_date']) ? $otherInfoValues['discount_start_date'] : '',
                    'discount_end_date' => isset($otherInfoValues['discount_end_date']) ? $otherInfoValues['discount_end_date'] : '',
                    'discount_permanant' => isset($otherInfoValues['discount_permanant']) ? $otherInfoValues['discount_permanant'] : '',
                    'user_type' => isset($otherInfoValues['user_type']) ? $otherInfoValues['user_type'] : '',
                    'discount_amount' => isset($otherInfoValues['discount_amount']) ? $otherInfoValues['discount_amount'] : '',
                    'discount_percentage' => isset($otherInfoValues['discount_percentage']) ? $otherInfoValues['discount_percentage'] : '',
                    'product_info' => isset($otherInfoValues['product_info']) ? $otherInfoValues['product_info'] : '',
                    'downpayment_value' => isset($otherInfoValues['downpayment_value']) ? $otherInfoValues['downpayment_value'] : '',
                    'special_vat' => isset($otherInfoValues['special_vat']) ? $otherInfoValues['special_vat'] : '',
                );

                if (Engine_Api::_()->getDbtable("modules", "core")->isModuleEnabled("sitecredit") && $isAdminDrivenStore && Engine_Api::_()->getApi('settings', 'core')->getSetting('sitecredit.store.credit.redemption', 'all_store') == 'product_wise') {
                    $otherInfoArray['credit_handling_type'] = isset($otherInfoValues['credit_handling_type']) ? $otherInfoValues['credit_handling_type'] : '';
                    $otherInfoArray['credit_limit'] = isset($otherInfoValues['credit_limit']) ? $otherInfoValues['credit_limit'] : '';
                }

                //DEFAULT LANGUAGE
                $temp_languages = Engine_Api::_()->getApi('settings', 'core')->getSetting('sitestoreproduct.languages', null);
                if (!empty($temp_languages)) {
                    $languageCount = Count($temp_languages);
                    foreach ($temp_languages as $language_label) {
                        if ($languageCount >= 2 && $language_label != 'en') {
                            $overview = "overview_" . $language_label;
                            $otherInfoArray[$overview] = isset($values[$overview]) ? $values[$overview] : '';
                        }
                    }
                }

                Engine_Api::_()->getDbTable('otherinfo', 'sitestoreproduct')->insert($otherInfoArray);
            }

            if ($sitestoreproduct->draft == 0 && $sitestoreproduct->search) {
                $actionTable = Engine_Api::_()->getDbtable('actions', 'activity');
                $activityFeedType = null;
                if (Engine_Api::_()->sitestore()->isStoreOwner($sitestore) && Engine_Api::_()->sitestore()->isFeedTypeStoreEnable())
                    $activityFeedType = 'sitestoreproduct_admin_new';
                elseif ($sitestore->all_post || Engine_Api::_()->sitestore()->isStoreOwner($sitestore))
                    $activityFeedType = 'sitestoreproduct_new';

                if ($activityFeedType) {
                    $action = $actionTable->addActivity($viewer, $sitestore, $activityFeedType);
                    Engine_Api::_()->getApi('subCore', 'sitestore')->deleteFeedStream($action);
                }
                //MAKE SURE ACTION EXISTS BEFOR ATTACHING THE NOTE TO THE ACTIVITY
                if ($action != null) {
                    $actionTable->attachActivity($action, $sitestoreproduct, Activity_Model_Action::ATTACH_MULTI);
                }

                //SENDING ACTIVITY FEED TO FACEBOOK.
                $enable_Facebooksefeed = $enable_fboldversion = Engine_Api::_()->getDbtable('modules', 'core')->isModuleEnabled('facebooksefeed');
                if (!empty($enable_Facebooksefeed)) {
                    $product_array = array();
                    $product_array['type'] = 'sitestoreproduct_new';
                    $product_array['object'] = $sitestoreproduct;
                    $product_array['store_title'] = $sitestore->getTitle();
                    $product_array['store_url'] = $sitestore->getHref();
                    Engine_Api::_()->facebooksefeed()->sendFacebookFeed($product_array);
                }
            }
//                Engine_Api::_()->getApi('Core', 'siteapi')->setLocal();
//                $defaultproductcreateMail=0;
//                try{
//                    //$defaultproductcreateMail=Engine_Api::_()->getApi('settings', 'core')->hasSetting('sitestoreproduct.defaultproductcreate.email');
//                } catch (Exception $ex) {
//
//                }
//                if ($defaultproductcreateMail) {
//
//                    $getDefaultProductCreateEmail = Engine_Api::_()->getApi('settings', 'core')->getSetting('sitestoreproduct.defaultproductcreate.email', null);
//                    $emailAddress = explode(",", $getDefaultProductCreateEmail);
//                    foreach ($emailAddress as $email) {
//                        if (!empty($email)) {
//                            $email = trim($email);
//                            $host = $_SERVER['HTTP_HOST'];
//                            $object_link = (_ENGINE_SSL ? 'https://' : 'http://') . $host . $sitestoreproduct->getHref();
//
//                            Engine_Api::_()->getApi('mail', 'core')->sendSystem($email, 'SITESTOREPRODUCT_PRODUCT_CREATION_EDITOR', array(
//                                'object_link' => $object_link,
//                                'object_title' => $sitestoreproduct->getTitle(),
//                                'object_description' => $sitestoreproduct->getDescription(),
//                                'queue' => true
//                            ));
//                        }
//                    }
//                } else {
//                    $users = Engine_Api::_()->getDbtable('editors', 'sitestoreproduct')->getAllEditors();
//                    foreach ($users as $user_ids) {
//                        if (!empty($user_ids->user_id)) {
//                            $subjectOwner = Engine_Api::_()->getItem('user', $user_ids->user_id);
//
//                            if (!empty($subjectOwner->email)) {
//                                $host = $_SERVER['HTTP_HOST'];
//                                $object_link = (_ENGINE_SSL ? 'https://' : 'http://') . $host . $sitestoreproduct->getHref();
//
//                                Engine_Api::_()->getApi('mail', 'core')->sendSystem($subjectOwner->email, 'SITESTOREPRODUCT_PRODUCT_CREATION_EDITOR', array(
//                                    'object_link' => $object_link,
//                                    'object_title' => $sitestoreproduct->getTitle(),
//                                    'object_description' => $sitestoreproduct->getDescription(),
//                                    'queue' => true
//                                ));
//                            }
//                        }
//                    }
//                }

            $db->commit();
        } catch (Exception $e) {
            $db->rollBack();
            $this->respondWithValidationError('internal_server_error', $e->getMessage());
        }

        // NOTIFICATION TO BUYERS, WHO FOLLOW THE STORE
        if (empty($sitestoreproduct->draft) && !empty($sitestoreproduct->search)) {
            $follow_table = Engine_Api::_()->getDbtable('follows', 'seaocore');
            $followers = $follow_table->select()
                            ->from($follow_table->info('name'), 'poster_id')
                            ->where('resource_type =?', 'sitestore_store')
                            ->where('resource_id =?', $sitestoreproduct->store_id)
                            ->query()->fetchAll();

            if (!empty($followers)) {
                $notification_table = Engine_Api::_()->getDbtable('notifications', 'activity');
                foreach ($followers as $follower) {
                    $followerObj = Engine_Api::_()->getItem('user', $follower['poster_id']);
                    if (!empty($followerObj))
                        $notification_table->addNotification($followerObj, $sitestore, $sitestoreproduct, 'sitestoreproduct_create');
                }
            }
        }

        //UPDATE KEYWORDS IN SEARCH TABLE
        if (!empty($keywords)) {
            Engine_Api::_()->getDbTable('search', 'core')->update(array('keywords' => $keywords), array('type = ?' => 'sitestoreproduct_product', 'id = ?' => $sitestoreproduct->product_id));
        }

        $bodyParams['response']['store_id'] = $sitestoreproduct->store_id;
        $bodyParams['response']['product_id'] = $sitestoreproduct->getIdentity();
        $this->respondWithSuccess($bodyParams);

//      //OVERVIEW IS ENABLED OR NOT
//      $allowOverview = Engine_Api::_()->authorization()->getPermission($viewer->level_id, 'sitestoreproduct_product', "overview");
//
//      //EDIT IS ENABLED OR NOT
//      $alloweEdit = Engine_Api::_()->authorization()->getPermission($viewer->level_id, 'sitestoreproduct_product', "edit");
        //REDIRECTION IN CONFIGURABLE AND DOWNLOADABLE PRODUCTS
        //$this->successResponseNoContent('no_content', true);
//        $this->setRequestMethod();
//        $this->_forward('view', 'index', 'sitestoreproduct', array(
//            'product_id' => $sitestoreproduct->product_id,
//        ));
//        return ;
    }

    //ACTION FOR EDITING THE SITESTOREPRODUCT
    public function editAction() {
        
        if (!$this->_helper->requireUser()->isValid())
            $this->respondWithError('unauthorized');

        $product_id = $this->_getParam('product_id', NULL);

        //IF STORE ID NOT SUPPLIED THEN STORE NOT FOUND
        if (empty($product_id)) {
            $this->respondWithError('unauthorized');
        }

        $sitestoreproduct = Engine_Api::_()->getItem('sitestoreproduct_product', $product_id);
        $sitestore = Engine_Api::_()->getItem('sitestore_store', $sitestoreproduct->store_id);
//    $authValue = Engine_Api::_()->sitestoreproduct()->isStoreAdmin($sitestoreproduct->store_id);
        $isProductEnabled = Engine_Api::_()->sitestoreproduct()->isProductEnabled();
        $directPayment = Engine_Api::_()->sitestoreproduct()->isDirectPaymentEnable();
        $isDownPaymentEnable = Engine_Api::_()->getApi('settings', 'core')->getSetting('sitestorereservation.downpayment', 0);
        $allowProductCode = Engine_Api::_()->getApi('settings', 'core')->getSetting('sitestoreproduct.productcode', 1);
        $isAdminDrivenStore = Engine_Api::_()->getApi('settings', 'core')->getSetting('is.sitestore.admin.driven', 0);

        //IS USER IS STORE ADMIN OR NOT
//    if (empty($authValue))
//      return $this->_forward('requireauth', 'error', 'core');
//    else if ($authValue == 1)
//      return $this->_forward('notfound', 'error', 'core');

        $settings = Engine_Api::_()->getApi('settings', 'core');

        //MULTI LANGUAGE IS ALLOWED OR NOT
        $multiLanguage = $settings->getSetting('sitestoreproduct.multilanguage', 0);

        //DEFAULT LANGUAGE
        $defaultLanguage = $defaultLanguage = $settings->getSetting('core.locale.locale', 'en');


        $title_link = 'title';
        $body_link = 'body';
        if ($multiLanguage) {
            //GET LANGUAGE ARRAY
            $localeMultiOptions = Engine_Api::_()->sitestoreproduct()->getLanguageArray();
            $languages = $settings->getSetting('sitestoreproduct.languages');
            $languageCount = Count($languages);
            $languageData = array();
            if (is_array($languages)) {
                foreach ($languages as $label) {
                    $languageData[] = $label;
                    if ($languageCount >= 2 && $defaultLanguage == $label && $label != 'en') {
                        $title_link = "title_$label";
                        $body_link = "body_$label";
                    }
                }
            }
        }

        $sitestores_view_menu = 1;
        $listValues = array();
        $response = array();
        $viewer = Engine_Api::_()->user()->getViewer();
        $viewer_id = $viewer->getIdentity();

        $category_edit = Engine_Api::_()->getApi('settings', 'core')->getSetting('sitestoreproduct.categoryedit', 1);
        // Comment Privacy
        $isCommentsAllow = Engine_Api::_()->sitestore()->isCommentsAllow("sitestoreproduct_product");
        $response['formValues'] = $sitestoreproductinfo = $sitestoreproduct->toArray();
        if(empty($response['formValues']['max_order_quantity']))
            $response['formValues']['max_order_quantity'] = "";
        $response['formValues']['stock_unlimited'] ='stock_unlimited_'.$sitestoreproduct->stock_unlimited;
        $category_id = $previous_category_id = $sitestoreproduct->category_id;
        $subcategory_id = $subcategory_id = $sitestoreproduct->subcategory_id;
        $subsubcategory_id = $subsubcategory_id = $sitestoreproduct->subsubcategory_id;

        $row = Engine_Api::_()->getDbtable('categories', 'sitestoreproduct')->getCategory($subcategory_id);
        $subcategory_name = "";
        if (!empty($row)) {
            $subcategory_name = $row->category_name;
        }

        if (!Engine_Api::_()->core()->hasSubject()) {
            Engine_Api::_()->core()->setSubject($sitestoreproduct);
        }

        if (!$this->_helper->requireSubject()->isValid())
            $this->respondWithError('unauthorized');

        if (!$this->_helper->requireAuth()->setAuthParams($sitestoreproduct, $viewer, "edit")->isValid()) {
            $this->respondWithError('unauthorized');
        }

        //MARK IN CALENDER FLAG
        $showMarkerInDate = $this->showMarkerInDate();

        //GET DEFAULT PROFILE TYPE ID
        $defaultProfileId = $defaultProfileId = Engine_Api::_()->getDbTable('metas', 'sitestoreproduct')->defaultProfileId();

        //GET PROFILE MAPPING ID
        $categoryIds = $oldCategoryIds = array();
        $categoryIds[] = $oldCategoryIds[] = $sitestoreproduct->category_id;
        if (!empty($sitestoreproduct->subcategory_id))
            $categoryIds[] = $oldCategoryIds[] = $sitestoreproduct->subcategory_id;
        if (!empty($sitestoreproduct->subsubcategory_id))
            $categoryIds[] = $oldCategoryIds[] = $sitestoreproduct->subsubcategory_id;
        try {


            $profileType = $previous_profile_type = Engine_Api::_()->getDbtable('categories', 'sitestoreproduct')->getProfileType($categoryIds, 0, 'profile_type');

            if (isset($_POST['category_id']) && !empty($_POST['category_id'])) {
                $categoryIds = array();
                $categoryIds[] = $_POST['category_id'];
                if (isset($_POST['subcategory_id']) && !empty($_POST['subcategory_id'])) {
                    $categoryIds[] = $_POST['subcategory_id'];
                }
                if (isset($_POST['subsubcategory_id']) && !empty($_POST['subsubcategory_id'])) {
                    $categoryIds[] = $_POST['subsubcategory_id'];
                }
                $profileType = $previous_profile_type = Engine_Api::_()->getDbtable('categories', 'sitestoreproduct')->getProfileType($categoryIds, 0, 'profile_type');
            }
        } catch (Exception $ex) {
            $profileType = 0;
        }
        //GET PRODUCT USING LEVEL OR PACKAGE BASED SETTINGS
        $packageEnable = Engine_Api::_()->getApi('settings', 'core')->getSetting('sitestore.package.enable', 1);
        if (!empty($packageEnable)) {
            $packageObj = Engine_Api::_()->getItem('sitestore_package', $sitestore->package_id);
            if (empty($packageObj->store_settings)) {
                $product_types = array('simple', 'configurable', 'virtual', 'grouped', 'bundled', 'downloadable');
            } else {
                $storeSettings = @unserialize($packageObj->store_settings);
                $product_types = $storeSettings['product_type'];
            }
        } else {
            $user = $sitestore->getOwner();
            $product_types = Engine_Api::_()->authorization()->getPermission($user->level_id, "sitestore_store", "product_type");
            $product_types = Zend_Json_Decoder::decode($product_types);
        }

        if ($sitestoreproduct->product_type == 'virtual')
            $showProductInventory = Engine_Api::_()->getApi('settings', 'core')->getSetting('sitestorereservation.productinventory', 1);
        else
            $showProductInventory = true;

        //MAKE FORM
        $productTypeName = $_POST['product_type'] = $sitestoreproduct->product_type;

        $inDraft = 1;
        if (empty($sitestoreproduct->draft)) {
            $inDraft = 0;
        }

        $temp_allow_selling = Engine_Api::_()->sitestoreproduct()->getIsAllowedSellingProducts($sitestoreproduct->store_id, false);


        $intrestedViewerEmailCount = Engine_Api::_()->getDbtable('notifyemails', 'sitestoreproduct')->getNotifyEmail($product_id, 'COUNT(notifyemail_id)')->query()->fetchColumn();
        if (!empty($intrestedViewerEmailCount)) {
//            $form->addElement('Checkbox', 'notify_viewer', array(
//                'label' => $this->view->translate(array('%s viewer is', '%s viewers are', $intrestedViewerEmailCount), $this->view->locale()->toNumber($intrestedViewerEmailCount)) . ' ' . $this->view->translate('intrested in this product. Do you want to send an email about availability of this product?'),
//                'value' => true,
//                'order' => 102,
//            ));
        }


        $expiry_setting = Engine_Api::_()->sitestoreproduct()->expirySettings();
        // ASSIGNED THE OTHERINFO TABLE CONTENT VALUES TO FORM
        $otherInfoObj = Engine_Api::_()->getDbtable('otherinfo', 'sitestoreproduct')->getOtherinfo($sitestoreproduct->product_id);
        $response['formValues'] = array_merge($response['formValues'], $otherInfoObj->toArray());
        $response['formValues']['discount'] = 'discount_' . $otherInfoObj->discount;
        $response['formValues']['out_of_stock'] = 'out_of_stock_' . $otherInfoObj->out_of_stock;
        $response['formValues']['discount_permanant'] = 'discount_permanant_' . $otherInfoObj->discount_permanant;
        if ($otherInfoObj->handling_type)
            $response['formValues']['handling_type'] = 'percent_' . $otherInfoObj->handling_type;
        else {
            $response['formValues']['handling_type'] = 'fixed_' . $otherInfoObj->handling_type;
        }
        $tempOtherInfos = array();
        $tempOtherInfos['out_of_stock'] = $otherInfoObj->out_of_stock;
        $tempOtherInfos['out_of_stock_action'] = $otherInfoObj->out_of_stock_action;
        $tempOtherInfos['discount'] = $otherInfoObj->discount;
        $tempOtherInfos['handling_type'] = $otherInfoObj->handling_type;
        $tempOtherInfos['discount_start_date'] = $otherInfoObj->discount_start_date;
        $tempOtherInfos['discount_end_date'] = $otherInfoObj->discount_end_date;
        $tempOtherInfos['discount_permanant'] = $otherInfoObj->discount_permanant;
        $tempOtherInfos['user_type'] = $otherInfoObj->user_type;
        if(!empty($otherInfoObj)){

            $tempOtherInfos['special_vat'] = $otherInfoObj->special_vat;

            $response['formValues']['special_vat'] = !empty($otherInfoObj->special_vat) ? $otherInfoObj->special_vat : '';
        }
        if (Engine_Api::_()->getDbtable("modules", "core")->isModuleEnabled("sitecredit") && $isAdminDrivenStore && Engine_Api::_()->getApi('settings', 'core')->getSetting('sitecredit.store.credit.redemption', 'all_store') == 'product_wise') {
            $tempOtherInfos['credit_limit'] = $otherInfoObj->credit_limit;
            $tempOtherInfos['credit_handling_type'] = $otherInfoObj->credit_handling_type;
        }
        $store_id = $sitestoreproduct->store_id;


        if ($sitestoreproduct->product_type == 'virtual' || $sitestoreproduct->product_type == 'bundled')
            $product_info = unserialize($otherInfoObj->product_info);

        $isSitestorereservationModuleExist = Engine_Api::_()->sitestoreproduct()->isSitestorereservationModuleExist();
        if ($sitestoreproduct->product_type == 'virtual' && !empty($isSitestorereservationModuleExist)) {
            $response['formValues']['virtual_product_price_range'] = $tempOtherInfos['virtual_product_price_range'] = isset($product_info['virtual_product_price_range']) ? $product_info['virtual_product_price_range'] : null;
            $isDateSelectorEnable = Engine_Api::_()->getApi('settings', 'core')->getSetting('sitestorereservation.dateselector', 0);
            if (!empty($isDateSelectorEnable))
                $response['formValues']['virtual_product_date_selector'] = $tempOtherInfos['virtual_product_date_selector'] = isset($product_info['virtual_product_date_selector']) ? $product_info['virtual_product_date_selector'] : null;
        }
        
        // SHOW DOWNPAYMENT VALUE PRE-FILLED
        if ($sitestoreproduct->product_type != 'grouped' && !empty($isDownPaymentEnable) && !empty($directPayment)) {
            if (empty($otherInfoObj->downpayment_value))
                $response['formValues']['downpayment'] = $tempOtherInfos['downpayment'] = 0;
            else {
                $response['formValues']['downpayment'] = $tempOtherInfos['downpayment'] = 1;
                $response['formValues']['downpaymentvalue'] = $tempOtherInfos['downpaymentvalue'] = $otherInfoObj->downpayment_value;
            }
        }

        if ($sitestoreproduct->product_type == 'bundled') {
            $response['formValues']['weight_type'] = $tempOtherInfos['weight_type'] = $otherInfoObj->weight_type;
            $response['formValues']['weight_type'] = "weight_type_" . $otherInfoObj->weight_type;
            $response['formValues']['enable_shipping'] = $tempOtherInfos['enable_shipping'] = $product_info['enable_shipping'];
            $response['formValues']['bundle_product_type'] = $tempOtherInfos['bundle_product_type'] = $product_info['bundle_product_type'];
        }


        if ($sitestoreproduct->product_type == 'bundled' || $sitestoreproduct->product_type == 'grouped') {

            $tempMappedIds = $otherInfoObj->mapped_ids;
            if (!empty($tempMappedIds)) {
                $productMappedIds = $tempMappedIds = Zend_Json_Decoder::decode($tempMappedIds);
                $productsArray = $tempProductsArray = array();

                foreach ($tempMappedIds as $tempIdsKey => $product_id) {
                    $productTitle = Engine_Api::_()->getDbTable('products', 'sitestoreproduct')->getProductTitle($product_id);
                    if (empty($productTitle)) {
                        unset($productMappedIds[$tempIdsKey]);
                        continue;
                    }
                    $tempProductsArray['title'] = $productTitle;
                    $tempProductsArray['id'] = $product_id;
                    $productsArray[] = $tempProductsArray;
                }

                $tempMappedIdsStr = @implode(",", $productMappedIds);
                $productArray = $productsArray;
                $response['formValues']['product_ids'] = $productArray;
            }
        }

        if (empty($otherInfoObj->handling_type))
            $response['formValues']['discount_price'] = $tempOtherInfos['discount_price'] = @number_format($otherInfoObj->discount_value, 2, '.', ',');
        else
            $response['formValues']['discount_rate'] = $tempOtherInfos['discount_rate'] = @number_format($otherInfoObj->discount_value, 2, '.', ',');


        //SAVE SITESTOREPRODUCT ENTRY
        if (!$this->getRequest()->isPost()) {

            //prepare tags
            $sitestoreproductTags = $sitestoreproduct->tags()->getTagMaps();
            $tagString = '';

            foreach ($sitestoreproductTags as $tagmap) {

                if ($tagString != '')
                    $tagString .= ', ';
                $tagString .= $tagmap->getTag()->getTitle();
            }

            $response['formValues']['tags'] = $tagString;

            // $tempValues = array_merge($sitestoreproduct->toArray(), $tempOtherInfos);

            if (array_key_exists("weight", $tempValues)) {
                $getPercisionValue = Engine_Api::_()->getApi('settings', 'core')->getSetting('sitestoreproduct.rate.precision', 2);
                $response['formValues']['tags'] = $tempValues['weight'] = @number_format($tempValues['weight'], 2, '.', ','); //@round($tempValues['weight'], $getPercisionValue);
            }


            if ($sitestoreproduct->end_date && $sitestoreproduct->end_date != '0000-00-00 00:00:00') {

                // Convert and re-populate times
                $end = strtotime($sitestoreproduct->end_date);
                $oldTz = date_default_timezone_get();
                date_default_timezone_set($viewer->timezone);
                $end = date('Y-m-d H:i:s', $end);
                $response['formValues']['end_date'] = $end;
                date_default_timezone_set($oldTz);
            } else if (empty($sitestoreproduct->end_date) || $sitestoreproduct->end_date == '0000-00-00 00:00:00') {
                $response['formValues']['end_date'] = $date = (string) date('Y-m-d');
            }

            // Convert and re-populate times
            $end = strtotime($sitestoreproduct->start_date);
            $oldTz = date_default_timezone_get();
            date_default_timezone_set($viewer->timezone);
            $response['formValues']['start_date'] = $end = date('Y-m-d H:i:s', $end);
            date_default_timezone_set($oldTz);

            $previous_profile_type = Engine_Api::_()->getDbtable('categories', 'sitestoreproduct')->getProfileType($categoryIds, 0, 'profile_type');

            if ($sitestoreproduct->product_type != 'grouped' && (empty($otherInfoObj->discount_start_date) || $otherInfoObj->discount_start_date == '0000-00-00 00:00:00')) {
                $date = (string) date('Y-m-d');
                $response['formValues']['discount_start_date'] = $date . ' 00:00:00';
            }

            if ($sitestoreproduct->product_type != 'grouped' && (empty($otherInfoObj->discount_end_date) || $otherInfoObj->discount_end_date == '0000-00-00 00:00:00')) {
                $toDate = (string) date('Y-m-d', strtotime("+1 Month"));
                $response['formValues']['discount_end_date'] = $toDate . ' 00:00:00';
            }


            $auth = Engine_Api::_()->authorization()->context;
            $roles = array('owner', 'owner_member', 'owner_member_member', 'owner_network', 'registered', 'everyone');

            foreach ($roles as $role) {

                if (1 == $auth->isAllowed($sitestoreproduct, $role, "view")) {
                    $response['formValues']['auth_view'] = $role;
                }



                if (1 == $auth->isAllowed($sitestoreproduct, $role, "comment")) {
                    $response['formValues']['auth_comment'] = $role;
                }
            }

            $roles_photo = array('owner', 'owner_member', 'owner_member_member', 'owner_network', 'registered');
            foreach ($roles_photo as $role_photo) {

                if (1 == $auth->isAllowed($sitestoreproduct, $role_photo, "photo")) {
                    $response['formValues']['auth_photo'] = $role_photo;
                }
            }

            $videoEnable = Engine_Api::_()->sitestoreproduct()->enableVideoPlugin();
            if ($videoEnable) {
                $roles_video = array('owner', 'owner_member', 'owner_member_member', 'owner_network', 'registered');
                foreach ($roles_video as $role_video) {

                    if (1 == $auth->isAllowed($sitestoreproduct, $role_video, "video")) {
                        $response['formValues']['auth_photo'] = $role_video;
                    }
                }
            }

            if (Engine_Api::_()->sitestoreproduct()->listBaseNetworkEnable()) {
                if (empty($sitestoreproduct->networks_privacy)) {
                    $response['formValues']['networks_privacy'] = array(0);
                }
            }

            //POPULATE USER TAX       
            $response['formValues']['user_tax'] = @unserialize($sitestoreproduct->user_tax);
        }

        //cagegory profile field level form work..................
        $response['formValues']['fieldCategoryLevel'] = "";
        if (isset($sitestoreproduct->category_id) && !empty($sitestoreproduct->category_id)) {
            $categoryObject = Engine_Api::_()->getItem('sitestoreproduct_category', $sitestoreproduct->category_id);
            if (!empty($categoryObject)) {
                $response['formValues']['fieldCategoryLevel'] = "category_id";
            }
        }

        if (isset($sitestoreproduct->subcategory_id) && !empty($sitestoreproduct->subcategory_id)) {
            $categoryObject = Engine_Api::_()->getItem('sitestoreproduct_category', $sitestoreproduct->subcategory_id);
            if (!empty($categoryObject)) {
                $response['formValues']['fieldCategoryLevel'] = "subcategory_id";
            }
        }

        if (isset($sitestoreproduct->subsubcategory_id) && !empty($sitestoreproduct->subsubcategory_id)) {
            $categoryObject = Engine_Api::_()->getItem('sitestoreproduct_category', $sitestoreproduct->subsubcategory_id);
            if (!empty($categoryObject)) {
                $response['formValues']['fieldCategoryLevel'] = "subsubcategory_id";
            }
        }
        $profileInfo = Engine_Api::_()->getApi('Siteapi_Core', 'sitestoreproduct')->getInfoFields($sitestoreproduct, true);
        $profileArray = array();
        foreach($profileInfo as $key => $value){
            $profileArray[$key] = $value;
        }

        if (!empty($profileInfo)) {
            $response['formValues'] = @array_merge($response['formValues'], $profileArray);
        }
        //end of cagegory profile field map...............................



        $categoryIds = array();
        if($sitestoreproduct->category_id)
            $categoryIds[] = $sitestoreproduct->category_id;
        if($sitestoreproduct->subcategory_id)
            $categoryIds[] = $sitestoreproduct->subcategory_id;
        if($sitestoreproduct->subsubcategory_id)
            $categoryIds[] = $sitestoreproduct->subsubcategory_id;


        if($categoryIds)
            $previous_profile_type = Engine_Api::_()->getDbtable('categories', 'sitestoreproduct')->getProfileType($categoryIds, 0, 'profile_type');
        else
            $previous_profile_type = $defaultProfileId;

        if ($this->getRequest()->isGet()) {
            $form = Engine_Api::_()->getApi('Siteapi_Core', 'sitestoreproduct')->getForm($previous_profile_type, $sitestoreproduct->store_id, $sitestoreproduct->product_type, $product_types, 0, $sitestoreproduct);
            $form['formValues'] = $response['formValues'];
            $this->respondWithSuccess($form);
        }

        // IF POST NO ACCORDIAN SET
        $form_post = 1;


        $values = $data = $_REQUEST;
        $values['product_type'] = $sitestoreproduct->product_type;
        if (@array_key_exists('section_id', $values))
            unset($values['section_id']);

        if (@array_key_exists('inputsection_id', $values))
            unset($values['inputsection_id']);

        if (isset($values['discount']) && !empty($values['discount'])) {

            $discount_array = explode("_", $values['discount']);
            $count = count($discount_array);
            $values['discount'] = $discount_array[$count - 1];
        }
        if (isset($values['handling_type']) && !empty($values['handling_type'])) {
            $handling_type = explode("_", $values['handling_type']);
            $count = count($handling_type);
            $values['handling_type'] = $handling_type[$count - 1];
        }

        if (isset($values['discount_permanant']) && !empty($values['discount_permanant'])) {
            $discount_permanant = explode("_", $values['discount_permanant']);
            $count = count($discount_permanant);
            $values['discount_permanant'] = $discount_permanant[$count - 1];
        }

        if (isset($values['stock_unlimited']) && !empty($values['stock_unlimited'])) {
            $stock_unlimited = explode("_", $values['stock_unlimited']);
            $count = count($stock_unlimited);
            $values['stock_unlimited'] = $stock_unlimited[$count - 1];
        }

        if (isset($values['out_of_stock']) && !empty($values['out_of_stock'])) {
            $out_of_stock = explode("_", $values['out_of_stock']);
            $count = count($out_of_stock);
            $values['out_of_stock'] = $out_of_stock[$count - 1];
        }

        if (isset($values['end_date_enable']) && !empty($values['end_date_enable'])) {
            $end_date_enable = explode("_", $productTypeValue['end_date_enable']);
            $count = count($end_date_enable);
            $values['end_date_enable'] = $values[$count - 1];
        }

        $data = $values;

        $validators = Engine_Api::_()->getApi('Siteapi_FormValidators', 'sitestoreproduct')->getFormValidators(1);
        $data['validators'] = $validators;
        $videovalidationMessage = $this->isValid($data);
        $videovalidationMessage = null;
        if (!empty($videovalidationMessage) && @is_array($videovalidationMessage)) {
            $this->respondWithValidationError('validation_fail', $videovalidationMessage);
        }
        if (!@is_array($videovalidationMessage) && isset($values['category_id'])) {
            $categoryIds = array();
            $categoryIds['categoryIds'][] = $values['category_id'];
            if (isset($values['subcategory_id']) && !empty($values['subcategory_id']))
                $categoryIds['categoryIds'][] = $values['subcategory_id'];
            if (isset($values['subsubcategory_id']) && !empty($values['subsubcategory_id']))
                $categoryIds['categoryIds'][] = $values['subsubcategory_id'];

            try {
                $values['profile_type'] = Engine_Api::_()->getDbtable('categories', 'sitestoreproduct')->getProfileType($categoryIds, 0, 'profile_type');
            } catch (Exception $ex) {
                $values['profile_type'] = 0;
            }
            if (isset($values['profile_type']) && !empty($values['profile_type'])) {                          //profile fields validation
                $profileFieldsValidators = Engine_Api::_()->getApi('Siteapi_FormValidators', 'sitestoreproduct')->getFieldsFormValidations($values, 'sitestoreproduct_product');
                $data['validators'] = $profileFieldsValidators;
                $profileFieldsValidationMessage = $this->isValid($data);
            }
        }
        if (is_array($videovalidationMessage) && is_array($profileFieldsValidationMessage))
            $validationMessage = array_merge($videovalidationMessage, $profileFieldsValidationMessage);
        else if (is_array($videovalidationMessage))
            $validationMessage = $videovalidationMessage;
        else if (is_array($profileFieldsValidationMessage))
            $validationMessage = $profileFieldsValidationMessage;
        else
            $validationMessage = 1;

        if (!empty($validationMessage) && @is_array($validationMessage)) {
            $this->respondWithValidationError('validation_fail', $validationMessage);
        }


        if ($values['product_type'] != "grouped" && !empty($values['discount']) && empty($values['discount_permanant']) && empty($values['discount_end_date'])) {
            $validationMessage = array();
            $validationMessage['discount_end_date'] = 'Please enter Discount end Date - it is required.';
            $this->respondWithValidationError('validation_fail', $validationMessage);
        }

        //VARIOUS LOGICAL CHECKS BITWEEN DIFFERENT PRODUCT ATTRIBUTES
        if ($values['product_type'] != "grouped" && (isset($_POST['stock_unlimited']) && empty($values['stock_unlimited'])) && !empty($values['min_order_quantity']) && $values['min_order_quantity'] > $values['in_stock']) {
            $validationMessage = array();
            $validationMessage['min_order_quantity'] = 'Minimum Order Quantity can not be greater than In Stock value.';
            $this->respondWithValidationError('validation_fail', $validationMessage);
        }

        if ($values['product_type'] != "grouped" && !empty($values['max_order_quantity']) && $values['max_order_quantity'] < $_POST['min_order_quantity']) {
            $validationMessage = array();
            $validationMessage['max_order_quantity'] = 'Minimum Order Quantity can not be greater than Maximum Order Quantity.';
            $this->respondWithValidationError('validation_fail', $validationMessage);
        }

        if ($values['product_type'] != "grouped" && !empty($values['discount']) && $values['discount'] == 1 && $values['handling_type'] == 0 && $values['discount_price'] >= $values['price']) {
            $validationMessage = array();
            $validationMessage['discount_price'] = 'Discount can not be more than and equal to actual price.';
            $this->respondWithValidationError('validation_fail', $validationMessage);
        }

        if (($values['product_type'] == "grouped" || $values['product_type'] == 'bundled') && (empty($values['product_ids']) || COUNT(explode(',', $values['product_ids'])) <= 1)) {

            $validationMessage['product_ids'] = 'You have not configured any products for this product. Please select atleast two products for creating this products.';
            $this->respondWithValidationError('validation_fail', $validationMessage);

            if (!empty($_POST['product_ids'])) {
                $productsArray = $tempProductsArray = array();
                $this->view->tempMappedIdsStr = $_POST['product_ids'];
                $tempMappedIds = explode(',', $_POST['product_ids']);
                foreach ($tempMappedIds as $product_id) {
                    $productTitle = Engine_Api::_()->getDbTable('products', 'sitestoreproduct')->getProductTitle($product_id);
                    if (empty($productTitle))
                        continue;
                    $tempProductsArray['title'] = $productTitle;
                    $tempProductsArray['id'] = $product_id;
                    $productsArray[] = $tempProductsArray;
                }
            }
        }

        //SETTING VALUES IN ARRAY FOR SITESTOREPRODUCT_OTHERINFO TABLE
        $sitestoreproductValues = array();
        $sitestoreproduct_values = $values;

//    if(empty ($temp_allow_selling)){
//        $sitestoreproduct_values['allow_purchase'] = 0;
//    }

        $emailToViewers = (bool) isset($sitestoreproduct_values['notify_viewer']) ? $sitestoreproduct_values['out_of_stock_action'] : false;
        unset($sitestoreproduct_values['notify_viewer']);

        //GET FORM VALUES

        if (isset($values['user_tax'])) {
            $values['user_tax'] = @serialize($values['user_tax']);
        }

        // SAVE VALUES IN OHERINFO TABLE.

        if (Engine_Api::_()->getDbtable("modules", "core")->isModuleEnabled("sitecredit") && $isAdminDrivenStore && Engine_Api::_()->getApi('settings', 'core')->getSetting('sitecredit.store.credit.redemption', 'all_store') == 'product_wise') {

            if (!empty($sitestoreproduct_values['credit_handling_type'])) {
                $otherInfoObj->credit_handling_type = $values['credit_handling_type'];
                $otherInfoObj->credit_limit = @round($values['credit_limit'], 2);
            } else {
                if (!empty($values['discount'])) {

                    if (empty($values['handling_type'])) {
                        $otherInfoObj->discount_amount = @round($values['discount_price'], 2);
                        $otherInfoObj->discount_value = @round($values['discount_price'], 2);
                        $otherInfoObj->discount_percentage = @round($values['discount_price'] * 100 / $values['price'], 2);
                    } else {
                        $otherInfoObj->discount_amount = @round(($values['discount_rate'] * $values['price'] / 100), 2);
                        $otherInfoObj->discount_value = @round($values['discount_rate'], 2);
                        $otherInfoObj->discount_percentage = @round($values['discount_rate'], 2);
                    }
                }
            }
        } else {
            if (!empty($values['discount'])) {

                if (empty($values['handling_type'])) {
                    $otherInfoObj->discount_amount = @round($values['discount_price'], 2);
                    $otherInfoObj->discount_value = @round($values['discount_price'], 2);
                    $otherInfoObj->discount_percentage = @round($values['discount_price'] * 100 / $values['price'], 2);
                } else {
                    $otherInfoObj->discount_amount = @round(($values['discount_rate'] * $values['price'] / 100), 2);
                    $otherInfoObj->discount_value = @round($values['discount_rate'], 2);
                    $otherInfoObj->discount_percentage = @round($values['discount_rate'], 2);
                }
            }
        }

        // SAVE DOWNPAYMENT VALUE
        if ($_POST['product_type'] != "grouped" && !empty($isDownPaymentEnable) && !empty($directPayment) && !empty($isSitestorereservationModuleExist)) {
            if (!empty($values['downpayment']))
                $otherInfoObj->downpayment_value = $values['downpaymentvalue'];
            else
                $otherInfoObj->downpayment_value = 0;
            unset($tempOtherInfos['downpayment']);
            unset($tempOtherInfos['downpaymentvalue']);
        }

        unset($tempOtherInfos['enable_shipping']);
        unset($tempOtherInfos['bundle_product_type']);

        if (!empty($isSitestorereservationModuleExist)) {
            unset($tempOtherInfos['virtual_product_price_range']);
            unset($tempOtherInfos['virtual_product_date_selector']);
        }

        // ADDING SPECIAL VAT IN OTHERINFO
        if (Engine_Api::_()->getApi('settings', 'core')->getSetting('sitestoreproduct.vat', 0) && isset($values['special_vat'])) {
            if (empty($values['special_vat'])) {
                $values['special_vat'] = null;
                $otherInfoObj->special_vat = null;
            }
        }

        foreach ($tempOtherInfos as $key => $value) {
            if ($key == 'discount_price' || $key == 'discount_rate')
                continue;
            else {
                if (isset($values[$key]))
                    $otherInfoObj->$key = $values[$key];
            }
            unset($values[$key]);
        }

        if ($values['product_type'] == 'grouped' || $values['product_type'] == 'bundled') {
            $mappedIdsArray = @explode(',', $values['product_ids']);
            $otherInfoObj->mapped_ids = Zend_Json_Encoder::encode($mappedIdsArray);

            if ($values['product_type'] == 'bundled') {
                $otherInfoObj->product_info = @serialize(array('enable_shipping' => $values['enable_shipping'], 'bundle_product_type' => $values['bundle_product_type']));
            }
        }

        if ($values['product_type'] == 'virtual' && !empty($isSitestorereservationModuleExist)) {
            $tempVirtualProductInfo = array();
            if (!empty($sitestoreproduct_values['virtual_product_price_range']))
                $tempVirtualProductInfo['virtual_product_price_range'] = $values['virtual_product_price_range'];

            $isDateSelectorEnable = Engine_Api::_()->getApi('settings', 'core')->getSetting('sitestorereservation.dateselector', 0);
            if (!empty($isDateSelectorEnable))
                $tempVirtualProductInfo['virtual_product_date_selector'] = $values['virtual_product_date_selector'];

            if (!empty($tempVirtualProductInfo)) {
                if (!empty($otherInfoObj->product_info)) {
                    $tempProductInfo = unserialize($otherInfoObj->product_info);
                    $otherInfoObj->product_info = serialize(array_merge($tempProductInfo, $tempVirtualProductInfo));
                } else {
                    $otherInfoObj->product_info = serialize($tempVirtualProductInfo);
                }
            }
        }

        $otherInfoObj->save();

        $tags = preg_split('/[,]+/', $values['tags']);
        $tags = array_filter(array_map("trim", $tags));

        $db = Engine_Db_Table::getDefaultAdapter();
        $db->beginTransaction();
        try {
            if (Engine_Api::_()->sitestoreproduct()->listBaseNetworkEnable() && isset($values['networks_privacy']) && !empty($values['networks_privacy']) && in_array(0, $values['networks_privacy'])) {
                $values['networks_privacy'] = new Zend_Db_Expr('NULL');
                $values['networks_privacy'] = array(0);
            }
            if ($expiry_setting == 1 && $values['end_date_enable'] == 1) {
                // Convert times
                $oldTz = date_default_timezone_get();
                date_default_timezone_set($viewer->timezone);
                $end = strtotime($values['end_date']);
                date_default_timezone_set($oldTz);
                $values['end_date'] = date('Y-m-d H:i:s', $end);
            } elseif ($expiry_setting == 1 && isset($values['end_date'])) {
                $values['end_date'] = NULL;
            } elseif (isset($values['end_date'])) {
                unset($values['end_date']);
            }

            // Convert times
            if (isset($values['start_date']) && !empty($values['start_date'])) {
                $oldTz = date_default_timezone_get();
                date_default_timezone_set($viewer->timezone);
                $end = strtotime($values['start_date']);
                date_default_timezone_set($oldTz);
                $values['start_date'] = date('Y-m-d H:i:s', $end);
            }

            if (empty($values['max_order_quantity'])) {
                $values['max_order_quantity'] = NULL;
            }

            if ($_POST['product_type'] == 'grouped')
                $values['stock_unlimited'] = 1;

            $values['weight'] = @number_format($values['weight'], 2, '.', ',');
            $values['price'] = @number_format($values['price'], 2, '.', '');

            $sitestoreproduct->setFromArray($values);
            $sitestoreproduct->modified_date = date('Y-m-d H:i:s');
            $sitestoreproduct->tags()->setTagMaps($viewer, $tags);


            if (!empty($_POST['section_id']) && !empty($_POST['inputsection_id']) && ($_POST['section_id'] == 'new')) {
                $tableSections = Engine_Api::_()->getDbTable('sections', 'sitestoreproduct');
                $tableSectionsName = $tableSections->info('name');

                $row_info = $tableSections->fetchRow($tableSections->select()->from($tableSectionsName, 'max(sec_order) AS sec_order'));
                $sec_order = $row_info['sec_order'] + 1;
                $row = $tableSections->createRow();
                $row->section_name = $_POST['inputsection_id'];
                $row->sec_order = $sec_order;
                $row->store_id = $sitestoreproduct->store_id;
                $newsec_id = $row->save();
                $sitestoreproduct->section_id = $newsec_id;
            }

            if (@array_key_exists("section_id", $_POST) && ($_POST['section_id'] != 'new'))
                $sitestoreproduct->section_id = $_POST['section_id'];



            $sitestoreproduct->save();

            //SAVE CUSTOM FIELDS

            Engine_Api::_()->getApi('Siteapi_Core', 'sitestore')->setProfileFields($sitestoreproduct, $data);

            if (isset($values['category_id']) && !empty($values['category_id'])) {
                $categoryIds = array();
                $categoryIds[] = $sitestoreproduct->category_id;
                $categoryIds[] = $sitestoreproduct->subcategory_id;
                $categoryIds[] = $sitestoreproduct->subsubcategory_id;
                $sitestoreproduct->profile_type = Engine_Api::_()->getDbtable('categories', 'sitestoreproduct')->getProfileType($categoryIds, 0, 'profile_type');
                if ($sitestoreproduct->profile_type != $previous_profile_type) {

                    $fieldvalueTable = Engine_Api::_()->fields()->getTable('sitestoreproduct_product', 'values');
                    $fieldvalueTable->delete(array('item_id = ?' => $sitestoreproduct->product_id));

                    Engine_Api::_()->fields()->getTable('sitestoreproduct_product', 'search')->delete(array(
                        'item_id = ?' => $sitestoreproduct->product_id,
                    ));

                    if (!empty($sitestoreproduct->profile_type) && !empty($previous_profile_type)) {
                        //PUT NEW PROFILE TYPE
                        $fieldvalueTable->insert(array(
                            'item_id' => $sitestoreproduct->product_id,
                            'field_id' => $defaultProfileId,
                            'index' => 0,
                            'value' => $sitestoreproduct->profile_type,
                        ));
                    }
                }
                $sitestoreproduct->save();
            }

            //NOT SEARCHABLE IF SAVED IN DRAFT MODE
            if (!empty($sitestoreproduct->draft)) {
                $sitestoreproduct->search = 0;
                $sitestoreproduct->save();
            }

            if ($sitestoreproduct->draft == 0 && $sitestoreproduct->search && $inDraft) {
                $actionTable = Engine_Api::_()->getDbtable('actions', 'activity');
                $activityFeedType = null;
                if (Engine_Api::_()->sitestore()->isStoreOwner($sitestore) && Engine_Api::_()->sitestore()->isFeedTypeStoreEnable())
                    $activityFeedType = 'sitestoreproduct_admin_new';
                elseif ($sitestore->all_post || Engine_Api::_()->sitestore()->isStoreOwner($sitestore))
                    $activityFeedType = 'sitestoreproduct_new';

                if ($activityFeedType) {
                    $action = $actionTable->addActivity($sitestoreproduct->getOwner(), $sitestore, $activityFeedType);
                    Engine_Api::_()->getApi('subCore', 'sitestore')->deleteFeedStream($action);
                }
                //MAKE SURE ACTION EXISTS BEFOR ATTACHING THE NOTE TO THE ACTIVITY
                if ($action != null) {
                    $actionTable->attachActivity($action, $sitestoreproduct, Activity_Model_Action::ATTACH_MULTI);
                }
            }

            //CREATE AUTH STUFF HERE
            $auth = Engine_Api::_()->authorization()->context;

            $roles = array('owner', 'owner_member', 'owner_member_member', 'owner_network', 'registered', 'everyone');

            if (empty($values['auth_view'])) {
                $values['auth_view'] = array("everyone");
            }

            if (empty($values['auth_comment'])) {
                $values['auth_comment'] = array("everyone");
            }

            $viewMax = array_search($values['auth_view'], $roles);
            $commentMax = array_search($values['auth_comment'], $roles);

            foreach ($roles as $i => $role) {
                $auth->setAllowed($sitestoreproduct, $role, "view", ($i <= $viewMax));
                $auth->setAllowed($sitestoreproduct, $role, "comment", ($i <= $commentMax));
            }

            $roles = array('owner', 'owner_member', 'owner_member_member', 'owner_network', 'registered');
            if ($values['auth_photo'])
                $auth_photo = $values['auth_photo'];
            else
                $auth_photo = "owner";
            $photoMax = array_search($auth_photo, $roles);

            foreach ($roles as $i => $role) {
                $auth->setAllowed($sitestoreproduct, $role, "photo", ($i <= $photoMax));
            }

            $roles_video = array('owner', 'owner_member', 'owner_member_member', 'owner_network', 'registered');
            if (!isset($values['auth_video']) && empty($values['auth_video'])) {
                $values['auth_video'] = "owner";
            }

            $videoMax = array_search($values['auth_video'], $roles_video);
            foreach ($roles_video as $i => $role_video) {
                $auth->setAllowed($sitestoreproduct, $role_video, "video", ($i <= $videoMax));
            }

            if ($previous_category_id != $sitestoreproduct->category_id) {
                Engine_Api::_()->getDbtable('ratings', 'sitestoreproduct')->editProductCategory($sitestoreproduct->product_id, $previous_category_id, $sitestoreproduct->category_id, $sitestoreproduct->getType());
            }

            if (!empty($emailToViewers) && !empty($intrestedViewerEmailCount)) {
                $intrestedViewerEmailSelect = Engine_Api::_()->getDbtable('notifyemails', 'sitestoreproduct')->getNotifyEmail($product_id, 'buyer_email');
                $intrestedViewerEmail = Engine_Api::_()->getDbtable('notifyemails', 'sitestoreproduct')->fetchAll($intrestedViewerEmailSelect);

                foreach ($intrestedViewerEmail as $email) {
                    Engine_Api::_()->getApi('mail', 'core')->sendSystem($email['buyer_email'], 'sitestoreproduct_notify_to_viewer', array(
                        'object_title' => $sitestoreproduct->getHref()
                    ));
                }
            }

            $db->commit();
        } catch (Exception $e) {
            $db->rollBack();
        }

        $db->beginTransaction();
        try {
            $actionTable = Engine_Api::_()->getDbtable('actions', 'activity');
            foreach ($actionTable->getActionsByObject($sitestoreproduct) as $action) {
                $actionTable->resetActivityBindings($action);
            }

            $sitestore = Engine_Api::_()->getItem('sitestore_store', $sitestoreproduct->store_id);

            $getPageAdmins = Engine_Api::_()->getDbtable('manageadmins', 'sitestore')->getManageAdmin($sitestore->store_id, $viewer->getIdentity());

            $db->commit();
            $this->successResponseNoContent('no_content');
        } catch (Exception $e) {
            $db->rollBack();
        }
    }

    // ACTION FOR DELETE PRODUCT
    public function deleteAction() {
        // LOGGED IN USER CAN DELETE PRODUCT
        if (!$this->_helper->requireUser()->isValid())
            $this->respondWithError('unauthorized');
        $viewer = Engine_Api::_()->user()->getViewer();

        // GET PRODUCT ID AND OBJECT
        $sitestoreproduct = Engine_Api::_()->getItem('sitestoreproduct_product', $this->_getParam('product_id'));

        if (empty($sitestoreproduct)) {
            $this->respondWithError('no_record');
        }

        $store_id = $sitestoreproduct->store_id;

        // AUTHORIZATION CHECK
        $authValue = Engine_Api::_()->sitestoreproduct()->isStoreAdmin($store_id);
        if (empty($authValue) || ($authValue == 1) || !$this->_helper->requireAuth()->setAuthParams($sitestoreproduct, $viewer, "delete")->isValid()) {
            $this->respondWithError('unauthorized');
        }
        $sitestoreproduct->delete();
        $this->successResponseNoContent('no_content');
    }

    public function indexAction() {
        $viewer = Engine_Api::_()->user()->getViewer();
        if (Engine_Api::_()->core()->hasSubject('sitestore_store'))
            $sitestore = $subject = Engine_Api::_()->core()->getSubject('sitestore_store');
        else
            $this->respondWithError('no_record');

        $this->validateRequestMethod();

        $values = $this->_getAllParams();

        if (empty($values['page']))
            $values['page'] = 1;

        if (empty($values['limit']))
            $values['limit'] = 20;

        $values['type'] = "browse";

        $this->respondWithSuccess($this->getStoreProductData($values), true);
    }

    /*
     * browse action
     */

    public function browseAction() {
        $this->validateRequestMethod();

        $values = $this->_getAllParams();

        if (empty($values['page']))
            $values['page'] = 1;

        if (empty($values['limit']))
            $values['limit'] = 20;

        $values['type'] = "browse";
        $values['orderby'] = $this->_getParam('orderby', 'product_id');

        $this->respondWithSuccess($this->getStoreProductData($values), true);
    }

    /*
     * Store product paginator
     */

    public function manageAction() {
        $viewer = Engine_Api::_()->user()->getViewer();
        $viewer_id = $viewer->getIdentity();

        if (!$viewer_id)
            $this->respondWithError('unauthorized');

        if (Engine_Api::_()->core()->hasSubject('sitestore_store'))
            $sitestore = $subject = Engine_Api::_()->core()->getSubject('sitestore_store');

        $this->validateRequestMethod();

        $values = $this->getAllParams();

        if (empty($values['page']))
            $values['page'] = 1;

        if (empty($values['limit']))
            $values['limit'] = 20;

        //MAKE DATA ARRAY
        $values['user_id'] = $viewer_id;
        $values['type'] = 'manage';
        $values['orderby'] = 'product_id';

        $this->respondWithSuccess($this->getStoreProductData($values), true);
    }

    private function getStoreProductData($values = array()) {
        $response = $tempResponse = array();
        $response['currency'] = Engine_Api::_()->getApi('settings', 'core')->getSetting('payment.currency', 'USD');
        $viewer = Engine_Api::_()->user()->getViewer();
        $viewer_id = $viewer->getIdentity();

        // wishlist work
        if ($viewer_id) {
            $wishlistMapsTable = Engine_Api::_()->getDbTable('wishlistmaps', 'sitestoreproduct');
            $wishlistTable = Engine_Api::_()->getDbTable('wishlists', 'sitestoreproduct');
            $wishlistTableName = $wishlistTable->info('name');
            $wishlistMapsTableName = $wishlistMapsTable->info("name");
            $wishlistProducts = array();

            $select = $wishlistTable->select()
                    ->distinct()
                    ->setIntegrityCheck(false)
                    ->from($wishlistTableName)
                    ->joinInner($wishlistMapsTableName, "$wishlistTableName.wishlist_id = .$wishlistMapsTableName.wishlist_id")
                    ->where($wishlistTableName . '.owner_id = ?', $viewer_id);

            $wishlistData = $select->query()->fetchAll();

            if (!empty($wishlistData)) {
                foreach ($wishlistData as $row => $value) {
                    $wishlistProducts[$value['product_id']][] = array('label' => $this->translate($value['title']), 'wishlist_id' => $value['wishlist_id']);
                }
            }
        }
        // wishlist work ends


        if (!empty($viewer_id)) {
            $level_id = Engine_Api::_()->user()->getViewer()->level_id;
        } else {
            $level_id = Engine_Api::_()->getDbtable('levels', 'authorization')->fetchRow(array('type = ?' => "public"))->level_id;
        }

        $action = $values['action'];

        $paginator = Engine_Api::_()->getApi('Siteapi_Core', 'sitestoreproduct')->getStoreProductPaginator($values);

        if ($values['action'] == 'category') {
            $paginator->setItemCountPerPage(500);
            $paginator->setCurrentPageNumber(1);
        }

        $response['totalItemCount'] = $paginator->getTotalItemCount();

        $can_view = Engine_Api::_()->authorization()->getPermission($level_id, 'sitestoreproduct_product', "view");

        if ($paginator){
            foreach ($paginator as $row => $value) {
                // authorization check
                if ($can_view == 0 && ((!empty($product->draft) || empty($product->approved)) && ($product->owner_id != $viewer_id))) {
                    --$response['totalItemCount'];
                    continue;
                }

                $data = Engine_Api::_()->getApi('Siteapi_Core', 'sitestoreproduct')->getProduct($value, $values);
                $data['information'] = Engine_Api::_()->getApi("Siteapi_Core", "sitestoreproduct")->getPriceFields($value);

                // Provides info if product is in stock
                $data['in_stock_product'] = (int) ($data['stock_unlimited'] || $data['in_stock']);
                $temp_allowed_selling = Engine_Api::_()->sitestoreproduct()->getIsAllowedSellingProducts($value->store_id);
                $data['canAddToCart'] = 0;
                if (!empty($temp_allowed_selling) && $value->allow_purchase && ($data['in_stock_product']))
                    $data['canAddToCart'] = 1;

                $data['discounted_amount'] = (float) $data['price'] - (float) $data['discount_amount'];

                if (!empty($wishlistProducts[$value->getIdentity()]))
                    $data['wishlist'] = $wishlistProducts[$value->getIdentity()];

                $response['response'][] = $data;
            }
        }

        $response['orderby'] = $this->_getOrderByOptions();

        if ($values['action'] == 'category')
            return $response['response'];

        $this->respondWithSuccess($response, false);
    }

    /*
     *  view Product
     */

    public function viewAction() {
        $response = $tempResponse = array();

        $values = $this->_getAllParams();
        $viewer = Engine_Api::_()->user()->getViewer();
        $viewer_id = $viewer->getIdentity();

        Engine_Api::_()->getApi('Core', 'siteapi')->setView();
        Engine_Api::_()->getApi('Core', 'siteapi')->setLocal();
        //GET USER LEVEL ID
        if (!empty($viewer_id)) {
            $level_id = $viewer->level_id;
        } else {
            $level_id = Engine_Api::_()->getDbtable('levels', 'authorization')->fetchRow(array('type = ?' => "public"))->level_id;
        }

        $product_id = $this->_getParam('product_id');
        $productTable = Engine_Api::_()->getDbtable('products', 'sitestoreproduct');

        if (!$product_id)
            $this->respondWithValidationError('parameter_missing', 'product_id missing');

        $product = Engine_Api::_()->getItem('sitestoreproduct_product', $product_id);

        if (!$product)
            $this->respondWithError('no_record');

        $sitestore = Engine_Api::_()->getItem('sitestore_store', $product->store_id);

        $can_view = Engine_Api::_()->authorization()->getPermission($level_id, 'sitestoreproduct_product', "view");

        //AUTHORIZATION CHECK
        if ($can_view != 2 && ((!empty($product->draft) || empty($product->approved)) && ($product->owner_id != $viewer_id)))
            $this->respondWithSuccess('unauthorized');

        if ($can_view != 2 && ($product->owner_id != $viewer_id)) {
            $reviewApi = Engine_Api::_()->sitestoreproduct();
            $expirySettings = $reviewApi->expirySettings();
            if ($expirySettings == 2) {
                $approveDate = $reviewApi->adminExpiryDuration();
                if ($approveDate > $product->approved_date) {
                    $this->respondWithError('unauthorized');
                }
            }
        }

        $isManageAdmin = Engine_Api::_()->sitestore()->isManageAdmin($sitestore, 'view');
        if (empty($isManageAdmin)) {
            $this->respondWithError('unauthorized');
        }

        if (!Engine_Api::_()->sitestore()->canViewStore($sitestore)) {
            $this->respondWithSuccess("unauthorized");
        }

        ++$product->view_count;
        $product->save();

        //SET PRODUCT VIEW DETAILS
        if (!empty($viewer_id)) {
            Engine_Api::_()->getDbtable('vieweds', 'sitestoreproduct')->setVieweds($product_id, $viewer_id);
        }

        $response = $product->toArray();
        if ($product->store_id) {
            $sitestore = Engine_Api::_()->getItem('sitestore_store', $product->store_id);
            $response['store_title'] = $sitestore->getTitle();
        }

        // Provides info if product is in stock
        $response['in_stock_product'] = (int) ($product->stock_unlimited || $product->in_stock);
        $error = $this->canAddtoCartError($product);
        if ($error) {
            $response['error'] = $error;
            $response['canAddtoCart'] = 0;
        } else
            $response['canAddtoCart'] = 1;

        $response = array_merge($response, Engine_Api::_()->getApi('Core', 'siteapi')->getContentImage($product));
        $response = array_merge($response, Engine_Api::_()->getApi('Core', 'siteapi')->getContentImage($product, true));
        // other info price work start

        $response['wishlistPresent'] = Engine_Api::_()->getApi("Siteapi_Core", "sitestoreproduct")->checkForWishlist($product);

        $host = $this->getSiteUrl();

        $scriptNametemp = explode("/", $_SERVER['SCRIPT_NAME']);
        $scriptName = $scriptNametemp[1];

        // other info price work ends
        if ($product->product_type == 'downloadable') {

            //PAGINATOR FOR SAMPLE FILES
            $downloadableProducts = Engine_Api::_()->getDbtable('downloadablefiles', 'sitestoreproduct')->getSampleFiles(array('product_id' => $product_id));

            $isAnyFileExist = Engine_Api::_()->getDbtable('downloadablefiles', 'sitestoreproduct')->IsAnyMainFileExist($product_id);

            if (!$isAnyMainFileExist) {
                $error = $this->translate("This product doesn't have any file to download");
                $response['canAddToCart'] = 0;
            }

            if (count($downloadableProducts) > 0) {
                foreach ($downloadableProducts as $sampleFiles) {
                    // $path = "/stores/product/download-sample/product_id/" . $product_id . "/downloadablefile_id/" . $sampleFiles->downloadablefile_id;

                    $downloadablefileItem = Engine_Api::_()->getItem('sitestoreproduct_downloadablefile', $sampleFiles->downloadablefile_id);

                    if (empty($downloadablefileItem) || $downloadablefileItem->type != 'sample')
                        continue;

                    $downloadablefile_name = $downloadablefileItem->filename;
                    $sampleDownloadFile['title'] = $downloadablefileItem->getTitle();
                    $url = $this->_helper->url->url(array('action' => 'download-sample', 'product_id' => $product_id, 'downloadablefile_id' => $sampleFiles->downloadablefile_id), 'sitestoreproduct_product_general', true);
                    $sampleDownloadFile['filepath'] = $host . $url;
                    $fileArray[] = $sampleDownloadFile;
                }
                if (isset($fileArray) && !empty($fileArray))
                    $response['sampleFiles'] = $fileArray;
            }
        }

        //VIEW GROUP PRODUCTS
        if ($product->product_type == 'grouped') {

            $params = array();
            $params['product_type'] = 'grouped';
            $params['product_id'] = $product_id;

            $groupedProducts = $productTable->getCombinedProducts($params);
            $minprice = 0.00;
            foreach ($groupedProducts as $individualProduct) {

                if ($this->canAddtoCartError($individualProduct))
                    continue;

                $indProduct = $individualProduct->toArray();
                $indProduct['information'] = Engine_Api::_()->getApi("Siteapi_Core", "sitestoreproduct")->getPriceFields($individualProduct);

                if ($minprice == 0.00 || $minprice > $indProduct['price'])
                    $minprice = $indProduct['price'];

                $indProduct = array_merge($indProduct, Engine_Api::_()->getApi('Core', 'siteapi')->getContentImage($individualProduct));
                $indProductArray[] = $indProduct;

                if (empty($indProductArray)) {
                    $error = $this->translate("No product is associated with this grouped product which is in stock");
                    $response['canAddToCart'] = 0;
                }
            }
            if (count($indProductArray) > 0) {
                $response['groupedProducts'] = $indProductArray;
            }

            $response['price'] = $minprice;
        }


        if ($product->product_type == 'bundled') {
            $params = array();
            $params['product_id'] = $product_id;
            $bundledProducts = Engine_Api::_()->getDbtable('products', 'sitestoreproduct')->getCombinedProducts($params);
            $tempBundleProductInfo = Engine_Api::_()->getDbTable('otherinfo', 'sitestoreproduct')->getColumnValue($product->product_id, "product_info");
            $bundleProductInfo = @unserialize($tempBundleProductInfo);
            if (!empty($bundleProductInfo) && !empty($bundleProductInfo['bundle_product_attribute'])) {
                $bundle_product_attributes = $bundleProductInfo['bundle_product_attribute'];
            }
            foreach ($bundledProducts as $individualProduct) {

                if ($this->canAddtoCartError($individualProduct))
                    continue;

                $indProduct = $individualProduct->toArray();
                $indProduct['price'] = $productTable->getProductDiscountedPrice($individualProduct->product_id);
                $indProduct['information'] = Engine_Api::_()->getApi("Siteapi_Core", "sitestoreproduct")->getPriceFields($individualProduct);
                $indProduct = array_merge($indProduct, Engine_Api::_()->getApi('Core', 'siteapi')->getContentImage($individualProduct));
                $indProductArray[] = $indProduct;
                if (empty($indProductArray)) {
                    $error = $this->translate("No product is associated with this bundled product which is in stock");
                    $response['canAddToCart'] = 0;
                }
            }
            if (count($indProductArray) > 0) {
                $response['bundledProducts'] = $indProductArray;
            }
        }

        $response['menu'] = Engine_Api::_()->getApi('Siteapi_Core', 'sitestoreproduct')->gutterMenus($sitestore, $product);
        $response['tabs'] = Engine_Api::_()->getApi('Siteapi_Core', 'sitestoreproduct')->profileTabs($sitestore, $product);
        $response['owner_title'] = $product->getOwner()->getTitle();
        $response = array_merge($response, Engine_Api::_()->getApi('Core', 'siteapi')->getContentURL($product->getOwner(), "owner_url"));
        $response = array_merge($response, Engine_Api::_()->getApi('Core', 'siteapi')->getContentURL($product));
        $response['currency'] = Engine_Api::_()->getApi('settings', 'core')->getSetting('payment.currency', 'USD');

        $photos = Engine_Api::_()->getDbtable('photos', 'sitestoreproduct')->GetProductPhoto($product->getIdentity());

        if ($photos) {
            foreach ($photos as $row => $value) {
                $photo = Engine_Api::_()->getItem('sitestoreproduct_photo', $value['photo_id']);
                $contentImages = Engine_Api::_()->getApi('Core', 'siteapi')->getContentImage($photo);
                unset($contentImages['content_url']);
                $response['images'][] = $contentImages;
            }
        }

        if ($product->product_type == 'configurable') {
            $form = Engine_Api::_()->getApi('Siteapi_Core', 'sitestoreproduct')->getCombinationOptions($product);
            $allowCombinations = Engine_Api::_()->getApi('settings', 'core')->getSetting('sitestoreproduct.combination', 1);
            if (!empty($form))
                $response['config'] = $form;
        }

        $productTags = $product->tags()->getTagMaps();
        $tagString = '';

        foreach ($productTags as $tagmap) {

            if ($tagString !== '')
                $tagString .= ', ';
            $tagString .= $tagmap->getTag()->getTitle();
        }

        if ($tagString)
            $response['tags'] = $tagString;

        $isAllowedView = $product->authorization()->isAllowed($viewer, 'view');
        $response["allow_to_view"] = empty($isAllowedView) ? 0 : 1;

        $isAllowedEdit = $product->authorization()->isAllowed($viewer, 'edit');
        $response["edit"] = empty($isAllowedEdit) ? 0 : 1;

        $isAllowedDelete = $product->authorization()->isAllowed($viewer, 'delete');
        $response["delete"] = empty($isAllowedDelete) ? 0 : 1;

        $like = $product->likes()->isLike($viewer);
        $response["is_liked"] = ($like) ? 1 : 0;

        $follow = Engine_Api::_()->getDbtable('follows', 'seaocore')->isFollow($product, $viewer);

        $response['is_followed'] = $follow ? 1 : 0;

        $response['information'] = Engine_Api::_()->getApi('Siteapi_Core', 'sitestoreproduct')->getInformation($product, $values);
        //added complete url work of overview..............................................
        if (isset($response['information']['description']))
            $response['information']['description'] = @str_replace('src="/', 'src="' . $this->getHost . '/', $response['information']['description']);

        $this->respondWithSuccess($response, false);
    }

    /*
     * product photos
     */

    public function photosAction() {
        $response = $tempResponse = array();

        $values = $this->getAllParams();
        $viewer = Engine_Api::_()->user()->getViewer();

        if (Engine_Api::_()->core()->hasSubject('sitestore_store'))
            $sitestore = $subject = Engine_Api::_()->core()->getSubject('sitestore_store');
        elseif ($values['action'] != 'category')
            $this->respondWithError('no_record');

        $product_id = $this->_getParam('product_id');

        if (!$product_id)
            $this->respondWithValidationError('parameter_missing', 'product_id missing');

        $product = Engine_Api::_()->getItem('sitestoreproduct_product', $product_id);

        if (!$product)
            $this->respondWithError('no_record');

        $productPhotos = Engine_Api::_()->getDbTable('photos', 'sitestoreproduct')->GetProductPhoto($product->getIdentity());

        $response['totalItemCount'] = count($productPhotos);

        if ($productPhotos) {
            foreach ($productPhotos as $row => $value) {
                $photo = Engine_Api::_()->getItem('sitestoreproduct_photo', $value['photo_id']);
                $data = $photo->toArray();
                $data = array_merge($data, Engine_Api::_()->getApi('Core', 'siteapi')->getContentImage($photo, false));
                $response['images'][] = $data;
            }
        }

        $this->respondWithSuccess($response, false);
    }

    /**
     *  Send a message to page owner
     */
    public function messageownerAction() {

        Engine_Api::_()->getApi('Core', 'siteapi')->setView();

        $response = $tempResponse = array();

        $values = $this->getAllParams();
        $viewer = Engine_Api::_()->user()->getViewer();

        if (Engine_Api::_()->core()->hasSubject('sitestore_store'))
            $sitestore = $subject = Engine_Api::_()->core()->getSubject('sitestore_store');
        elseif ($values['action'] != 'category')
            $this->respondWithError('no_record');

        $product_id = $this->_getParam('product_id');

        if (!$product_id)
            $this->respondWithValidationError('parameter_missing', 'product_id missing');

        $product = Engine_Api::_()->getItem('sitestoreproduct_product', $product_id);

        if (!$product)
            $this->respondWithError('no_record');

        // Page owner can't send message to himself
        if ($viewer_id == $product->owner_id)
            $this->respondWithError('unauthorized');

        if ($this->getRequest()->isGet()) {
            $response = Engine_Api::_()->getApi('Siteapi_Core', 'Sitestoreproduct')->getMessageOwnerForm();
            $this->respondWithSuccess($response, true);
        } elseif ($this->getRequest()->isPost()) {

            // Get admins id for sending message
            $manageAdminData = Engine_Api::_()->getDbtable('manageadmins', 'sitestore')->getManageAdmin($sitestore->getIdentity());
            $manageAdminData = $manageAdminData->toArray();

            $recipients = array();
            if (!empty($manageAdminData)) {
                foreach ($manageAdminData as $key => $user_ids) {
                    $user_id = $user_ids['user_id'];
                    if ($viewer_id != $user_id) {
                        $recipients[] = $user_id;
                    }
                }
            }

            $values = $this->getAllParams();
            $validators = Engine_Api::_()->getApi('Siteapi_FormValidators', 'sitestoreproduct')->getMessageOwnerFormValidators();
            $values['validators'] = $validators;
            $validationMessage = $this->isValid($values);

            // Response validation error
            if (!empty($validationMessage) && @is_array($validationMessage)) {
                $this->respondWithValidationError('validation_fail', $validationMessage);
            }

            $db = Engine_Api::_()->getDbtable('messages', 'messages')->getAdapter();
            $db->beginTransaction();

            try {
                // Limit recipients if it is not a special list of members
                $recipients = array_slice($recipients, 0, 1000);
                $recipients = array_unique($recipients);
                $recipientsUsers = Engine_Api::_()->getItemMulti('user', $recipients);
                $sitestoreproduct_title = $product->title;
                $contentData = Engine_Api::_()->getApi('Core', 'siteapi')->getContentImage($product, false);

                $product_title_with_link = "<a href ='" . $contentData['content_url'] . "'>$sitestoreproduct_title</a>";

                $conversation = Engine_Api::_()->getItemTable('messages_conversation')->send(
                        $viewer, $recipients, $values['title'], $values['body'] . "<br><br>" . $this->translate("This message corresponds to the Product:") . $product_title_with_link
                );

                foreach ($recipientsUsers as $user) {
                    if ($user->getIdentity() == $viewer->getIdentity()) {
                        continue;
                    }

                    Engine_Api::_()->getDbtable('notifications', 'activity')->addNotification(
                            $user, $viewer, $conversation, 'message_new'
                    );
                }

                // Increment message counter
                Engine_Api::_()->getDbtable('statistics', 'core')->increment('messages.creations');
                $db->commit();
                $this->successResponseNoContent('no_content');
            } catch (Exception $e) {
                $db->rollBack();
                $this->respondWithError('internal_server_error', $e->getMessage());
            }
        }
    }

    /**
     *  Message friends about this page
     */
    public function tellafriendAction() {

        $viewer = Engine_Api::_()->user()->getViewer();
        $viewer_id = $viewer->getIdentity();

        if (Engine_Api::_()->core()->hasSubject('sitestore_store'))
            $sitestore = $subject = Engine_Api::_()->core()->getSubject('sitestore_store');
        elseif ($values['action'] != 'category')
            $this->respondWithError('no_record');

        $product_id = $this->_getParam('product_id');

        if (!$product_id)
            $this->respondWithValidationError('parameter_missing', 'product_id missing');

        $product = Engine_Api::_()->getItem('sitestoreproduct_product', $product_id);

        if (!$product)
            $this->respondWithError('no_record');

        // Check user validation
        if (!$this->_helper->requireUser()->isValid())
            $this->respondWithError('unauthorized');

        // Get viewer
        $viewer = Engine_Api::_()->user()->getViewer();
        $viewer_id = $viewer->getIdentity();

        // Get form
        if ($this->getRequest()->isGet()) {
            $response = Engine_Api::_()->getApi('Siteapi_Core', 'sitestoreproduct')->getTellAFriendForm();

            if ($viewer_id) {
                $response['formValues']['sender_email'] = $viewer->email;
                $response['formValues']['sender_name'] = $this->translate($viewer->displayname);
            }

            $this->respondWithSuccess($response, true);
        } else if ($this->getRequest()->isPost()) {

            // Get form values
            $values = $this->_getAllParams();

            // Start form validation
            $validators = Engine_Api::_()->getApi('Siteapi_FormValidators', 'sitestoreproduct')->tellaFriendFormValidators();
            $values['validators'] = $validators;
            $validationMessage = $this->isValid($values);

            // Response validation error
            if (!empty($validationMessage) && @is_array($validationMessage)) {
                $this->respondWithValidationError('validation_fail', $validationMessage);
            }
            // Explode email ids
            $reciver_ids = explode(',', $values['receiver_emails']);
            if (!empty($values['send_me'])) {
                $reciver_ids[] = $values['sender_email'];
            }
            $sender_email = $values['sender_email'];

            $heading = $product->title;

            // Check valid email id format
            $validator = new Zend_Validate_EmailAddress();
            $validator->getHostnameValidator()->setValidateTld(false);

            if (!$validator->isValid($sender_email)) {
                $this->respondWithValidationError('validation_fail', 'Invalid sender email address value');
            }

            if (!empty($reciver_ids)) {
                foreach ($reciver_ids as $receiver_id) {
                    $receiver_id = trim($receiver_id, ' ');
                    ($reciver_ids);
                    if (!$validator->isValid($receiver_id)) {
                        $this->respondWithValidationError('validation_fail', 'Please enter correct email address of the receiver(s).');
                    }
                }
            }

            $sender = $values['sender_name'];
            $message = $values['message'];
            $contentData = Engine_Api::_()->getApi('Core', 'siteapi')->getContentImage($product, false);

            try {
                Engine_Api::_()->getApi('mail', 'core')->sendSystem($reciver_ids, 'SITESTOREPRODUCT_TELLAFRIEND_EMAIL', array(
                    'host' => $_SERVER['HTTP_HOST'],
                    'sender' => $sender,
                    'heading' => $heading,
                    'message' => '<div>' . $message . '</div>',
                    'object_link' => $contentData['content_url'],
                    'email' => $sender_email,
                    'queue' => true
                ));
            } catch (Exception $ex) {
                $this->respondWithError('internal_server_error', $ex->getMessage());
            }
            $this->successResponseNoContent('no_content');
        }
    }

    //ACTION FOR ASK OPINION ABOUT PRODUCT
    public function askopinionAction() {

        $viewer = Engine_Api::_()->user()->getViewer();
        $viewer_id = $viewer->getIdentity();

        if (Engine_Api::_()->core()->hasSubject('sitestore_store'))
            $sitestore = $subject = Engine_Api::_()->core()->getSubject('sitestore_store');
        elseif ($values['action'] != 'category')
            $this->respondWithError('no_record');

        $product_id = $this->_getParam('product_id');

        if (!$product_id)
            $this->respondWithValidationError('parameter_missing', 'product_id missing');

        $product = Engine_Api::_()->getItem('sitestoreproduct_product', $product_id);

        if (!$product)
            $this->respondWithError('no_record');

        // Check user validation
        if (!$this->_helper->requireUser()->isValid())
            $this->respondWithError('unauthorized');

        // Get viewer
        $viewer = Engine_Api::_()->user()->getViewer();
        $viewer_id = $viewer->getIdentity();

        // Get form
        if ($this->getRequest()->isGet()) {
            $response = Engine_Api::_()->getApi('Siteapi_Core', 'sitestoreproduct')->getTellAFriendForm();

            if ($viewer_id) {
                $response['formValues']['sender_email'] = $viewer->email;
                $response['formValues']['sender_name'] = $this->translate($viewer->displayname);
            }

            $this->respondWithSuccess($response, true);
        } else if ($this->getRequest()->isPost()) {

            // Get form values
            $values = $this->_getAllParams();

            // Start form validation
            $validators = Engine_Api::_()->getApi('Siteapi_FormValidators', 'sitestoreproduct')->tellaFriendFormValidators();
            $values['validators'] = $validators;
            $validationMessage = $this->isValid($values);

            // Response validation error
            if (!empty($validationMessage) && @is_array($validationMessage)) {
                $this->respondWithValidationError('validation_fail', $validationMessage);
            }
            // Explode email ids
            $reciver_ids = explode(',', $values['receiver_emails']);
            if (!empty($values['send_me'])) {
                $reciver_ids[] = $values['sender_email'];
            }
            $sender_email = $values['sender_email'];

            $heading = $product->title;

            // Check valid email id format
            $validator = new Zend_Validate_EmailAddress();
            $validator->getHostnameValidator()->setValidateTld(false);

            if (!$validator->isValid($sender_email)) {
                $this->respondWithValidationError('validation_fail', 'Invalid sender email address value');
            }

            if (!empty($reciver_ids)) {
                foreach ($reciver_ids as $receiver_id) {
                    $receiver_id = trim($receiver_id, ' ');
                    ($reciver_ids);
                    if (!$validator->isValid($receiver_id)) {
                        $this->respondWithValidationError('validation_fail', 'Please enter correct email address of the receiver(s).');
                    }
                }
            }

            $sender = $values['sender_name'];
            $message = $values['message'];
            $contentData = Engine_Api::_()->getApi('Core', 'siteapi')->getContentImage($product, false);

            try {
                Engine_Api::_()->getApi('mail', 'core')->sendSystem($reciver_ids, 'SITESTOREPRODUCT_ASKOPINION_EMAIL', array(
                    'host' => $_SERVER['HTTP_HOST'],
                    'sender' => $sender,
                    'heading' => $heading,
                    'message' => '<div>' . $message . '</div>',
                    'object_link' => $contentData['content_url'],
                    'email' => $sender_email,
                    'queue' => true
                ));
            } catch (Exception $ex) {
                $this->respondWithError('internal_server_error', $ex->getMessage());
            }
            $this->successResponseNoContent('no_content');
        }
    }

    /*
     * Product search form
     */

    public function productSearchFormAction() {
        $this->respondWithSuccess(Engine_Api::_()->getApi('Siteapi_Core', 'sitestoreproduct')->productSearchForm());
    }

    /*
     * get variation options
     */

    public function variationOptionAction() {
        Engine_Api::_()->getApi('Core', 'siteapi')->setView();
        Engine_Api::_()->getApi('Core', 'siteapi')->setLocal();
        $values = $this->_getAllParams();

        $defaultPrice = $this->_getParam('price', 0);

        // match option_id
        $key = array_values(preg_grep("/^select_([0-9]+)/", array_keys($values)));

        if (!empty($key))
            $key = $key[0];
        else
            $this->respondWithValidationError('parameter_missing', 'option parameter missing');

        $combination_attribute_id = $values[$key];

        if (!$values['product_id'])
            $this->respondWithValidationError('parameter_missing', 'product_id missing');

        $product = Engine_Api::_()->getItem('sitestoreproduct_product', $values['product_id']);
        $profileFields = Engine_Api::_()->getDbtable('Productfields', 'sitestoreproduct');
        $cartProductFieldsMeta = Engine_Api::_()->getDbTable('CartproductFieldMeta', 'sitestoreproduct');
        $cartProductFieldsOptions = Engine_Api::_()->getDbtable('CartproductFieldOptions', 'sitestoreproduct');
        $combinationAttributesTable = Engine_Api::_()->getDbTable('CombinationAttributes', 'sitestoreproduct');
        $combinationTable = Engine_Api::_()->getDbTable('Combinations', 'sitestoreproduct');
        $combinationAttributeMapsTable = Engine_Api::_()->getDbTable('CombinationAttributeMap', 'sitestoreproduct');
        $combinationTableName = $combinationTable->info('name');
        $combinationAttributesTableName = $combinationAttributesTable->info('name');
        $combinationAttributeMapsTableName = $combinationAttributeMapsTable->info('name');
        $cartProductFieldsMetaTableName = $cartProductFieldsMeta->info('name');
        $cartProductFieldsOptionsTableName = $cartProductFieldsOptions->info('name');

        $combinationAttributeSelect = $combinationAttributesTable->select()
                ->from($combinationAttributesTableName)
                ->setIntegrityCheck(false)
                ->joinInner($combinationAttributeMapsTableName, $combinationAttributeMapsTableName . ".attribute_id = " . $combinationAttributesTableName . ".attribute_id", array('combination_id'))
                ->joinInner($combinationTableName, $combinationTableName . ".combination_id = " . $combinationAttributeMapsTableName . ".combination_id", array('status', 'quantity'))
                ->where("$combinationAttributesTableName.combination_attribute_id = ?", $combination_attribute_id);

        $combinationAttributeData = $combinationAttributeSelect->query()->fetchAll();

        if (!$combinationAttributeData)
            $this->respondWithError("no_record");

        $price = $combinationAttributeData[0]['price'];

        if (!isset($defaultPrice) || empty($defaultPrice))
            $defaultPrice = $product->price;

        if ($combinationAttributeData[0]['price_increment'])
            $defaultPrice += $price;
        else
            $defaultPrice -= $price;

        $combinationidsArray = array();
        $order = $combinationAttributeData[0]['order'];

        foreach ($combinationAttributeData as $row)
            $combinationidsArray[] = $row['combination_id'];

        $combinationAttributeSelect = $combinationAttributesTable->select()
                ->from($combinationAttributesTableName)
                ->setIntegrityCheck(false)
                ->joinInner($combinationAttributeMapsTableName, $combinationAttributeMapsTableName . ".attribute_id = " . $combinationAttributesTableName . ".attribute_id", array())
                ->joinInner($cartProductFieldsMetaTableName, "$cartProductFieldsMetaTableName.field_id = $combinationAttributesTableName.field_id", array('label as field_label'))
                ->joinInner($cartProductFieldsOptionsTableName, "$cartProductFieldsOptionsTableName.option_id = $combinationAttributesTableName.combination_attribute_id", array('label'))
                ->where("$combinationAttributeMapsTableName.combination_id in (?)", $combinationidsArray)
                ->where("$combinationAttributesTableName.order = ?", $order + 1);

        $combinationNextData = $combinationAttributeSelect->query()->fetchALL();

        // if(empty($combinationNextData))
        //     $this->respondWithSuccess(array('productPrice' => $defaultNamespace->productPrice));

        $fieldArray = $response = array();

        foreach ($combinationNextData as $attribute) {
            $price = $attribute['price'];
            unset($data);
            $data = array('label' => $attribute['label']);
            $data['price'] = number_format($price, 2);
            $data['price_increment'] = false;
            if ($attribute['price_increment'])
                $data['price_increment'] = true;

            if (empty($fieldArray)) {
                $fieldArray = array(
                    'name' => "select_" . $attribute['field_id'],
                    'label' => $attribute['field_label'],
                    'type' => 'select',
                    'order' => $attribute['order'] + 1,
                    'multiOptions' => array(
                        '0' => $this->translate('-- select --'),
                        $attribute['combination_attribute_id'] => $data,
                    ),
                );
            } else
                $fieldArray['multiOptions'][$attribute['combination_attribute_id']]['label'] = $this->translate($attribute['label']);
        }

        $response['field'] = $fieldArray;
        $response['productPrice'] = $defaultPrice;

        if (empty($response['field'])) {
            foreach ($combinationAttributeData as $row => $combination) {
                if ($combination['quantity']) {
                    $response['quantity_available'] = $combination['quantity'];
                    $response['combination_id'] = $combination['combination_id'];
                    $response['status'] = $combination['status'];
                    break;
                }
            }

            if (!$response['status'])
                $response['error'] = $this->translate("This combination is not enabled , please choose another one");

            if (!$response['quantity_available'])
                $response['error'] = $this->translate("The product with these combinations is out of stock");
        }

        $this->respondWithSuccess($response, false);
    }

    /*
     * Add to cart
     */

    public function addToCartAction() {
        $this->validateRequestMethod("POST");
        // Get viewer
        $viewer = Engine_Api::_()->user()->getViewer();
        $values = $this->_getAllParams();
        $product_id = $values['product_id'];

        $configData = (isset($values['product_config']) && $values['product_config']) ? Zend_Json::decode(urldecode($values['product_config'])) : 0;

        if ($configData) {
            foreach ($configData as $row => $value)
                if (is_string($value) && strpos($value, ',') !== false)
                    $configData[$row] = explode(',', $value);
        }
        $productTable = Engine_Api::_()->getDbtable('products', 'sitestoreproduct');

        $viewer_id = $viewer->getIdentity();

        if (!empty($viewer_id)) {
            $level_id = Engine_Api::_()->user()->getViewer()->level_id;
        } else {
            $level_id = Engine_Api::_()->getDbtable('levels', 'authorization')->fetchRow(array('type = ?' => "public"))->level_id;
        }

        if (!$values['product_id'])
            $this->respondWithValidationError('parameter_missing', 'product_id missing');

        $db = Engine_Db_Table::getDefaultAdapter();

        $productObj = $product = Engine_Api::_()->getItem('sitestoreproduct_product', $values['product_id']);

        if (!$productObj)
            $this->respondWithError('no_record');

        if ($productObj->product_type == 'configurable') {

            $sql = "select count(*) as count from engine4_sitestoreproduct_combination_attributes where product_id='" . $values['product_id'] . "'";
            $result = $db->query($sql)->fetchALL();

            if ($result[0]['count'] > 0) {

                // $this->respondWithError('unauthorized', "Store Admin didn't define and configurations for this product");
                if (!$configData['combination_id'])
                    $this->respondWithError('unauthorized', 'Please select configurations of product');

                // check for whether can apply this combination id
                $combinationTable = Engine_Api::_()->getDbTable("combinations", "sitestoreproduct");

                $select = $combinationTable->select()
                        ->where('combination_id = ?', $configData['combination_id']);

                $combination = $select->query()->fetchALL();

                if (!$combination)
                    $this->respondWithError('unauthorized', 'No such Combination exists');

                $combination = $combination[0];

                if (!$combination['status'])
                    $this->respondWithError("unauthorized", $this->translate("The combination does not exist"));

                unset($configData['combination_id']);
            }
        }

        if ($product->product_type == 'downloadable') {
            $isAnyFileExist = Engine_Api::_()->getDbtable('downloadablefiles', 'sitestoreproduct')->isAnyMainFileExist($product->getIdentity());

            if (empty($isAnyFileExist))
                $this->respondWithError('unauthorized', 'Product is downloadable but there are no downloadable files present, please contact the store admin');
        }

        if (Engine_Api::_()->getApi('settings', 'core')->getSetting('sitestoreproduct.openclose', 0)) {
            if (!empty($productObj->draft) || !empty($productObj->closed) || empty($productObj->search) || empty($productObj->approved) || $productObj->start_date > date('Y-m-d H:i:s') || ($productObj->end_date < date('Y-m-d H:i:s') && !empty($productObj->end_date_enable))) {
                $this->respondWithError('unauthorized', $this->translate("This product is currently not available for purchase"));
            }
        } else {
            if (!empty($productObj->draft) || empty($productObj->search) || empty($productObj->approved) || $productObj->start_date > date('Y-m-d H:i:s') || ($productObj->end_date < date('Y-m-d H:i:s') && !empty($productObj->end_date_enable))) {
                $this->respondWithError('unauthorized', $this->translate("This product is currently not available for purchase"));
            }
        }

        $temp_allowed_selling = Engine_Api::_()->sitestoreproduct()->getIsAllowedSellingProducts($productObj->store_id);
        if (empty($temp_allowed_selling) || empty($productObj->allow_purchase)) {
            $this->respondWithError('unauthorized', $this->translate("This product is currently not available for purchase"));
        }


        // if the user is not logged in then we will just give them success message and android/ios developers will save the product with configurations on their side

        if (!$viewer_id)
            $this->successResponseNoContent('no_content');

        $productsArray = array();

        if ($productObj->product_type == 'grouped') {
            $params = array();
            $params['product_type'] = 'grouped';
            $params['product_id'] = $productObj->getIdentity();

            $groupedProducts = $productTable->getCombinedProducts($params);

            foreach ($groupedProducts as $individualProduct) {
                $temp_allowed_selling = Engine_Api::_()->sitestoreproduct()->getIsAllowedSellingProducts($individualProduct->store_id);

                if (!(!empty($temp_allowed_selling) && $product->allow_purchase && ((int) ($product->stock_unlimited || $product->in_stock))))
                    continue;
                $productsArray[] = $individualProduct->getIdentity();
            }
        }

        if (empty($productsArray))
            $productsArray[] = $productObj->getIdentity();

        $directPayment = Engine_Api::_()->sitestoreproduct()->isDirectPaymentEnable();
        $isDownPaymentEnable = Engine_Api::_()->getApi('settings', 'core')->getSetting('sitestorereservation.downpayment', 0);

        $cartTable = Engine_Api::_()->getDbtable('carts', 'sitestoreproduct');
        $cart_product_table = Engine_Api::_()->getDbtable('cartproducts', 'sitestoreproduct');

        $cart_id = $cartTable->getCartId($viewer_id);

        $db = $cartTable->getAdapter();
        $db->beginTransaction();

        try {
            foreach ($productsArray as $row => $product_id) {
                $productObj = Engine_Api::_()->getItem("sitestoreproduct_product", $product_id);
                if (empty($cart_id)) {
                    $row = $cartTable->createRow();
                    $row->setFromArray(array('owner_id' => $viewer_id));
                    $cart_id = $row->save();

                    $lastInsertId = $cart_product_table->insert(array('cart_id' => $cart_id, 'product_id' => $product_id, 'quantity' => $productObj->min_order_quantity));

                    if ($productObj->product_type == 'configurable' && isset($result) && $result[0]['count'] > 0) {
                        $cartProductFieldValue = Engine_Api::_()->getDbtable('CartProductFieldValues', 'sitestoreproduct');
                        unset($configData['combination_id']);
                        foreach ($configData as $row => $value) {
                            $key = explode('_', $row);
                            if (count($key) == 2) {
                                $cartProductFieldValue->insert(array('item_id' => $lastInsertId, 'field_id' => $key[1], 'value' => $value, 'category_attribute' => 1));
                            } elseif (count($key) == 3) {
                                if (is_array($value)) {
                                    foreach ($value as $subrow => $subvalue) {
                                        $cartProductFieldValue->insert(array('item_id' => $lastInsertId, 'field_id' => $key[2], 'value' => $subvalue, 'category_attribute' => 0, 'index' => $subrow));
                                    }
                                    continue;
                                }

                                $cartProductFieldValue->insert(array('item_id' => $lastInsertId, 'field_id' => $key[2], 'value' => $value, 'category_attribute' => 0));
                            }
                        }
                    }
                } else {
                    // CHECK PRODUCT PAYMENT TYPE => DOWNPAYMENT OR NOT
                    $ids = Engine_Api::_()->getDbtable('carts', 'sitestoreproduct')->getProductCounts($cart_id);
                    if (!empty($directPayment) && !empty($isDownPaymentEnable) && !empty($ids)) {
                        $productIds = Engine_Api::_()->getDbtable('cartproducts', 'sitestoreproduct')->getCartProductIds($cart_id);
                        $product_ids = implode(",", $productIds);

                        $selectedProductDownpaymentValue = Engine_Api::_()->getDbTable('otherinfo', 'sitestoreproduct')->getColumnValue($productObj->product_id, 'downpayment_value');

                        $cartProductPaymentType = Engine_Api::_()->sitestoreproduct()->getProductPaymentType($product_ids);

                        if (empty($selectedProductDownpaymentValue) && !empty($cartProductPaymentType)) {
                            $this->respondWithValidationError('validation_fail', $this->translate("You can't add to cart this product right now as your cart contain products which have enabled downpayment and for this product downpayment is not enabled."));
                        } else if (!empty($selectedProductDownpaymentValue) && empty($cartProductPaymentType)) {
                            $this->respondWithValidationError('validation_fail', $this->translate("You can't add to cart this product right now as your cart contain products for which downpayment is not enabled and for this product downpayment is enabled."));
                        }
                    }

                    $cart_product_values = $cart_product_table->getConfigurationId($product_id, $cart_id);
                    $cart_product_obj = null;
                    if (!empty($cart_product_values) && $productObj->product_type == 'configurable' && isset($result) && $result[0]['count'] > 0) {
                        foreach ($cart_product_values as $row => $value) {
                            $cartProduct = Engine_Api::_()->getItem('sitestoreproduct_cartproduct', $value);
                            $fieldValues = Engine_Api::_()->fields()->getFieldsValues($cartProduct);
                            $cartProductFieldValue = $fieldValues->getRowsMatching(array(
                                'item_id' => $cartProduct->getIdentity(),
                            ));
                            $fieldvalueArray = array();
                            foreach ($cartProductFieldValue as $fieldIndex => $fieldValue) {
                                $fieldValue = $fieldValue->toArray();
                                if ($fieldValue['category_attribute'])
                                    $fieldvalueArray['select_' . $fieldValue['field_id']] = $fieldValue['value'];
                                else {
                                    if (isset($fieldvalueArray[$productObj->store_id . '_' . $productObj->getIdentity() . '_' . $fieldValue['field_id']])) {
                                        if (!is_array($fieldvalueArray[$productObj->store_id . '_' . $productObj->getIdentity() . '_' . $fieldValue['field_id']])) {
                                            $tempdata = $fieldvalueArray[$productObj->store_id . '_' . $productObj->getIdentity() . '_' . $fieldValue['field_id']];
                                            $fieldvalueArray[$productObj->store_id . '_' . $productObj->getIdentity() . '_' . $fieldValue['field_id']] = array();
                                            $fieldvalueArray[$productObj->store_id . '_' . $productObj->getIdentity() . '_' . $fieldValue['field_id']][] = $tempdata;
                                        }
                                        $fieldvalueArray[$productObj->store_id . '_' . $productObj->getIdentity() . '_' . $fieldValue['field_id']][] = $fieldValue['value'];
                                        continue;
                                    }
                                    $fieldvalueArray[$productObj->store_id . '_' . $productObj->getIdentity() . '_' . $fieldValue['field_id']] = $fieldValue['value'];
                                }
                            }
                            $array_diff_assoc = Engine_Api::_()->sitestoreproduct()->multidimensional_array_diff($fieldvalueArray, $configData);
                            if ($array_diff_assoc) {
                                $cart_product_obj = $cartProduct;
                                break;
                            }
                        }
                    } else if (!empty($cart_product_values))
                        $cart_product_obj = Engine_Api::_()->getItem('sitestoreproduct_cartproduct', $cart_product_values[0]);



                    // (array('cart_id = ?' => $cart_id, 'product_id =?' => $product_id));
                    // IF PRODUCT IS NOT IN VIEWER CART, THEN ADD IT TO CART
                    if (empty($cart_product_obj)) {
                        $lastInsertId = $cart_product_table->insert(array('cart_id' => $cart_id, 'product_id' => $product_id, 'quantity' => $productObj->min_order_quantity));

                        if ($productObj->product_type == 'configurable') {
                            $cartProductFieldValue = Engine_Api::_()->getDbtable('CartProductFieldValues', 'sitestoreproduct');
                            foreach ($configData as $row => $value) {
                                $key = explode('_', $row);

                                if (count($key) == 2) {
                                    $cartProductFieldValue->insert(array('item_id' => $lastInsertId, 'field_id' => $key[1], 'value' => $value, 'category_attribute' => 1));
                                } elseif (count($key) == 3) {
                                    if (is_array($value)) {
                                        foreach ($value as $subrow => $subvalue) {
                                            try {
                                                $cartProductFieldValue->insert(array('item_id' => $lastInsertId, 'field_id' => $key[2], 'value' => $subvalue, 'category_attribute' => 0, 'index' => $subrow));
                                            } catch (Exception $e) {
                                                // null exception
                                            }
                                        }
                                        continue;
                                    }
                                    $cartProductFieldValue->insert(array('item_id' => $lastInsertId, 'field_id' => $key[2], 'value' => $value, 'category_attribute' => 0));
                                }
                            }
                        }
                    } else {
                        $product_qty = $cart_product_obj->quantity;
                        $updatedQty = $product_qty + 1;

                        if (empty($productObj->stock_unlimited) && empty($productObj->in_stock)) {
                            $this->respondWithValidationError('validation_fail', $this->translate("This product is currently not available for purchase."));
                        } elseif (empty($productObj->stock_unlimited) && $productObj->in_stock < $updatedQty) {
                            if ($productObj->in_stock == 1)
                                $this->respondWithValidationError('validation_fail', $this->translate("Only 1 quantity of this product is available in stock. Please enter the quantity as 1."));
                            else
                                $this->respondWithValidationError('validation_fail', $this->translate("Only %s quantities of this product are available in stock. Please enter the quantity less than or equal to %s.", $productObj->in_stock, $productObj->in_stock));
                        }
                        else if (!empty($productObj->max_order_quantity) && $updatedQty > $productObj->max_order_quantity) {
                            if ($productObj->max_order_quantity == 1)
                                $this->respondWithValidationError('validation_fail', $this->translate("You can purchase maximum 1 quantity of this product in a single order. So, please enter the quantity as 1."));
                            else
                                $this->respondWithValidationError('validation_fail', $this->translate("You can purchase maximum %s quantities of this product in a single order. So, please enter the quantity as less than or equal to %s.", $productObj->max_order_quantity, $productObj->max_order_quantity));
                        }
                        else {
                            $dbsql = $cart_product_table->getAdapter();
                            $sql = "update " . $cart_product_table->info('name') . " set quantity=quantity+1 where cartproduct_id=?";
                            $query = $dbsql->query($sql, array($cart_product_obj->getIdentity()));
                        }
                    }
                }
            }
            $db->commit();
            $this->successResponseNoContent('no_content');
        } catch (Exception $e) {
            $db->rollBack();
            $this->respondWithError('internal_server_error', $e->getMessage());
        }
    }

    /**
     * Returns Categories , Sub-Categories, SubSub-Categories and pages array
     * 
     */
    public function categoryAction() {
        // Validate request method
        $this->validateRequestMethod();

        // Get viewer
        $viewer = Engine_Api::_()->user()->getViewer();

        // Prepare response
        $values = $response = array();
        $category_id = $this->getRequestParam('category_id', null);
        $subCategory_id = $this->getRequestParam('subcategory_id', null);
        $subsubcategory_id = $this->getRequestParam('subsubcategory_id', null);
        $showAllCategories = $this->getRequestParam('showAllCategories', 1);
        $showCategories = $this->getRequestParam('showCategories', 1);
        $showProducts = $this->getRequestParam('showProducts', 1);
        if ($this->getRequestParam('showCount')) {
            $showCount = 1;
        } else {
            $showCount = $this->getRequestParam('showCount', 0);
        }

        $orderBy = $this->getRequestParam('orderBy', 'category_name');

        $productApi = Engine_Api::_()->getApi('Siteapi_Core', 'sitestoreproduct');
        Engine_Api::_()->getApi('Core', 'siteapi')->setView();

        $categories = array();
        // Get pages table
        $tableSitepage = Engine_Api::_()->getDbtable('stores', 'sitestore');
        $sitepageShowAllCategories = Engine_Api::_()->getApi('settings', 'core')->getSetting('sitestore.categorywithslug', 1);
        $showAllCategories = !empty($sitepageShowAllCategories) ? $showAllCategories : 0;

        if ($showCategories) {
            $product = 1;
            if ($showAllCategories)
                $product = 0;

            $category_info = $productApi->getAllCategories(0, 'category_id', $product, '', '', '');

            $categoriesCount = count($category_info);

            foreach ($category_info as $value) {
                $sub_cat_array = array();
                $category_array = array('category_id' => $value->category_id,
                    'category_name' => $this->translate($value->category_name),
                    'order' => $value->cat_order,
                    'images' => Engine_Api::_()->getApi('Core', 'siteapi')->getContentImage($value),
                );
                if ($showCount)
                    $category_array['count'] = $value->count;

                $response['categories'][] = $category_array;
            }

            if (!empty($category_id)) {

                $product = 1;
                if ($showAllCategories)
                    $product = 0;

                $category_info2 = $productApi->getAllCategories($category_id, 'subcategory_id', $product, '', '', '');
                foreach ($category_info2 as $subresults) {
                    $tmp_array = array('sub_cat_id' => $subresults->category_id,
                        'sub_cat_name' => $this->translate($subresults->category_name),
                        'order' => $subresults->cat_order);

                    if ($showCount)
                        $tmp_array['count'] = $subresults->count;

                    $response['subCategories'][] = $tmp_array;
                }
            }

            if (!empty($subCategory_id)) {

                $product = 1;
                if ($showAllCategories)
                    $product = 0;

                $category_info2 = $productApi->getAllCategories($subCategory_id, 'subsubcategory_id', $product, '', '', '');
                foreach ($category_info2 as $subsubresults) {
                    $tmp_array = array('tree_sub_cat_id' => $subsubresults->category_id,
                        'tree_sub_cat_name' => $this->translate($subsubresults->category_name),
                        'order' => $subsubresults->cat_order);

                    if ($showCount)
                        $tmp_array['count'] = $subsubresults->count;

                    $response['subsubCategories'][] = $tmp_array;
                }
            }
        }

        // show categories at browse page
        // if ($this->getRequestParam('action', null) == 'browse')
        //     return $response;

        if ($showProducts && isset($category_id) && !empty($category_id)) {

            $params = array();

            $itemCount = $params['itemCount'] = $this->_getParam('itemCount', 0);

            // Get categories
            $categories = array();

            $category_products_array = array();

            $values = $this->getAllParams();
            $values['action'] = "category";
            $values['type'] = "browse";

            if (empty($values['page']))
                $values['page'] = 1;

            if (empty($values['limit']))
                $values['limit'] = 20;

            if (@$values['show'] == 2) {
                $friends = $viewer->membership()->getMembers();

                foreach ($friends as $friend)
                    $values['users'][] = $friend->user_id;
            } else if (!isset($values['show']))
                $values['show'] = 3;

            // get the stores
            if (isset($values['subCategory_id']))
                $values['subcategory_id'] = $values['subCategory_id'];

            $response['response'] = $this->getStoreProductData($values);
            $response['totalProductCount'] = count($response['response']);
        }

        if (isset($categoriesCount) && !empty($categoriesCount))
            $response['totalItemCount'] = $categoriesCount;

        $response['canCreate'] = Engine_Api::_()->authorization()->isAllowed('sitestore_store', $viewer, 'create');
        $response['currency'] = Engine_Api::_()->getApi('settings', 'core')->getSetting('payment.currency', 'USD');

        $this->respondWithSuccess($response, false);
    }

    // To display products in the auto suggest at report form
    public function suggestproductsAction() {
        $owner_id = $this->_getParam('owner_id', '');
        $text = $this->_getParam('product_search', null);
        $store_ids = $this->_getParam('store_ids', null);
        $store_id = $this->_getParam('store_id', null);
        $select_store = $this->_getParam('select_store', 'current_store');
        $product_ids = $this->_getParam('product_ids', null);
        $limit = $this->_getParam('limit', 40);
        $productCreateFlag = 1;

        if (!empty($productCreateFlag))
            $store_ids = $this->_getParam('store_id');
        $productTypes = array();
        $product_types = $this->_getParam('product_types', null);
        if (!empty($product_types)) {
            $search_product_types = explode(",", $product_types);

            foreach ($search_product_types as $values) {
                if ($values == 'simple')
                    $productTypes[] = "'simple'";
                if ($values == 'configurable')
                    $productTypes[] = "'configurable'";
                if ($values == 'virtual')
                    $productTypes[] = "'virtual'";
                if ($values == 'downloadable')
                    $productTypes[] = "'downloadable'";
            }
        }
        $selectedProductTypes = @implode(',', $productTypes);
//    $selectedProductTypes = array('simple' => $isSimpleProduct, 'configurable' => $isConfigurableProduct, 'virtual' => $isVirtualProduct, 'downloadable' => $isDownloadableProduct);

        if (($select_store == 'specific_store') && empty($store_ids))
            $store_ids = $this->_getParam();

        if ($select_store == 'current_store')
            $store_ids = $store_id;

        $productObjects = Engine_Api::_()->getDbtable('products', 'sitestoreproduct')->getProductsByText($store_ids, $text, $limit, $product_ids, $owner_id, $productCreateFlag, $selectedProductTypes);
        $data = array();

        $host = Engine_Api::_()->getApi('Core', 'siteapi')->getHost();
        $baseParentUrl = Zend_Controller_Front::getInstance()->getBaseUrl();
        $baseParentUrl = @trim($baseParentUrl, "/");
        $staticBaseUrl = Engine_Api::_()->getApi('settings', 'core')->getSetting('core.static.baseurl', null);
        $getDefaultStorageId = Engine_Api::_()->getDbtable('services', 'storage')->getDefaultServiceIdentity();
        $getDefaultStorageType = Engine_Api::_()->getDbtable('services', 'storage')->getService($getDefaultStorageId)->getType();


        if ($getDefaultStorageType == 'local')
            $host = !empty($staticBaseUrl) ? $staticBaseUrl : $host;

        $mode = $this->_getParam('struct');
        if ($mode == 'text') {
            foreach ($productObjects as $products) {
                $data[] = $products->title;
            }
        } else {
            foreach ($productObjects as $products) {

                $photoUrl = $products->getPhotoUrl('thumb.icon');

                if (!strstr($photoUrl, 'http'))
                    $photoUrl = $host . $photoUrl;
                $data[] = array(
                    'id' => $products->product_id,
                    'label' => $products->title,
                    'price' => $products->price,
                    'product_type' => $products->product_type,
                    'photo' => $photoUrl,
                );
            }
        }
        $response['response'] = $data;
        $this->respondWithSuccess($response, true);
    }

    private function _getOrderByOptions() {
        $settings = $coreSettings = Engine_Api::_()->getApi('settings', 'core');
        $storesearchsettings = Engine_Api::_()->getDbTable('searchformsetting', 'seaocore');

        $row = $storesearchsettings->getFieldsOptions('sitestoreproduct', 'orderby');
        if (!empty($row) && !empty($row->display)) {
            if (Engine_Api::_()->getApi('settings', 'core')->getSetting('sitestoreproduct.reviews', 2) == 3 || Engine_Api::_()->getApi('settings', 'core')->getSetting('sitestoreproduct.reviews', 2) == 2) {
                if (Engine_Api::_()->sitestore()->isCommentsAllow("sitestoreproduct_product")) {
                    $multiOptionsOrderBy = array(
                        '' => "",
                        'price_low_to_high' => 'Price low to high',
                        'price_high_to_low' => 'Price high to low',
                        'discount_amount' => 'Most Discounted',
                        'title' => "Alphabetic",
                        'product_id' => 'Most Recent',
                        'view_count' => 'Most Viewed',
                        'like_count' => "Most Liked",
                        'comment_count' => "Most Commented",
                        'review_count' => "Most Reviewed",
                        'rating_avg' => "Most Rated",
                    );
                } else {
                    $multiOptionsOrderBy = array(
                        '' => "",
                        'price_low_to_high' => 'Price low to high',
                        'price_high_to_low' => 'Price high to low',
                        'discount_amount' => 'Most Discounted',
                        'title' => "Alphabetic",
                        'product_id' => 'Most Recent',
                        'view_count' => 'Most Viewed',
                        'like_count' => "Most Liked",
//            'comment_count' => "Most Commented",
                        'review_count' => "Most Reviewed",
                        'rating_avg' => "Most Rated",
                    );
                }
            } elseif (Engine_Api::_()->getApi('settings', 'core')->getSetting('sitestoreproduct.reviews', 2) == 1) {
                if (Engine_Api::_()->sitestore()->isCommentsAllow("sitestoreproduct_product")) {
                    $multiOptionsOrderBy = array(
                        '' => "",
                        'price_low_to_high' => 'Price low to high',
                        'price_high_to_low' => 'Price high to low',
                        'discount_amount' => 'Most Discounted',
                        'title' => "Alphabetic",
                        'product_id' => 'Most Recent',
                        'view_count' => 'Most Viewed',
                        'like_count' => "Most Liked",
                        'comment_count' => "Most Commented",
                        'rating_avg' => "Most Rated",
                    );
                } else {
                    $multiOptionsOrderBy = array(
                        '' => "",
                        'price_low_to_high' => 'Price low to high',
                        'price_high_to_low' => 'Price high to low',
                        'discount_amount' => 'Most Discounted',
                        'title' => "Alphabetic",
                        'product_id' => 'Most Recent',
                        'view_count' => 'Most Viewed',
                        'like_count' => "Most Liked",
//            'comment_count' => "Most Commented",
                        'rating_avg' => "Most Rated",
                    );
                }
            } else {
                if (Engine_Api::_()->sitestore()->isCommentsAllow("sitestoreproduct_product")) {
                    $multiOptionsOrderBy = array(
                        '' => "",
                        'price_low_to_high' => 'Price low to high',
                        'price_high_to_low' => 'Price high to low',
                        'discount_amount' => 'Most Discounted',
                        'title' => "Alphabetic",
                        'product_id' => 'Most Recent',
                        'view_count' => 'Most Viewed',
                        'like_count' => "Most Liked",
                        'comment_count' => "Most Commented",
                    );
                } else {
                    $multiOptionsOrderBy = array(
                        '' => "",
                        'price_low_to_high' => 'Price low to high',
                        'price_high_to_low' => 'Price high to low',
                        'discount_amount' => 'Most Discounted',
                        'title' => "Alphabetic",
                        'product_id' => 'Most Recent',
                        'view_count' => 'Most Viewed',
                        'like_count' => "Most Liked",
//            'comment_count' => "Most Commented",
                    );
                }
            }
        }
        return $multiOptionsOrderBy;
    }

    private function getSiteUrl() {
        $staticBaseUrl = Engine_Api::_()->getApi('settings', 'core')->getSetting('core.static.baseurl', null);
        $serverHost = Engine_Api::_()->getApi('Core', 'siteapi')->getHost();
        $getDefaultStorageId = Engine_Api::_()->getDbtable('services', 'storage')->getDefaultServiceIdentity();
        $getDefaultStorageType = Engine_Api::_()->getDbtable('services', 'storage')->getService($getDefaultStorageId)->getType();
        $getHost = '';
        $getHost = !empty($staticBaseUrl) ? $staticBaseUrl : $serverHost;

        return $getHost;
    }

    private function canAddtoCartError($product) {
        $error = null;
        if (!$product)
            return $this->translate("NO such product exists");

        $in_stock_product = (int) ($product->stock_unlimited || $product->in_stock);
        if ((!$in_stock_product))
            $error = $this->translate("Product is out of stock");

        if (Engine_Api::_()->getApi('settings', 'core')->getSetting('sitestoreproduct.openclose', 0)) {
            if (!empty($product->draft) || !empty($product->closed) || empty($product->search) || empty($product->approved) || $product->start_date > date('Y-m-d H:i:s') || ($product->end_date < date('Y-m-d H:i:s') && !empty($product->end_date_enable))) {
                $error = $this->translate("This product is currently not available for purchase.");
            }
        } else {
            if (!empty($product->draft) || empty($product->search) || empty($product->approved) || $product->start_date > date('Y-m-d H:i:s') || ($product->end_date < date('Y-m-d H:i:s') && !empty($product->end_date_enable))) {
                $error = $this->translate("This product is currently not available for purchase.");
            }
        }

        $temp_allowed_selling = Engine_Api::_()->sitestoreproduct()->getIsAllowedSellingProducts($product->store_id);
        if (empty($temp_allowed_selling) || empty($product->allow_purchase)) {
            $error = $this->translate("This product is currently not available for purchase.");
        }

        return $error;
    }

    public function getcombinationAction() {
        $viewer = Engine_Api::_()->user()->getViewer();
        $viewer_id = $viewer->getIdentity();
        $values = $this->_getAllParams();
        $product_id = $values['product_id'];
        if (!$product_id)
            $this->respondWithValidationError("parameter_missing", "product_id missing");

        $product = Engine_Api::_()->getItem("sitestoreproduct_product", $product_id);

        if (!$product)
            $this->respondWithError("no_record");

        $productsTable = Engine_Api::_()->getDbTable("products", "sitestoreproduct");
        $db = $productsTable->getAdapter();

        $attributeIdsString = "";

        foreach ($values as $key => $value) {
            $keyArray = explode("_", $key);
            if ($keyArray[0] == 'select') {
                $sql = "select attribute_id from engine4_sitestoreproduct_combination_attributes where field_id='" . $keyArray[1] . "' and combination_attribute_id='" . $value . "'";

                $result = $db->query($sql)->fetch();

                $attributeIdsString .= "'" . $result['attribute_id'] . "',";
            }
        }

        $attributeIdsString = trim($attributeIdsString, ",");

        $sql = "select * from engine4_sitestoreproduct_combination_attributes_map 
                group by combination_id
                having attribute_id in ($attributeIdsString)";

        $result = $db->query($sql)->fetch();

        $response = array();

        if (!$result['combination_id'])
            $this->respondWithError('no_record');

        $response['combination_id'] = $result['combination_id'];
        $combinationPrice = Engine_Api::_()->getApi("Siteapi_Core", 'sitestore')->getcombinationPrice($response['combination_id'], $product_id);

        $isVatAllow = Engine_Api::_()->getApi('settings', 'core')->getSetting('sitestoreproduct.vat', 0);

        if (!empty($isVatAllow)) {
            $productPricesArray = Engine_Api::_()->sitestoreproduct()->getPriceOfProductsAfterVAT($product);
            $productDiscountedPrice = number_format($productPricesArray['product_price_after_discount'], 2);
        } else {
            $productDiscountedPrice = $productsTable->getProductDiscountedPrice($product->product_id);
        }

        $response['price'] = $productDiscountedPrice + $combinationPrice;

        $this->respondWithSuccess($response, true);
    }

    //ACTION TO SET OVERVIEW
    public function overviewAction() {

        //ONLY LOGGED IN USER CAN ADD OVERVIEW
        if (!$this->_helper->requireUser()->isValid())
            $this->respondWithError('unauthorized');

        //GET VIEWER
        $viewer = Engine_Api::_()->user()->getViewer();

        //GET PRODUCT ID AND OBJECT
        $product_id = $this->_getParam('product_id');
        $sitestoreproduct = Engine_Api::_()->getItem('sitestoreproduct_product', $product_id);
        $sitestore = Engine_Api::_()->getItem('sitestore_store', $sitestoreproduct->store_id);

        if (!(Engine_Api::_()->getApi('settings', 'core')->getSetting('sitestoreproduct.overview', 1))) {
            $this->respondWithError('unauthorized');
        }

        if (!$sitestoreproduct->authorization()->isAllowed($viewer, 'edit')) {
            $this->respondWithError('unauthorized');
        }

        if (!Engine_Api::_()->authorization()->getPermission($viewer->level_id, 'sitestoreproduct_product', "overview")) {
            $this->respondWithError('unauthorized');
        }
        $settings = Engine_Api::_()->getApi('settings', 'core');
        $defaultLanguage = $settings->getSetting('core.locale.locale', 'en');

        //MULTI LANGUAGE IS ALLOWED OR NOT
        $multiLanguage = $settings->getSetting('sitestoreproduct.multilanguage', 0);

        //DEFAULT LANGUAGE
        $defaultLanguage = $settings->getSetting('core.locale.locale', 'en');

        //MULTI LANGUAGE WORK
        $languageCount = 0;
        $languageData = array();
        $formValues = array();
        $overview_link = 'overview';
        $product_id = $sitestoreproduct->getIdentity();
        $tableOtherinfo = Engine_Api::_()->getDbTable('otherinfo', 'sitestoreproduct');

        if ($this->getRequest()->isGet()) {
            $formValues['form'] = Engine_Api::_()->getApi('Siteapi_Core', 'sitestoreproduct')->getOverviewForm();
            $formValues['formValues']['overview'] = $tableOtherinfo->getColumnValue($product_id, 'overview');
            $this->respondWithSuccess($formValues);
        }
        if ($multiLanguage) {
            //GET LANGUAGE ARRAY
            $localeMultiOptions = Engine_Api::_()->sitestoreproduct()->getLanguageArray();
            $languages = $settings->getSetting('sitestoreproduct.languages');
            $languageCount = Count($languages);
            $languageData = array();
            if (is_array($languages)) {
                foreach ($languages as $label) {
                    $languageData[] = $label;
                    if ($languageCount >= 2 && $defaultLanguage == $label && $label != 'en') {
                        $overview_link = $add_show_hide_overview_link = "overview_$label";
                    }
                }
            }
        }


        // SETTINGS FOR MULTILANGUAL WORK
        $temp_languages = $settings->getSetting('sitestoreproduct.languages');
        $languageCount = Count($temp_languages);

        //SAVE THE VALUE
        if ($this->getRequest()->isPost()) {
            $tableOtherinfo->update(array('overview' => $_POST['overview']), array('product_id = ?' => $product_id));

            // MULTI LANGUAL WORK
            foreach ($temp_languages as $language_label) {
                if ($languageCount >= 2 && $language_label != 'en') {
                    $overview = "overview_" . $language_label;
                    $tableOtherinfo->update(array($overview => $_POST[$overview]), array('product_id = ?' => $product_id));
                }
            }
            $this->successResponseNoContent('no_content', true);
        }
    }

    public function showMarkerInDate() {
        $localeObject = Zend_Registry::get('Locale');
        $dateLocaleString = $localeObject->getTranslation('long', 'Date', $localeObject);
        $dateLocaleString = preg_replace('~\'[^\']+\'~', '', $dateLocaleString);
        $dateLocaleString = strtolower($dateLocaleString);
        $dateLocaleString = preg_replace('/[^ymd]/i', '', $dateLocaleString);
        $dateLocaleString = preg_replace(array('/y+/i', '/m+/i', '/d+/i'), array('y', 'm', 'd'), $dateLocaleString);
        $dateFormat = $dateLocaleString;
        return $dateFormat == "mdy" ? 1 : 0;
    }

}
