<?php

class Sitestories_Model_DbTable_Stories extends Engine_Db_Table {

    protected $_name = 'sitestories_stories';
    protected $_rowClass = 'Sitestories_Model_Story';

    public function getStoryPaginator($subject = array()) {
        return Zend_Paginator::factory($this->getStorySelect($subject));
    }

    public function getStorySelect($subject) {
        $muteIds = Engine_Api::_()->getDbtable('muteusers', 'sitestories')->getMuteUserIds();
        $storyTableName = $this->info('name');
        $select = $subject->membership()->getMembersOfSelect();
        $friends = $paginator = Zend_Paginator::factory($select);
        $paginator->setItemCountPerPage(1000);
        $paginator->setCurrentPageNumber(1);

        $days = Engine_Api::_()->getApi('settings', 'core')->getSetting('sitestories_max_allowed_days', 1);
        
        $ids = array();
        foreach ($friends as $friend) {
            $ids[] = $friend->resource_id;
        }
        if (count($ids) > 0) {
            $storyids = $this->getfriendStoryids($ids, $subject);

            $select = $this->select()
                    ->where('story_id IN(?)', $storyids)
                    ->where('enable = ?', 1)
                    ->where('expiry_date >= now()')
                    ->where('create_date >= now() - INTERVAL '.$days.' DAY')
                    ->group("owner_id")
                    ->where("owner_id NOT IN ($muteIds)")
                    ->order("create_date DESC");
            return $select;
        } else {
            $select = $this->select()
                    ->where('enable = ?', 1)  
                    ->where('expiry_date >= now()')
                    ->where('create_date >= now() - INTERVAL '.$days.' DAY')
                    ->where("owner_id=?", $subject->getIdentity())
                    ->order("create_date DESC")
                    ->where("owner_id NOT IN ($muteIds)")
                    ->limit(1);
            return $select;
        }
    }

    public function getUserStory($user_id, $isSendMessage = 0) {
        if (empty($user_id))
            return;
        $muteIds = array();
        $muteIds = Engine_Api::_()->getDbtable('muteusers', 'sitestories')->getMuteUserIds();
        $days = Engine_Api::_()->getApi('settings', 'core')->getSetting('sitestories_max_allowed_days', 1);

        if (!empty($isSendMessage)) {
            $select = $this->select()
                    ->where('enable = ?', 1)
                    ->where('owner_id =?', $user_id)
                    ->where('expiry_date >= now()')
                    ->where('create_date >= now() - INTERVAL '.$days.' DAY')
                    ->order("create_date ASC");
        } else {
            $select = $this->select()
                    ->where('enable = ?', 1)
                    ->where('owner_id =?', $user_id)
                    ->where('expiry_date >= now()')
                    ->where('create_date >= now() - INTERVAL '.$days.' DAY')
                    ->where('privacy = ?', 'everyone')
                    ->order("create_date ASC");
        }

        return Zend_Paginator::factory($select);
    }

    public function getyourStory($user_id) {
        $viewer = Engine_Api::_()->user()->getViewer();
        if (empty($user_id))
            return;
        $muteIds = Engine_Api::_()->getDbtable('muteusers', 'sitestories')->getMuteUserIds();
        $days = Engine_Api::_()->getApi('settings', 'core')->getSetting('sitestories_max_allowed_days', 1);

        $select = $this->select()
                ->where('enable = ?', 1)
                ->where('owner_id =?', $user_id)
                ->where('expiry_date >= now()')
                ->where('create_date >= now() - INTERVAL '.$days.' DAY')
                ->where("owner_id NOT IN ($muteIds)")
                ->order("story_id DESC");
        
        return Zend_Paginator::factory($select);
    }

    public function getTotalStoryCount($user_id) {
        if (empty($user_id))
            return 0;
        $muteIds = Engine_Api::_()->getDbtable('muteusers', 'sitestories')->getMuteUserIds();
        $days = Engine_Api::_()->getApi('settings', 'core')->getSetting('sitestories_max_allowed_days', 1);
        $select = $this->select()
                ->where('enable = ?', 1)
                ->where('owner_id =?', $user_id)
                ->where('expiry_date >= now()')
                ->where('create_date >= now() - INTERVAL '.$days.' DAY')
                ->order("create_date DESC")
                ->where("owner_id NOT IN ($muteIds)");
        $result = $this->fetchAll($select);
        return count($result);
    }

    public function getEveryoneStory($subject) {
        if (empty($subject))
            return;
        $muteIds = Engine_Api::_()->getDbtable('muteusers', 'sitestories')->getMuteUserIds();
        $days = Engine_Api::_()->getApi('settings', 'core')->getSetting('sitestories_max_allowed_days', 1);
        $storyTableName = $this->info('name');
        $select = $subject->membership()->getMembersOfSelect();
        $friends = $paginator = Zend_Paginator::factory($select);
        $paginator->setItemCountPerPage(1000);
        $paginator->setCurrentPageNumber(1);
       
        
        $ids = array();
        
        foreach ($friends as $friend) {
            $ids[] = $friend->resource_id;
        }
        if (count($ids) > 0) {
            $storyids = $this->getEveryoneStoryids($ids, $subject);
            $select1 = $this->select()
                    ->where('enable = ?', 1)
                    ->where('story_id IN(?)', $storyids)
                    ->where('expiry_date >= now()')
                    ->where('create_date >= now() - INTERVAL '.$days.' DAY')
                    ->where('privacy = ?', 'everyone')
                    ->where("owner_id NOT IN ($muteIds)")
                    ->order("create_date DESC");
        } else {
            $storyids = $this->getEveryoneStoryids($ids, $subject);
            $select1 = $this->select()
                    ->where('enable = ?', 1)
                    ->where('story_id IN(?)', $storyids)
                    ->where('expiry_date >= now()')
                    ->where('create_date >= now() - INTERVAL '.$days.' DAY')
                    ->where('privacy = ?', 'everyone')
                    ->where("owner_id NOT IN ($muteIds)")
                    ->order("create_date DESC");
        }
        return Zend_Paginator::factory($select1);
    }

    public function getEveryoneStoryids($ids = array(), $subject = array()) {

        $muteIds = Engine_Api::_()->getDbtable('muteusers', 'sitestories')->getMuteUserIds();
        $days = Engine_Api::_()->getApi('settings', 'core')->getSetting('sitestories_max_allowed_days', 1);

        $table = Engine_Api::_()->getDbtable('stories', 'sitestories');
        if (count($ids) > 0) {
            $result = $table->select()
                            ->from($table->info('name'), array('story_id', 'owner_id'))
                            ->where('owner_id NOT IN(?)', $ids)
                            ->where('enable = ?', 1)
                            ->where('expiry_date >= now()')
                            ->where('create_date >= now() - INTERVAL '.$days.' DAY')
                            ->where('privacy = ?', 'everyone')
                            ->where("owner_id NOT IN ($muteIds)")
                            ->order("create_date DESC")
                            ->query()->fetchAll();
        } else {
            $result = $this->select()
                            ->from($table->info('name'), array('story_id', 'owner_id'))
                            ->where('owner_id !=?', $subject->getIdentity())
                            ->where('enable = ?', 1)
                            ->where('expiry_date >= now()')
                            ->where('create_date >= now() - INTERVAL '.$days.' DAY')
                            ->where('privacy = ?', 'everyone')
                            ->where("owner_id NOT IN ($muteIds)")
                            ->order("create_date DESC")
                            ->query()->fetchAll();
        }
        $ownerids = array();
        $storyids = array();
        $storyids[] = 0;
        foreach ($result as $value) {
            if (!in_array($value['owner_id'], $ownerids)) {
                $storyids[] = $value['story_id'];
                $ownerids[] = $value['owner_id'];
            }
        }
        return $storyids;
    }

    public function getfriendStoryids($ids = array(), $subject = array()) {

        $muteIds = Engine_Api::_()->getDbtable('muteusers', 'sitestories')->getMuteUserIds();
        $days = Engine_Api::_()->getApi('settings', 'core')->getSetting('sitestories_max_allowed_days', 1);
        $table = Engine_Api::_()->getDbtable('stories', 'sitestories');
        if (count($ids) > 0) {
            $result = $table->select()
                            ->from($table->info('name'), array('story_id', 'owner_id'))
                            ->where('owner_id IN(?)', $ids)
                            ->where('enable = ?', 1)
                            ->where('expiry_date >= now()')
                            ->where('create_date >= now() - INTERVAL '.$days.' DAY')
                            ->where("owner_id NOT IN ($muteIds)")
                            ->order("create_date DESC")
                            ->query()->fetchAll();
        } else {
            $result = $this->select()
                            ->from($table->info('name'), array('story_id', 'owner_id'))
                            ->where('owner_id =?', $subject->getIdentity())
                            ->where('enable = ?', 1)
                            ->where('expiry_date >= now()')
                            ->where('create_date >= now() - INTERVAL '.$days.' DAY')
                            ->where("owner_id NOT IN ($muteIds)")
                            ->order("create_date DESC")
                            ->query()->fetchAll();
        }
        $ownerids = array();
        $storyids = array();
        $storyids[] = 0;
        foreach ($result as $value) {
            if (!in_array($value['owner_id'], $ownerids)) {
                $storyids[] = $value['story_id'];
                $ownerids[] = $value['owner_id'];
            }
        }
        return $storyids;
    }
}

?>
