<?php

class Sitestoriesweb_Model_DbTable_Stories extends Engine_Db_Table {

    protected $_name = 'sitestories_stories';
    protected $_rowClass = 'Sitestoriesweb_Model_Story';
    
    public function getUserStory($user_id, $isSendMessage = 0) {
        if (empty($user_id))
            return;
        $user = Engine_Api::_()->user()->getUser($user_id);
        $muteIds = Engine_Api::_()->getDbtable('muteusers', 'sitestoriesweb')->getMuteUserIds();
        $days = Engine_Api::_()->getApi('settings', 'core')->getSetting('sitestories_max_allowed_days', 1);
        
        $select = $this->select()
            ->where('enable = ?', 1)
            ->where('owner_id =?', $user_id)
            ->where('expiry_date >= now()')
            ->where('create_date >= now() - INTERVAL '.$days.' DAY')
            ->order("create_date ASC");
        return $this->fetchAll($select);
    }

    public function getyourStory($user_id,$paginator = 1,$limit = 0) {
        if (empty($user_id))
            return;
        $muteIds = Engine_Api::_()->getDbtable('muteusers', 'sitestoriesweb')->getMuteUserIds();
        $currentDate = date('Y-m-d H:i:s');
        $days = Engine_Api::_()->getApi('settings', 'core')->getSetting('sitestories_max_allowed_days', 1);
        
        $select = $this->select()
            ->where('enable = ?', 1)
            ->where('owner_id =?', $user_id)
            ->where('expiry_date >= now()')
            ->where('create_date >= now() - INTERVAL '.$days.' DAY')
            ->where("owner_id NOT IN ($muteIds)")
        ;
        if($limit){
            $select->limit(1);
        }else{
            $select->order("create_date DESC");
        }
        
        if($paginator)
            return Zend_Paginator::factory($select);
        
        return $this->fetchAll($select);
    }

    public function getTotalStoryCount($user_id) {
        if (empty($user_id))
            return 0;
        $muteIds = Engine_Api::_()->getDbtable('muteusers', 'sitestoriesweb')->getMuteUserIds();
        $currentDate = date('Y-m-d H:i:s');
        $days = Engine_Api::_()->getApi('settings', 'core')->getSetting('sitestories_max_allowed_days', 1);
        
        $select = $this->select()
            ->where('enable = ?', 1)
            ->where('owner_id =?', $user_id)
            ->where('expiry_date >= now()')
            ->where('create_date >= now() - INTERVAL '.$days.' DAY')
            ->order("create_date DESC")
            ->where("owner_id NOT IN ($muteIds)");
        $result = $this->fetchAll($select);
        return count($result);
    }

    


    public function getUsers($title, $customUsers,$limit = 10){
        //MAKE QUERY
        $viewer = Engine_Api::_()->user()->getViewer();
        $table = Engine_Api::_()->getDbtable('users', 'user');
        $select = Engine_Api::_()->user()->getViewer()->membership()->getMembersObjectSelect();
        
        $blockedUserIds = !$viewer->isAdmin() ? $viewer->getAllBlockedUserIds() : array();
        if( $blockedUserIds ) {
            $select->where('user_id NOT IN(?)', (array) $blockedUserIds);
        }
        if( 0 < ($limit = (int) $limit) ) {
            $select->limit($limit);
        }

        if( null !== $title ) {
            $select->where('`'.$table->info('name').'`.`displayname` LIKE ?', '%'. $title .'%');
        }
                
        if(!empty($customUsers))
            $select->where('`'.$table->info('name').'`.`user_id` NOT IN ('.$customUsers.')');

        //FETCH RESULTS
        return $table->fetchAll($select);
    }


    public function getUserStoryList($user_id){
        $days = Engine_Api::_()->getApi('settings', 'core')->getSetting('sitestories_max_allowed_days', 1);
        $select = $this->select()
        ->from($this,'story_id')
        ->where('enable = ?', 1)
        ->where('owner_id =?', $user_id)
        // ->where('create_date >= ?', $pastDate)
        ->where('expiry_date >= now()')
        ->where('create_date >= now() - INTERVAL '.$days.' DAY')
        ->order("create_date ASC");
        return $this->fetchAll($select);
    }

    public function storiesForUser($user,$customFields = 0){
        if(empty($user->getIdentity()))
            return;
        $days = Engine_Api::_()->getApi('settings', 'core')->getSetting('sitestories_max_allowed_days', 1);
        $muteIds = Engine_Api::_()->getDbtable('muteusers', 'sitestoriesweb')->getMuteUserIds();
        $selectStories = $this->select();
        if($customFields)
            $selectStories->from($this->info('name'), array('owner_id','privacy','max(create_date) AS maxCreateDate'));
        $selectStories
        ->where('owner_id <> ?',$user->getIdentity())
        ->where('expiry_date >= now()')
        ->where('create_date >= now() - INTERVAL '.$days.' DAY')
        ->where('enable = ?',1)
        ->where("owner_id NOT IN ($muteIds)")
        ->group('owner_id')
        ->order('max(create_date) DESC')
        ;
        return $this->fetchAll($selectStories); 
        
    }

}

?>
