<?php

/**
 * SocialEngine
 *
 * @category   Application_Extensions
 * @package    Sitesubscription
 * @copyright  Copyright 2012-2013 BigStep Technologies Pvt. Ltd.
 * @license    http://www.socialengineaddons.com/license/
 * @version    $Id: Core.php 6590 2017-03-07 00:00:00Z SocialEngineAddOns $
 * @author     SocialEngineAddOns
 */

class Sitesubscription_Api_Core extends Core_Api_Abstract
{

  public function translateDuration($value)
  {
    if ($value == 'year')
      return "Yearly";
    elseif ($value == 'month')
      return "Monthly";
    elseif ($value == 'forever') 
      return "One-time";
    elseif ($value == 'day') 
      return "Daily";
    elseif ($value == 'week') 
      return "Weekly";
    else
      return "-";
  }

  public function getReccurenceDuration($package_id)
  {
    $package = Engine_Api::_()->getDbtable('packages','sitesubscription')->getSubscriptionPackage($package_id);
    
    if ( (float) $package->price == 0.00 || $package->recurrence == '0') 
      return '';
    else if ($package->recurrence == '1' || $package->recurrence == '0' || $package->recurrence_type == 'forever') 
      return strtolower($this->translateDuration($package->recurrence_type));
    else
      return "per ".$package->recurrence.' '.$package->recurrence_type;
  }

  public function sendMails($user = null, $email_template = null , $time = null ) {
    $site_title = $_SERVER['HTTP_HOST'];

    if ( empty($user) || empty($email_template) ) {
      return;
    }
    
    Engine_Api::_()->getApi('mail', 'core')->sendSystem($user, $email_template, array(
            'time' => $time,
            'site_title' => $site_title,
            'queue' => true ));
  }

  public function getCurrencySymbol() {
    $localeObject = Zend_Registry::get('Locale');
    $currencyCode = Engine_Api::_()->getApi('settings', 'core')->getSetting('payment.currency', 'USD');
    $currencySymbol = Zend_Locale_Data::getContent($localeObject, 'currencysymbol', $currencyCode);

    if(Engine_Api::_()->hasModuleBootstrap('sitemulticurrency') && Engine_Api::_()->getDbtable('modules', 'core')->isModuleEnabled('sitemulticurrency') && Engine_Api::_()->getDbtable('modules', 'sitemulticurrency')->isModuleEnable('sitesubscription')) { 
        //PASS 1 AS ARGUMENT TO GET CURRENCY SYMBOL
        $currencySymbol = Engine_Api::_()->sitemulticurrency()->getSelectedCurrency(1);  
    }
    return $currencySymbol;
  }

  public function getTemplateData($param = null) {
    // Get packages and ordering
    $temp = Engine_Api::_()->getDbtable('packages','sitesubscription')->getSubscriptionPackages();
    foreach ($temp as $key => $value) 
      $packages[$value['package_id']] = $value;

    // Get the package order 
    $packageOrder = array();
    $packageOrder = Engine_Api::_()->getDbtable('packageorder','sitesubscription')->getPackageOrder();
    asort($packageOrder);
    $maxorder = max($packageOrder);

    // Remove package order packages that do not exist
    foreach ($packageOrder as $key => $value)
      if (!array_key_exists($key, $packages)) 
        unset($packageOrder[$key]);

    // Enter package ids not in order table 
    if (count($packages) != count($packageOrder))
      foreach ($packages as $key => $value)
        if (!array_key_exists($key, $packageOrder)) 
            $packageOrder[$key] = (string) ++$maxorder;

    // Get activated template ad its structure type
    $activeTemplate = ($param == null) ? Engine_Api::_()->getDbTable('templates','sitesubscription')->getActivatedTemplate() : Engine_Api::_()->getDbTable('templates','sitesubscription')->getTemplate($param);
    $layout_id = $activeTemplate['layout'] ;
    $structureType = Engine_Api::_()->getDbTable('layouts','sitesubscription')->getLayoutStructureType($layout_id);
    $templateStyle = json_decode($activeTemplate['template_values'],true);
    $best_choice = Engine_Api::_()->getApi('settings', 'core')->getSetting('sitesubscription.popularplan', '0');

    // Get if feature is enabled 
    $structureTypeSettings = json_decode(Engine_Api::_()->getApi('settings', 'core')->getSetting('sitesubscription.structuretype.'.$structureType,null),true);
    $isFeatureEnabled = $structureTypeSettings['features'];

    $featuresRowData = Engine_Api::_()->getDbTable('fields','sitesubscription')->getFields($structureType);
    foreach ($featuresRowData as $value) {
      $features[$value['feature_order']]['field_id'] = $value['field_id'];
      $features[$value['feature_order']]['label'] = $value['feature_label'];
    }
    ksort($features);

    foreach ($featuresRowData as $feature) {
      $valueRowData = Engine_Api::_()->getDbTable('values','sitesubscription')->getFieldValues($feature['field_id']);
      if (!empty($valueRowData)) 
        foreach ($valueRowData as $value) {
          $fieldValues[$feature['field_id']][$value['package_id']] = $value['value'];
        }
      else
        $fieldValues[$feature['field_id']] = [];
    }

    $return_arr = array(
      'packages' => $packages,
      'packageOrder' => $packageOrder,
      'isFeatureEnabled' => $isFeatureEnabled,
      'activeTemplate' => $activeTemplate,
      'layout_id' => $layout_id,
      'structureType' => $structureType,
      'best_choice' => $best_choice,
      'templateStyle' => $templateStyle,
      'featuresRowData' => $featuresRowData,
      'features' => $features,
      'valueRowData' => $valueRowData,
      'fieldValues' => $fieldValues,
      );

    return $return_arr;
  }

  function toJsonReadableFormat($string = null) {
    if (empty($string)) 
      return;

    $string = str_replace("'", "&#39;", $string);
    $string = str_replace('"', "&#34;", $string);

    return $string;
  }

  //Function to return Currency Conversion rate
  public function getPriceWithCurrency($price, $priceOnly = 0, $search = 0) {    
  
      if (empty($price)) {
          return $price;
      } 
      if(Engine_Api::_()->hasModuleBootstrap('sitemulticurrency') && Engine_Api::_()->getDbtable('modules', 'core')->isModuleEnabled('sitemulticurrency') && Engine_Api::_()->getDbtable('modules', 'sitemulticurrency')->isModuleEnable('sitesubscription')) {   
  
          $priceStr = Engine_Api::_()->sitemulticurrency()->convertCurrencyRate($price, $priceOnly, $search);  
      } else {  
          $defaultParams = array();
          $defaultParams['locale'] = Zend_Registry::get('Locale');
          $viewer_id = Engine_Api::_()->user()->getViewer()->getIdentity();
          if (empty($viewer_id)) {
              $defaultParams['locale'] = Engine_Api::_()->getApi('settings', 'core')->getSetting('core.locale.locale', 'auto');
          } 
          $currency = Engine_Api::_()->getApi('settings', 'core')->getSetting('payment.currency', 'USD');
          $defaultParams['precision'] = 2;
          $price = (float) $price;
          if(!empty($priceOnly))
          return $price;
          $priceStr = Zend_Registry::get('Zend_View')->locale()->toCurrency($price, $currency, $defaultParams); 
      }
    
      return $priceStr;
  }

}