<?php 
/**
 * SocialEngine
 *
 * @category   Application_Extensions
 * @package    Sitesubscription
 * @copyright  Copyright 2012-2013 BigStep Technologies Pvt. Ltd.
 * @license    http://www.socialengineaddons.com/license/
 * @version    $Id: Subscription.php 6590 2017-03-07 00:00:00Z SocialEngineAddOns $
 * @author     SocialEngineAddOns
 */

class Sitesubscription_Form_Signup_Subscription extends Engine_Form
{
  protected $_isSignup = true;
  
  protected $_packages;
  
  public function setIsSignup($flag)
  {
    $this->_isSignup = (bool) $flag;
  }

  public function getUserProfileMap($user_id = null)
  {
    if ($user_id == null) 
      return;

    $topStructure = Engine_Api::_()->fields()->getFieldStructureTop('user');
    if( count($topStructure) ==  1 && $topStructure[0]->getChild()->type ==  'profile_type' ) {
      $profileTypeField = $topStructure[0]->getChild();
    }

    $db = Engine_Db_Table::getDefaultAdapter();
    $map = $db->select()
              ->from('engine4_user_fields_values')
              ->where('field_id = ?',$profileTypeField->field_id)
              ->where('item_id = ?',$user_id)
              ->query()
              ->fetchAll(); 

    if (empty($map)) 
      return '0';

    else
      return (int) $map[0]['value'];
  }
  
  public function init()
  {
    $this
      ->setTitle('')
      ->setDescription('')
      ;

    // Get available subscriptions
    $packagesTable = Engine_Api::_()->getDbtable('packages', 'payment');
    $tableName  = $packagesTable->info('name');
    
    // Get the package order 
    $packageOrder = array();
    $packageOrderTable = Engine_Api::_()->getDbtable('packageorder','sitesubscription');
    $packageOrderTableName = $packageOrderTable->info('name');
    $packageOrder = $packageOrderTable->select()->query()->fetchAll();

    $db = Zend_Db_Table::getDefaultAdapter();
    $select = $db->select();
    $select->from($tableName);

    if (!empty($packageOrder)) {
      $select->joinLeft($packageOrderTableName,"`$tableName`.package_id = `$packageOrderTableName`.package_id",array("$packageOrderTableName.order" ));
      $select->order("$packageOrderTableName.order ASC");
    }
      $select->where('enabled = ?', true);
    if( $this->_isSignup ) {
      $this->setAction(Zend_Controller_Front::getInstance()->getRouter()->assemble(array(), 'user_signup', true));
      $select->where('signup = ?', true);
    }
    else{
      $select->where('after_signup = ?', true);
    }
    $dummySelect = $select->query()->fetchAll();

    $this->_packages = array(); 

    foreach ($dummySelect as $dummyPackage) {
      $this->_packages[$dummyPackage['package_id']] = $packagesTable->find($dummyPackage['package_id'])->current();
    }
    
    // Remove the package from package list for upgrading packages
    $request = Zend_Controller_Front::getInstance()->getRequest();
    $action = $request->getActionName();
    $controller = $request->getControllerName();
    $profileMapAllowed = Engine_Api::_()->getApi('settings', 'core')->getSetting('sitesubscription.profile.mapping', '0');

    // Set package count while upgrading subscription
    if ($action == "upgrade-subscription") 
    {
      $viewer = Engine_Api::_()->user()->getViewer();
      $userMappedProfile = $this->getUserProfileMap($viewer->getIdentity());
      // $viewer_subscription = Engine_Api::_()->getDbtable('subscriptions','sitesubscription')->getUserSubscription($viewer->getIdentity());
      // $userMappedProfile = Engine_Api::_()->getDbtable('profiletypemapping','sitesubscription')->getProfileMap($viewer_subscription);

      foreach ($this->_packages as $key=>$value) {
        $subscriptionMappedProfile = Engine_Api::_()->getDbtable('profiletypemapping','sitesubscription')->getProfileMap($value['package_id']);

        // if ($key == $viewer_subscription) {
        //   unset($this->_packages[$key]);
        // }
        
        if ($profileMapAllowed == '1' && !empty($userMappedProfile) && !empty($subscriptionMappedProfile) && $userMappedProfile != $subscriptionMappedProfile) {
          unset($this->_packages[$key]);
        }

      }
    }
    // Set package count while logging in
    if ($action == "choose" || $action == "check-subscription") 
    {
      $user_session = new Zend_Session_Namespace('Payment_Subscription');
      $userMappedProfile = $this->getUserProfileMap($user_session->user_id);

      foreach ($this->_packages as $key=>$value) {
        $subscriptionMappedProfile = Engine_Api::_()->getDbtable('profiletypemapping','sitesubscription')->getProfileMap($value['package_id']);

        if ($profileMapAllowed == '1' && $userMappedProfile != $subscriptionMappedProfile && !empty($subscriptionMappedProfile)) {
          unset($this->_packages[$key]);
        }

      }
    }
    // Set package count while signup
    if ($action == 'index' && $controller == 'signup') {
      $accountSession = new Zend_Session_Namespace('User_Plugin_Signup_Account');
      $profileTypeValue = @$accountSession->data['profile_type'];

      if ($profileTypeValue) 
      {
        foreach ($this->_packages as $key=>$value) {
          $subscriptionMappedProfile = Engine_Api::_()->getDbtable('profiletypemapping','sitesubscription')->getProfileMap($value['package_id']);

          if ($profileMapAllowed == '1' && $profileTypeValue != $subscriptionMappedProfile && !empty($subscriptionMappedProfile)) {
            unset($this->_packages[$key]);
          }
        }
      }
    }

    $this->_packages = (object) $this->_packages;

    // Insert Form elements
    foreach( $this->_packages as $package ) {
      $multiOptions[$package->package_id] = $package->title
        . ' (' . $package->getPackageDescription() . ')'
        ;
    }
    // Element: package_id
    if( count($multiOptions) >= 1 ) {
      $this->addElement('Select', 'package_id', array(
        'label' => 'Choose Plan:',
        'required' => true,
        'allowEmpty' => false,
        'multiOptions' => $multiOptions,
      ));
    }
    // Init submit
    $this->addElement('Button', 'submit', array(
      'label' => 'Continue',
      'type' => 'submit',
      'ignore' => true,
    ));
  }
  
  public function getPackages()
  {
    return $this->_packages;
  }
  
  public function setPackages($packages)
  {
    $this->_packages = $packages;
  }
}