<?php
/**
 * SocialEngine
 *
 * @category   Application_Extensions
 * @package    Sitesubscription
 * @copyright  Copyright 2012-2013 BigStep Technologies Pvt. Ltd.
 * @license    http://www.socialengineaddons.com/license/
 * @version    $Id: AdminMappingController.php 6590 2017-03-07 00:00:00Z SocialEngineAddOns $
 * @author     SocialEngineAddOns
 */

class Sitesubscription_AdminMappingController extends Core_Controller_Action_Admin
{
    // Action for admin-side content module-subscription mapping action. 
    public function moduleAction()
    {
        
        include_once APPLICATION_PATH .'/application/modules/Sitesubscription/controllers/license/license2.php';
        if(empty($sitesubscription_mapping_module) || empty($mapping_module)){
            
            $this->_helper->content->setNoRender();
            return;
        }

        $this->view->navigation = $navigation = Engine_Api::_()->getApi('menus', 'core')
                ->getNavigation('sitesubscription_admin_main', array(), 'sitesubscription_admin_module_mapping');

        $this->view->packages = $packages = Engine_Api::_()->getDbtable('packages','sitesubscription')->getSubscriptionPackages();

        $modules = array();

        // Get enabled modules
        $enabledModules = Engine_Api::_()->getDbTable('modules','core')->getModulesAssoc();
        foreach ($enabledModules as $name => $enabledModule) {
            $modules[$name]['title'] = $enabledModule->title;
        }
        // Insert package setting route in array 
        $data = $this->getRoute('package');
        foreach ($data as $moduleData) {
            $modules[$moduleData['module']]['title'] = Engine_Api::_()->getDbTable('modules','core')->getModule($moduleData['module'])->title;
            $modules[$moduleData['module']]['package_setting_route'] = $moduleData['params'];
            $modules[$moduleData['module']]['level_setting_route'] = '0';
        }

        // Insert level setting route in array
        $route_data = $this->getRoute('level');
        foreach ($route_data as $moduleData) {
            if (array_key_exists($moduleData['module'], $modules)) {
                $modules[$moduleData['module']]['level_setting_route'] = $moduleData['params'];
            }
        }

      foreach ($modules as $key => $value) {
        if ( ($modules[$key]['level_setting_route'] == null && $modules[$key]['package_setting_route'] == null) || $key == 'core') 
          unset($modules[$key]);
      }

      $this->view->modules = $modules;
    }

    // Action for admin-side profile type-subscription mapping action. 
    public function profileTypeAction()
    {
      
      include_once APPLICATION_PATH .'/application/modules/Sitesubscription/controllers/license/license2.php';
      if(empty($sitesubscription_profile_type) || empty($profile_type)){
          
          $this->_helper->content->setNoRender();
          return;
      }
      
      $this->view->navigation = $navigation = Engine_Api::_()->getApi('menus', 'core')->getNavigation('sitesubscription_admin_main', array(), 'sitesubscription_admin_profile_mapping');
      $this->view->packages = $packages = Engine_Api::_()->getDbtable('packages','sitesubscription')->getSubscriptionPackages();
      
      $topStructure = Engine_Api::_()->fields()->getFieldStructureTop('user');

      if( count($topStructure) ==  1 && $topStructure[0]->getChild()->type ==  'profile_type' ) {
        $profileTypeField = $topStructure[0]->getChild();
        $options = $profileTypeField->getOptions();
      }
      
      foreach ($options as $value) {
        $profileTypes[$value->option_id] = $value->label;
        // Get the profiletypes with required fields
        if ($this->checkProfileType($value->option_id) == true){
          $strictProfileTypes[] = $value->option_id;    
        }
      }

      // Get signup step order 
      $stepTable = Engine_Api::_()->getDbtable('signup', 'user');
      $step = $stepTable->select()
          ->order('order')
          ->limit(1)
          ->query()
          ->fetch();

      $step = explode("_", $step['class']);
      $class = $step[count($step)-1];

      if($class != 'Subscription')
          $formSequence = '0';
      else
          $formSequence = '1';

      if ( $this->getRequest()->isPost() ) {
        if ($this->_getParam('submit') !== null) {
          $values['package_id'] = (int) $this->_getParam('submit');
          $name = 'profile_type_'.$values['package_id'];
          $values['option_id'] = (int) $this->_getParam($name);
          Engine_Api::_()->getDbTable('profiletypemapping','sitesubscription')->setValues($values);
        }
      }

      $array = Engine_Api::_()->getDbTable('profiletypemapping','sitesubscription')->getMappedPackages();
      foreach ($array as $value) {
          $mappedPackages[$value['package_id']]['label'] = $profileTypes[$value['option_id']];
          $mappedPackages[$value['package_id']]['option_id'] = $value['option_id'];
      }

      $this->view->formSequence = $formSequence;
      $this->view->profileTypes = $profileTypes;
      $this->view->strictProfileTypes = $strictProfileTypes;
      $this->view->mappedPackages = $mappedPackages;
      $this->view->enableMapping = $enableMapping = Engine_Api::_()->getDbtable('settings', 'core')->getSetting('sitesubscription.profile.mapping','0');
    }

    // Action for confirmation on updating profile-type. Creates backup of user profile data. Nested in admin-side profile-type-subscription mapping page. Serves in a smoothbox.  
    public function updateProfileTypeAction() 
    {
      $this->view->package_id = $values['package_id'] = $this->_getParam('package_id');
      $this->view->option_id = $values['option_id'] = $this->_getParam('option_id');

      $db = Engine_Db_Table::getDefaultAdapter()->getConfig();
      $tables = array('engine4_user_fields_values', 'engine4_user_fields_maps', 'engine4_user_fields_options', 'engine4_user_fields_meta', 'engine4_user_fields_search');
      $this->view->permission = $this->backupTables($db['host'],$db['username'],$db['password'],$db['dbname'],$tables);
      

      // Get member totals for plan
      $this->view->memberCounts = Engine_Api::_()->getDbtable('subscriptions','sitesubscription')->getMembersCount($values['package_id']);
      
      $subscribers = Engine_Api::_()->getDbtable('subscriptions','sitesubscription')->getSubscribers($values['package_id']);
      $this->view->subscribers = json_encode($subscribers);

      if( is_null($this->getRequest()) ) {
        return;
      }
      if (!$this->getRequest()->isPost()) {
        return;
      }

      $this->_forward('success', 'utility', 'core', array(
                'smoothboxClose' => true,
                'parentRefresh' => true,
                'messages' => array(Zend_Registry::get('Zend_Translate')->_('Profile type updated successfuly.'))
            ));
    }

    // Action for updating new profile-type. Nested in admin-side profile-type-subscription mapping page. Called via ajax request.
    public function updateProfileMapAction() {
        if( is_null($this->getRequest()) ) {
          return;
        }
        if (!$this->getRequest()->isPost()) {
          return;
        }

        $values['package_id'] = $this->_getParam('package_id');
        $values['option_id'] = $this->_getParam('option_id');

        $status = Engine_Api::_()->getDbTable('profiletypemapping','sitesubscription')->updateValues($values);

        if ($status == true) 
            $response['status'] = "success";
        else 
            $response['status'] = "faliure";

        echo json_encode($response);

        exit(1);
    }

    // Action for updating user data to new profile type. Nested in admin-side profile-type-subscription mapping page. Called via ajax request.
    public function updateUserDataAction() {
        if( is_null($this->getRequest()) ) {
          return;
        }
        if (!$this->getRequest()->isPost()) {
          return;
        }

        $values['subscribers'] = json_decode($this->_getParam('subscribers'));
        $values['option_id'] = $this->_getParam('option_id');

        $status = Engine_Api::_()->getDbtable('profiletypemapping','sitesubscription')->updateProfileType($values);

        if ($status == '1') {
            echo "success";
        } else
            echo "failure";

        exit(1);
    }

    public function downloadBackupAction()
    {
      $filePath = realpath(APPLICATION_PATH . "/public/sitesubscription/backup.zip");
      @chmod($filePath, 0777);

      header("Cache-Control: no-cache, must-revalidate"); // HTTP/1.1
      header("Content-type: application/zip");
      
      echo file_get_contents($filePath);
      exit();
    }

    public function restrictMappingAction(){
      
    }

    public function getRoute($type = null)
    {
      $enabledModules = Engine_Api::_()->getDbTable('modules','core')->getEnabledModuleNames();
      $label = ($type === 'package') ?  '%Packages%' : 'Member Level Settings';
      $menuItems = Engine_Api::_()->getDbtable('menuItems','sitesubscription')->getMenuItems($label);

      if( !empty($enabledModules) ) 
        foreach ($menuItems as $key => $value) 
          if (!in_array($value['module'], $enabledModules))
            unset($menuItems[$key]);
        
      return $menuItems;
    }

    /* backup the db OR just a table */
    public function backupTables($host,$user,$pass,$name,$tables = '*')
    {
      
      $filepath = APPLICATION_PATH."/public/sitesubscription/";
      if(!is_writable($filepath)){
        mkdir($filepath);
      }

      $link = mysqli_connect($host,$user,$pass);
      mysqli_select_db($link, $name);
      
      //get all of the tables
      if($tables == '*')
      {
        $tables = array();
        $result = mysqli_query($link, 'SHOW TABLES');
        while($row = mysqli_fetch_row($result))
        {
          $tables[] = $row[0];
        }
      }
      else
      {
        $tables = is_array($tables) ? $tables : explode(',',$tables);
      }
    
      //cycle through
      foreach($tables as $table)
      {
        $result = mysqli_query($link, 'SELECT * FROM '.$table);
        $num_fields = mysqli_num_fields($result);
        
        $return = '';
        $return.= 'DROP TABLE '.$table.';';
        $row2 = mysqli_fetch_row(mysqli_query($link, 'SHOW CREATE TABLE '.$table));
        $return.= "\n\n".$row2[1].";\n\n";
        
        for ($i = 0; $i < $num_fields; $i++) 
        {
          while($row = mysqli_fetch_row($result))
          {
            $return.= 'INSERT INTO '.$table.' VALUES(';
            for($j=0; $j < $num_fields; $j++) 
            {
              $row[$j] = addslashes($row[$j]);
              $row[$j] = ereg_replace("\n","\\n",$row[$j]);
              if (isset($row[$j])) { $return.= '"'.$row[$j].'"' ; } else { $return.= '""'; }
              if ($j < ($num_fields-1)) { $return.= ','; }
            }
            $return.= ");\n";
          }
        }
        $return.="\n\n\n";
      }
      
      try {
        if (!is_writable($filepath)) 
          return false;

        //save file
        $handle = fopen($filepath.'backup.sql','w+');
        fwrite($handle,$return);
        fclose($handle);
        chmod($filepath.'backup.sql', 0777);

        $zip = new ZipArchive();
        if ($zip->open($filepath.'backup.zip', ZipArchive::CREATE)!==TRUE) {
          echo("cannot open <$filepath>\n");
        }
        $zip->addFile($filepath.'backup.sql', 'backup.sql');
        $zip->close();
        chmod($filepath.'backup.zip', 0777);
      } catch (Exception $e) {
        echo $e->getMessage();
        exit();
      }

      return true;
    }

    public function checkProfileType($option_id = null) {

      // update the profile type to the new mapped type
      $db = Engine_Db_Table::getDefaultAdapter();
      $array_ = $db->select()
                ->from('engine4_user_fields_meta','field_id')
                ->where('required = 1')
                ->query()
                ->fetchAll(); 

      foreach ($array_ as $value) {
        $required[] = $value['field_id'];
      }

      $db = Engine_Db_Table::getDefaultAdapter();
      $childs = $db->select()
                ->from('engine4_user_fields_maps','child_id')
                ->where('field_id = ?',$option_id)
                ->query()
                ->fetchAll();

      foreach ($childs as $value) {
        if (in_array($value['child_id'], $required)) {
          return true;
        }
      }

      return false;
      exit(1);
    }
}
