<?php
/**
 * SocialEngine
 *
 * @category   Application_Extensions
 * @package    Sitesubscription
 * @copyright  Copyright 2012-2013 BigStep Technologies Pvt. Ltd.
 * @license    http://www.socialengineaddons.com/license/
 * @version    $Id: Subscription.php 6590 2017-03-07 00:00:00Z SocialEngineAddOns $
 * @author     SocialEngineAddOns
 */

class Sitesubscription_SubscriptionController extends Core_Controller_Action_Standard
{
  protected $_user;

  protected $_session;
  
  public function init()
  {
    // If there are no enabled gateways or packages, disable
    // if( Engine_Api::_()->getDbtable('gateways', 'payment')->getEnabledGatewayCount() <= 0 ||
    //     Engine_Api::_()->getDbtable('packages', 'payment')->getEnabledNonFreePackageCount() <= 0 ) {
    //   return $this->_helper->redirector->gotoRoute(array(), 'default', true);
    // }
    
    // Get user and session
    $this->_user = Engine_Api::_()->user()->getViewer();
    $this->_session = new Zend_Session_Namespace('Payment_Subscription');
    
    // Check viewer and user
    if( !$this->_user || !$this->_user->getIdentity() ) {
      if( !empty($this->_session->user_id) ) {
        $this->_user = Engine_Api::_()->getItem('user', $this->_session->user_id);
      }
      // If no user, redirect to home?
      if( !$this->_user || !$this->_user->getIdentity() ) {
        $this->_session->unsetAll();
        // REDIRECT USER TO SAME PAGE AFTER LOGIN IF USER IS NOT LOGGED IN
        return $this->_helper->requireUser()->isValid();
        // return $this->_helper->redirector->gotoRoute(array(), 'default', true);
      }
    }
  }

  public function indexAction()
  {
  	return $this->_forward('choose');
  }

  public function chooseAction()
  {
    // Check subscription status
    // if( $this->_checkSubscriptionStatus() ) {
    //  return;
    // }

    // Unset certain keys
    unset($this->_session->package_id);
    unset($this->_session->subscription_id);
    unset($this->_session->gateway_id);
    unset($this->_session->order_id);
    unset($this->_session->errorMessage);
    
    // Check for default plan
    $this->_checkDefaultPaymentPlan();
    
    // Make form
    $this->view->form = $form = new Sitesubscription_Form_Signup_Subscription(array(
      'isSignup' => false,
      'action' => $this->view->url(),
    ));

    // Check method/valid
    if( !$this->getRequest()->isPost() ) {
      return;
    }
    if( !$form->isValid($this->getRequest()->getPost()) ) {
      return;
    }

    // Get package
    if( !($packageId = $this->_getParam('package_id', $this->_session->package_id)) ||
        !($package = Engine_Api::_()->getItem('payment_package', $packageId)) ) {
      return;
    }
    $this->view->package = $package;
    
    // Process
    $subscriptionsTable = Engine_Api::_()->getDbtable('subscriptions', 'payment');
    $user = $this->_user;
    $currentSubscription = $subscriptionsTable->fetchRow(array(
      'user_id = ?' => $user->getIdentity(),
      'active = ?' => true,
    ));
    
    // Cancel any other existing subscriptions
    Engine_Api::_()->getDbtable('subscriptions', 'payment')
      ->cancelAll($user, 'User cancelled the subscription.', $currentSubscription);

    // Insert the new temporary subscription
    $db = $subscriptionsTable->getAdapter();
    $db->beginTransaction();

    try {
      $subscription = $subscriptionsTable->createRow();
      $subscription->setFromArray(array(
        'package_id' => $package->package_id,
        'user_id' => $user->getIdentity(),
        'status' => 'initial',
        'active' => false, // Will set to active on payment success
        'creation_date' => new Zend_Db_Expr('NOW()'),
      ));
      $subscription->save();

      // If the package is free, let's set it active now and cancel the other
      if( $package->isFree() ) {
        $subscription->setActive(true);
        $subscription->onPaymentSuccess();
        if( $currentSubscription ) {
          $currentSubscription->cancel();
        }
      }

      $subscription_id = $subscription->subscription_id;

      $db->commit();
    } catch( Exception $e ) {
      $db->rollBack();
      throw $e;
    }

    $this->_session->subscription_id = $subscription_id;
    // Check if the user is good (this will happen if they choose a free plan)
    $subscriptionsTable = Engine_Api::_()->getDbtable('subscriptions', 'payment');
    if( $package->isFree() && $subscriptionsTable->check($this->_user) ) {
      $check = $this->_finishPayment($package->isFree() ? 'free' : 'active');
      $this->_helper->redirector->gotoRoute(array(), 'default', true);
    }
    // Otherwise redirect to the payment page
    return $this->_helper->redirector->gotoRoute(array('module' => 'payment', 'controller' => 'subscription', 'action' => 'gateway','subscription_id' => $subscription_id));
  }

  protected function _checkDefaultPaymentPlan()
  {
    // No user?
    if( !$this->_user ) {
      return $this->_helper->redirector->gotoRoute(array(), 'default', true);
    }
    
    // Handle default payment plan
    try {
      $subscriptionsTable = Engine_Api::_()->getDbtable('subscriptions', 'payment');
      if( $subscriptionsTable ) {
        $subscription = $subscriptionsTable->activateDefaultPlan($this->_user);
        if( $subscription ) {
          return $this->_finishPayment('free');
        }
      }
    } catch( Exception $e ) {
      // Silence
    }
    
    // Fall-through
  }

  protected function _checkSubscriptionStatus(
      Zend_Db_Table_Row_Abstract $subscription = null)
  {
    if( !$this->_user ) {
      return false;
    }

    if( null === $subscription ) {
      $subscriptionsTable = Engine_Api::_()->getDbtable('subscriptions', 'payment');
      $subscription = $subscriptionsTable->fetchRow(array(
        'user_id = ?' => $this->_user->getIdentity(),
        'active = ?' => true,
      ));
    }

    if( !$subscription ) {
      return false;
    }
    
    if( $subscription->status == 'active' ||
        $subscription->status == 'trial' ) {
      if( !$subscription->getPackage()->isFree() ) {
        $this->_finishPayment('active');
      } else {
        $this->_finishPayment('free');
      }
      return true;
    } else if( $subscription->status == 'pending' ) {
      $this->_finishPayment('pending');
      return true;
    }
    
    return false;
  }

  protected function _finishPayment($state = 'active')
  {
    $viewer = Engine_Api::_()->user()->getViewer();
    $user = $this->_user;

    // No user?
    if( !$this->_user ) {
      return "userNotFound";
      // return $this->_helper->redirector->gotoRoute(array(), 'default', true);
    }

    // Log the user in, if they aren't already
    if( ($state == 'active' || $state == 'free') &&
        $this->_user &&
        !$this->_user->isSelf($viewer) &&
        !$viewer->getIdentity() ) {
      Zend_Auth::getInstance()->getStorage()->write($this->_user->getIdentity());
      Engine_Api::_()->user()->setViewer();
      $viewer = $this->_user;
    }

    // Handle email verification or pending approval
    if( $viewer->getIdentity() && !$viewer->enabled ) {
      Engine_Api::_()->user()->setViewer(null);
      Engine_Api::_()->user()->getAuth()->getStorage()->clear();

      $confirmSession = new Zend_Session_Namespace('Signup_Confirm');
      $confirmSession->approved = $viewer->approved;
      $confirmSession->verified = $viewer->verified;
      $confirmSession->enabled  = $viewer->enabled;
      return 'viewerNotEnables';
      // return $this->_helper->_redirector->gotoRoute(array('action' => 'confirm'), 'user_signup', true);
    }
    
    // Clear session
    $errorMessage = $this->_session->errorMessage;
    $userIdentity = $this->_session->user_id;
    $this->_session->unsetAll();
    $this->_session->user_id = $userIdentity;
    $this->_session->errorMessage = $errorMessage;

    // Redirect
    if( $state == 'free' ) {
      return 'freeDone';
      // return $this->_helper->redirector->gotoRoute(array(), 'default', true);
    } else {
      return 'paidDone';
      // return $this->_helper->redirector->gotoRoute(array('action' => 'finish', 'state' => $state));
    }
  }

  // Action for choose-susbscripion pop-up blocking the user account in case of cancelled or expired subscription. 
  public function checkSubscriptionAction()
  {
    // Unset certain keys
    unset($this->_session->package_id);
    if( $this->getRequest()->isPost() ) {
      unset($this->_session->subscription_id);
    }
    unset($this->_session->gateway_id);
    unset($this->_session->order_id);
    unset($this->_session->errorMessage);
    
    // Check for default plan
    $this->_checkDefaultPaymentPlan();
    
    // Make form
    $this->view->form = $form = new Sitesubscription_Form_Signup_Subscription(array(
      'isSignup' => false,
      'action' => Zend_Controller_Front::getInstance()->getRouter()->assemble(array(
        'module' => 'sitesubscription',
        'controller' => 'subscription',
        'action' => 'check-subscription'),
        'default'),
    ));

    $this->view->form->setTitle('');
    $this->view->form->setDescription('');

    // Check method/valid
    if( !$this->getRequest()->isPost() ) {
      return;
    }
    if( !$form->isValid($this->getRequest()->getPost()) ) {
      return;
    }

    // Get package
    if( !($packageId = $this->_getParam('package_id', $this->_session->package_id)) ||
        !($package = Engine_Api::_()->getItem('payment_package', $packageId)) ) {
      return;
    }
    $this->view->package = $package;
    
    // Process
    $subscriptionsTable = Engine_Api::_()->getDbtable('subscriptions', 'payment');
    $user = $this->_user;
    $currentSubscription = $subscriptionsTable->fetchRow(array(
      'user_id = ?' => $user->getIdentity(),
      'active = ?' => true,
    ));
    
    // Cancel any other existing subscriptions
    Engine_Api::_()->getDbtable('subscriptions', 'payment')
      ->cancelAll($user, 'User cancelled the subscription.', $currentSubscription);

    // Insert the new temporary subscription
    $db = $subscriptionsTable->getAdapter();
    $db->beginTransaction();

    try {
      $subscription = $subscriptionsTable->createRow();
      $subscription->setFromArray(array(
        'package_id' => $package->package_id,
        'user_id' => $user->getIdentity(),
        'status' => 'initial',
        'active' => false, // Will set to active on payment success
        'creation_date' => new Zend_Db_Expr('NOW()'),
      ));
      $subscription->save();

      // If the package is free, let's set it active now and cancel the other
      if( $package->isFree() ) {
        $subscription->setActive(true);
        $subscription->onPaymentSuccess();
        if( $currentSubscription ) {
          $currentSubscription->cancel();
        }
      }

      $subscription_id = $subscription->subscription_id;

      $db->commit();
    } catch( Exception $e ) {
      $db->rollBack();
      throw $e;
    }

    $this->_session = new Zend_Session_Namespace('Payment_Subscription');
    unset($this->_session->user_id);
    unset($this->_session->subscription_id);
    $this->_session->subscription_id = $subscription_id;
    $this->_session->user_id = $this->_user->getIdentity();
    
    // Check if the user is good (this will happen if they choose a free plan)
    $subscriptionsTable = Engine_Api::_()->getDbtable('subscriptions', 'payment');
    if( $package->isFree() && $subscriptionsTable->check($this->_user) ) {
      // return $this->_finishPayment($package->isFree() ? 'free' : 'active');
      $check = $this->_finishPayment($package->isFree() ? 'free' : 'active');
      $this->_forward('success', 'utility', 'core', array(
            'smoothboxClose' => 20,
            'parentRedirect' => Zend_Controller_Front::getInstance()->getRouter()->assemble(array(
              'module' => 'members', 
              'controller' => 'home', 
              'action' => 'index'), 
            'default'),
          'messages' => array(Zend_Registry::get('Zend_Translate')->_('Selected Subscription Successfully.'))
      ));
    }
    else {
      // Otherwise redirect to the payment page
      $this->_forward('success', 'utility', 'core', array(
            'smoothboxClose' => true,
            'parentRedirect' => Zend_Controller_Front::getInstance()->getRouter()->assemble(array(
                'module' => 'payment',
                'controller' => 'subscription',
                'action' => 'gateway',
                'subscription_id' => $subscription_id),
                'default'),
          'messages' => array(Zend_Registry::get('Zend_Translate')->_('Selected Subscription Successfully.'))
      ));
    }
    
  }

  // Action for upgade-subscription pop-up.
  public function upgradeSubscriptionAction() 
  {
    // Set up navigation
    $this->view->navigation = $navigation = Engine_Api::_()
      ->getApi('menus', 'core')
      ->getNavigation('user_settings', ( $id ? array('params' => array('id'=>$id)) : array()));
      
    // Unset certain keys
    unset($this->_session->package_id);
    if( $this->getRequest()->isPost() ) {
      unset($this->_session->subscription_id);
    }
    unset($this->_session->gateway_id);
    unset($this->_session->order_id);
    unset($this->_session->errorMessage);
    
    // Check for default plan
    $this->_checkDefaultPaymentPlan();
    
    // Make form
    $this->view->form = $form = new Sitesubscription_Form_Signup_Subscription(array(
      'isSignup' => false,
      'action' => Zend_Controller_Front::getInstance()->getRouter()->assemble(array(
        'module' => 'sitesubscription',
        'controller' => 'subscription',
        'action' => 'check-subscription'),
        'default'),
    ));

    $this->view->form->setTitle('');
    $this->view->form->setDescription('');

    // Check method/valid
    if( !$this->getRequest()->isPost() ) {
      return;
    }
    if( !$form->isValid($this->getRequest()->getPost()) ) {
      return;
    }

    // Get package
    if( !($packageId = $this->_getParam('package_id', $this->_session->package_id)) ||
        !($package = Engine_Api::_()->getItem('payment_package', $packageId)) ) {
      return;
    }
    $this->view->package = $package;
    
    // Process
    $subscriptionsTable = Engine_Api::_()->getDbtable('subscriptions', 'payment');
    $user = $this->_user;
    $currentSubscription = $subscriptionsTable->fetchRow(array(
      'user_id = ?' => $user->getIdentity(),
      'active = ?' => true,
    ));
    
    // Cancel any other existing subscriptions
    Engine_Api::_()->getDbtable('subscriptions', 'payment')
      ->cancelAll($user, 'User cancelled the subscription.', $currentSubscription);

    // Insert the new temporary subscription
    $db = $subscriptionsTable->getAdapter();
    $db->beginTransaction();

    try {
      $subscription = $subscriptionsTable->createRow();
      $subscription->setFromArray(array(
        'package_id' => $package->package_id,
        'user_id' => $user->getIdentity(),
        'status' => 'initial',
        'active' => false, // Will set to active on payment success
        'creation_date' => new Zend_Db_Expr('NOW()'),
      ));
      $subscription->save();

      // If the package is free, let's set it active now and cancel the other
      if( $package->isFree() ) {
        $subscription->setActive(true);
        $subscription->onPaymentSuccess();
        if( $currentSubscription ) {
          $currentSubscription->cancel();
        }
      }

      $subscription_id = $subscription->subscription_id;

      $db->commit();
    } catch( Exception $e ) {
      $db->rollBack();
      throw $e;
    }

    $this->_session = new Zend_Session_Namespace('Payment_Subscription');
    unset($this->_session->user_id);
    unset($this->_session->subscription_id);
    $this->_session->subscription_id = $subscription_id;
    $this->_session->user_id = $this->_user->getIdentity();
    
    // Check if the user is good (this will happen if they choose a free plan)
    $subscriptionsTable = Engine_Api::_()->getDbtable('subscriptions', 'payment');
    if( $package->isFree() && $subscriptionsTable->check($this->_user) ) {
      // return $this->_finishPayment($package->isFree() ? 'free' : 'active');
      $check = $this->_finishPayment($package->isFree() ? 'free' : 'active');
      $this->_forward('success', 'utility', 'core', array(
            'smoothboxClose' => 20,
            'parentRedirect' => Zend_Controller_Front::getInstance()->getRouter()->assemble(array(
              'module' => 'members', 
              'controller' => 'home', 
              'action' => 'index'), 
            'default'),
          'messages' => array(Zend_Registry::get('Zend_Translate')->_('Selected Subscription Successfully.'))
      ));
    }
    else {
      // Otherwise redirect to the payment page
      $this->_forward('success', 'utility', 'core', array(
            'smoothboxClose' => true,
            'parentRedirect' => Zend_Controller_Front::getInstance()->getRouter()->assemble(array(
                'module' => 'payment',
                'controller' => 'subscription',
                'action' => 'gateway',
                'subscription_id' => $subscription_id),
                'default'),
          'messages' => array(Zend_Registry::get('Zend_Translate')->_('Selected Subscription Successfully.'))
      ));
    }
    
  }
}
