<?php

class Siteteam_Form_Admin_Teams_Add extends Engine_Form
{

  protected $_item;

  public function getItem()
  {
    return $this->_item;
  }

  public function setItem(Core_Model_Item_Abstract $item)
  {
    $this->_item = $item;
    return $this;
  }

  public function init()
  {
    // Set form attributes
    $this->setTitle('Add New Team Member');
    $this->setDescription('Here, you can choose a team member of your website and enter various information about the team member like Designation, Description, Email, Social URLs, etc.');
    $this->setAttrib('id', 'form-upload');
    $this->setAction(Zend_Controller_Front::getInstance()->getRouter()->assemble(array()));

    $this->addElement('Select', 'type', array(
      'label' => 'Member Type',
      'required' => true,
      'onchange' => 'memberTypeChoose()',
      'multiOptions' => array(
        1 => 'Site Member',
        0 => 'Non Site Member'
      ),
    ));

    // Element: name    
    $this->addElement('Text', "name", array(
      'label' => 'Member Name',
      'description' => "Enter the name of member to be added as team member to your website",
    ));
    $this->addElement('Text', "site_member_name", array(
      'label' => 'Site Member Name',
      'placeholder' => 'Type site member name',
      'description' => "Enter the name of member on your website who you want to add as your Team Member in the auto-suggest below.",
    ));

    $this->addElement('Hidden', 'user_id', array('order' => 1000));

    $this->addElement('Select', 'designation_id', array(
      'label' => 'Designation',
      'description' => "Choose the designation of the team member.",
      'multiOptions' => Engine_Api::_()->getDbtable('designations', 'siteteam')->getDesignationsAssoc(array('0' => 'Choose a designation')),
    ));

    $this->addElement('Textarea', 'body', array(
      'label' => 'Description',
      'validators' => array(
        array('NotEmpty', true),
      ),
      'filters' => array(
        'StripTags',
        new Engine_Filter_Censor(),
        new Engine_Filter_EnableLinks(),
      ),
    ));

    // Init file
    $this->addElement('File', 'photo', array(
      'label' => 'Profile Photo',
      'description' => "Choose a profile photo for the team member.",
    ));
    $this->photo->addValidator('Extension', false, 'jpg,jpeg,png,gif,PNG,GIF,JPG,JPEG');
    if( $this->_item && $this->_item->photo_id ) {
      $path = $this->_item->getPhotoUrl();
      if( !empty($path) ) {
        $this->addElement('Image', 'photo_preview', array(
          'label' => 'Member Photo Preview',
          'src' => $path,
          'width' => 100,
          'height' => 100,
        ));
      }

      $this->addElement('Checkbox', 'remove_photo', array(
        'label' => 'Yes, remove profile photo.'
      ));
    }

    $this->addElement('Text', "email", array(
      'label' => 'Email',
      'description' => "Enter email address of the team member which will be displayed on the team page.",
    ));

    $this->addElement('Text', "location", array(
      'label' => 'Location',
      'description' => "Enter location of the team member from the auto-suggest below. [When clicked location will open in Google Map.]",
    ));

    $this->addElement('Text', "phone", array(
      'label' => 'Phone',
      'description' => "Enter phone number of the team member.",
    ));

    $this->addElement('Text', "skype", array(
      'label' => 'Skype',
      'description' => "Enter skype username of the team member.",
    ));

    $this->addElement('Text', "website", array(
      'label' => 'Website',
      'description' => "Enter website of the team member.",
    ));

    $this->addElement('Text', "facebook", array(
      'label' => 'Facebook URL',
      'description' => "Enter URL of the Facebook Profile or Page of the team member.",
    ));

    $this->addElement('Text', "twitter", array(
      'label' => 'Twitter URL',
      'description' => "Enter URL of the Twitter Profile of the team member.",
    ));

    $this->addElement('Text', "linkdin", array(
      'label' => 'LinkedIn URL',
      'description' => "Enter URL of the LinkedIn Profile of the team member.",
    ));

    $this->addElement('Text', "googleplus", array(
      'label' => 'Google Plus URL',
      'description' => "Enter URL of the Google Plus Profile of the team member.",
    ));

    $this->addElement('Checkbox', 'enabled', array(
      'label' => 'Yes, Enable this team member.'
    ));
    // Element: submit
    $this->addElement('Button', 'submit', array(
      'label' => 'Add',
      'type' => 'submit',
      'ignore' => true,
      'decorators' => array('ViewHelper')
    ));


    // Element: cancel
    $this->addElement('Cancel', 'cancel', array(
      'label' => 'cancel',
      'link' => true,
      'prependText' => ' or ',
      'href' => Zend_Controller_Front::getInstance()->getRouter()->assemble(array('module' => 'siteteam', 'controller' => 'teams', 'action' => 'index'), 'admin_default', true),
      'decorators' => array(
        'ViewHelper'
      )
    ));
    $this->addDisplayGroup(array('submit', 'cancel'), 'buttons');
    $this->getDisplayGroup('buttons');
  }

}