<?php

class Siteteam_AdminTeamsController extends Core_Controller_Action_Admin
{

  public function init()
  {
    $this->view->navigation = $navigation = Engine_Api::_()->getApi('menus', 'core')
      ->getNavigation('siteteam_admin_main', array(), 'siteteam_admin_settings_teams');
    $this->view->subNavigation = Engine_Api::_()->getApi('menus', 'core')->getNavigation('siteteam_admin_settings_teams', array(), 'siteteam_admin_team_members');
  }

  public function indexAction()
  {
    $table = Engine_Api::_()->getDbTable('teams', 'siteteam');
    $this->view->params = $params = array(
      'limit' => $this->_getParam('limit', 10),
      'page' => $this->_getParam('page', 1),
    );
    $this->view->paginator = $table->getTeamsPaginator($params);
  }

  public function addAction()
  {
    $this->view->form = $form = new Siteteam_Form_Admin_Teams_Add();
    // Check stuff
    if( !$this->getRequest()->isPost() ) {
      return;
    }
    if( !$form->isValid($this->getRequest()->getPost()) ) {
      return;
    }
    $table = Engine_Api::_()->getDbTable('teams', 'siteteam');
    // Save
    $values = $form->getValues();
    if( $values['type'] ) {
      if( !$values["user_id"] ) {
        $itemError = Zend_Registry::get('Zend_Translate')->_("You have not chosen a member from the auto-suggest textbox. Please choose the member from auto-suggest textbox below.");
        $form->addError($itemError);
        return;
      }
      $result = $table->getTeamId(array('user_id' => $values["user_id"]));
      if( !empty($result) ) {
        $itemError = Zend_Registry::get('Zend_Translate')->_("This member has already been added as team member, please choose any other member.");
        $form->addError($itemError);
        return;
      }
    } else {
      if( empty($values['name']) ) {
        $itemError = Zend_Registry::get('Zend_Translate')->_("Member Name
Please complete this field - it is required..");
        $form->addError($itemError);
        return;
      }
    }

    $db = $table->getAdapter();
    $db->beginTransaction();
    try {
      $team = $table->createRow();
      $team->setFromArray($values);
      $team->save();
      // Set photo
      if( !empty($values['photo']) ) {
        $team->setPhoto($form->photo);
      }
      $db->commit();
    } catch( Exception $e ) {
      $db->rollback();
      throw $e;
    }
    // redirect to manage page for now
    $this->_helper->redirector->gotoRoute(array('module' => 'siteteam', 'controller' => 'teams'), 'admin_default', true);
  }

  public function editAction()
  {
    $this->view->team_id = $teamId = $this->_getParam('id');
    $this->view->team = $team = Engine_Api::_()->getDbtable('teams', 'siteteam')->getTeam($teamId);
    if( !$team ) {
      throw new Core_Model_Exception('missing team');
    }

    $this->view->form = $form = new Siteteam_Form_Admin_Teams_Edit(array('item' => $team));

    // Make safe
    $teamData = $team->toArray();
    if( is_array($teamData['params']) ) {
      $teamData = array_merge($teamData, $teamData['params']);
    }

    // Check stuff
    if( !$this->getRequest()->isPost() ) {
      $form->populate($teamData);
      return;
    }

    if( !$form->isValid($this->getRequest()->getPost()) ) {
      return;
    }
    // Save
    $values = $form->getValues();
    $table = Engine_Api::_()->getDbTable('teams', 'siteteam');
    $db = $table->getAdapter();
    $db->beginTransaction();
    try {
      $team->setFromArray($values);
      if( !empty($values['remove_photo']) ) {
        $team->photo_id = 0;
      }
      $team->save();
      // Set photo
      if( !empty($values['photo']) && empty($values['remove_photo']) ) {
        $team->setPhoto($form->photo);
      }
      $db->commit();
    } catch( Exception $e ) {
      $db->rollback();
      throw $e;
    }
    // redirect to manage page for now
    $this->_helper->redirector->gotoRoute(array('module' => 'siteteam', 'controller' => 'teams'), 'admin_default', true);
  }

  public function deleteAction()
  {
    $this->view->team_id = $teamId = $this->_getParam('id');
    $team = Engine_Api::_()->getDbtable('teams', 'siteteam')->getTeam($teamId);

    if( !$team ) {
      throw new Core_Model_Exception('missing menu item');
    }

    // Get form
    $this->view->form = $form = new Siteteam_Form_Admin_Teams_Delete();

    // Check stuff
    if( !$this->getRequest()->isPost() || !$form->isValid($this->getRequest()->getPost()) ) {
      return;
    }


    $team->delete();
    $this->_forward('success', 'utility', 'core', array(
      'smoothboxClose' => true,
      'parentRefresh' => true,
      'format' => 'smoothbox',
      'messages' => array(Zend_Registry::get('Zend_Translate')->_("Team Deleted"))
    ));
  }

  public function orderAction()
  {

    if( !$this->getRequest()->isPost() )
      return;

    $table = Engine_Api::_()->getDbtable($this->_getParam('item_type', 'teams'), 'siteteam');
    $teams = $table->fetchAll($table->select());
    foreach( $teams as $team ) {
      $order = $this->getRequest()->getParam($team->getGuid());
      if( $order ) {
        $team->order = $order;
        $team->save();
      }
    }
    return;
  }

  public function designationsAction()
  {
    $this->view->subNavigation = Engine_Api::_()->getApi('menus', 'core')->getNavigation('siteteam_admin_settings_teams', array(), 'siteteam_admin_team_designations');
    $table = Engine_Api::_()->getDbtable('designations', 'siteteam');
    $select = $table->select()->order('order ASC');
    $this->view->designations = $table->fetchAll($select);
  }

  public function addDesignationAction()
  {
    // In smoothbox
    $this->_helper->layout->setLayout('admin-simple');

    // Generate and assign form
    $form = $this->view->form = new Siteteam_Form_Admin_Teams_Designation();
    $form->setAction($this->getFrontController()->getRouter()->assemble(array()));
    // Check post
    if( $this->getRequest()->isPost() && $form->isValid($this->getRequest()->getPost()) ) {
      // we will add the designation
      $values = $form->getValues();

      $db = Engine_Db_Table::getDefaultAdapter();
      $db->beginTransaction();

      try {
        // add designation to the database
        // Transaction
        $table = Engine_Api::_()->getDbtable('designations', 'siteteam');
        $user = Engine_Api::_()->user()->getViewer();

        // insert the siteteam designation entry into the database
        $row = $table->createRow();
        $row->designation_name = $values["label"];
        $row->save();

        // change the designation of all the siteteams using that designation

        $db->commit();
      } catch( Exception $e ) {
        $db->rollBack();
        throw $e;
      }
      $this->_forward('success', 'utility', 'core', array(
        'smoothboxClose' => 10,
        'parentRefresh' => 10,
        'messages' => array('')
      ));
    }
  }

  public function deleteDesignationAction()
  {
    // In smoothbox
    $this->_helper->layout->setLayout('admin-simple');
    $this->view->designation_id = $id = $this->_getParam('id');

    // Must have an id
    if( !($id = $this->_getParam('id')) ) {
      throw new Zend_Exception('No identifier specified');
    }

    $designationTable = Engine_Api::_()->getDbtable('designations', 'siteteam');
    $designation = $designationTable->find($id)->current();

    // Check post
    if( $this->getRequest()->isPost() ) {
      $db = Engine_Db_Table::getDefaultAdapter();
      $db->beginTransaction();

      try {
        // go through logs and see which siteteam used this designation and set it to ZERO
        $teamTable = Engine_Api::_()->getDbtable('teams', 'siteteam');
        $teamTable->update(array(
          'designation_id' => 0,
          ), array(
          'designation_id = ?' => $designation->designation_id,
        ));

        // delete the siteteam designation in the database
        $designation->delete();

        $db->commit();
      } catch( Exception $e ) {
        $db->rollBack();
        throw $e;
      }
      return $this->_forward('success', 'utility', 'core', array(
          'smoothboxClose' => 10,
          'parentRefresh' => 10,
          'messages' => array('')
      ));
    }
  }

  public function editDesignationAction()
  {
    // In smoothbox
    $this->_helper->layout->setLayout('admin-simple');
    $form = $this->view->form = new Siteteam_Form_Admin_Teams_Designation();
    $form->setAction($this->getFrontController()->getRouter()->assemble(array()));

    // Must have an id
    if( !($id = $this->_getParam('id')) ) {
      throw new Zend_Exception('No identifier specified');
    }

    $designationTable = Engine_Api::_()->getDbtable('designations', 'siteteam');
    $designation = $designationTable->find($id)->current();

    // Generate and assign form
    $form->setField($designation);

    // Check post
    if( $this->getRequest()->isPost() && $form->isValid($this->getRequest()->getPost()) ) {
      // Ok, we're good to add field
      $values = $form->getValues();

      $db = Engine_Db_Table::getDefaultAdapter();
      $db->beginTransaction();

      try {
        $designation->designation_name = $values["label"];
        $designation->save();

        $db->commit();
      } catch( Exception $e ) {
        $db->rollBack();
        throw $e;
      }
      return $this->_forward('success', 'utility', 'core', array(
          'smoothboxClose' => 10,
          'parentRefresh' => 10,
          'messages' => array('')
      ));
    }
  }

  //Add new team member using auto suggest
  public function suggestUsersAction()
  {

    $sesdata = array();
    $users_table = Engine_Api::_()->getDbtable('users', 'user');
    $select = $users_table->select()
        ->where('displayname  LIKE ? ', '%' . $this->_getParam('text') . '%')
        ->order('displayname ASC')->limit('20');
    $users = $users_table->fetchAll($select);

    foreach( $users as $user ) {
      $user_icon_photo = $this->view->itemPhoto($user, 'thumb.icon');
      $sesdata[] = array(
        'id' => $user->user_id,
        'label' => $user->displayname,
        'photo' => $user_icon_photo
      );
    }
    return $this->_helper->json($sesdata);
  }

}