<?php
/**
 * SocialEngine
 *
 * @category   Application_Extensions
 * @package    Sitetheme
 * @copyright  Copyright 2012-2013 BigStep Technologies Pvt. Ltd.
 * @license    http://www.socialengineaddons.com/license/
 * @version    $Id: IndexController.php 2013-11-22 00:00:00Z SocialEngineAddOns $
 * @author     SocialEngineAddOns
 */

class Sitetheme_IndexController extends Core_Controller_Action_Standard
{
  public function friendRequestAction()
  {
    $viewer = Engine_Api::_()->user()->getViewer();
    
    $this->view->noOfUpdates = $noOfUpdates = $this->_getParam('noOfUpdates', 10);

    $this->view->requests = $friendRequests = Engine_Api::_()->getDbtable('updates', 'sitetheme')->getRequestsPaginator($viewer);
    $friendRequests->setItemCountPerPage($noOfUpdates);

    // Force rendering now
    $this->_helper->viewRenderer->postDispatch();
    $this->_helper->viewRenderer->setNoRender(true);
//    $this->view->hasunread = false;

    // Now mark them all as view
    $notificationIds = array();
    foreach( $friendRequests as $friendRequest ) {
      $notificationIds[] = $friendRequest->notification_id;
    }
    Engine_Api::_()->getDbtable('updates', 'sitetheme')->markUpdatesAsShow($viewer, $notificationIds);
  }
  
  public function notificationAction()
  {
    $viewer = Engine_Api::_()->user()->getViewer();
    
    $this->view->noOfUpdates = $noOfUpdates = $this->_getParam('noOfUpdates', 10);

    $notifications_sql = Engine_Api::_()->getDbtable('updates', 'sitetheme')->getNotificationsPaginatorSql($viewer);
    $notificationsObj = Engine_Api::_()->getDbtable('notifications', 'activity')->fetchAll($notifications_sql);
    $this->view->notifications = $notifications = Zend_Paginator::factory($notifications_sql);
    $notifications->setItemCountPerPage($noOfUpdates);

    // Force rendering now
    $this->_helper->viewRenderer->postDispatch();
    $this->_helper->viewRenderer->setNoRender(true);

    $this->view->hasunread = false;
   
    // Now mark them all as view
    $notificationIds = array();
    foreach( $notificationsObj as $notification ) {
      $notificationIds[] = $notification->notification_id;
    }
    Engine_Api::_()->getDbtable('updates', 'sitetheme')->markUpdatesAsShow($viewer, $notificationIds);
  }
  
  public function messageAction()
  {
    $viewer = Engine_Api::_()->user()->getViewer();
    $this->view->noOfUpdates = $noOfUpdates = $this->_getParam('noOfUpdates', 10);
    $this->view->paginator = $paginator = Engine_Api::_()->getItemTable('messages_conversation')->getInboxPaginator($viewer);
    $paginator->setItemCountPerPage($noOfUpdates);
    $paginator->setCurrentPageNumber($this->_getParam('page'));
    
    // Now mark them all as view
    $conversation_ids = array();
    foreach( $paginator as $conversation ) {
      $conversation_ids[] = $conversation->conversation_id;
    }
    Engine_Api::_()->getDbtable('updates', 'sitetheme')->markMessagesAsShow($viewer, $conversation_ids);
  }
  
  public function checkNewUpdatesAction()
  {
    $viewer = Engine_Api::_()->user()->getViewer();
    
    $this->view->newMessage = Engine_Api::_()->getDbtable('updates', 'sitetheme')->getUnreadMessageCount($viewer);
    
    $this->view->newFriendRequest = Engine_Api::_()->getDbtable('updates', 'sitetheme')->getNewUpdatesCount($viewer, array('type' => 'friend_request'));
    
    $this->view->newNotification = Engine_Api::_()->getDbtable('updates', 'sitetheme')->getNewUpdatesCount($viewer, array('isNotification' => 'true'));
  }
  
  public function settingAction()
  {
    $this->view->settings = $navigation = Engine_Api::_()->getApi('menus', 'core')->getNavigation("user_settings", array());
    // Check last super admin
    $user = Engine_Api::_()->user()->getViewer();
    if( $user && $user->getIdentity() ) {
      if( 1 === count(Engine_Api::_()->user()->getSuperAdmins()) && 1 === $user->level_id ) {
        foreach( $navigation as $page ) {
          if( $page instanceof Zend_Navigation_Page_Mvc &&
              $page->getAction() == 'delete' ) {
            $navigation->removePage($page);
          }
        }
      }
    }
  }

  public function getCartItemCountAction()
  {
    $viewer_id = Engine_Api::_()->user()->getViewer()->getIdentity();
    $cartProductCounts = 0;

    if (empty($viewer_id)) {
      $session = new Zend_Session_Namespace('sitestoreproduct_viewer_cart');
      $tempUserCart = @unserialize($session->sitestoreproduct_guest_user_cart);
      if (empty($tempUserCart))
      {
        $this->view->cartProductCounts = $cartProductCounts;
        return;
      }
      
      foreach ($tempUserCart as $values) {
        if (isset($values['config']) && is_array($values['config']))
          foreach ($values['config'] as $quantity) {
            $cartProductCounts += $quantity['quantity'];
          }
        else
          $cartProductCounts += $values['quantity'];
      }
    } else {
      $getCartId = Engine_Api::_()->getDbtable('carts', 'sitestoreproduct')->getCartId($viewer_id);
      if (!empty($getCartId) )
        $cartProductCounts = Engine_Api::_()->getDbtable('carts', 'sitestoreproduct')->getProductCounts($getCartId);
    }
    
    $this->view->cartProductCounts = $cartProductCounts;
  }
  
  public function userLoginAction()
  {
    $this->_helper->layout->setLayout('default-simple');
  }
  
  public function markMessageReadUnreadAction()
  {
    $message_id = $this->_getParam('messgae_id', null);
    $is_read = $this->_getParam('is_read', 0);
    if( empty($message_id) )
      return;
    
    Engine_Api::_()->sitetheme()->markMessageReadUnread($message_id, $is_read);
  }
  
  public function markNotificationsAsReadAction()
  {
    $viewer = Engine_Api::_()->user()->getViewer();
    Engine_Api::_()->getDbtable('updates', 'sitetheme')->markNotificationsAsRead($viewer);
  }
}
