<?php

/**
 * SocialEngine
 *
 * @category   Application_Module
 * @package    Sitetour
 * @copyright  Copyright 2017-2018 BigStep Technologies Pvt. Ltd.
 * @license    http://www.socialengineaddons.com/license/
 * @version    AdminSettingsController.php 2015-09-10 00:00:00Z SocialEngineAddOns $
 * @author     SocialEngineAddOns
 */
class Sitetour_AdminTourStepsController extends Core_Controller_Action_Admin
{
  public function indexAction()
  {
    $this->view->navigation = Engine_Api::_()->getApi('menus', 'core')
      ->getNavigation('sitetour_admin_main', array(), 'sitetour_admin_main_tours');
    $tour_id = $this->_getParam('tour_id');
    $this->view->tour = $tour = Engine_Api::_()->getItem('sitetour_tour', $tour_id);
  }

  public function createAction()
  {
    $this->_helper->layout->setLayout('admin-simple');
    $this->view->form = $form = new Sitetour_Form_Admin_Tour_Step_Add();
    if( !$this->getRequest()->isPost() ) {
      return;
    }

    if( !$form->isValid($this->getRequest()->getPost()) ) {
      return;
    }

    $db = Engine_Api::_()->getItemTable('sitetour_step')->getAdapter();
    $db->beginTransaction();

    try {
      $step = Engine_Api::_()->getDbtable('steps', 'sitetour')->createRow();
      $params = $form->getValues();
      $values = array(
        'title' => $params['title'],
        'body' => $params['body'],
        'enabled' => $params['enabled'],
        'type' => $params['type'],
        'tour_id' => $this->_getParam('tour_id'),
      );
      unset($params['title']);
      unset($params['body']);
      unset($params['enabled']);
      $data = array();
      if( $params['type'] == 'widget' ) {
        $widget = Engine_Api::_()->getDbtable('content', 'core')->findRow($params['content_id']);
        $params['widget_name'] = $widget->name;
        $params['element-class'] = 'layout_' . preg_replace('/[^\w\d]/', '_', $widget->name);
        $params['element'] = '#layout_container_' . $widget->type . '_' . $widget->content_id;
        $parent = Engine_Api::_()->getDbtable('content', 'core')->findRow($widget->parent_content_id);
        if( $parent && $parent->name == 'core.container-tabs' ) {
          $params['element-class'] = 'tab_' . $params['element-class'];
          $params['element'] = 'li.tab_' . $widget->content_id;
        }
        $contentAreasNameList = Engine_Api::_()->sitetour()->getNameListOfContentAreas();
        $params['widget_title'] = $contentAreasNameList[$widget->name] . (!empty($widget->params['title']) ? ' (' . preg_replace('#<script(.*?)>(.*?)</script>#is', '', $widget->params['title']) . ')' : '');
      } else {
        $params['element'] = $params['content_id'];
      }
      $values['params'] = $params;

      $step->setFromArray($values);
      $step->save();
      $db->commit();
    } catch( Exception $e ) {
      $db->rollBack();
      throw $e;
    }

    $this->_forward('success', 'utility', 'core', array(
      'smoothboxClose' => 10,
      'parentRefresh' => 10,
      'messages' => array(Zend_Registry::get('Zend_Translate')->_('Tour Created!'))
    ));
  }

  public function deleteAction()
  {
    //LAYOUT
    $this->_helper->layout->setLayout('admin-simple');
    $this->view->step_id = $step_id = $this->_getParam('step_id');

    if( !$this->getRequest()->isPost() ) {
      return;
    }
    $values = $this->getRequest()->getPost();

    if( $values['confirm'] != $step_id ) {
      return;
    }

    $db = Engine_Db_Table::getDefaultAdapter();
    $db->beginTransaction();

    try {
      $step = Engine_Api::_()->getItem('sitetour_step', $step_id);
      $step->delete();

      $db->commit();
    } catch( Exception $ex ) {
      $db->rollBack();
      throw $ex;
    }
    $this->_forward('success', 'utility', 'core', array(
      'smoothboxClose' => 10,
      'parentRefresh' => 10,
      'messages' => array(Zend_Registry::get('Zend_Translate')->_('Deleted'))
    ));
  }

  public function editAction()
  {
    //LAYOUT
    $this->_helper->layout->setLayout('admin-simple');
    $this->view->step_id = $step_id = $this->_getParam('step_id');
    // Get form
    $this->view->form = $form = new Sitetour_Form_Admin_Tour_Step_Edit();
    $step = Engine_Api::_()->getItem('sitetour_step', $step_id);
    if( !$this->getRequest()->isPost() ) {
      $data = $step->toArray();
      $data = array_merge($data, $data['params']);
      $form->populate($data);
      return;
    }

    if( !$form->isValid($this->getRequest()->getPost()) ) {
      return;
    }

    // Process
    $db = Engine_Db_Table::getDefaultAdapter();
    $db->beginTransaction();
    try {
      $params = $form->getValues();
      $values = array(
        'title' => $params['title'],
        'body' => $params['body'],
        'enabled' => $params['enabled'],
        'type' => $params['type'],
      );
      if (isset($params['params'])) {
        $values['params'] = $params['params'];
      }
      unset($params['title']);
      unset($params['body']);
      unset($params['enabled']);
      unset($params['content_id']);
      if (isset($params['params'])) {
        unset($params['params']);
      }

      $values['params'] = array_merge($step->params, $params);

      $step->setFromArray($values);
      $step->save();

      $db->commit();
    } catch( Exception $ex ) {
      $db->rollBack();
      throw $ex;
    }
    $this->_forward('success', 'utility', 'core', array(
      'smoothboxClose' => 10,
      'parentRefresh' => 10,
      'messages' => array(Zend_Registry::get('Zend_Translate')->_('Saved Changes!'))
    ));
  }

  //ACTION FOR UPDATE ORDER 
  public function updateOrderAction()
  {
    //CHECK POST
    if( $this->getRequest()->isPost() ) {
      $db = Engine_Db_Table::getDefaultAdapter();
      $db->beginTransaction();
      $values = $_POST;
      try {
        foreach( $values['order'] as $key => $value ) {
          $row = Engine_Api::_()->getItem('sitetour_step', (int) $value);
          if( !empty($row) ) {
            $row->order = $key + 1;
            $row->save();
          }
        }

        $db->commit();

        $this->_redirect('admin/sitetour/tour-steps/index/tour_id/' . $row->tour_id);
      } catch( Exception $e ) {
        $db->rollBack();
        throw $e;
      }
    }
  }

  public function enabledAction()
  {
    $step_id = $this->_getParam('step_id');
    $db = Engine_Db_Table::getDefaultAdapter();
    $db->beginTransaction();

    try {
      $step = Engine_Api::_()->getItem('sitetour_step', $step_id);
      $step->enabled = 1;
      $step->save();
      $db->commit();
    } catch( Exception $ex ) {
      $db->rollBack();
      throw $ex;
    }
    $this->_redirect('admin/sitetour/tour-steps/index/tour_id/' . $step->tour_id);
  }

  public function disabledAction()
  {
    $step_id = $this->_getParam('step_id');
    $db = Engine_Db_Table::getDefaultAdapter();
    $db->beginTransaction();

    try {
      $step = Engine_Api::_()->getItem('sitetour_step', $step_id);
      $step->enabled = 0;
      $step->save();
      $db->commit();
    } catch( Exception $ex ) {
      $db->rollBack();
      throw $ex;
    }
    $this->_redirect('admin/sitetour/tour-steps/index/tour_id/' . $step->tour_id);
  }

}

?>