<?php

/**
 * SocialEngine
 *
 * @category   Application_Module
 * @package    Sitetour
 * @copyright  Copyright 2017-2018 BigStep Technologies Pvt. Ltd.
 * @license    http://www.socialengineaddons.com/license/
 * @version    AdminSettingsController.php 2015-09-10 00:00:00Z SocialEngineAddOns $
 * @author     SocialEngineAddOns
 */
class Sitetour_AdminToursController extends Core_Controller_Action_Admin
{
  public function indexAction()
  {
    error_reporting(E_ALL);
    ini_set('display_errors', true);
    //TABS CREATION
    $this->view->navigation = Engine_Api::_()->getApi('menus', 'core')
      ->getNavigation('sitetour_admin_main', array(), 'sitetour_admin_main_tours');
    if( $this->getRequest()->isPost() ) {
      $values = $this->getRequest()->getPost();
      foreach( $values as $key => $value ) {
        if( $key == 'delete_' . $value ) {
          $tour = Engine_Api::_()->getItem('tour', $value);
          $tour->delete();
        }
      }
    }

    $this->view->paginator = Engine_Api::_()->getItemTable('sitetour_tour')->getToursPaginator(array(
      'orderby' => 'tour_id',
      'limit' => 25,
      'page' => $this->_getParam('page', 1),
    ));
  }

  public function createAction()
  {
    $this->_helper->layout->setLayout('admin-simple');
    $this->view->form = $form = new Sitetour_Form_Admin_Tour_Create();
    if( !$this->getRequest()->isPost() ) {
      return;
    }

    if( !$form->isValid($this->getRequest()->getPost()) ) {
      return;
    }

    $db = Engine_Api::_()->getItemTable('sitetour_tour')->getAdapter();
    $db->beginTransaction();

    try {
      $tour = Engine_Api::_()->getDbtable('tours', 'sitetour')->createRow();
      $params = $form->getValues();
      $values = array(
        'page_name' => $params['page_name'],
        'enabled' => $params['enabled']
      );
      unset($params['page_name']);
      unset($params['enabled']);
      $values['params'] = $params;

      $tour->setFromArray($values);
      $tour->save();
      $db->commit();
    } catch( Exception $e ) {
      $db->rollBack();
      throw $e;
    }

    $this->_forward('success', 'utility', 'core', array(
      'smoothboxClose' => 10,
      'parentRefresh' => 10,
      'messages' => array(Zend_Registry::get('Zend_Translate')->_('Tour Created!'))
    ));
  }

  public function editAction()
  {
    $this->_helper->layout->setLayout('admin-simple');
    $tour_id = $this->_getParam('tour_id');
    $this->view->tour = $tour = Engine_Api::_()->getItem('sitetour_tour', $tour_id);
    $this->view->form = $form = new Sitetour_Form_Admin_Tour_Edit();
    try {
      if( !$this->getRequest()->isPost() ) {
        $data = $tour->toArray();
        $data = array_merge($data, $data['params']);
        $form->populate($data);
        return;
      }
      if( !$form->isValid($this->getRequest()->getPost()) ) {
        return;
      }
      // Process
      $db = Engine_Db_Table::getDefaultAdapter();
      $db->beginTransaction();
      $params = $form->getValues();
      $values = array(
        'enabled' => $params['enabled']
      );
      unset($params['page_name']);
      unset($params['enabled']);
      $values['params'] = $params;
      $tour->setFromArray($values);
      $tour->save();


      $db->commit();
    } catch( Exception $e ) {
      $db->rollBack();
      die("Exception " . $e);
    }
    $this->_forward('success', 'utility', 'core', array(
      'smoothboxClose' => 10,
      'parentRefresh' => 10,
      'messages' => array(Zend_Registry::get('Zend_Translate')->_('Save sucessfully!'))
    ));
  }

  public function deleteAction()
  {
    //LAYOUT
    $this->_helper->layout->setLayout('admin-simple');
    $this->view->tour_id = $tour_id = $this->_getParam('tour_id');

    if( !$this->getRequest()->isPost() ) {
      return;
    }
    $values = $this->getRequest()->getPost();

    if( $values['confirm'] != $tour_id ) {
      return;
    }

    $db = Engine_Db_Table::getDefaultAdapter();
    $db->beginTransaction();

    try {
      $tour = Engine_Api::_()->getItem('sitetour_tour', $tour_id);
      $tour->delete();
      $db->commit();
    } catch( Exception $ex ) {
      $db->rollBack();
      throw $ex;
    }
    $this->_forward('success', 'utility', 'core', array(
      'smoothboxClose' => 10,
      'parentRefresh' => 10,
      'messages' => array(Zend_Registry::get('Zend_Translate')->_('Deleted'))
    ));
  }

  public function enabledAction()
  {
    $tour_id = $this->_getParam('tour_id');
    $db = Engine_Db_Table::getDefaultAdapter();
    $db->beginTransaction();

    try {
      $tour = Engine_Api::_()->getItem('sitetour_tour', $tour_id);
      $tour->enabled = 1;
      $tour->save();

      $db->commit();
    } catch( Exception $ex ) {
      $db->rollBack();
      throw $ex;
    }
    $this->_redirect('admin/sitetour/tours');
  }

  public function disabledAction()
  {
    $tour_id = $this->_getParam('tour_id');
    $db = Engine_Db_Table::getDefaultAdapter();
    $db->beginTransaction();

    try {
      $tour = Engine_Api::_()->getItem('sitetour_tour', $tour_id);
      $tour->enabled = 0;
      $tour->save();
      $db->commit();
    } catch( Exception $ex ) {
      $db->rollBack();
      throw $ex;
    }
    $this->_redirect('admin/sitetour/tours');
  }

}

?>