<?php
/**
 * SocialEngine
 *
 * @category   Application_Extensions
 * @package    Siteuserexport
 * @copyright  Copyright 2006-2010 Webligo Developments
 * @license    http://www.socialengine.com/license/
 * @version    $Id: Managetemplates.php 10168 2014-04-17 16:29:36Z andres $
 * @author     SocialEngineAddons
 */

class Siteuserexport_Form_Admin_Manage_Managetemplates extends Engine_Form {

	protected $_profileFields;
	protected $_templateId;
	protected $_optionId;

	public function setTemplateId($templateId) {
		$this->_templateId = $templateId;
	}

	public function setProfileFields($params) {
		$this->_profileFields = $params;
	}

	public function setOptionId($optionId) {
		$this->_optionId = $optionId;
	}

	public function init() {

		$templateFields = Engine_Api::_()->getDbtable('templates', 'siteuserexport')->getTemplatefields($this->_templateId);

		$fieldsKey = array();
		if (!empty($templateFields)) {
			foreach ($templateFields as $key => $value) {
				$fieldsKey[] = $key;
			}
		}

		$getProfileTypes = Engine_Api::_()->getApi('Core', 'siteuserexport')->getProfileTypes();

		$profileType = array();
		$profileType[$this->_optionId] = $getProfileTypes[$this->_optionId];

		// Init form
		$this->setDescription("Below you can select the fields which you want for the users being exported. If you don’t select any field then by default all fields will be included for the users in the exported file.");
		$this->setAttrib('id', 'fields_select');

		$this->addElement('Hidden', 'template_id', array(
			'value' => $this->_templateId,
			'order' => -1,
		));

		$this->addElement('Select', 'option_id', array(
			'label' => 'Profile Type: ',
			'onchange' => 'showProfileFields();',
			'multiOptions' => $profileType,
			'order' => 0,
			'disabled' => TRUE,
			'id' => 'profile_type',
		));

		$this->addElement('Checkbox', 'select_all', array(
			'label' => 'Select All',
			'onclick' => 'selectAll();',
			'order' => 1,
		));

		$userExportApi = Engine_Api::_()->getApi('Core', 'siteuserexport');
		$fields = $userExportApi->getFields($this->_optionId);

		$order = 990;

		foreach ($fields as $key => $field) {

			$displayGroup = "myDisplayGroup" . $field;
			$asClass = $key . "_field_as";
			$order += 1;
			$fieldName = 'fields_' . $key;
			$editedLable = 'edited_' . $key;

			if (!empty($templateFields[$key])) {
				$asLable = 'asvalu_' . $key . '_labelAs_' . $templateFields[$key];
			} else {
				$asLable = 'asvalu_' . $key . '_labelAs_' . $field;
			}

			$v = '0';
			if (in_array($key, $fieldsKey)) {
				$v = '1';
			}

			$this->addElement('Checkbox', $fieldName, array(
				'label' => $field,
				'value' => $v,
				'order' => $order,
				'class' => 'field_select',
			));

			$order += 1;

			$this->addElement('Dummy', $fieldName . "_dummy", array(
				'order' => $order,

				'decorators' => array(array('ViewScript', array(
					'viewScript' => '_fieldEdit.tpl',
					'class' => $asClass,
					'params' => array('lable' => $asLable),
				))),
			));

			$this->addDisplayGroup(array($fieldName, $asLable), $displayGroup);
			$group = $this->getDisplayGroup($displayGroup);

			$group->setDecorators(array(
				'FormElements',
				array('HtmlTag', array('tag' => 'div', 'class' => 'fields_pair')),
			));

			$order += 1;

			$value = '';
			if (!empty($templateFields[$key])) {
				$value = $templateFields[$key];
			} else {
				$value = $field;
			}

			$this->addElement('Hidden', $editedLable, array(
				'value' => $value,
				'order' => $order,
			));
			// $this->getElement($fieldName)->setValue(true);
		}

		$this->addElement('Button', 'execute', array(
			'label' => 'Save',
			'type' => 'submit',
			'order' => 9991,
		));
	}

}