<?php

class Siteuserkyc_Api_Core extends Core_Api_Abstract {

	protected $_engineApi = null;
	protected $_kyc_setting = null;
	protected $_coreSetting = null;
	protected $_memberLevels = null;
	protected $_viewer = null;
	protected $_viewer_id = null;

	protected $_isViewerKYCAllow = null;
	protected $_allowedDocuments = null;
	protected $_getAdmins = null;
	protected $_canDocAutoApproved = null;

	protected $_maxAllowedFileSizeByte = null;


	public function __construct() {

		$this->_engineApi = Engine_Api::_();
		$this->_coreSetting = $this->_engineApi->getApi('settings', 'core');
		$this->_viewer = $this->_engineApi->user()->getViewer();
		$this->_viewer_id = $this->_viewer->getIdentity();

		// Get KYC admin settings now
		$this->getKycAdminSetting();

	}


	public function allowedmemberlevel() {
		return empty($this->_kyc_setting['allowedmemberlevel']) ? array() : $this->_kyc_setting['allowedmemberlevel'];
	}


	// Check if viewer allowed to upload documents for KYC process
	public function isViewerAllow() {

		if ( is_null($this->_isViewerKYCAllow) ) {
			if ( empty($this->_kyc_setting['allowedmemberlevel']) || !is_array($this->_kyc_setting['allowedmemberlevel']) || empty($this->_viewer_id ) ) {
				$this->_isViewerKYCAllow = false;
			} else {
				$this->_isViewerKYCAllow = in_array( $this->_viewer->level_id, $this->_kyc_setting['allowedmemberlevel'] );
			}
		}
		return $this->_isViewerKYCAllow;

	}


	public function canUserVerifyKYCDocuments( User_Model_User $user ) {

		if ( empty($user->getIdentity()) ) {
			throw new Exception("Invalid User", 1);
		}
		if ( $this->canDocAutoApproved() ) {
			return true;
		}
		// Check if user is super admin or not
		$table = $this->_engineApi->getDbtable('levels', 'authorization');
		$select = $table->select()->where( "type = 'admin' and flag = 'superadmin' ")->where( 'level_id = ?', $user->level_id );
		$levelRow = $table->fetchRow( $select );
		if ( !empty($levelRow) ) {
			return true;
		}
		$allowedAdmins = $this->getAllowedAdmins();
		if ( !$user->isAdminOnly() || empty( trim($allowedAdmins) ) ) {
			return false;
		}
		$allowedAdmins = explode(',', $allowedAdmins);
		return in_array( $user->getIdentity(), $allowedAdmins );

	}


	// return the list of documents which are allowed for kyc process
	public function getAllowedDocuments() {

		if ( is_null($this->_allowedDocuments) ) {
			$this->_allowedDocuments = is_array($this->_kyc_setting['alloweddocumentlist']) ? $this->_kyc_setting['alloweddocumentlist'] : array();
		}
		return $this->_allowedDocuments;

	}


	// Who can approve and disapprove user's kyc below user's must be admin
	public function getAllowedAdmins() {

		if ( is_null($this->_getAdmins) ) {
			$settings = &$this->_kyc_setting;
			$this->_getAdmins = ( !empty($settings['toValues']) ) ? $settings['toValues'] : array();
		}
		return $this->_getAdmins;

	}


	public function canDocAutoApproved() {

		if ( is_null($this->_canDocAutoApproved) ) {
			if ( empty($this->_kyc_setting['autoapproveddocument']) || $this->_kyc_setting['autoapproveddocument'] != 'yes' ) {
				$this->_canDocAutoApproved = false;
			} else {
				$this->_canDocAutoApproved = true;
			}
		}
		return $this->_canDocAutoApproved;

	}


	public function getKycAdminSetting() {

		if ( is_null($this->_kyc_setting) ) {
			$settings = $this->_coreSetting->getSetting('siteuserkyc_adminmembersetting', null);
			$this->_kyc_setting = empty($settings) ? array() : (array)json_decode($settings);
		}
		return $this->_kyc_setting;

	}


	public function setKycAdminSetting( array $settings ) {

		$this->_coreSetting->setSetting('siteuserkyc_adminmembersetting', json_encode($settings));
		$this->_kyc_setting = $settings;
	}


	public function getMemberLevelOptions() {

		if ( is_null($this->_memberLevels) ) {
			$this->_memberLevels = array();
			$table = $this->_engineApi->getDbtable('levels', 'authorization');
			$select = $table->select()->where( 'type not like "public"');
			$memberLevels = $table->fetchAll( $select );
			if ( !empty($memberLevels) ) {
				foreach ($memberLevels as $memberLevel) {
					$this->_memberLevels[$memberLevel->level_id] = $memberLevel->getTitle();
				}
			}
		}
		return $this->_memberLevels;
	}


	public function return_bytes($val) {

		$val = trim($val);
		$last = $val[strlen($val)-1];
		$val = rtrim($val, $last);
		$last = strtolower($last);
		switch($last) {
			case 'g': $val *= 1024;
			case 'm': $val *= 1024;
			case 'k': $val *= 1024;
		}
		return $val;
	}


	public function getAdmins( string $title = '', int $limit = 10, $user_id = null, array $user_not_allowed = array() ) {

		$table = $this->_engineApi->getDbtable('levels', 'authorization');
		$select = $table->select()->from( $table->info('name'), 'level_id' )->where( "type = 'admin' and ( flag != 'superadmin' or flag is null ) " );
		$levels = $table->getAdapter()->fetchCol($select);
		if ( empty($levels) ) { // only admins are allowed superadmin are bydefault allowed
			return;
		}
		//MAKE QUERY
		$table = $this->_engineApi->getItemTable('user');
		$select = $table->select()->from( $table->info('name'), array('user_id', 'displayname', 'username', 'photo_id', 'email') )
						->where('level_id in(?)', $levels);
		if ( !empty($user_not_allowed) ) {
			$select->where( 'user_id not in (?)', $user_not_allowed );
		}
		if ( !empty($user_id) ) {
			if ( is_array($user_id) ) {
				$select->where( 'user_id in(?)', $user_id );
			} else {
				$select->where('user_id = ?', $user_id);
			}
		}
		if ( !empty($title) ) {
			$select->where( "displayname LIKE '%$title%' or username LIKE '%$title%' or email LIKE '%$title%' " );
		}
		if ( !empty($this->_viewer_id)) {
			$select->where( 'user_id != ?', $this->_viewer_id );
		}
		$select->order('displayname ASC')->limit($limit);
		//FETCH RESULTS
		return $table->fetchAll($select);

	}


	public function getMaxAllowFileSizeByte() {

		if ( is_null($this->_maxAllowedFileSizeByte) ) {
			//select maximum upload size
			$max_upload = $this->return_bytes(ini_get('upload_max_filesize'));
			//select post limit
			$max_post = $this->return_bytes(ini_get('post_max_size'));
			//select memory limit
			$memory_limit = $this->return_bytes(ini_get('memory_limit'));
			// return the smallest of them, this defines the real limit
			$this->_maxAllowedFileSizeByte = min($max_upload, $max_post, $memory_limit);
		}
		return $this->_maxAllowedFileSizeByte;
	}


	public function getSiteuserkycsPaginator( User_Model_User $user, array $params = array() ) {
	
		if ( empty($user->getIdentity()) ) {
			throw new Exception( "Invalid User", 1 );
		}
		$params['user_id'] = $user->getIdentity();
		$paginator = Zend_Paginator::factory( $this->getSitekycsSelect( $params ) );
		if( !empty($params['page']) ) {
		  $paginator->setCurrentPageNumber($params['page']);
		}
		if( !empty($params['limit']) ) {
		  $paginator->setItemCountPerPage($params['limit']);
		}
		return $paginator;
	}


	public function getSitekycsSelect( array $params = array() ) {

		$table = $this->_engineApi->getDbtable('kycs', 'siteuserkyc');
		$select = $table->select();
		if( !empty($params['user_id']) ) {
		  $select->where( 'user_id = ?', $params['user_id'] );
		}
		if( !empty($params['search']) ) {
		  $select->where( "title LIKE  '" . '%' . $params['search'] . '%'."'");
		}
		if( !empty($params['limit']) ) {
		  $select->limit($params['limit']);
		}
		return $select;

	}


	public function sendDocumentSubmitMail( $object, $user ) {


		$view = Zend_Registry::get('Zend_View');
		$site_link = (_ENGINE_SSL ? 'https://' : 'http://') . $_SERVER['HTTP_HOST'];
		$userLink = '<a href="' . $site_link . $user->getHref() . '">' . $user->getTitle() . '</a>';
		$viewerLink = '<a href="' . $site_link . $this->_viewer->getHref() . '">' . $this->_viewer->getTitle() . '</a>';
		$click_here_link = '<a href="' . $site_link .  $view->url( array( 'module' => 'siteuserkyc', 'controller' => 'manage' ), 'admin_default', true ) . '">' . 'Click Here' . '</a>';

		$mailParams = array( 'site_kyc_verifier' => $userLink,
							 'username' => $viewerLink,
							 'click_here_link' => $click_here_link
							);
		/*$mailParams = array( 'host' => $_SERVER['HTTP_HOST'],
							'date' => time(),
							'sender_email' => $this->_viewer->email,
							'sender_title' => $this->_viewer->getTitle(),
							'sender_link' => $this->_viewer->getHref(),
							'sender_photo' => $this->_viewer->getPhotoUrl('thumb.icon'),
							'object_link' => $object->getHref(),
							'title' => $object->getTitle(),
						);*/

		$this->_engineApi->getApi('mail', 'core')->sendSystem($user->email, 'SITEUSERKYC_ON_UPLOAD_NEW_DOCUMENT', $mailParams);

	}


	//APROVED/ REJECTED EMAIL NOTIFICATION FOR CLASSIFEID
	public function aprovedEmailNotification($object, $message) {

		$user = $this->_engineApi->getItem('user', $object->user_id);
		$mailParams = array( 'host' => $_SERVER['HTTP_HOST'],
							 'date' => time(),
							 'sender_email' => $user->email,
							 'sender_title' => $user->getTitle(),
							 'sender_link' => $user->getHref(),
							 'sender_photo' => $user->getPhotoUrl('thumb.icon'),
							 'object_link' => $object->getHref(),
							 'title' => $object->getTitle(),
							 'status' => $message
							);
		$this->_engineApi->getApi('mail', 'core')->sendSystem($user->email, 'SITEUSERKYC_APPROVED_EMAIL_NOTIFICATION',$mailParams);

	}


}