<?php

class Siteuserkyc_AdminManageController extends Core_Controller_Action_Admin {

	protected $_engineApi = null;
    protected $_viewer = null;
    protected $_viewer_id = null;
	protected $_coreSetting = null;
	protected $_siteuserkyc = null;


	public function init() {

		$this->_engineApi = Engine_Api::_();
        $this->_viewer = $this->_engineApi->user()->getViewer();
        $this->_viewer_id = $this->_viewer->getIdentity();
		$this->_coreSetting = $this->_engineApi->getApi('settings', 'core');
		$this->_siteuserkyc = $this->_engineApi->siteuserkyc();
	}


	public function indexAction() {

        $this->view->canViewerVerify =  $this->_siteuserkyc->canUserVerifyKYCDocuments( $this->_viewer );
		$page = $this->_getParam('page', 1);
        $tableUserName = $this->_engineApi->getItemTable('user')->info('name');
        $kycTable = $this->_engineApi->getDbtable('kycs', 'siteuserkyc');
        $kycTableName = $kycTable->info('name');

        //MAKE QUERY
        $select = $kycTable->select()->setIntegrityCheck(false)->from($kycTableName)
                           ->where( "$kycTableName.verification = ?",1)
                           ->joinLeft($tableUserName, "$kycTableName.user_id = $tableUserName.user_id", '*')
                           ->group("$kycTableName.kyc_id");


        $values = $this->_getAllParams();
        unset($values['module']);
        unset($values['controller']);
        unset($values['action']);

        if ( !empty($values['search']) ) {

            if (!empty($values['displayname'])) {
                $select->where( $tableUserName . '.displayname  LIKE ?', '%' . $values['displayname'] . '%' );
            }
            if (!empty($values['username'])) {
                $select->where( $tableUserName . '.username  LIKE ?', '%' . $values['username'] . '%' );
            }
            if (!empty($values['email'])) {
                $select->where( $tableUserName . '.email  LIKE ?', '%' . $values['email'] . '%' );
            }
            if (!empty($values['level_id'])) {
                $select->where( $tableUserName . '.level_id  LIKE ?', '%' . $values['level_id'] . '%' );
            }
            if ( !empty($values['document_verification_status']) ) {
                $select->where($kycTableName . '.document_verification_status LIKE ? ', $values['document_verification_status'] );
            }
        }
        if ( empty($values['order']) ) {
            $values['order'] = 'kyc_id';
        }
        if ( empty($values['order_direction']) ) {
            $values['order_direction'] = 'DESC';
        }
        $select->order( $values['order'] . ' ' . $values['order_direction'] );
        $this->view->assign($values);
        $this->view->values = $values;
        //MAKE PAGINATOR
        $this->view->paginator = Zend_Paginator::factory($select);
        $this->view->paginator->setItemCountPerPage(20);
        $this->view->paginator = $this->view->paginator->setCurrentPageNumber($page);

	}


    //ACTION FOR MULTI-DELETE DOCUMENT
    public function multiDeleteAction() {

        if ( !$this->_siteuserkyc->canUserVerifyKYCDocuments( $this->_viewer ) ) {
            return $this->_forward('requireauth', 'error', 'core');
        }

        if ($this->getRequest()->isPost()) {
            $values = $this->getRequest()->getPost();
            foreach ($values as $key => $value) {
                if ($key == 'delete_' . $value) {
                    $kycDoc = $this->_engineApi->getItem('siteuserkyc_kyc', $value);
                    if ( !empty($kycDoc) ) {
                        $kycDoc->delete();
                    }
                }
            }
        }
        return $this->_helper->redirector->gotoRoute(array('action' => 'index'));

    }


	public function deleteAction() {

        if ( !$this->_siteuserkyc->canUserVerifyKYCDocuments( $this->_viewer ) ) {
            return $this->_forward('requireauth', 'error', 'core');
        }

        if ($this->getRequest()->isPost()) {
            $kyc_id = $this->getRequest()->getPost('delete_id');
            $kycDoc = $this->_engineApi->getItem('siteuserkyc_kyc', $kyc_id);
            if ( !empty($kycDoc) ) {
                $kycDoc->delete();
            }
            $this->_forward( 'success', 'utility', 'core', array( 'smoothboxClose' => 10, 'parentRefresh' => 10, 'messages' => array('Deleted Succesfully.') ) );
        }
        return $this->_helper->redirector->gotoRoute(array('action' => 'index'));
    }


    public function detailAction() {
        //GET THE ITEM
        $this->view->kycItem = $this->_engineApi->getItem('siteuserkyc_kyc', $this->_getParam('id'));
    }


    public function approvedAction() {

        if ( !$this->_siteuserkyc->canUserVerifyKYCDocuments( $this->_viewer ) ) {
            return $this->_forward('requireauth', 'error', 'core');
        }
    	$kycItem = $this->_engineApi->getItem('siteuserkyc_kyc', $this->_getParam('id'));
        if ( empty($kycItem) ) {
            return $this->_forward('notfound', 'error', 'core');
        }
        $owner = $this->_engineApi->getItem('user',$kycItem->user_id);
        $kycItem->document_verification_status = 'approved';
    	$kycItem->save();
        $notify = $this->_engineApi->getDbtable('notifications', 'activity');
        $notify->addNotification( $owner, $this->_viewer, $kycItem, 'siteuserkyc_approve_document', array( 'document' => $this->view->htmlLink( $this->view->url( array(), 'siteuserkyc_documents_manage', true ), 'document' ) ));
        //$this->_siteuserkyc->aprovedEmailNotification($kycItem, 'approved');
        if ( $this->_getParam('format') == 'smoothbox' ) {
            $this->_forward( 'success', 'utility', 'core', array( 'smoothboxClose' => 10, 'parentRefresh' => 10, 'messages' => array('Submitted Succesfully.') ) ); 
        } else {
            return $this->_helper->redirector->gotoRoute(array('action' => 'index'));
        }

    }


    public function rejectedAction() {

        if ( !$this->_siteuserkyc->canUserVerifyKYCDocuments( $this->_viewer ) ) {
            return $this->_forward('requireauth', 'error', 'core');
        }
    	$kycItem = $this->_engineApi->getItem('siteuserkyc_kyc', $this->_getParam('id'));
        if ( empty($kycItem) ) {
            return $this->_forward('notfound', 'error', 'core');
        }
        $owner = $this->_engineApi->getItem('user',$kycItem->user_id);
        $kycItem->document_verification_status = 'rejected';
    	$kycItem->save();
        $notify = $this->_engineApi->getDbtable('notifications', 'activity');
        $notify->addNotification( $owner, $this->_viewer, $kycItem, 'siteuserkyc_reject_document', array( 'document' => $this->view->htmlLink( $this->view->url( array(), 'siteuserkyc_documents_manage', true ), 'document' ) ));
        //$this->_siteuserkyc->aprovedEmailNotification($kycItem, 'rejected');

        if ( $this->_getParam('format') == 'smoothbox' ) {
            $this->_forward( 'success', 'utility', 'core', array( 'smoothboxClose' => 10, 'parentRefresh' => 10, 'messages' => array('Submitted Succesfully.') ) ); 
        } else {
            return $this->_helper->redirector->gotoRoute(array('action' => 'index'));
        }

    }

}