<?php

/**
 * SocialEngine
 *
 * @category   Application_Extensions
 * @package    Siteuserurl
 * @copyright  Copyright 2017-2022 BigStep Technologies Pvt. Ltd.
 * @license    http://www.socialengineaddons.com/license/
 * @version    $Id: Global.php 2017-03-28 9:40:21Z SocialEngineAddOns $
 * @author     SocialEngineAddOns
 */
class Siteuserurl_Form_Admin_Settings_Global extends Engine_Form
{
  public function init()
  {

    $this->setTitle('Global Settings')
      ->setDescription('These settings affect all members in your community.')
      ->setName('siteuserurl_global_settings');

    $settings = Engine_Api::_()->getApi('settings', 'core');

    $this->addElement('Radio', 'siteuserurl_enabled', array(
      'label' => 'User Profile URL',
      'description' => "Choose the User Profile URL format which you want to set on your website.",
      'multiOptions' => array(
        0 => 'Default',
        1 => 'Automatically shorten the User Profile URL. [Note: The shorten URL will appear as:
www.your_website.com/username.]',
        2 => "Add alternate text for 'profile' in the User Profile URL.",
        3 => 'Set User Profile URL based on member levels.',
      ),
      'onclick' => 'siteuserurlEnableType(this.value)',
      'value' => $settings->getSetting('siteuserurl.enabled', 1),
    ));

    $this->addElement('Text', 'siteuserurl_profileCustomUrl', array(
      'label' => "Alternate text for 'profile'",
      'allowEmpty' => false,
      'required' => true,
      'description' => "Please enter the text below which you want to add in place of 'profile' in the User Profile URLs. [Note: Default URL format is 'www.your_website.com/profile/username', it will change to 'www.your_website/NEW_PATH_URI/username' .]
",
      'value' => $settings->getSetting('siteuserurl.profileCustomUrl', "profile"),
    ));
    $levels = Engine_Api::_()->getItemTable('authorization_level')->select()
      ->order('level_id ASC')
      ->query()
      ->fetchAll();
    $options = array();
    foreach( $levels as $level ) {
      if( $level['type'] == 'public' ) {
        continue;
      }
      $options[$level['level_id']] = $level['title'];
    }

    foreach( $levels as $level ) {
      if( $level['type'] == 'public' ) {
        continue;
      }
      $this->addElement('MultiCheckbox', 'siteuserurl_profileSortUrlLevel', array(
        'description' => 'Enable Short User Profile URL for below selected member levels. [Note: Custom User Profile URL added by you in below settings will not reflect for the member levels enabled for Short User Profile URL.]',
        'label' => 'Enable Short URL',
        'multiOptions' => $options,
        'onclick' => 'siteuserurlShowCustomFileds(this.value, this.checked)',
        'value' => $settings->getSetting('siteuserurl.profileSortUrlLevel', array("withtags", "emotions", "userprivacy", "webcam", "postTarget", "schedulePost")),
      ));
      $this->addElement('Text', 'siteuserurl_profileUrlLevel_' . $level['level_id'], array(
        'label' => "Alternate text for 'profile' for " . $level['title'],
        'allowEmpty' => false,
        'required' => true,
        'description' => "Please enter the text below which you want to add in place of 'profile' in the User Profile URLs of " . $level['title'] . ". [Note: Default URL format is 'www.your_website.com/profile/username', it will change to 'www.your_website/NEW_PATH_URI/username' .]",
        'value' => $settings->getSetting('siteuserurl.profileUrlLevel.' . $level['level_id'], "profile"),
      ));
    }
    $this->addElement('Button', 'save', array(
      'label' => 'Save Changes',
      'type' => 'submit',
      'ignore' => true
    ));
  }

}
