<?php

class Siteuserurl_Plugin_Core extends Zend_Controller_Plugin_Abstract
{
  public function routeStartup(Zend_Controller_Request_Abstract $request)
  {
    $settings = Engine_Api::_()->getApi('settings', 'core');
    if( !$settings->getSetting('siteuserurl.enabled', 1) ) {
      return;
    }
    $route['user_profile_original'] = array(
      'route' => 'profile/:id/*',
      'defaults' => array(
        'module' => 'user',
        'controller' => 'profile',
        'action' => 'index'
      )
    );
    if( $settings->getSetting('siteuserurl.enabled', 1) == 2 ) {
      $route['user_profile'] = array(
        'route' => $settings->getSetting('siteuserurl.profileCustomUrl', "profile") . '/:id/*',
        'defaults' => array(
          'module' => 'user',
          'controller' => 'profile',
          'action' => 'index'
        )
      );
    } elseif( $settings->getSetting('siteuserurl.enabled', 1) == 3 ) {
      $levels = Engine_Api::_()->getItemTable('authorization_level')->select()
        ->query()
        ->fetchAll();
      foreach( $levels as $level ) {
        if( $level['type'] == 'public' ) {
          continue;
        }

        $route['user_profile_level_' . $level['level_id']] = array(
          'route' => $settings->getSetting('siteuserurl.profileUrlLevel.' . $level['level_id'], "profile") . '/:id/*',
          'defaults' => array(
            'module' => 'user',
            'controller' => 'profile',
            'action' => 'index'
          )
        );
      }
    }
    Zend_Registry::get('Zend_Controller_Front')->getRouter()->addConfig(new Zend_Config($route));
  }

  public function routeShutdown(Zend_Controller_Request_Abstract $request)
  {
    $settings = Engine_Api::_()->getApi('settings', 'core');
    $siteuserurlEnabled = $settings->getSetting('siteuserurl.enabled', 1);
    $profileSortUrlLevels = $settings->getSetting('siteuserurl.profileSortUrlLevel', array());
    if( !( $siteuserurlEnabled == 1 || ($siteuserurlEnabled == 3 && $profileSortUrlLevels) ) ) {
      return;
    }
    $shortProfileRoute = array(
      'route' => ':id/*',
      'defaults' => array(
        'module' => 'user',
        'controller' => 'profile',
        'action' => 'index'
      )
    );
    if( $siteuserurlEnabled == 1 ) {
      $route['user_profile'] = $shortProfileRoute;
    } else {
      foreach( $profileSortUrlLevels as $levelId ) {
        $route['user_profile_level_' . $levelId] = $shortProfileRoute;
      }
    }
    Zend_Registry::get('Zend_Controller_Front')->getRouter()->addConfig(new Zend_Config($route));

    // if url is admin based
    if( (substr($request->getPathInfo(), 1, 5) === "admin" ) ) {
      return;
    }

    $path = $request->getPathInfo();
    $pathArray = explode('/', trim($path, '/'));
    $customPath = $request->getModuleName() . '_' . $request->getControllerName() . "_" . $request->getActionName();
    // check if a core controller is in request
    $coreControllers = array('comment', 'cross-domain', 'error', 'help', 'index', 'like', 'link', 'pages', 'report', 'search', 'sitemap', 'tag', 'utility', 'widget');
    if( empty($pathArray) || (($customPath !== 'core_' . $pathArray[0] . '_index') && in_array($pathArray[0], $coreControllers)) ) {
      return;
    }
    $userTable = Engine_Api::_()->getItemTable('user');
    $select = $userTable->select();
    $id = $pathArray[0];
    if( is_numeric($id) ) {
      $select->where('user_id = ?', $id);
    } else {
      $select->where('username = ?', $id);
    }
    $userInfo = $userTable->fetchRow($select);
    if( $userInfo && ($siteuserurlEnabled == 1 || ($siteuserurlEnabled == 3 && in_array($userInfo->level_id, $profileSortUrlLevels))) ) {
      $request->setModuleName('user');
      $request->setControllerName('profile');
      $request->setActionName('index');
      $request->setParam("id", $id);
      $request->setParam("module", 'user');
      $request->setParam("controller", 'profile');
      $request->setParam("action", 'index');
      unset($pathArray[0]);
      for( $i = 1; $i <= count($pathArray); $i = $i + 2 ) {
        if( isset($pathArray[$i + 1]) ) {
          $request->setParam($pathArray[$i], $pathArray[$i + 1]);
        }
      }
    }
  }

}
