<?php

require APPLICATION_PATH . '/application/libraries/SEAO/aws/aws-autoloader.php';

use Aws\Common\Exception\MultipartUploadException;
use Aws\S3\MultipartUploader;
use Aws\S3\S3Client;

/**
 * SocialEngine
 *
 * @category   Application_Extensions
 * @package    Sitevod
 * @copyright  Copyright 2018-2019 BigStep Technologies Pvt. Ltd.
 * @license    http://www.socialengineaddons.com/license/
 * @version    $Id: 4.10.3 2018-09-08 00:00:00Z SocialEngineAddOns $
 * @author     SocialEngineAddOns
 */
class Sitevod_Service_S3 extends Storage_Service_S3
{

  protected $_schemeClass = 'Sitevod_Service_Scheme_Dynamic';

  /**
   * @var Zend_Service_Amazon_S3
   */
  protected $_sitevodConfig;

  public function __construct(array $config)
  {
    parent::__construct($config);
    $this->_sitevodConfig = $config;
  }

  public function getFilePath(Storage_Model_File $model)
  {
    return $this->getScheme()->generate($model->toArray());
  }

  /**
   * Stores a local file in the storage service
   *
   * @param Zend_Form_Element_File|array|string $file Temporary local file to store
   * @param array $params Contains iden
   * @return string Storage type specific path (internal use only)
   */
  public function store(Storage_Model_File $model, $file)
  {
    $path = $this->getScheme()->generate($model->toArray());

    // Prefix path with bucket?
    //$path = $this->_bucket . '/' . $path;
    // Copy file
    try {
      $this->uplaod($file, $path);
//      $return = $this->_internalService->putFile($file, $this->_bucket . '/' . $path, array(
//        Zend_Service_Amazon_S3::S3_ACL_HEADER => Zend_Service_Amazon_S3::S3_ACL_PUBLIC_READ,
//        'Cache-Control' => 'max-age=864000, public',
//      ));
//      if( !$return ) {
//        throw new Storage_Service_Exception('Unable to store file.');
//      }
    } catch( Exception $e ) {
      throw $e;
    }

    return $path;
  }

  public function uplaod($file, $path)
  {
//    print_r($this->_sitevodConfig);die;
    $this->_sitevodInternalService = new S3Client(array(
      'version' => 'latest',
      'region' => $this->_sitevodConfig['region'],
      'credentials' => array(
        'key' => $this->_sitevodConfig['accessKey'],
        'secret' => $this->_sitevodConfig['secretKey']
      ),
    ));

// Prepare the upload parameters.
    $uploader = new MultipartUploader($this->_sitevodInternalService, $file, array(
      'bucket' => $this->_bucket,
      'key' => $path
    ));

// Perform the upload.
    try {
      $result = $uploader->upload();
      if( empty($result['ObjectURL']) ) {
        throw new Storage_Service_Exception('Unable to store file.');
      }
//      echo "Upload complete: {$result['ObjectURL']}" . PHP_EOL;
    } catch( MultipartUploadException $e ) {
      throw new Storage_Service_Exception('Unable to store file.');
    }
  }

//
//  /**
//   * Stores a local file in the storage service
//   *
//   * @param Zend_Form_Element_File|array|string $file Temporary local file to store
//   * @param array $params Contains iden
//   * @return string Storage type specific path (internal use only)
//   */
//  public function upload($params, $file)
//  {
//    $path = $this->_generate($params);
//    // Prefix path with bucket?
//    //$path = $this->_bucket . '/' . $path;
//    // Copy file
//    try {
//      $return = $this->_internalService->putFile($file, $this->_bucket . '/' . $path, array(
//        Zend_Service_Amazon_S3::S3_ACL_HEADER => Zend_Service_Amazon_S3::S3_ACL_PUBLIC_READ,
//        'Cache-Control' => 'max-age=864000, public',
//      ));
//      if( !$return ) {
//        throw new Storage_Service_Exception('Unable to store file.');
//      }
//    } catch( Exception $e ) {
//      throw $e;
//    }
//
//    return $path;
//  }
}