<?php


/**
 * SocialEngine
 *
 * @category   Application_Extensions
 * @package    Siteyoutube
 * @copyright  Copyright 2015-2016 BigStep Technologies Pvt. Ltd.
 * @license    http://www.socialengineaddons.com/license/
 * @version    $Id: AdminSettingsController.php 2015-06-04 00:00:00Z SocialEngineAddOns $
 * @author     SocialEngineAddOns
 */
class Siteyoutube_AdminSettingsController extends Core_Controller_Action_Admin
{ 
  public function indexAction() {

    $this->view->navigation = $navigation = Engine_Api::_()->getApi('menus', 'core')
      ->getNavigation('siteyoutube_admin_main', array(), 'siteyoutube_admin_settings_index');

    //MAKE FORM
    $this->view->form = $form = new Siteyoutube_Form_Admin_Settings_Landingpage_Landing();

    // Check method/data
    if( !$this->getRequest()->isPost() ) {
      return;
    }
    if( !$form->isValid($this->getRequest()->getPost()) ) {
      return;
    }

    $coreSettings = Engine_Api::_()->getApi('settings', 'core');
    $values = $form->getValues();

    foreach( $values as $key => $value ) {
      if ( $coreSettings->hasSetting( $key, $value ) ) {
          $coreSettings->removeSetting($key);
      }
      $coreSettings->setSetting($key, $value);
    }
    $form->addNotice('Your changes have been saved.');

  }

  public function layoutAction()
  {
    $this->view->navigation = Engine_Api::_()->getApi('menus', 'core')->getNavigation('siteyoutube_admin_main', array(), 'siteyoutube_admin_theme_customiz');
    $this->view->subNavigation = Engine_Api::_()->getApi('menus', 'core')->getNavigation('siteyoutube_admin_theme_customiz', array(), 'siteyoutube_admin_layout_index');

    //MAKE FORM
    $this->view->form = $form = new Siteyoutube_Form_Admin_Settings_Layout();


    if( !$this->getRequest()->isPost() )
      return;

    if( !$form->isValid($this->getRequest()->getPost()) ) {
      return;
    }


    $values = $form->getValues();

    $fileName = 'siteyoutubeThemeGeneralConstants.css';
    $valuesWithPx = $values;
    $valuesWithPx['siteyoutube_layout_theme_width'] = $valuesWithPx['siteyoutube_layout_theme_width'].'px';
    $valuesWithPx['siteyoutube_layout_left_column_width'] = $valuesWithPx['siteyoutube_layout_left_column_width'].'px';
    $valuesWithPx['siteyoutube_layout_right_column_width'] = $valuesWithPx['siteyoutube_layout_right_column_width'].'px';
    $successfullySaved = Engine_Api::_()->getApi('customization', 'siteyoutube')->setConstants($valuesWithPx, $fileName);

    foreach( $values as $key => $value ) {
        Engine_Api::_()->getApi('settings', 'core')->setSetting($key, $value);
    }

    if( !empty($successfullySaved) ) {
      Core_Model_DbTable_Themes::clearScaffoldCache();

      $form->addNotice('Changes successfully saved. If changes not reflect to frontend then please change the mode to Development.');
    }
  }

  public function themesAction()
  {
    $this->view->navigation = Engine_Api::_()->getApi('menus', 'core')->getNavigation('siteyoutube_admin_main', array(), 'siteyoutube_admin_theme_customiz');
    $this->view->subNavigation = Engine_Api::_()->getApi('menus', 'core')->getNavigation('siteyoutube_admin_theme_customiz', array(), 'siteyoutube_admin_theme_customization_color');
    
    // Get themes
    $themes = $this->view->themes = Engine_Api::_()->getDbtable('themes', 'siteyoutube')->fetchAll();
    $activeTheme = $this->view->activeTheme = $themes->getRowMatching('active', 1);

    // Install any themes that are missing from the database table
    $reload_themes = false;
    foreach( glob(APPLICATION_PATH . '/application/themes/siteyoutube/*', GLOB_ONLYDIR) as $dir ) {
      if( file_exists("$dir/manifest.php") && is_readable("$dir/manifest.php") && file_exists("$dir/theme.css") && is_readable("$dir/theme.css") ) {
        $name = basename($dir);
        if( !$themes->getRowMatching('name', $name) ) {
          $meta = include("$dir/manifest.php");
          $row = $themes->createRow();
          // @todo meta key is deprecated and pending removal in 4.1.0; b/c removal in 4.2.0
          if( isset($meta['package']['meta']) ) {
            $meta['package'] = array_merge($meta['package']['meta'], $meta['package']);
            unset($meta['package']['meta']);
          }

          $row->title = $meta['package']['title'];
          $row->name = $name;
          $row->description = isset($meta['package']['description']) ? $meta['package']['description'] : '';
          $row->active = 0;
          $row->save();
          $reload_themes = true;
        }
      }
    }
    foreach( $themes as $theme ) {
      if( !is_dir(APPLICATION_PATH . '/application/themes/siteyoutube/' . $theme->name) ) {
        $theme->delete();
        $reload_themes = true;
      }
    }
    if( $reload_themes ) {
      $themes = $this->view->themes = Engine_Api::_()->getDbtable('themes', 'siteyoutube')->fetchAll();
      $activeTheme = $this->view->activeTheme = $themes->getRowMatching('active', 1);
      if( empty($activeTheme) ) {
        $themes->getRow(0)->active = 1;
        $themes->getRow(0)->save();
        $activeTheme = $this->view->activeTheme = $themes->getRowMatching('active', 1);
      }
    }

    // Process each theme
    $manifests = array();
    $writeable = array();
    $modified = array();
    $colorVariants = array();
    $hasLess = defined('_ENGINE_HAS_VENDOR') ? true : false;
    foreach( $themes as $key => $theme ) {
      // Get theme manifest
      $themePath = "application/themes/siteyoutube/{$theme->name}";
      $manifest = @include APPLICATION_PATH . "/$themePath/manifest.php";
      if( !is_array($manifest) ) {
        $manifest = array(
          'package' => array(),
          'files' => array()
        );
      }
      // sort($manifest['files']);
      // Pre-check manifest thumb
      // @todo meta key is deprecated and pending removal in 4.1.0; b/c removal in 4.2.0
      if( isset($manifest['package']['meta']) ) {
        $manifest['package'] = array_merge($manifest['package']['meta'], $manifest['package']);
        unset($manifest['package']['meta']);
      }

      if( !isset($manifest['package']['thumb']) ) {
        $manifest['package']['thumb'] = 'thumb.jpg';
      }
      $thumb = preg_replace('/[^A-Z_a-z-0-9\/\.]/', '', $manifest['package']['thumb']);
      if( file_exists(APPLICATION_PATH . "/$themePath/$thumb") ) {
        $manifest['package']['thumb'] = "$themePath/{$thumb}";
      } else {
        $manifest['package']['thumb'] = null;
      }

      // Check if theme files are writeable
      $writeable[$theme->name] = false;
      try {
        foreach( array_merge(array(''), $manifest['files']) as $key => $file ) {
          if( !file_exists(APPLICATION_PATH . "/$themePath/$file") ) {
            throw new Core_Model_Exception('Missing file in theme ' . $manifest['package']['title']);
          } else {
            $this->checkWriteable(APPLICATION_PATH . "/$themePath/$file");
          }
        }
        $writeable[$theme->name] = true;
      } catch( Exception $e ) {
        if( $activeTheme->name == $theme->name ) {
          $this->view->errorMessage = $e->getMessage();
        }
      }

      // Check if theme files have been modified
      $modified[$theme->name] = array();
      foreach( $manifest['files'] as $path ) {
        $originalName = 'original.' . $path;
        if( file_exists(APPLICATION_PATH . "/$themePath/$originalName") ) {
          if( file_get_contents(APPLICATION_PATH . "/$themePath/$originalName") != file_get_contents(APPLICATION_PATH . "/$themePath/$path") ) {
            $modified[$theme->name][] = $path;
          }
        }
      }

      // Child themes (color variants)
      if( isset($manifest['colorVariants']) ) {
        foreach( $manifest['colorVariants'] as $key => $val ) {
          $colorVariants[$key] = array(
            'version' => $manifest['package']['version'],
            'parentTheme' => $theme->name,
          );
        }
      }

      $manifests[$theme->name] = $manifest;
    }

    $this->view->manifest = $manifests;
    $this->view->writeable = $writeable;
    $this->view->modified = $modified;
    $this->view->colorVariants = $colorVariants;

    foreach( $manifests[$activeTheme->name]['files'] as $key => $file ) {
      if( substr($file, -5) == '.less' && !$hasLess ) {
        unset($manifests[$activeTheme->name]['files'][$key]);
      }
    }

    $manifests[$activeTheme->name]['files'] = array_values($manifests[$activeTheme->name]['files']); 

    //FETCH THE SEPERATE RESULTS TO SHOW THEM IN SEPERATE SECTIONS
    $this->view->customThemes = Engine_Api::_()->getDbtable('themes', 'siteyoutube')->getThemes(array('type' => 0, 'themeIdDesc' => true));
    $this->view->defaultLightThemes = Engine_Api::_()->getDbtable('themes', 'siteyoutube')->getThemes(array('type' => 1));
  }

  public function configurePagesAction() {
    $this->view->navigation = $navigation = Engine_Api::_()->getApi('menus', 'core')
      ->getNavigation('siteyoutube_admin_main', array(), 'siteyoutube_admin_configure_pages');

     
    $this->view->form = $form = new Siteyoutube_Form_Admin_Settings_Configure();

    if( $this->getRequest()->isPost() && $form->isValid($this->_getAllParams()) ) {
      $values = $form->getValues();
      
      foreach( $values as $key => $value ) {
        Engine_Api::_()->getApi('settings', 'core')->setSetting($key, $value);
      }
      $view = Zend_Registry::isRegistered('Zend_View') ? Zend_Registry::get('Zend_View') : null;
      $URL = $view->baseUrl() . '/admin/content';

      if ($values['siteyoutube_landing_page_layout']) {
        Engine_Api::_()->getApi('pagelayouts', 'siteyoutube')->setDefaultLayout($values);
      } else {
        Engine_Api::_()->getApi('pagelayouts', 'siteyoutube')->restorePageBackup(array('pageUrl' => 'landing_page_backup', 'name' => 'core_index_index'));
      }

      if ($values['siteyoutube_header_page_layout']) {
        Engine_Api::_()->getApi('pagelayouts', 'siteyoutube')->setHeaderLayout($values);
      } else {
        Engine_Api::_()->getApi('pagelayouts', 'siteyoutube')->restorePageBackup(array('pageUrl' => 'header_backup', 'name' => 'header'));
      }

      if ($values['siteyoutube_footer_page_layout']) {
        Engine_Api::_()->getApi('pagelayouts', 'siteyoutube')->setFooterLayout($values);
      } else {
        Engine_Api::_()->getApi('pagelayouts', 'siteyoutube')->restorePageBackup(array('pageUrl' => 'footer_backup', 'name' => 'footer'));
      }

      if ($values['siteyoutube_login_page_layout']) {
        Engine_Api::_()->getApi('pagelayouts', 'siteyoutube')->setSignInPageLayout($values);
      } else {
        Engine_Api::_()->getApi('pagelayouts', 'siteyoutube')->restorePageBackup(array('pageUrl' => 'user_auth_login_backup', 'name' => 'user_auth_login'));
      }

      if ($values['siteyoutube_login_required_page_layout']) {
        Engine_Api::_()->getApi('pagelayouts', 'siteyoutube')->setSignInRequiredPageLayout($values);
      } else {
        Engine_Api::_()->getApi('pagelayouts', 'siteyoutube')->restorePageBackup(array('pageUrl' => 'core_error_requireuser_backup', 'name' => 'core_error_requireuser'));
      }
      
      if ($values['siteyoutube_signup_page_layout']) {
        Engine_Api::_()->getApi('pagelayouts', 'siteyoutube')->setSignUpPageLayout($values);
      } else {
        Engine_Api::_()->getApi('pagelayouts', 'siteyoutube')->restorePageBackup(array('pageUrl' => 'user_signup_index_backup', 'name' => 'user_signup_index'));
      }
      $form->addNotice('Your changes have been saved. Please check your pages layout from <a href="' . $URL . '" target="_blank">here</a>.');
    }
  }

  public function activateAction() {
    //CHANGE LAYOUT OF HEADER,FOOTER,SIGNIN,SIGNUP AND LANDING PAGE
    Engine_Api::_()->getApi('pagelayouts', 'siteyoutube')->setDefaultLayout(array('siteyoutube_landing_page_layout' => 1));
    Engine_Api::_()->getApi('pagelayouts', 'siteyoutube')->setHeaderLayout(array('siteyoutube_header_page_layout' => 1));
    Engine_Api::_()->getApi('pagelayouts', 'siteyoutube')->setFooterLayout(array('siteyoutube_footer_page_layout' => 1));
    Engine_Api::_()->getApi('pagelayouts', 'siteyoutube')->setSignInPageLayout(array('siteyoutube_login_page_layout' => 1));
    Engine_Api::_()->getApi('pagelayouts', 'siteyoutube')->setSignInRequiredPageLayout(array('siteyoutube_login_required_page_layout' => 1));
    Engine_Api::_()->getApi('pagelayouts', 'siteyoutube')->setSignUpPageLayout(array('siteyoutube_signup_page_layout' => 1));

    $redirect = $this->_getParam('redirect', false);
    if( $redirect == 'install' ) {
      $this->_redirect('install/manage');
    } elseif( $redirect == 'query' ) {
      $this->_redirect('install/manage/complete');
    }
  }

  public function footerMenuAction()
  {
    $this->_redirect('admin/menus?name=core_footer');
  }

  public function signinPopupAction()
  {
    $this->view->navigation = $navigation = Engine_Api::_()->getApi('menus', 'core')
      ->getNavigation('siteyoutube_admin_main', array(), 'siteyoutube_admin_settings_signin_popup');

    $this->view->form = $form = new Siteyoutube_Form_Admin_Settings_SigninPopup();

    if( $this->getRequest()->isPost() && $form->isValid($this->_getAllParams()) ) {
      $values = $form->getValues();

      foreach( $values as $key => $value ) {
        Engine_Api::_()->getApi('settings', 'core')->setSetting($key, $value);
      }
      $form->addNotice('Your changes have been saved.');
    }
  }

  public function setOrderAction()
  {
    if( empty($_POST) || empty($_POST['order']) ) {
      return;
    }

    $item = $_POST['item'];
    foreach( $_POST['order'] as $key => $value ) {
      if( strstr($key, "content_") ) {
        $keyArray = explode("content_", $key);
        $itemId = end($keyArray);

        if( !empty($itemId) ) {
          $obj = Engine_Api::_()->getItem($item, $itemId);
          print_r($obj->toArray());
          $obj->order = $value;
          $obj->save();
        }
      }
    }
  }

  public function deleteAction()
  {

    $this->_helper->layout->setLayout('admin-simple');

    $this->view->id = $id = $this->_getParam('id');

    if( $this->getRequest()->isPost() ) {
      $item = Engine_Api::_()->getItem('siteyoutube_image', $id);

      $item->delete();
      $this->_forward('success', 'utility', 'core', array(
        'smoothboxClose' => 10,
        'parentRefresh' => 10,
        'messages' => array('Deleted Succesfully.')
      ));
    }
  }

  public function enabledAction()
  {
    $id = $this->_getParam('id');
    if( !empty($id) ) {
      $item = Engine_Api::_()->getItem('siteyoutube_image', $id);
      $item->enabled = !$item->enabled;
      $item->save();
    }

    $this->_redirect('admin/siteyoutube/settings/landing-images');
  }

  public function enabledBannersAction()
  {
    $id = $this->_getParam('id');
    if( !empty($id) ) {
      $item = Engine_Api::_()->getItem('siteyoutube_banner', $id);
      $item->enabled = !$item->enabled;
      $item->save();
    }

    $this->_redirect('admin/siteyoutube/settings/inner-images');
  }

  public function deleteBannersAction()
  {

    $this->_helper->layout->setLayout('admin-simple');

    $this->view->id = $id = $this->_getParam('id');

    if( $this->getRequest()->isPost() ) {
      $item = Engine_Api::_()->getItem('siteyoutube_banner', $id);

      $item->delete();
      $this->_forward('success', 'utility', 'core', array(
        'smoothboxClose' => 10,
        'parentRefresh' => 10,
        'messages' => array('Deleted Succesfully.')
      ));
    }
  }

  public function faqAction()
  {
    $this->view->navigation = Engine_Api::_()->getApi('menus', 'core')
      ->getNavigation('siteyoutube_admin_main', array(), 'siteyoutube_admin_settings_faq');
    $this->view->faq_id = $faq_id = $this->_getParam('faq', 'faq_1');
  }

  public function placeHtaccessFileAction()
  {
    if( $this->getRequest()->isPost() ) {
      $successfullyAdded = false;
      $getFileContent = '<FilesMatch ".(ttf|otf|woff)$">
    Header set Access-Control-Allow-Origin "*"
</FilesMatch>';

      $global_directory_name = APPLICATION_PATH . '/application/themes/siteyoutube';
      $global_settings_file = $global_directory_name . '/.htaccess';
      $is_file_exist = @file_exists($global_settings_file);

      // IF FILE NOT EXIST THEN CREATE NEW .HTACCESS FILE THERE.
      if( empty($is_file_exist) ) {
        if( is_dir($global_directory_name) ) {
          @mkdir($global_directory_name, 0777);

          $fh = @fopen($global_settings_file, 'w') or die('Unable to create .htaccess file; please give the CHMOD 777 recursive permission to the directory "' . APPLICATION_PATH . '/application/themes/siteyoutube' . '" and then try again.');
          @fwrite($fh, $getFileContent);
          @fclose($fh);

          @chmod($global_settings_file, 0777);
          $successfullyAdded = true;
        }
      } else {
        if( !is_writable($global_settings_file) ) {
          @chmod($global_settings_file, 0777);
          if( !is_writable($global_settings_file) ) {
            $form->addError('Unable to create .htaccess file; please give the CHMOD 777 recursive permission to the directory "' . APPLICATION_PATH . '/application/themes/siteyoutube' . '" and then try again.');
            return;
          }
        }
        $successfullyAdded = @file_put_contents($global_settings_file, $getFileContent);
      }

      if( !empty($successfullyAdded) ) {
        $this->_forward('success', 'utility', 'core', array(
          'smoothboxClose' => 10,
          'parentRefresh' => 10,
          'messages' => array('File Succesfully Created.')
        ));
      }
    }
  }

  public function placeCustomizationFileAction()
  {
    if( $this->getRequest()->isPost() ) {
      $global_directory_name = APPLICATION_PATH . '/application/themes/siteyoutube';
      @chmod($global_directory_name, 0777);

      if( !is_readable($global_directory_name) ) {
        $this->view->error_message = "<span style='color:red'>Note: You do not have readable permission on the path below, please give 'chmod 777 recursive permission' on it to continue with the installation process : <br /> 
Path Name: <b>" . $global_directory_name . "</b></span>";
        return;
      }

      $global_settings_file = $global_directory_name . '/customization.css';
      $is_file_exist = @file_exists($global_settings_file);
      if( empty($is_file_exist) ) {
        @chmod($global_directory_name, 0777);
        if( !is_writable($global_directory_name) ) {
          $this->view->error_message = "<span style='color:red'>Note: You do not have writable permission on the path below, please give 'chmod 777 recursive permission' on it to continue with the installation process : <br /> 
Path Name: " . $global_directory_name . "</span>";
          return;
        }

        $fh = @fopen($global_settings_file, 'w');
        @fwrite($fh, '/* ADD CUSTOM STYLE */');
        @fclose($fh);

        @chmod($global_settings_file, 0777);
      }

      $this->_forward('success', 'utility', 'core', array(
        'smoothboxClose' => 10,
        'parentRefresh' => 10,
        'messages' => array('File Succesfully Created.')
      ));
    }
  }

  //ACTION FOR MULTI-DELETE OF IMAGES
  public function multiDeleteAction()
  {

    if( $this->getRequest()->isPost() ) {

      $values = $this->getRequest()->getPost();

      foreach( $values as $key => $value ) {

        if( $key == 'delete_' . $value ) {

          $item = Engine_Api::_()->getItem('siteyoutube_image', $value);

          $item->delete();
        }
      }
    }
    return $this->_helper->redirector->gotoRoute(array('action' => 'images'));
  }

  //ACTION FOR MULTI-DELETE OF BANNERS
  public function multiDeleteBannersAction()
  {

    if( $this->getRequest()->isPost() ) {

      $values = $this->getRequest()->getPost();

      foreach( $values as $key => $value ) {

        if( $key == 'delete_' . $value ) {

          $item = Engine_Api::_()->getItem('siteyoutube_banner', $value);

          $item->delete();
        }
      }
    }
    return $this->_helper->redirector->gotoRoute(array('action' => 'banners'));
  }

  public function customCssAction()
  {
    $this->view->navigation = Engine_Api::_()->getApi('menus', 'core')->getNavigation('siteyoutube_admin_main', array(), 'siteyoutube_admin_theme_customiz');
    $this->view->subNavigation = Engine_Api::_()->getApi('menus', 'core')->getNavigation('siteyoutube_admin_theme_customiz', array(), 'siteyoutube_admin_settings_custom_css');
    $filePath = APPLICATION_PATH . '/application/themes/siteyoutube/customization.css';
    $isFileExist = @file_exists($filePath);

    $this->view->message = '';
    $this->view->sucess = false;

    if( empty($isFileExist) ) {
      $fh = @fopen($filePath, 'w') or die('Unable to write customization CSS file; please give the CHMOD 777 recursive permission to the directory /application/themes/siteyoutube/, then try again.');
      @fclose($fh);
    } elseif( !is_writable($filePath) ) {
      @chmod($filePath, 0777);
      if( !is_writable($filePath) ) {
        $this->view->message = 'Unable to write customization CSS file; please give the CHMOD 777 recursive permission to the directory /application/themes/siteyoutube/, then try again.';
        return;
      }
    }

    $this->view->fileContent = file_get_contents($filePath);

    // Check method/data
    if( !$this->getRequest()->isPost() ) {
      return;
    }

    if( !isset($_POST['siteyoutube_custom_css']) ) {
      return;
    }

    if( @file_put_contents($filePath, $_POST['siteyoutube_custom_css']) ) {
      @chmod($filePath, 0777);
      $this->view->message = 'Your changes have been saved.';
      $this->view->sucess = true;
    }
    $this->view->fileContent = $_POST['siteyoutube_custom_css'];
  } 
}
