<?php

/**
 * SocialEngine
 *
 * @category   Application_Core
 * @package    Install
 * @copyright  Copyright 2006-2010 Webligo Developments
 * @license    http://www.socialengine.com/license/
 * @version    $Id: SdkController.php 9747 2012-07-26 02:08:08Z john $
 * @author     John
 */
/**
 * @category   Application_Core
 * @package    Install
 * @copyright  Copyright 2006-2010 Webligo Developments
 * @license    http://www.socialengine.com/license/
 */
require_once 'SdkController.php';

class SeaoSdkController extends SdkController
{

	public function init()
	{
		// Check if already logged in
		if( !Zend_Registry::get('Zend_Auth')->getIdentity() ) {
			return $this->_helper->redirector->gotoRoute(array(), 'default', true);
		}

		// temporary package folder path
		$tempPackagePath = APPLICATION_PATH . DIRECTORY_SEPARATOR . 'temporary'
			. DIRECTORY_SEPARATOR . 'package' . DIRECTORY_SEPARATOR;
		// path to store tar files
		$this->_outputPath = $tempPackagePath . 'seao-sdk';
		// path to store created zip files on local
		$this->_pluginZips = $tempPackagePath . 'plugin-zips';

		//Create the output folder if not exists
		if( !is_dir($this->_outputPath) ) {
			mkdir($this->_outputPath);
		}
		//Create the plugin zip folder if not exists
		if( !is_dir($this->_pluginZips) ) {
			mkdir($this->_pluginZips);
		}
		shell_exec("chmod -R 0777 " . $this->_outputPath);
		shell_exec("chmod -R 0777 " . $this->_pluginZips);

		if( !is_writable($this->_outputPath) ) {
			throw new Engine_Exception(sprintf('Package output path "%s" is not writable. Please create and chmod 777.', $this->_outputPath));
		}
		if( !is_writable($this->_pluginZips) ) {
			throw new Engine_Exception(sprintf('Zip folder path "%s" is not writable. Please create and chmod 777.', $this->_pluginZips));
		}
	}

	public function buildAction()
	{
		$availablePackages = array();

    $ignorePackages  = array(
      'externals' => array(),
      'languages' => array(),
      'libraries' => array(),
      'modules' => array('seaocore', 'sitehashtag', 'sitetagcheckin'),
      'plugins' => array(),
      'themes' => array(),
      'widgets' => array(),
    );
		// Iterate over types
		foreach( $this->_getStructure() as $type => $info ) {
      if (in_array($type, array('themes'))) {
        continue;
      }
			// Get current path and list of dirs
			$path = APPLICATION_PATH . DIRECTORY_SEPARATOR . str_replace(array('/', '\\'), DIRECTORY_SEPARATOR, trim($info['path'], '/\\'));

			$dirs = scandir($path);
			foreach( $dirs as $dir ) {
				$dirPath = $path . DIRECTORY_SEPARATOR . $dir;
				if( $dir[0] == '.' || !is_dir($dirPath) ) {
					continue;
				}

				// Get manifest data
				$manifestPath = $dirPath . DIRECTORY_SEPARATOR . str_replace(array('/', '\\'), DIRECTORY_SEPARATOR, trim($info['manifest']));
				$manifestData = include $manifestPath;
				//There are some unusefull files, like languages folder and externals folder, we can skip them here, they create empty row with checkbox
				if(empty($manifestData['package']['name'])){
					continue;
				}
        if (!empty($ignorePackages[$type]) && in_array($manifestData['package']['name'], $ignorePackages[$type])) {
        continue;
      }
				$availablePackages[] = array(
					'type' => $manifestData['package']['type'],
					'name' => $manifestData['package']['name'],
					'guid' => $manifestData['package']['type'] . '-' . $manifestData['package']['name'],
					'key' => $manifestData['package']['type'] . '-' . $manifestData['package']['name'] . '-' . $manifestData['package']['version'],
					'manifestPath' => $manifestPath,
					'manifest' => $manifestData,
				);
			}
			//} // END IF ACTION
		} // END STRUCTURE
		// Fiter out ours
		$buildPackages = array();
		foreach( $availablePackages as $availablePackage ) {
			if( empty($availablePackage['manifest']['package']['author']) ||
				$availablePackage['manifest']['package']['author'] != 'Webligo Developments' ||
				$this->_includeNative ) {
				$buildPackages[] = $availablePackage;
			}
		}
		$this->view->buildPackages = $buildPackages;

		// return if not post
		if( !$this->getRequest()->isPost() ) {
			return;
		}

		// BUILD!
		$selected = $this->_getParam('build');
		if( empty($selected) ) {
			$this->view->error = 'No package selected.';
			return;
		}
		// Check if selected exist
		$toBuildPackages = array();
		foreach( $buildPackages as $buildPackage ) {
			if( in_array($buildPackage['key'], $selected) ) {
				$toBuildPackages[] = $buildPackage;
			}
		}
		if( empty($toBuildPackages) ) {
			$this->view->error = 'No valid package selected.';
			return;
		}
		//MAKE THE DIRECTORY EMPTY BEFORE CREATION OF NEW PACKAGES
		$this->emptyDirectory($this->_outputPath);
		// Build 'em
		foreach( $toBuildPackages as $toBuildPackage ) {
			try {
				$title = $toBuildPackage['manifest']['package']['title'];
				//IF THE SHORT TITLE IS DEFINED THAN TAKE IT
				if( !empty($toBuildPackage['manifest']['package']['shortTitle']) ) {
					$title = $toBuildPackage['manifest']['package']['shortTitle'];
				}
				$version = $toBuildPackage['manifest']['package']['version'];
				$name = $toBuildPackage['name'];
				$pluginsInfo[$toBuildPackage['key'] . '.tar'] = array('name' => $name, 'title' => $title, 'version' => $version);
				$this->_buildPackage($toBuildPackage['manifestPath']);
			} catch( Exception $e ) {
				$this->view->error = $e->getMessage();
				return;
			}
		}

		$this->view->status = true;
		$this->_forward('confirm', 'seao-sdk', 'default', array('pluginInfo' => urlencode(serialize($pluginsInfo)), 'confirmOnly' => true));
	}

	public function confirmAction()
	{
		$params = $this->_getAllParams();

		$this->view->status = false;
		if( !empty($params['pluginsInfoOld']) ) {
			//PLUGINS INFO STORED TO COMPARE WITH CONFIRMED PLUGINS
			$pluginsInfo = $params['pluginsInfoOld'];
		} else {
			$pluginsInfo = $params['pluginInfo'];
		}
		$this->view->pluginsInfoOld = $pluginsInfo;
		$this->view->pluginsInfo = $pluginsInfo = unserialize(urldecode($pluginsInfo));
		$this->view->buildConfirm = array();
		// return if not post

		if( !empty($params['confirmOnly']) ) {
			return;
		}

		$this->view->buildConfirm = $buildConfirm = $this->_getParam('buildConfirm');

		if( empty($buildConfirm) ) {
			$this->view->error = 'No package selected for confirmation.';
			return;
		}
		foreach( $pluginsInfo as $key => $value ) {
			if( !in_array($key, $buildConfirm) ) {
				unset($pluginsInfo[$key]);
			}
		}

		$allTarFiles = scandir($this->_outputPath);
		$configFilePath = APPLICATION_PATH . DIRECTORY_SEPARATOR . 'install' . DIRECTORY_SEPARATOR . 'seao-config/remote-urls.php';
      if( !file_exists($configFilePath) ) {
      $configFilePath = APPLICATION_PATH . DIRECTORY_SEPARATOR . 'install' . DIRECTORY_SEPARATOR . 'seao-config/urls.php';
    }
    $urls = include $configFilePath;
		foreach( $allTarFiles as $name ) {

			$zipFilesDestination = $urls['destinationUrl'];
			if( $name === '.' || $name === '..' ) {
				continue;
			}
 
			if( !in_array($name, $buildConfirm) ) {
				//DELETE THE TAR FILE IF YOU DO NOT WANT TO UPGRADE THE RELATED PLUGIN
				unlink($this->_outputPath . '/' . $name);
				continue;
			}
			$currentWorkDir = getcwd();
			//REPLACE SPECIAL CHARACTER WITH SPACE
			$pluginTitle = preg_replace('/[^a-zA-Z0-9_.]/', " ", $pluginsInfo[$name]['title']);
			//REPLACE BLANK SPACES WITH SIGNLE SPACE
			$pluginsInfo[$name]['zipName'] = $folderForZipFile = strtolower(str_replace(" ", "_", trim(preg_replace('!\s+!', ' ', $pluginTitle))))."_".$pluginsInfo[$name]['version'];

			$zipFileCreationDir = $this->_pluginZips . "/" . $folderForZipFile;

			shell_exec("mkdir " . $zipFileCreationDir);
			shell_exec("chmod -R 0777 " . $zipFileCreationDir);

			shell_exec("cp -f common/install.html " . $zipFileCreationDir);
			shell_exec("cp -f common/license.html " . $zipFileCreationDir);

			$installHtmlFile = $zipFileCreationDir . '/install.html';
			$licenseHtmlFile = $zipFileCreationDir . '/license.html';
			shell_exec("chmod -R 0777 " . $zipFileCreationDir);
			
			$this->replaceTitleInFile($installHtmlFile, $pluginTitle);
			$this->replaceTitleInFile($licenseHtmlFile, $pluginTitle);
			$zipFile = rtrim($zipFilesDestination) . "/" . $folderForZipFile . ".zip";
			//some themes tar file names comes with spaces, that create problem in comamnd, we have to remove those spaces and than we'll run command 
			$pluginsInfo[$name]['tarName'] = $nameWithoutSpaces = preg_replace('/\s+/', '', $name);
			rename($this->_outputPath . "/" . $name, $this->_outputPath . "/" . $nameWithoutSpaces);
			shell_exec("cp -f " . $this->_outputPath . "/" . $nameWithoutSpaces . " " . rtrim($zipFilesDestination) . "/");
			shell_exec("cp -f " . $this->_outputPath . "/" . $nameWithoutSpaces . " " . $zipFileCreationDir);
			$tarFile = rtrim($zipFilesDestination) . "/" . $nameWithoutSpaces;
			
			chdir($zipFileCreationDir);
			shell_exec("zip -r " . $zipFile . " *");
			shell_exec("rm -rf " . $zipFileCreationDir);
			chmod($zipFile, 0777);
			shell_exec("chmod -R 0777 " . rtrim($zipFilesDestination) . "/");
			$pluginsInfo[$name]['addedZip'] = (int) file_exists($zipFile);
			$pluginsInfo[$name]['addedTar'] = (int) file_exists($tarFile);
			$pluginsInfo[$name]['upgraded'] = $pluginsInfo[$name]['addedTar'] && $pluginsInfo[$name]['addedZip'];
			chdir($currentWorkDir);
      unlink($this->_outputPath . "/" . $nameWithoutSpaces);
		}
		//PACKAGES AFTER CONFIRM
		$this->view->pluginsInfo = $pluginsInfo;

		$infoUrl = $urls['infoUrl'];
		//SEND THE DETAILS OF UPGRADED PLUGINS TO ADDONS URL
    try {
      Zend_Feed::setHttpClient(new Zend_Http_Client(null, array('timeout' => 60, 'adapter' => 'Zend_Http_Client_Adapter_Curl')));
      $client = Zend_Feed::getHttpClient()
        ->setMethod(Zend_Http_Client::POST)
        ->setUri($infoUrl);
      $client->setParameterPost(array('pluginUpgradeRequest' => $pluginsInfo));
      $response = $client->request();
      $responseData = Zend_Json::decode($response->getBody(), Zend_Json::TYPE_ARRAY);
    } catch( Exception $e ) {
      
    }
    $this->view->status = true;
	}

	private function emptyDirectory($directory)
	{
		foreach( scandir($directory) as $file ) {
			shell_exec("chmod -R 0777 " . $file);
			if( $file != '.' && $file != '..' ) {
				if( is_dir($directory . '/' . $file) ) {
					if( !rmdir($directory . '/' . $file) ) {
						$this->emptyDirectory($directory . '/' . $file);
					}
					rmdir($directory . '/' . $file);
				} else {
					unlink($directory . '/' . $file);
				}
			}
		}
	}

	private function replaceTitleInFile($filePath, $title)
	{
		$replace = "SEAO_PRODUCT_TITLE";
		$content = file_get_contents($filePath);
		$content = str_replace("$replace", "$title", $content);
		file_put_contents($filePath, $content);
	}

      protected function _buildPackage($manifest, $date = null)
    {
      $temparyManifestPath;
      if (is_string($manifest)) {
          $browser = file_get_contents($manifest);

          $temparyManifestPath = APPLICATION_PATH . DS . 'temporary' . DS . 'package' . DS . md5(time()).'-manifest.php';
          shell_exec("cp -f " . $manifest . " ".$temparyManifestPath);
          if (strpos($browser, 'sku') !== false) {
            $browser =preg_replace('/sku/', 'seao-sku', $browser, 1);
            file_put_contents($manifest, $browser);
            chmod($manifest, 0777);
        }

      }

        if (null === $date) {
            $date = time();
        }
        // Get manifest data
        if (is_string($manifest)) {
            $manifestData = require $manifest;
            if (empty($manifestData['package'])) {
                throw new Exception(sprintf('Missing package data for package in path: %s', $manifestPath));
            }
            $manifestData = $manifestData['package'];

        } elseif (is_array($manifest)) {
            $manifestData = $manifest;
        } else {
            throw new Exception('Invalid manifest data type');
        }

        // Override date (for now at least)
        $manifestData['date'] = $date;
        if (isset($manifestData['sku'])) {
          unset($manifestData['sku']);
        }
        // Build package file
        $package = new Engine_Package_Manifest($manifestData);

        // Build archive
        $archiveFile = Engine_Package_Archive::deflate($package, $this->_outputPath);

        // Verify archive for integrity
        $extractedPath = Engine_Package_Archive::inflate($archiveFile, $this->_outputPath);
        $loaded = new Engine_Package_Manifest($extractedPath);

        // Remove verified archive
        Engine_Package_Utilities::fsRmdirRecursive($extractedPath, true);
        if ($temparyManifestPath) {
        	shell_exec("cp -f " . $temparyManifestPath . "  " . $manifest);
          unlink($temparyManifestPath);
        }
        return $archiveFile;
    }

}