<?php

/**
 * SocialEngine
 *
 * @category   Application_Extensions
 * @package    Phpfoximporter
 * @copyright  Copyright 2015-2016 BigStep Technologies Pvt. Ltd.
 * @license    http://www.socialengineaddons.com/license/
 * @version    BlogSitereviewListings.php 2015-07-30 00:00:00Z SocialEngineAddOns $
 * @author     SocialEngineAddOns
 */
class Install_Import_Phpfox_BlogSitereviewListings extends Install_Import_Phpfox_Abstract {

    protected $_fromTable = '';
    protected $_toTable = '';
    protected $_priority = 5000;
    protected $_warningMessage = array();

    protected function _initPre() {
        $this->_fromTable = $this->getFromPrefix() . 'blog';
        $this->_toTable = 'engine4_sitereview_listings';
        $this->_warningMessage = array("key" => 'escape', 'value' => '');
    }

    protected function _translateRow(array $data, $key = null) {

        //RETURN FALSE IF USER NOT SELECTED TO INSERT DATA INSIDE THE SOCIAL ENGINE ADDON BLOG LISTING
        if ($this->getParam('import_blog_seblog') == 1 || $data['module_id'] == 'pages')
            return false;
        // FIND PAGE TYPE ID
        $type_id = $this->getFromDb()->select()
                ->from($this->getfromPrefix() . 'blog', null)
                ->join($this->getfromPrefix() . 'pages', $this->getfromPrefix() . 'pages.page_id=' . $this->getfromPrefix() . 'blog.item_id', 'type_id')
                ->where($this->getfromPrefix() . 'blog.blog_id = ?', $data['blog_id'])
                ->query()
                ->fetchColumn();

        //GET LISTINGTYPE ID
        $listingtype_id = $this->getParam('listingtypes');

        if ($listingtype_id == 0)
            return false;

        $newData = array();

        //GETTING CATEGORY ID
        $category_id = $this->getFromDb()->select()
                ->from($this->getfromPrefix() . 'blog_category_data', 'category_id')
                ->where('blog_id = ?', $data['blog_id'])
                ->query()
                ->fetchColumn();

        //GETTING CATEGORY NAME
        $category_name = $this->getFromDb()->select()
                ->from($this->getfromPrefix() . 'blog_category', 'name')
                ->where('category_id = ?', $category_id)
                ->query()
                ->fetchColumn();

        //GET SE CATEGORY ID
        $se_category_id = $this->getToDb()->select()
                ->from('engine4_sitereview_categories', 'category_id')
                ->where('category_name = ?', $category_name)
                ->query()
                ->fetchColumn();


        //GETTING TEXT
        $text = $this->getFromDb()->select()
                ->from($this->getfromPrefix() . 'blog_text', 'text')
                ->where('blog_id = ?', $data['blog_id'])
                ->query()
                ->fetchColumn();

        if (is_null($text) || $text === false)
            $text = '';

        $userInfo = array(
            'user_id' => $data['user_id'],
            'time_stamp' => $data['time_stamp'],
            'text' => $text,
            'item_id' => $data['blog_id'],
            'album_title' => 'Blog Photos',
            'album_type' => 'blog',
            'categoryId' => 'blog'
        );
        //FIND THE BODY
        $body = $this->getBody($userInfo);
        if (is_null($body))
            $body = '';

        //MAKING BLOG ARRAY FOR INSERTION
        $newData['title'] = $data['title'];
        $newData['body'] = $body;
        $newData['owner_id'] = $data['user_id'];
        $newData['listingtype_id'] = $listingtype_id;
        if ($this->_columnExist('engine4_sitereview_listings', 'package_id'))
            $newData['package_id'] = 1;
        $newData['profile_type'] = 0;
        $newData['approved'] = 1;
        $newData['creation_date'] = $this->_translateTime($data['time_stamp']);
        $newData['approved_date'] = $this->_translateTime($data['time_stamp']);
        if ($data['time_update']) {
            $newData['modified_date'] = $this->_translateTime($data['time_update']);
        } else {
            $newData['modified_date'] = $this->_translateTime($data['time_stamp']);
        }
        $newData['view_count'] = $data['total_view'];
        $newData['comment_count'] = $data['total_comment'];
        $newData['like_count'] = $data['total_like'];
        $newData['search'] = $data['is_approved'];
        if ($data['post_status'] == 1) {
            $newData['draft'] = 0;
        } else {
            $newData['draft'] = 1;
        }
        $newData['category_id'] = $se_category_id;
        if ($this->_columnExist('engine4_sitereview_listings', 'pending'))
            $newData['pending'] = 0;

        //INSERTION OF BLOG LISTING
        $this->getToDb()->insert($this->getToTable(), $newData);
        $sitereviewIdentity = $this->getToDb()->lastInsertId();
        //MAPPING THE BLOG
        $this->setSitereviewMap('blog', $data['blog_id'], $sitereviewIdentity);
        //PRIVACY
        try {
            $this->_insertPrivacy('sitereview_listing', $sitereviewIdentity, 'view', $this->_translateBlogPrivacy($data['privacy']));
            $this->_insertPrivacy('sitereview_listing', $sitereviewIdentity, 'comment', $this->_translateBlogPrivacy($data['privacy_comment']));
            $this->_insertPrivacy('sitereview_listing', $sitereviewIdentity, "view_listtype_$listingtype_id", $this->_translateBlogPrivacy($data['privacy']));
            $this->_insertPrivacy('sitereview_listing', $sitereviewIdentity, "comment_listtype_$listingtype_id", $this->_translateBlogPrivacy($data['privacy_comment']));
            $this->_insertPrivacy('sitereview_listing', $sitereviewIdentity, "photo_listtype_$listingtype_id", $this->_translateBlogPrivacy(0));
            $this->_insertPrivacy('sitereview_listing', $sitereviewIdentity, "video_listtype_$listingtype_id", $this->_translateBlogPrivacy(0));
            $this->_insertPrivacy('sitereview_listing', $sitereviewIdentity, "event_listtype_$listingtype_id", $this->_translateBlogPrivacy(0));
            $this->_insertPrivacy('sitereview_listing', $sitereviewIdentity, "topic_listtype_$listingtype_id", $this->_translateBlogPrivacy(0));
        } catch (Exception $e) {
            $this->_error('Problem adding privacy options for object id ' . $sitereviewIdentity . ' : ' . $e->getMessage());
        }
        $otherInfoData = array();
        $otherInfoData['listing_id'] = $sitereviewIdentity;
        if (strpos($body, '<img src="') !== FALSE)
            $otherInfoData['overview'] = $body;
        //INSERT BLOGLISTING OTHER INFO
        $this->getToDb()->insert('engine4_sitereview_otherinfo', $otherInfoData);

        //SEARCH
        if (@$newData['search']) {
            $this->_insertSearch('sitereview_listing', $sitereviewIdentity, @$newData['title'], @$newData['body']);
        }

        return false;
    }

}

/*
CREATE TABLE IF NOT EXISTS `phpfox_blog` (
  `blog_id` int(10) unsigned NOT NULL AUTO_INCREMENT,
  `user_id` int(10) unsigned NOT NULL,
  `title` varchar(255) NOT NULL,
  `time_stamp` int(10) unsigned NOT NULL,
  `time_update` int(10) unsigned NOT NULL DEFAULT '0',
  `is_approved` tinyint(1) NOT NULL,
  `privacy` tinyint(1) NOT NULL DEFAULT '0',
  `privacy_comment` tinyint(1) NOT NULL DEFAULT '0',
  `post_status` tinyint(1) NOT NULL,
  `total_comment` int(10) unsigned NOT NULL DEFAULT '0',
  `total_attachment` int(10) unsigned NOT NULL DEFAULT '0',
  `total_view` int(10) unsigned NOT NULL DEFAULT '0',
  `total_like` int(10) unsigned NOT NULL DEFAULT '0',
  `total_dislike` int(10) unsigned NOT NULL DEFAULT '0',
  `module_id` varchar(75) NOT NULL DEFAULT 'blog',
  `item_id` int(10) unsigned NOT NULL DEFAULT '0',
  PRIMARY KEY (`blog_id`),
  KEY `public_view` (`is_approved`,`privacy`,`post_status`),
  KEY `user_id_2` (`user_id`,`is_approved`,`privacy`,`post_status`),
  KEY `time_stamp` (`time_stamp`,`is_approved`,`privacy`,`post_status`),
  KEY `user_id` (`user_id`,`time_stamp`,`is_approved`,`privacy`,`post_status`),
  KEY `title` (`title`,`is_approved`,`privacy`,`post_status`)
) ENGINE=MyISAM  DEFAULT CHARSET=latin1 AUTO_INCREMENT=1;
 */

/*
CREATE TABLE IF NOT EXISTS `phpfox_blog_category_data` (
  `blog_id` int(10) unsigned NOT NULL,
  `category_id` int(10) unsigned NOT NULL,
  KEY `blog_id` (`blog_id`),
  KEY `category_id` (`category_id`)
) ENGINE=MyISAM DEFAULT CHARSET=latin1;
 */

/*
CREATE TABLE IF NOT EXISTS `phpfox_blog_text` (
  `blog_id` int(10) unsigned NOT NULL,
  `text` mediumtext,
  `text_parsed` mediumtext,
  PRIMARY KEY (`blog_id`)
) ENGINE=MyISAM DEFAULT CHARSET=latin1;
 */

/*
CREATE TABLE IF NOT EXISTS `engine4_blog_blogs` (
  `blog_id` int(11) unsigned NOT NULL AUTO_INCREMENT,
  `title` varchar(128) COLLATE utf8_unicode_ci NOT NULL,
  `body` longtext COLLATE utf8_unicode_ci NOT NULL,
  `owner_type` varchar(64) CHARACTER SET latin1 COLLATE latin1_general_ci NOT NULL,
  `owner_id` int(11) unsigned NOT NULL,
  `category_id` int(11) unsigned NOT NULL DEFAULT '0',
  `creation_date` datetime NOT NULL,
  `modified_date` datetime NOT NULL,
  `view_count` int(11) unsigned NOT NULL DEFAULT '0',
  `comment_count` int(11) unsigned NOT NULL DEFAULT '0',
  `search` tinyint(1) NOT NULL DEFAULT '1',
  `draft` tinyint(1) unsigned NOT NULL DEFAULT '0',
  PRIMARY KEY (`blog_id`),
  KEY `owner_type` (`owner_type`,`owner_id`),
  KEY `search` (`search`,`creation_date`),
  KEY `owner_id` (`owner_id`,`draft`),
  KEY `draft` (`draft`,`search`)
) ENGINE=InnoDB  DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci AUTO_INCREMENT=1 ;
 */