<?php

/**
 * SocialEngine
 *
 * @category   Application_Extensions
 * @package    Phpfoximporter
 * @copyright  Copyright 2015-2016 BigStep Technologies Pvt. Ltd.
 * @license    http://www.socialengineaddons.com/license/
 * @version    EventSiteevents.php 2015-07-30 00:00:00Z SocialEngineAddOns $
 * @author     SocialEngineAddOns
 */
class Install_Import_Phpfox_EventSiteevents extends Install_Import_Phpfox_Abstract {

    protected $_fromTable = '';
    protected $_toTable = '';
    protected $_warningMessage = array();

    protected function _initPre() {
        $this->_fromTable = $this->getFromPrefix() . 'event';
        $this->_toTable = 'engine4_siteevent_events';
        $this->_warningMessage = array("key" => 'escape', 'value' => '');
    }

    //protected $_fromWhere = array('module_id=?' => 'event');
    protected function _translateRow(array $data, $key = null) {

        //RETURN FALSE IF USER NOT SELECTED TO INSERT DATA INSIDE THE SOCIAL ENGINE ADDON ADVANCED EVENT PLUGIN
        if ($this->getParam('import_event_seevent', 1) == 1)
            return false;

        $parent_type = 'user';
        $parent_id = $data['user_id'];

        //GET TYPE ID
        if ($data['module_id'] == 'pages') {
            $type_id = $this->getFromDb()->select()
                    ->from($this->getfromPrefix() . 'pages', 'type_id')
                    ->where('page_id = ?', $data['item_id'])
                    ->query()
                    ->fetchColumn();

            if ($type_id == 3 && ($this->getParam('import_group_segroup', 1) == 1)) {
                $parent_type = 'group';
                $parent_id = $data['item_id'];
            } else {
                return false;
            }
        }

        //GET CATGEORY ID
        $category_id = $this->getFromDb()->select()
                ->from($this->getfromPrefix() . 'event_category_data', 'category_id')
                ->where('event_id = ?', $data['event_id'])
                ->query()
                ->fetchColumn();

        //GET DESCRIPTION
        $description = $this->getFromDb()->select()
                ->from($this->getfromPrefix() . 'event_text', 'description_parsed')
                ->where('event_id = ?', $data['event_id'])
                ->query()
                ->fetchColumn();

        //MAKING EVENT ARRAY FOR INSERTION
        $newData = array();
        $newData['event_id'] = $data['event_id'];
        $newData['title'] = $data['title'];
        $newData['body'] = $description ? $description : '';
        $newData['approved'] = 1;
        $newData['category_id'] = $category_id;
        $newData['host_type'] = 'user';
        $newData['host_id'] = $newData['owner_id'] = $data['user_id'];
        $newData['parent_type'] = $parent_type;
        $newData['parent_id'] = $parent_id;
        $newData['creation_date'] = $this->_translateTime($data['time_stamp']);
        $newData['modified_date'] = $this->_translateTime($data['time_stamp']);
        $newData['location'] = $data['location'];
        $newData['location'] = empty($data['city']) ? ($data['country_iso']) : ($data['city'] . "," . $data['country_iso']);
        $newData['featured'] = $data['is_featured'];
        $newData['sponsored'] = $data['is_sponsor'];
        $newData['comment_count'] = $data['total_comment'];
        $newData['like_count'] = $data['total_like'];

        //INSERTING INTO LIST TABLE
        $this->getToDb()->insert('engine4_siteevent_lists', array(
            'owner_id' => $data['event_id'],
            'title' => 'SITEEVENT_LEADERS'
        ));
        $list_id = $this->getToDb()->lastInsertId();

        if ($type_id) {
            //GETTING THE PRIVACY
            $perms = $this->getFromDb()->select()
                    ->from($this->getfromPrefix() . 'pages_perm', '*')
                    ->where('page_id = ?', $data['item_id'])
                    ->query()
                    ->fetchAll();

            $viewPrivacy = 0;
            foreach ($perms as $permissions) {
                switch ($permissions['var_name']) {
                    case 'event.view_browse_events':
                        $viewPrivacy = $permissions['var_value'];
                        break;
                }
            }
            //INSERT THE PRIVACY
            $this->_insertPrivacy('siteevent_event', $data['event_id'], 'view', $this->_translateParentEventPrivacy($viewPrivacy));
        } else {
            $this->_insertPrivacy('siteevent_event', $data['event_id'], 'view', $this->_translateSiteeventPrivacy($data['privacy'], null, $list_id, 'view'));
        }

        // privacy
        try {
            $this->_insertPrivacy('siteevent_event', $data['event_id'], 'comment', $this->_translateSiteeventPrivacy($data['privacy_comment'], null, $list_id, 'comment'));

            $this->_insertPrivacy('siteevent_event', $data['event_id'], 'photo', $this->_translateSiteeventPrivacy(0, null, $list_id, 'photo'));

            $this->_insertPrivacy('siteevent_event', $data['event_id'], 'video', $this->_translateSiteeventPrivacy(0, null, $list_id, 'video'));

            $this->_insertPrivacy('siteevent_event', $data['event_id'], 'topic', $this->_translateSiteeventPrivacy(0, null, $list_id, 'topic'));

            $this->_insertPrivacy('siteevent_event', $data['event_id'], 'post', $this->_translateSiteeventPrivacy(0, null, $list_id, 'post'));

            $this->_insertPrivacy('siteevent_event', $data['event_id'], 'invite', $this->_translateSiteeventPrivacy(0, null, $list_id, 'invite'));

            $this->_insertPrivacy('siteevent_event', $data['event_id'], 'photo.edit', $this->_translateSiteeventPrivacy(3, null, $list_id, 'photo.edit'));
            $this->_insertPrivacy('siteevent_event', $data['event_id'], 'topic.edit', $this->_translateSiteeventPrivacy(3, null, $list_id, 'topic.edit'));
            $this->_insertPrivacy('siteevent_event', $data['event_id'], 'video.edit', $this->_translateSiteeventPrivacy(3, null, $list_id, 'video.edit'));
        } catch (Exception $e) {
            $this->_error('Problem adding privacy options for object id ' . $data['event_id'] . ' : ' . $e->getMessage());
        }

        //GET DESTINATION AND INSERT THE MAIN PHOTO OF EVENT
        if (!empty($data['image_path'])) {
            $des = explode('%s', $this->getFromPath() . DIRECTORY_SEPARATOR . 'file/pic/event' . DIRECTORY_SEPARATOR . $data['image_path']);
            $file = $des[0];
            if (isset($des[1])) {
                $file = $this->getPhotoUrl($des[0], $des[1]);
                if (empty($file))
                    $file = $des[0] . $des[1];
            }

            if ($file) {
                try {
                    //CREATE THE FILE FOR MAIN PHOTO
                    if ($this->getParam('resizePhotos', true)) {
                        $file_id = $this->_translatePhoto($file, array(
                            'parent_type' => 'siteevent_event',
                            'parent_id' => $data['event_id'],
                            'user_id' => @$data['user_id'],
                        ));
                    } else {
                        $file_id = $this->_translateFile($file, array(
                            'parent_type' => 'siteevent_event',
                            'parent_id' => $data['event_id'],
                            'user_id' => @$data['user_id'],
                                ), true);
                    }
                } catch (Exception $e) {
                    $file_id = null;
                    $this->_logFile($e->getMessage());
                }

                if ($file_id) {
                    $newData['photo_id'] = $file_id;
                }
                //INSERT THE ADVANCE EVENT SITE ALBUM
                $this->getToDb()->insert('engine4_siteevent_albums', array(
                    'event_id' => $data['event_id'],
                    'creation_date' => $this->_translateTime($data['time_stamp']),
                    'modified_date' => $this->_translateTime($data['time_stamp']),
                    'collectible_count' => 1
                ));

                $album_id = $this->getToDb()->lastInsertId();
                try {
                    if ($this->getParam('resizePhotos', true)) {
                        $filephoto_id = $this->_translatePhoto($file, array(
                            'parent_type' => 'siteevent_photo',
                            'parent_id' => $data['album_id'],
                            'user_id' => @$data['user_id'],
                        ));
                    } else {
                        $filephoto_id = $this->_translateFile($file, array(
                            'parent_type' => 'siteevent_photo',
                            'parent_id' => $data['album_id'],
                            'user_id' => @$data['user_id'],
                                ), true);
                    }
                } catch (Exception $e) {
                    $filephoto_id = null;
                    $this->_logFile($e->getMessage());
                }
                // INSERT THE ADVANCE EVENT PHOTO
                $this->getToDb()->insert('engine4_siteevent_photos', array(
                    'album_id' => $album_id,
                    'collection_id' => $album_id,
                    'event_id' => $data['event_id'],
                    'creation_date' => $this->_translateTime($data['time_stamp']),
                    'modified_date' => $this->_translateTime($data['time_stamp']),
                    'user_id' => @$data['user_id'],
                    'file_id' => $filephoto_id
                ));
                $photo_id = $this->getToDb()->lastInsertId();
                //CHECKING FOR EVENT COVER COLUMN EXIST OR NOT
                if ($this->_columnExist('engine4_siteevent_events', 'event_cover')) {
                    $newData['event_cover'] = $photo_id;
                }
            }
        }
        $newData['search'] = 1;
        //SEARCH
        if (@$newData['search']) {
            $this->_insertSearch('siteevent_event', @$newData['event_id'], @$newData['title'], @$newData['description']);
        }
        //INSERT OTHER INFO ADVANCE EVENT
        $this->getToDb()->insert('engine4_siteevent_otherinfo', array(
            'event_id' => $data['event_id']
        ));
        //INSERT THE OCCURRENCES OF ADVANCE EVENT
        $this->getToDb()->insert('engine4_siteevent_occurrences', array(
            'event_id' => $data['event_id'],
            'starttime' => $this->_translateTime($data['start_time']),
            'endtime' => $this->_translateTime($data['end_time']),
        ));
        $occurrence_id = $this->getToDb()->lastInsertId();
        //GET INVITES
        $invites = $this->getFromDb()->select()
                ->from($this->getfromPrefix() . 'event_invite', '*')
                ->where('event_id = ?', $data['event_id'])
                ->query()
                ->fetchAll();
        $count = count($invites);
        $active = 1;
        $resource_approved = 1;
        $user_approved = 1;
        foreach ($invites as $invite) {
            if ($invite['rsvp_id'] == 1) {
                $rsvp = 2;
            } else if ($invite['rsvp_id'] == 2) {
                $rsvp = 1;
            } else if ($invite['rsvp_id'] == 3) {
                $rsvp = 0;
            } else if ($invite['rsvp_id'] == 0) {
                $rsvp = 3;
                $active = 0;
                $user_approved = 0;
            }
            // INSERT ALL THE MEMBER OF THIS EVENT
            $this->getToDb()->insert('engine4_siteevent_membership', array(
                'resource_id' => $invite['event_id'],
                'user_id' => $invite['invited_user_id'],
                'active' => $active,
                'resource_approved' => $resource_approved,
                'user_approved' => $user_approved,
                'rsvp' => $rsvp,
                'occurrence_id' => $occurrence_id
            ));
        }
        $newData['member_count'] = $count;

        return $newData;
    }

}

/*
 * CREATE TABLE IF NOT EXISTS `phpfox_event` (
  `event_id` int(10) unsigned NOT NULL AUTO_INCREMENT,
  `view_id` tinyint(1) NOT NULL DEFAULT '0',
  `is_featured` tinyint(1) NOT NULL DEFAULT '0',
  `is_sponsor` tinyint(1) NOT NULL DEFAULT '0',
  `privacy` tinyint(1) NOT NULL DEFAULT '0',
  `privacy_comment` tinyint(1) NOT NULL DEFAULT '0',
  `module_id` varchar(75) NOT NULL DEFAULT 'event',
  `item_id` int(10) unsigned NOT NULL DEFAULT '0',
  `user_id` int(10) unsigned NOT NULL,
  `title` varchar(255) NOT NULL,
  `location` varchar(255) DEFAULT NULL,
  `country_iso` char(2) DEFAULT NULL,
  `country_child_id` mediumint(8) unsigned NOT NULL DEFAULT '0',
  `postal_code` varchar(20) DEFAULT NULL,
  `city` varchar(255) DEFAULT NULL,
  `time_stamp` int(10) unsigned NOT NULL,
  `start_time` int(10) unsigned NOT NULL,
  `end_time` int(10) unsigned NOT NULL,
  `image_path` varchar(75) DEFAULT NULL,
  `server_id` tinyint(1) NOT NULL DEFAULT '0',
  `total_comment` int(10) unsigned NOT NULL DEFAULT '0',
  `total_like` int(10) unsigned NOT NULL DEFAULT '0',
  `total_dislike` int(10) unsigned NOT NULL DEFAULT '0',
  `mass_email` int(10) unsigned NOT NULL DEFAULT '0',
  `start_gmt_offset` varchar(15) DEFAULT NULL,
  `end_gmt_offset` varchar(15) DEFAULT NULL,
  `gmap` varchar(255) DEFAULT NULL,
  `address` varchar(255) DEFAULT NULL,
  PRIMARY KEY (`event_id`),
  KEY `module_id` (`module_id`,`item_id`),
  KEY `user_id` (`user_id`),
  KEY `view_id` (`view_id`,`privacy`,`item_id`,`start_time`),
  KEY `view_id_2` (`view_id`,`privacy`,`item_id`,`user_id`,`start_time`),
  KEY `view_id_3` (`view_id`,`privacy`,`user_id`),
  KEY `view_id_4` (`view_id`,`privacy`,`item_id`,`title`),
  KEY `view_id_5` (`view_id`,`privacy`,`module_id`,`item_id`,`start_time`)
) ENGINE=MyISAM  DEFAULT CHARSET=latin1 AUTO_INCREMENT=1 ;
 */

/*
 * CREATE TABLE IF NOT EXISTS `phpfox_event_text` (
  `event_id` int(10) unsigned NOT NULL,
  `description` mediumtext,
  `description_parsed` mediumtext,
  KEY `event_id` (`event_id`)
) ENGINE=MyISAM DEFAULT CHARSET=latin1; 
 */

/*
 * CREATE TABLE IF NOT EXISTS `phpfox_event_category_data` (
  `event_id` int(10) unsigned NOT NULL,
  `category_id` int(10) unsigned NOT NULL,
  KEY `category_id` (`category_id`),
  KEY `event_id` (`event_id`)
) ENGINE=MyISAM DEFAULT CHARSET=latin1;
 */

/*
 * CREATE TABLE IF NOT EXISTS `phpfox_event_invite` (
  `invite_id` int(10) unsigned NOT NULL AUTO_INCREMENT,
  `event_id` int(10) unsigned NOT NULL,
  `type_id` tinyint(1) NOT NULL DEFAULT '0',
  `rsvp_id` tinyint(1) NOT NULL DEFAULT '0',
  `user_id` int(10) unsigned NOT NULL DEFAULT '0',
  `invited_user_id` int(10) unsigned NOT NULL DEFAULT '0',
  `invited_email` varchar(100) DEFAULT NULL,
  `time_stamp` int(10) unsigned NOT NULL,
  PRIMARY KEY (`invite_id`),
  KEY `event_id` (`event_id`),
  KEY `event_id_2` (`event_id`,`invited_user_id`),
  KEY `invited_user_id` (`invited_user_id`),
  KEY `event_id_3` (`event_id`,`rsvp_id`,`invited_user_id`),
  KEY `rsvp_id` (`rsvp_id`,`invited_user_id`)
) ENGINE=MyISAM  DEFAULT CHARSET=latin1 AUTO_INCREMENT=1 ;
 */

/*
 * CREATE TABLE IF NOT EXISTS `engine4_event_events` (
  `event_id` int(11) unsigned NOT NULL AUTO_INCREMENT,
  `title` varchar(128) COLLATE utf8_unicode_ci NOT NULL,
  `description` text COLLATE utf8_unicode_ci NOT NULL,
  `user_id` int(11) unsigned NOT NULL,
  `parent_type` varchar(64) COLLATE utf8_unicode_ci NOT NULL,
  `parent_id` int(11) unsigned NOT NULL,
  `search` tinyint(1) NOT NULL DEFAULT '1',
  `creation_date` datetime NOT NULL,
  `modified_date` datetime NOT NULL,
  `starttime` datetime NOT NULL,
  `endtime` datetime NOT NULL,
  `host` varchar(115) COLLATE utf8_unicode_ci NOT NULL,
  `location` varchar(115) COLLATE utf8_unicode_ci NOT NULL,
  `view_count` int(11) unsigned NOT NULL DEFAULT '0',
  `member_count` int(11) unsigned NOT NULL DEFAULT '0',
  `approval` tinyint(1) NOT NULL DEFAULT '0',
  `invite` tinyint(1) NOT NULL DEFAULT '0',
  `photo_id` int(11) unsigned NOT NULL,
  `category_id` int(11) unsigned NOT NULL DEFAULT '0',
  PRIMARY KEY (`event_id`),
  KEY `user_id` (`user_id`),
  KEY `parent_type` (`parent_type`,`parent_id`),
  KEY `starttime` (`starttime`),
  KEY `search` (`search`)
) ENGINE=InnoDB  DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci AUTO_INCREMENT=1 ;
 */

/*
 * CREATE TABLE IF NOT EXISTS `engine4_event_membership` (
  `resource_id` int(11) unsigned NOT NULL,
  `user_id` int(11) unsigned NOT NULL,
  `active` tinyint(1) NOT NULL DEFAULT '0',
  `resource_approved` tinyint(1) NOT NULL DEFAULT '0',
  `user_approved` tinyint(1) NOT NULL DEFAULT '0',
  `message` text COLLATE utf8_unicode_ci,
  `rsvp` tinyint(3) NOT NULL DEFAULT '3',
  `title` text COLLATE utf8_unicode_ci,
  PRIMARY KEY (`resource_id`,`user_id`),
  KEY `REVERSE` (`user_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
 */

/*
 * CREATE TABLE IF NOT EXISTS `engine4_event_albums` (
  `album_id` int(11) unsigned NOT NULL AUTO_INCREMENT,
  `event_id` int(11) unsigned NOT NULL,
  `title` varchar(128) COLLATE utf8_unicode_ci NOT NULL,
  `description` varchar(255) COLLATE utf8_unicode_ci NOT NULL,
  `creation_date` datetime NOT NULL,
  `modified_date` datetime NOT NULL,
  `search` tinyint(1) NOT NULL DEFAULT '1',
  `photo_id` int(11) unsigned NOT NULL DEFAULT '0',
  `view_count` int(11) unsigned NOT NULL DEFAULT '0',
  `comment_count` int(11) unsigned NOT NULL DEFAULT '0',
  `collectible_count` int(11) unsigned NOT NULL DEFAULT '0',
  PRIMARY KEY (`album_id`),
  KEY `event_id` (`event_id`),
  KEY `search` (`search`)
) ENGINE=InnoDB  DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci AUTO_INCREMENT=1 ;
 */

/*
 * 
CREATE TABLE IF NOT EXISTS `engine4_event_photos` (
  `photo_id` int(11) unsigned NOT NULL AUTO_INCREMENT,
  `album_id` int(11) unsigned NOT NULL,
  `event_id` int(11) unsigned NOT NULL,
  `user_id` int(11) unsigned NOT NULL,
  `title` varchar(128) COLLATE utf8_unicode_ci NOT NULL,
  `description` varchar(255) COLLATE utf8_unicode_ci NOT NULL,
  `collection_id` int(11) unsigned NOT NULL,
  `file_id` int(11) unsigned NOT NULL,
  `creation_date` datetime NOT NULL,
  `modified_date` datetime NOT NULL,
  `view_count` int(11) unsigned NOT NULL DEFAULT '0',
  `comment_count` int(11) unsigned NOT NULL DEFAULT '0',
  PRIMARY KEY (`photo_id`),
  KEY `album_id` (`album_id`),
  KEY `event_id` (`event_id`),
  KEY `collection_id` (`collection_id`)
) ENGINE=InnoDB  DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci AUTO_INCREMENT=1 ;
 */