<?php

/**
 * SocialEngine
 *
 * @category   Application_Extensions
 * @package    Phpfoximporter
 * @copyright  Copyright 2015-2016 BigStep Technologies Pvt. Ltd.
 * @license    http://www.socialengineaddons.com/license/
 * @version    PagesSitegroups.php 2015-07-30 00:00:00Z SocialEngineAddOns $
 * @author     SocialEngineAddOns
 */
class Install_Import_Phpfox_PagesSitegroups extends Install_Import_Phpfox_Abstract {

    protected $_fromTable = '';
    protected $_toTable = '';
    protected $_fromWhere = array('type_id=?' => 3);
    protected $_priority = 4000;
    protected $_warningMessage = array();

    protected function _initPre() {
        $this->_truncateTable($this->getToDb(), 'engine4_sitegroup_photos');
        $this->_truncateTable($this->getToDb(), 'engine4_sitegroup_albums');
        $this->_truncateTable($this->getToDb(), 'engine4_sitegroup_membership');
        $this->_truncateTable($this->getToDb(), 'engine4_sitegroup_lists');
        $this->_truncateTable($this->getToDb(), 'engine4_sitegroup_manageadmins');

        $this->_fromTable = $this->getFromPrefix() . 'pages';
        $this->_toTable = 'engine4_sitegroup_groups';
        $this->_warningMessage = array("key" => 'groupkit', 'value' => '<span style="font-weight:bolder;">Warning:</span>  Your PHPfox Groups Blogs, PHPfox Groups Music and PHPfox Groups Videos content are not migrated into SocialEngine PHP. You may ignore this warning or you can install <a target="_blank" href="http://www.socialengineaddons.com/socialengine-groups-communities-plugin" >Groups - Product Kit </a> on your SocialEngine PHP site to fix this warning. ');

        $prefix = $this->getfromPrefix();
        $picSize = $this->getFromDb()
                ->select()
                ->from($prefix . "setting", 'value_actual')
                ->where('var_name = ?', 'photo_pic_sizes')
                ->query()
                ->fetchColumn(0);
        $this->_fileSize = null;
        if ($picSize !== false) {
            $picSize = explode(':"', $picSize);
            if (isset($picSize[1])) {
                $picSize = explode(';";', $picSize[1]);
                if (isset($picSize[0])) {
                    $picSize = $picSize[0];
                    $picSizeArr = $this->get_string_between($picSize, "=>", ",");
                    foreach ($picSizeArr as $ps) {
                        $ps = str_replace("'", "", $ps);
                        $dt[] = (int) $ps;
                    }
                    rsort($dt);
                    if (isset($dt[0]))
                        $this->_fileSize = $dt[0];
                }
            }
        }
    }

    protected function _translateRow(array $data, $key = null) {

        //RETURN FALSE IF USER NOT SELECTED TO INSERT DATA INSIDE THE SOCIAL ENGINE ADDON GROUP COMMUNITY PLUGIN
        if ($this->getParam('import_group_segroup', 1) == 1)
            return false;
        $newData = array();

        //GET PAGE USER ID
        $page_user_id = $this->getFromDb()->select()
                ->from($this->getfromPrefix() . 'user', 'user_id')
                ->where('profile_page_id = ?', $data['page_id'])
                ->query()
                ->fetchColumn();
        //GETTING TEXT
        $text = $this->getFromDb()->select()
                ->from($this->getfromPrefix() . 'pages_text', 'text_parsed')
                ->where('page_id = ?', $data['page_id'])
                ->query()
                ->fetchColumn();
        //CHECKING TEXT IS NULL OR NOT
        if (is_null($text) || $text === false)
            $text = '';

        $newData['group_id'] = $data['page_id'];
        $newData['pending'] = 0;
        $newData['package_id'] = 1;
        //SET "DEFAULT TYPE" PROFILE
        $newData['profile_type'] = 1;

        //GETTING URL
        $vanity_url = $this->getFromDb()->select()
                ->from($this->getfromPrefix() . 'pages_url', 'vanity_url')
                ->where('page_id = ?', $data['page_id'])
                ->query()
                ->fetchColumn();
        if ($vanity_url)
            $newData['group_url'] = $vanity_url;
        else {
            //GETTING TEXT
            $newData['group_url'] = trim(preg_replace('/-+/', '-', preg_replace('/[^a-z0-9-]+/i', '-', strtolower($data['title']))), '-');
            $newData['group_url'] = $newData['group_url'] . '-' . $data['page_id'];
        }

        $newData['owner_id'] = $data['user_id'];
        $newData['title'] = $data['title'];
        $newData['body'] = $text;
        $newData['category_id'] = $data['category_id'];
        $newData['search'] = 1;
        $newData['member_invite'] = 1;
        $newData['approved'] = 1;
        $newData['draft'] = 1;
        if ($data['reg_method'] == 0 || $data['reg_method'] == 2) {
            $newData['member_approval'] = 0;
        } else {
            $newData['member_approval'] = 1;
        }
        $newData['creation_date'] = $this->_translateTime($data['time_stamp']);
        $newData['modified_date'] = $this->_translateTime($data['time_stamp']);
        $newData['aprrove_date'] = $this->_translateTime($data['time_stamp']);
        //INSERTING INTO LIST TABLE
        $this->getToDb()->insert('engine4_sitegroup_lists', array(
            'owner_id' => $data['user_id'],
            'group_id' => $data['page_id'],
            'title' => 'SITEGROUP_LIKE'
        ));

        //INSERTING INTO MANAGE ADMIN TABLE
        $this->getToDb()->insert('engine4_sitegroup_manageadmins', array(
            'user_id' => $data['user_id'],
            'group_id' => $data['page_id']
        ));

        //GET OTHER MANAGE ADMINS FOR THIS PAGE
        $admins = $this->getFromDb()->select()
                ->from($this->getfromPrefix() . 'pages_admin', '*')
                ->where('page_id = ?', $data['page_id'])
                ->query()
                ->fetchAll();

        foreach ($admins as $admin) {
            //INSERTING INTO MANAGE ADMIN TABLE
            $adminDataArr = array(
                'user_id' => $data['user_id'],
                'group_id' => $admin['page_id']
            );
            $this->_insertOrUpdate($this->getToDb(), 'engine4_sitegroup_manageadmins', $adminDataArr, $adminDataArr);
            //$this->getToDb()->insert('engine4_sitegroup_manageadmins', $adminDataArr);
        }

        //FIND ALL THE MEMBER OF THIS PAGE
        $user_all_ids = $this->getFromDb()->select()
                ->from($this->getfromPrefix() . 'friend', 'user_id')
                ->where('friend_user_id = ?', $page_user_id)
                ->where('is_page = ?', 1)
                ->query()
                ->fetchAll();
        //INSERT ALL THE MEMBER OF THIS PAGE
        foreach ($user_all_ids as $userids) {
            $this->getToDb()->insert('engine4_sitegroup_membership', array(
                'resource_id' => $data['page_id'],
                'user_id' => $userids['user_id'],
                'active' => 1,
                'resource_approved' => 1,
                'user_approved' => 1,
                'join_date' => $this->_translateTime($data['time_stamp']),
                'group_id' => $data['page_id'],
            ));
        }
        //UPDATING THE MEMBER COUNT
        $newData['member_count'] = count($user_all_ids);

        //HERE WE GETTING THE USER IDS WHO HAVE REQUESTED TO JOIN THE PAGE.
        $requested_user_all_ids = $this->getFromDb()->select()
                ->from($this->getfromPrefix() . 'pages_signup', 'user_id')
                ->where('page_id = ?', $data['page_id'])
                ->query()
                ->fetchAll();

        //INSERTING THE REQUESTED PEOPLE
        foreach ($requested_user_all_ids as $user_request_ids) {
            $this->getToDb()->insert('engine4_sitegroup_membership', array(
                'resource_id' => $data['page_id'],
                'user_id' => $user_request_ids['user_id'],
                'active' => 0,
                'resource_approved' => 0,
                'user_approved' => 1,
                'join_date' => $this->_translateTime($data['time_stamp']),
                'group_id' => $data['page_id'],
            ));
        }
        //INSERTION OF USER PROFILE PHOTO.
        if (!empty($data['image_path'])) {

            $album = $this->getFromDb()->query("SELECT * FROM " . $this->getfromPrefix() . "photo_album WHERE (user_id = $page_user_id) AND (name = '{phrase var=\'photo.profile_pictures\'}' OR name = 'Profile Pictures')")->fetch();
            if ($album) {
                //GET DESCRIPTION
                $description = $this->getFromDb()->select()
                        ->from($this->getfromPrefix() . 'photo_album_info', 'description')
                        ->where('album_id = ?', $album['album_id'])
                        ->query()
                        ->fetchColumn();
                //INSERTION OF GROUP PROFILE ALBUM
                $this->getToDb()->insert('engine4_sitegroup_albums', array(
                    'album_id' => $album['album_id'],
                    'title' => $data['title'],
                    'description' => $description ? $description : '',
                    'group_id' => $data['page_id'],
                    'owner_id' => $data['user_id'],
                    'creation_date' => $this->_translateTime($album['time_stamp']),
                    'modified_date' => $album['time_stamp_update'] ? $this->_translateTime($album['time_stamp_update']) : $this->_translateTime($album['time_stamp']),
                    'collectible_count' => 1,
                    'default_value' => 1
                ));
                $album_id = $album['album_id'];
                $seAlbumId = $this->getToDb()->lastInsertId();
                //SELECTION OF ALL PHOTOS OF PROFILE ALBUM
                $photos = $this->getFromDb()->select()
                        ->from($this->getfromPrefix() . 'photo', '*')
                        ->where('album_id = ?', $album_id)
                        ->query()
                        ->fetchAll();

                //INSERTION OF ALL PHOTOS OF PROFILE ALBUM
                foreach ($photos as $photo) {
                    try {

                        $phDest = $this->get_string_between($photo['destination'], '[GROUP]{', '}');
                        if (!empty($phDest) && count($phDest) > 0)
                            $srcPath = $this->getFromPath() . DIRECTORY_SEPARATOR . $phDest[0];
                        else {
                            if (strpos($photo['destination'], '[GROUP]') !== false) {
                                $phDest = substr($photo['destination'], 7);
                                if (!empty($phDest) && count($phDest) > 0) {
                                    $srcPath = $this->getFromPath() . DIRECTORY_SEPARATOR . $phDest[0];
                                }
                            } else {
                                $phDest = $this->get_string_between($photo['destination'], '{', '}');
                                if (!empty($phDest) && count($phDest) > 0) {
                                    $srcPath = $this->getFromPath() . DIRECTORY_SEPARATOR . $phDest[0];
                                } else
                                    $srcPath = $this->getFromPath() . DIRECTORY_SEPARATOR . 'file/pic/photo' . DIRECTORY_SEPARATOR . $photo['destination'];
                            }
                        }
                        $des = explode('%s', $srcPath);

                        /*

                          $phDest = $this->get_string_between($photo['destination'], '[GROUP]{', '}');
                          if (!empty($phDest) && count($phDest) > 0)
                          $srcPath = $this->getFromPath() . DIRECTORY_SEPARATOR . $phDest[0];
                          else {
                          $srcPath = $this->getFromPath() . DIRECTORY_SEPARATOR . 'file/pic/photo' . DIRECTORY_SEPARATOR . $photo['destination'];
                          }
                          $des = explode('%s', $srcPath);



                         */



                        $file = $des[0];
                        if (isset($des[1])) {
                            $file = $this->getPhotoUrl($des[0], $des[1]);
                            if (empty($file))
                                $file = $des[0] . $des[1];
                        }
                        $fileInfo = array(
                            'parent_type' => 'sitegroup_photo',
                            'parent_id' => $photo['photo_id'],
                            'user_id' => $data['user_id'],
                        );
                        $filephoto_id = $this->_translateFile($file, $fileInfo, true);
                        if (is_null($filephoto_id) || $filephoto_id == 0) {
                            $filephoto_id = $this->createFileDiffSize($file, $fileInfo, $this->_fileSize);
                        }
                    } catch (Exception $e) {
                        $filephoto_id = null;
                        $this->_warning($e->getMessage(), 1);
                    }
                    if (empty($filephoto_id)) {
                        $this->_logFile("Group main photo not found . Photo path " . $file);
                        continue;
                    }
                    //INSERTION OF GROUP PHOTO
                    $this->getToDb()->insert('engine4_sitegroup_photos', array(
                        'photo_id' => $photo['photo_id'],
                        'album_id' => $seAlbumId,
                        'collection_id' => $seAlbumId,
                        'group_id' => $data['page_id'],
                        'creation_date' => $this->_translateTime($photo['time_stamp']),
                        'modified_date' => $this->_translateTime($photo['time_stamp']),
                        'user_id' => $data['user_id'],
                        'file_id' => $filephoto_id,
                        'comment_count' => $photo['total_comment'],
                        'featured' => $photo['is_featured'],
                        'view_count' => $photo['total_view']
                    ));
                    //CHECKING WHEATER SELECTED PHOTO IS PROFILE PHOTO
                    if ($photo['is_profile_photo']) {
                        $newData['photo_id'] = $filephoto_id;
                        //UPDATE PHOTO ID
                        $this->getToDb()->update('engine4_sitegroup_albums', array(
                            'photo_id' => $filephoto_id,
                                ), array(
                            'album_id = ?' => $seAlbumId,
                        ));
                    }
                }
            } else {
                $album_id = $this->findAlbum(0, $data['page_id'], @$data['user_id'], $this->_translateTime($data['time_stamp']));
                try {

                    $phDest = $this->get_string_between($data['image_path'], '[GROUP]{', '}');
                    if (!empty($phDest) && count($phDest) > 0)
                        $srcPath = $this->getFromPath() . DIRECTORY_SEPARATOR . $phDest[0];
                    else {
                        if (strpos($data['image_path'], '[GROUP]') !== false) {
                            $phDest = substr($data['image_path'], 7);
                            if (!empty($phDest) && count($phDest) > 0) {
                                $srcPath = $this->getFromPath() . DIRECTORY_SEPARATOR . $phDest[0];
                            }
                        } else {
                            $phDest = $this->get_string_between($data['image_path'], '{', '}');
                            if (!empty($phDest) && count($phDest) > 0) {
                                $srcPath = $this->getFromPath() . DIRECTORY_SEPARATOR . $phDest[0];
                            } else
                                $srcPath = $this->getFromPath() . DIRECTORY_SEPARATOR . 'file/pic/photo' . DIRECTORY_SEPARATOR . $data['image_path'];
                        }
                    }
                    $des = explode('%s', $srcPath);

                    /*

                      $phDest = $this->get_string_between($data['image_path'], '[GROUP]{', '}');
                      if (!empty($phDest) && count($phDest) > 0)
                      $srcPath = $this->getFromPath() . DIRECTORY_SEPARATOR . $phDest[0];
                      else {
                      $srcPath = $this->getFromPath() . DIRECTORY_SEPARATOR . 'file/pic/photo' . DIRECTORY_SEPARATOR . $data['image_path'];
                      }
                      $des = explode('%s', $srcPath); */
                    $file = $des[0];
                    if (isset($des[1])) {
                        $file = $this->getPhotoUrl($des[0], $des[1]);
                        if (empty($file))
                            $file = $des[0] . $des[1];
                    }
                    $fileInfo = array(
                        'parent_type' => 'sitegroup_photo',
                        'parent_id' => $photo['photo_id'],
                        'user_id' => $data['user_id'],
                    );
                    $filephoto_id = $this->_translateFile($file, $fileInfo, true);
                    if (is_null($filephoto_id) || $filephoto_id == 0) {
                        $filephoto_id = $this->createFileDiffSize($file, $fileInfo, $this->_fileSize);
                    }
                } catch (Exception $e) {
                    $filephoto_id = null;
                    $this->_logFile($e->getMessage());
                }
                if (!empty($filephoto_id)) {
                    $maxId = $this->getToDb()
                            ->select()
                            ->from('engine4_sitegroup_photos', 'max(photo_id)')
                            ->limit(1)
                            ->query()
                            ->fetchColumn(0);
                    if ($maxId === false || $maxId < 1000000)
                        $maxId = 1000000;
                    else
                        $maxId++;
                    //INSERTION OF GROUP PHOTO

                    $this->getToDb()->insert('engine4_sitegroup_photos', array(
                        'photo_id' => $maxId,
                        'album_id' => $album_id,
                        'collection_id' => $album_id,
                        'group_id' => $data['page_id'],
                        'creation_date' => $this->_translateTime($photo['time_stamp']),
                        'modified_date' => $this->_translateTime($photo['time_stamp']),
                        'user_id' => @$data['user_id'],
                        'file_id' => $filephoto_id,
                        'comment_count' => 0,
                        'view_count' => 0
                    ));
                }
                else {
                    $this->_logFile("Group main photo not found.Photo path " . $file);
                }
            }
        }
        //INSERTION OF ALL OTHER ALBUM AND PHOTOS(INSTEAD OF PROFILE ALBUM).
        $this->_insertPhotoExt($data, $this->_fileSize);
        //INSERTION OF COVER PHOTO.
        $newData['group_cover'] = $this->insertSitegroupCoverPhoto($data);
        //PRIVACY
        $this->setSitegroupPrivacy($data);
        //SEARCH
        $this->_insertSearch('sitegroup_group', @$data['page_id'], @$data['title'], $text);
        return $newData;
    }

    /*
     * THIS FUNCTION CHECK WHEATER THE ALBUM EXIST OR NOT .IF IT DOES NOT EXIST THEN CREATE NEW ONE AND THEN RETURN THE ALBUM ID.
     */

    public function findAlbum($albumId, $page_id, $user_id, $timestamp) {

        if ($albumId != 0) {
            $album = $this->getFromDb()
                    ->select()
                    ->from($this->getfromPrefix() . 'photo_album', '*')
                    ->where('album_id = ?', $albumId)
                    ->query()
                    ->fetch();
            $seAlbumId = $this->getToDb()->select()
                    ->from('engine4_sitegroup_albums', 'album_id')
                    ->where('album_id = ?', $albumId)
                    ->query()
                    ->fetchColumn(0);
            if ($seAlbumId === false) {
                //GET DESCRIPTION
                $description = $this->getFromDb()->select()
                        ->from($this->getfromPrefix() . 'photo_album_info', 'description')
                        ->where('album_id = ?', $album['album_id'])
                        ->query()
                        ->fetchColumn();
                //ALBUM INSERTION
                $this->getToDb()->insert('engine4_sitegroup_albums', array(
                    'album_id' => $album['album_id'],
                    'title' => $album['name'],
                    'description' => $description ? $description : '',
                    'group_id' => $album['group_id'],
                    'owner_id' => $album['user_id'],
                    'creation_date' => $this->_translateTime($album['time_stamp']),
                    'modified_date' => $album['time_stamp_update'] ? $this->_translateTime($album['time_stamp_update']) : $this->_translateTime($album['time_stamp']),
                    'collectible_count' => 1,
                    'default_value' => 1
                ));
                $seAlbumId = $this->getToDb()->lastInsertId();
            }
        } else {
            //CHECKING WHEATER Untitled Album EXIST OR NOT
            $seAlbumId = $this->getToDb()->select()
                    ->from('engine4_sitegroup_albums', 'album_id')
                    ->where('title = ?', 'Untitled Album')
                    ->where('group_id = ?', $page_id)
                    ->query()
                    ->fetchColumn(0);
            //IF NOT EXIST THEN CREATE NEW ONE
            if ($seAlbumId === false) {

                $maxId = $this->getToDb()
                        ->select()
                        ->from('engine4_sitegroup_albums', 'max(album_id)')
                        ->limit(1)
                        ->query()
                        ->fetchColumn(0);
                if ($maxId === false || $maxId < 1000000)
                    $maxId = 1000000;
                else
                    $maxId++;

                //INSERTION OF GROUP ALBUM.
                $this->getToDb()->insert('engine4_sitegroup_albums', array(
                    'album_id' => $maxId,
                    'title' => 'Untitled Album',
                    'description' => '',
                    'group_id' => $page_id,
                    'owner_id' => $user_id,
                    'creation_date' => $this->_translateTime($timestamp),
                    'modified_date' => $this->_translateTime($timestamp),
                    'collectible_count' => 1,
                    'default_value' => 1
                ));
                $seAlbumId = $this->getToDb()->lastInsertId();
            }
        }
        return $seAlbumId;
    }

    //INSERT ALL THE PHOTO OF GROUP.
    public function _insertPhotoExt($data, $fileSize) {

        $photos = $this->getFromDb()
                ->select()
                ->from($this->getfromPrefix() . 'photo', '*')
                ->where('module_id = ?', 'pages')
                ->where('group_id = ?', $data['page_id'])
                ->query()
                ->fetchAll();
        $this->_insertSiteGroupPhoto($data, $photos, $fileSize);
        $photos = $this->getFromDb()
                ->select()
                ->from($this->getfromPrefix() . 'photo', $this->getfromPrefix() . 'photo.*')
                ->join($this->getfromPrefix() . 'event', $this->getfromPrefix() . 'event.event_id=' . $this->getfromPrefix() . 'photo.group_id', null)
                ->where($this->getfromPrefix() . 'photo.module_id = ?', 'event')
                ->where($this->getfromPrefix() . 'event.module_id = ?', 'pages')
                ->where($this->getfromPrefix() . 'event.item_id = ?', $data['page_id'])
                ->query()
                ->fetchAll();
        $this->_insertSiteGroupPhoto($data, $photos, $fileSize);
    }

    //INSERT THE GROUP ALBUM AND PHOTO
    public function _insertSiteGroupPhoto($data, $photos, $fileSize) {

        foreach ($photos as $photo) {
            //Get Owner UserId
            $userId = $this->getFromDb()->query("SELECT  " . $this->getfromPrefix() . "pages.user_id FROM " . $this->getfromPrefix() . "user left join  " . $this->getfromPrefix() . "pages on page_id=profile_page_id where profile_page_id<>0 and  " . $this->getfromPrefix() . "user.user_id=" . $photo['user_id'])->fetchColumn(0);
            if ($userId)
                $photo['user_id'] = $userId;

            $album_id = $this->findAlbum($photo['album_id'], $photo['group_id'], $photo['user_id'], $photo['time_stamp']);

            try {

                $phDest = $this->get_string_between($photo['destination'], '[GROUP]{', '}');
                if (!empty($phDest) && count($phDest) > 0)
                    $srcPath = $this->getFromPath() . DIRECTORY_SEPARATOR . $phDest[0];
                else {
                    if (strpos($photo['destination'], '[GROUP]') !== false) {
                        $phDest = substr($photo['destination'], 7);
                        if (!empty($phDest) && count($phDest) > 0) {
                            $srcPath = $this->getFromPath() . DIRECTORY_SEPARATOR . $phDest[0];
                        }
                    } else {
                        $phDest = $this->get_string_between($photo['destination'], '{', '}');
                        if (!empty($phDest) && count($phDest) > 0) {
                            $srcPath = $this->getFromPath() . DIRECTORY_SEPARATOR . $phDest[0];
                        } else
                            $srcPath = $this->getFromPath() . DIRECTORY_SEPARATOR . 'file/pic/photo' . DIRECTORY_SEPARATOR . $photo['destination'];
                    }
                }
                $des = explode('%s', $srcPath);
                /*
                  $phDest = $this->get_string_between($photo['destination'], '[GROUP]{', '}');
                  if (!empty($phDest) && count($phDest) > 0)
                  $srcPath = $this->getFromPath() . DIRECTORY_SEPARATOR . $phDest[0];
                  else {
                  $phDest = $this->get_string_between($photo['destination'], '{', '}');
                  if (!empty($phDest) && count($phDest) > 0) {
                  $srcPath = $this->getFromPath() . DIRECTORY_SEPARATOR . $phDest[0];
                  } else
                  $srcPath = $this->getFromPath() . DIRECTORY_SEPARATOR . 'file/pic/photo' . DIRECTORY_SEPARATOR . $photo['destination'];
                  }
                  $des = explode('%s', $srcPath); */
                $file = $des[0];
                if (isset($des[1])) {
                    $file = $this->getPhotoUrl($des[0], $des[1]);
                    if (empty($file))
                        $file = $des[0] . $des[1];
                }
                $fileInfo = array(
                    'parent_type' => 'sitegroup_photo',
                    'parent_id' => $photo['photo_id'],
                    'user_id' => @$data['user_id'],
                );
                $filephoto_id = $this->_translateFile($file, $fileInfo, true);
                if (is_null($filephoto_id) || $filephoto_id == 0) {
                    $filephoto_id = $this->createFileDiffSize($file, $fileInfo, $fileSize);
                }
            } catch (Exception $e) {
                $filephoto_id = null;
                $this->_warning($e->getMessage(), 1);
            }
            if (empty($filephoto_id)) {
                $this->_logFile("Group photo not found. file path " . $file);
                continue;
            }
            //INSERT THE GROUP PHOTO
            $this->getToDb()->insert('engine4_sitegroup_photos', array(
                'photo_id' => $photo['photo_id'],
                'album_id' => $album_id,
                'collection_id' => $album_id,
                'group_id' => $data['page_id'],
                'creation_date' => $this->_translateTime($photo['time_stamp']),
                'modified_date' => $this->_translateTime($photo['time_stamp']),
                'user_id' => @$data['user_id'],
                'file_id' => $filephoto_id,
                'comment_count' => $photo['total_comment'],
                'featured' => $photo['is_featured'],
                'view_count' => $photo['total_view']
            ));
            //UPDATE PHOTO ID
            $this->getToDb()->update('engine4_sitegroup_albums', array(
                'photo_id' => $filephoto_id,
                    ), array(
                'album_id = ?' => $album_id,
            ));
        }
    }

    /*
     * INSERT THE GROUP COVER PHOTO
     */

    public function insertSitegroupCoverPhoto($data) {
        $filephoto_id = null;
        if (is_null($data['cover_photo_id']))
            return 0;

        $photo = $this->getFromDb()
                ->select()
                ->from($this->getfromPrefix() . 'photo', '*')
                ->where('photo_id = ?', $data['cover_photo_id'])
                ->query()
                ->fetch();
        if (!$photo)
            return 0;

        $photoFileId = $this->getToDb()->select()
                ->from('engine4_sitegroup_photos', 'file_id')
                ->where('photo_id = ?', $data['cover_photo_id'])
                ->query()
                ->fetchColumn(0);
        if ($photoFileId) {
            $filephoto_id = $photoFileId;
            $maxId = $this->getToDb()
                    ->select()
                    ->from('engine4_sitegroup_photos', 'max(album_id)')
                    ->limit(1)
                    ->query()
                    ->fetchColumn(0);
            if ($maxId === false || $maxId < 1000000)
                $maxId = 1000000;
            else
                $maxId++;
            $photo['photo_id'] = $maxId;
        }
        $seAlbumId = $this->getToDb()->select()
                ->from('engine4_sitegroup_albums', 'album_id')
                ->where('title = ?', 'Cover Photos')
                ->where('group_id = ?', $data['page_id'])
                ->query()
                ->fetchColumn(0);

        if ($seAlbumId === false) {

            $maxId = $this->getToDb()
                    ->select()
                    ->from('engine4_sitegroup_albums', 'max(album_id)')
                    ->limit(1)
                    ->query()
                    ->fetchColumn(0);
            if ($maxId === false || $maxId < 1000000)
                $maxId = 1000000;
            else
                $maxId++;

            $cParams = array('top' => 0, 'left' => 0);

            //POSITION OF COVER PHOTO
            if (!empty($data['cover_photo_position']))
                $cParams['top'] = $data['cover_photo_position'];

            //GROUP ALBUM INSERTION
            $this->getToDb()->insert('engine4_sitegroup_albums', array(
                'album_id' => $maxId,
                'title' => 'Cover Photos',
                'description' => '',
                'group_id' => $data['page_id'],
                'owner_id' => $data['user_id'],
                'creation_date' => $this->_translateTime($data['time_stamp']),
                'modified_date' => $this->_translateTime($data['time_stamp']),
                'collectible_count' => 1,
                'default_value' => 1,
                'type' => 'cover',
                'cover_params' => Zend_Json_Encoder::encode($cParams)
            ));
            $seAlbumId = $this->getToDb()->lastInsertId();
        }
        try {
            if (!$filephoto_id) {

                $des = '';
                $phDest = $this->get_string_between($photo['destination'], '{', '}');
                if (!empty($phDest) && count($phDest) > 0) {
                    $des = explode('%s', $this->getFromPath() . DIRECTORY_SEPARATOR . $phDest[0]);
                } else {
                    $des = explode('%s', $this->getFromPath() . DIRECTORY_SEPARATOR . 'file/pic/user' . DIRECTORY_SEPARATOR . $photo['destination']);
                }
                //$des = explode('%s', $this->getFromPath() . DIRECTORY_SEPARATOR . 'file/pic/photo' . DIRECTORY_SEPARATOR . $photo['destination']);
                $file = $des[0];
                if (isset($des[1])) {
                    $file = $this->getPhotoUrl($des[0], $des[1]);
                    if (empty($file))
                        $file = $des[0] . $des[1];
                }

                $filephoto_id = $this->_translateFile($file, array(
                    'parent_type' => 'sitegroup_photo',
                    'parent_id' => $photo['photo_id'],
                    'user_id' => @$data['user_id'],
                        ), true);
            }
        } catch (Exception $e) {
            $filephoto_id = null;
            $this->_warning($e->getMessage(), 1);
        }
        //INSERT GROUP PHOTO
        $this->getToDb()->insert('engine4_sitegroup_photos', array(
            'photo_id' => $photo['photo_id'],
            'album_id' => $seAlbumId,
            'collection_id' => $seAlbumId,
            'group_id' => $data['page_id'],
            'creation_date' => $this->_translateTime($photo['time_stamp']),
            'modified_date' => $this->_translateTime($photo['time_stamp']),
            'user_id' => @$data['user_id'],
            'file_id' => $filephoto_id,
            'comment_count' => $photo['total_comment'],
            'featured' => $photo['is_featured'],
            'view_count' => $photo['total_view']
        ));
        $photoId = $this->getToDb()->lastInsertId();
        //UPDATE PHOTO ID
        $this->getToDb()->update('engine4_sitegroup_albums', array(
            'photo_id' => $filephoto_id,
                ), array(
            'album_id = ?' => $seAlbumId,
        ));

        return $photoId;
    }

    /*
     * SET GROUP PRIVACY
     */

    public function setSitegroupPrivacy($data) {

        $roles = array('owner', 'owner_member', 'owner_member_member', 'owner_network', 'registered', 'everyone');

        //CHECKING "Groups / Communities - Group Members" PLUGIN EXIST OR NOT
        if ($this->isPluginExist('sitegroupmember')) {
            $roles[] = 'member';
        }
        //PRIVACY
        try {
            $this->_insertPrivacy('sitegroup_group', $data['page_id'], 'view', $this->_translateSitegroupPrivacy($data['privacy']));
            $this->_insertPrivacy('sitegroup_group', $data['page_id'], 'comment', $this->_translateSitegroupPrivacy($data['privacy']));
            $this->_insertPrivacy('sitegroup_group', $data['page_id'], 'print', $roles);
            $this->_insertPrivacy('sitegroup_group', $data['page_id'], 'tfriend', $roles);
            $this->_insertPrivacy('sitegroup_group', $data['page_id'], 'overview', $roles);
            $this->_insertPrivacy('sitegroup_group', $data['page_id'], 'map', $roles);
            $this->_insertPrivacy('sitegroup_group', $data['page_id'], 'insight', $roles);
            $this->_insertPrivacy('sitegroup_group', $data['page_id'], 'layout', $roles);
            $this->_insertPrivacy('sitegroup_group', $data['page_id'], 'contact', $roles);
            $this->_insertPrivacy('sitegroup_group', $data['page_id'], 'form', $roles);
            $this->_insertPrivacy('sitegroup_group', $data['page_id'], 'offer', $roles);
            $this->_insertPrivacy('sitegroup_group', $data['page_id'], 'invite', $roles);
            //FIND ALL THE PARAMETER OF PAGES
            $perms = $this->findPagesPerm($data['page_id']);
            //CHECKING MODULE EXIST OR NOT AFTER THAT INSERT THE PRIVACY.
            if ($this->isPluginExist('sitegroupdiscussion'))
                $this->_insertPrivacy('sitegroup_group', $data['page_id'], 'sdicreate'
                        , $this->_translateSitegroupExtPrivacy($perms['forum.share_forum']));
            if ($this->isPluginExist('sitegroupalbum'))
                $this->_insertPrivacy('sitegroup_group', $data['page_id'], 'spcreate'
                        , $this->_translateSitegroupExtPrivacy($perms['photo.share_photos']));

            if ($this->isPluginExist('sitegroupvideo'))
                $this->_insertPrivacy('sitegroup_group', $data['page_id'], 'svcreate'
                        , $this->_translateSitegroupExtPrivacy($perms['video.share_videos']));

            if ($this->isPluginExist('sitegroupnote'))
                $this->_insertPrivacy('sitegroup_group', $data['page_id'], 'sncreate'
                        , $this->_translateSitegroupExtPrivacy($perms['blog.share_blogs']));

            if ($this->isPluginExist('sitegroupmusic'))
                $this->_insertPrivacy('sitegroup_group', $data['page_id'], 'smcreate'
                        , $this->_translateSitegroupExtPrivacy($perms['music.share_music']));

            $this->_insertPrivacy('sitegroup_group', $data['page_id'], 'secreate'
                    , $this->_translateSitegroupExtPrivacy($perms['event.share_events']));
        } catch (Exception $e) {
            $this->_error('Problem adding privacy options for object id ' . $data['video_id'] . ' : ' . $e->getMessage());
        }
    }

    /*
     * SELECT ALL THE SETTINGS OF THIS PAGE
     */

    public function findPagesPerm($pageId) {
        $arr = array();
        $perms = $this->getFromDb()->select()->from($this->getfromPrefix() . 'pages_perm', '*')
                ->where('page_id = ?', $pageId)
                ->query()
                ->fetchAll();
        foreach ($perms as $perm)
            $arr[$perm['var_name']] = $perm['var_value'];
        return $arr;
    }

}
