<?php

/**
 * SocialEngine
 *
 * @category   Application_Extensions
 * @package    Phpfoximporter
 * @copyright  Copyright 2015-2016 BigStep Technologies Pvt. Ltd.
 * @license    http://www.socialengineaddons.com/license/
 * @version    SitepageeventEvents.php 2015-07-30 00:00:00Z SocialEngineAddOns $
 * @author     SocialEngineAddOns
 */
class Install_Import_Phpfox_SitepageeventEvents extends Install_Import_Phpfox_Abstract {

    protected $_fromTable = '';
    protected $_toTable = '';
    protected $_fromWhere = array('module_id=?' => 'pages');
    protected $_warningMessage = array();

    protected function _initPre() {
        $this->_truncateTable($this->getToDb(), 'engine4_sitepageevent_albums');
        $this->_truncateTable($this->getToDb(), 'engine4_sitepageevent_membership');
        $this->_truncateTable($this->getToDb(), 'engine4_sitepageevent_photos');
        $this->_fromTable = $this->getFromPrefix() . 'event';
        $this->_toTable = 'engine4_sitepageevent_events';
        $this->_warningMessage = array("key" => 'pagekit', 'value' => '<span style="font-weight:bolder;">Warning:</span>  Your PHPfox Pages Blogs, PHPfox Pages Music and PHPfox Pages Videos content are not migrated into SocialEngine PHP. You may ignore this warning or you can install<a target="_blank" href="http://www.socialengineaddons.com/socialengine-directory-pages-plugin" > Directory / Pages and Essential Extensions - Product Kit</a>  on your SocialEngine PHP site to fix this warning.  ');
    }

    protected function _translateRow(array $data, $key = null) {

        //RETURN FALSE IF USER NOT SELECTED TO INSERT DATA INSIDE THE SOCIAL ENGINE ADDON DIRECTORY/PAGES PLUGIN
        if ($this->getParam('import_group_sepage', 1) == 1)
            return false;
        $parent_type = 'sitepage_page';
        $page_id = $data['item_id'];
        $type_id = $this->getFromDb()->select()
                ->from($this->getfromPrefix() . 'pages', 'type_id')
                ->where('page_id = ?', $data['item_id'])
                ->query()
                ->fetchColumn();

        if ($type_id == 3) {
            return false;
        }

        //Get Owner UserId
        $userId = $this->getFromDb()->query("SELECT  " . $this->getfromPrefix() . "pages.user_id FROM " . $this->getfromPrefix() . "user left join  " . $this->getfromPrefix() . "pages on page_id=profile_page_id where profile_page_id<>0 and  " . $this->getfromPrefix() . "user.user_id=" . $data['user_id'])->fetchColumn(0);
        if ($userId)
            $data['user_id'] = $userId;
        //GET CATGEORY ID
        $category_id = $this->getFromDb()->select()
                ->from($this->getfromPrefix() . 'event_category_data', 'category_id')
                ->where('event_id = ?', $data['event_id'])
                ->query()
                ->fetchColumn();

        //GET DESCRIPTION
        $description = $this->getFromDb()->select()
                ->from($this->getfromPrefix() . 'event_text', 'description_parsed')
                ->where('event_id = ?', $data['event_id'])
                ->query()
                ->fetchColumn();

        //MAKING EVENT ARRAY FOR INSERTION
        $newData = array();
        $newData['event_id'] = $data['event_id'];
        $newData['title'] = $data['title'];
        $newData['description'] = $description ? $description : '';
        $newData['category_id'] = $category_id;
        $newData['user_id'] = $data['user_id'];
        $newData['parent_type'] = $parent_type;
        $newData['page_id'] = $page_id;
        $newData['creation_date'] = $this->_translateTime($data['time_stamp']);
        $newData['modified_date'] = $this->_translateTime($data['time_stamp']);
        $newData['starttime'] = $this->_translateTime($data['start_time']);
        $newData['endtime'] = $this->_translateTime($data['end_time']);
        $newData['location'] = $data['location'];
        $newData['featured'] = $data['is_featured'];

        // privacy
        try {
            $this->_insertPrivacy('sitepageevent_event', $data['event_id'], 'view', $this->_translateEventPrivacy($data['privacy']));
            $this->_insertPrivacy('sitepageevent_event', $data['event_id'], 'comment', $this->_translateEventPrivacy($data['privacy_comment']));
            $this->_insertPrivacy('sitepageevent_event', $data['event_id'], 'photo', $this->_translateEventPrivacy(0));
            $this->_insertPrivacy('sitepageevent_event', $data['event_id'], 'invite', $this->_translateEventPrivacy(5));
        } catch (Exception $e) {
            $this->_error('Problem adding privacy options for object id ' . $data['event_id'] . ' : ' . $e->getMessage());
        }

        //GET DESTINATION AND INSERT THE MAIN PHOTO OF EVENT
        if (!empty($data['image_path'])) {

            //INSERT THE ALBUM 
            $this->getToDb()->insert('engine4_sitepageevent_albums', array(
                'event_id' => $data['event_id'],
                'creation_date' => $this->_translateTime($data['time_stamp']),
                'modified_date' => $this->_translateTime($data['time_stamp']),
                'collectible_count' => 1
            ));
            $album_id = $this->getToDb()->lastInsertId();
            //INSERT THE SEARCH FOR THIS ALBUM.
            $this->_insertSearch('sitepageevent_album', $album_id, '', '');
            try {
                $des = explode('%s', $this->getFromPath() . DIRECTORY_SEPARATOR . 'file/pic/event' . DIRECTORY_SEPARATOR . $data['image_path']);

                $file = $des[0];
                if (isset($des[1])) {
                    $file = $this->getPhotoUrl($des[0], $des[1]);
                    if (empty($file))
                        $file = $des[0] . $des[1];
                }
                // CREATE THE FILE EVENT MAIN PHOTO.
                $filephoto_id = $this->_translateFile($file, array(
                    'parent_type' => 'sitepage_photo',
                    'parent_id' => $album_id,
                    'user_id' => @$data['user_id'],
                        ), true);
            } catch (Exception $e) {
                $filephoto_id = null;
                $this->_warning($e->getMessage(), 1);
            }
            //INSERT THE MAIN PHOTO
            $this->getToDb()->insert('engine4_sitepageevent_photos', array(
                'album_id' => $album_id,
                'collection_id' => $album_id,
                'event_id' => $data['event_id'],
                'creation_date' => $this->_translateTime($data['time_stamp']),
                'modified_date' => $this->_translateTime($data['time_stamp']),
                'user_id' => @$data['user_id'],
                'file_id' => $filephoto_id
            ));
            $photo_id = $this->getToDb()->lastInsertId();
            $newData['photo_id'] = $filephoto_id;
            //INSERT SEARCH
            $this->_insertSearch('sitepageevent_photo', $photo_id, '', '');
        }
        $newData['search'] = 1;

        //GET INVITES
        $invites = $this->getFromDb()->select()
                ->from($this->getfromPrefix() . 'event_invite', '*')
                ->where('event_id = ?', $data['event_id'])
                ->query()
                ->fetchAll();
        $count = count($invites);
        $active = 1;
        $resource_approved = 1;
        $user_approved = 1;
        foreach ($invites as $invite) {
            if ($invite['rsvp_id'] == 1) {
                $rsvp = 2;
            } else if ($invite['rsvp_id'] == 2) {
                $rsvp = 1;
            } else if ($invite['rsvp_id'] == 3) {
                $rsvp = 0;
            } else if ($invite['rsvp_id'] == 0) {
                $rsvp = 3;
                $active = 0;
                $user_approved = 0;
            }
            //INSERT THE MEMBER OF THIS EVENT.
            $this->getToDb()->insert('engine4_sitepageevent_membership', array(
                'resource_id' => $invite['event_id'],
                'user_id' => $invite['invited_user_id'],
                'active' => $active,
                'resource_approved' => $resource_approved,
                'user_approved' => $user_approved,
                'rsvp' => $rsvp
            ));
        }
        $newData['member_count'] = $count;
        return $newData;
    }

}

/*
 * CREATE TABLE IF NOT EXISTS `phpfox_event` (
`event_id` int(10) unsigned NOT NULL,
  `view_id` tinyint(1) NOT NULL DEFAULT '0',
  `is_featured` tinyint(1) NOT NULL DEFAULT '0',
  `is_sponsor` tinyint(1) NOT NULL DEFAULT '0',
  `privacy` tinyint(1) NOT NULL DEFAULT '0',
  `privacy_comment` tinyint(1) NOT NULL DEFAULT '0',
  `module_id` varchar(75) NOT NULL DEFAULT 'event',
  `item_id` int(10) unsigned NOT NULL DEFAULT '0',
  `user_id` int(10) unsigned NOT NULL,
  `title` varchar(255) NOT NULL,
  `location` varchar(255) DEFAULT NULL,
  `country_iso` char(2) DEFAULT NULL,
  `country_child_id` mediumint(8) unsigned NOT NULL DEFAULT '0',
  `postal_code` varchar(20) DEFAULT NULL,
  `city` varchar(255) DEFAULT NULL,
  `time_stamp` int(10) unsigned NOT NULL,
  `start_time` int(10) unsigned NOT NULL,
  `end_time` int(10) unsigned NOT NULL,
  `image_path` varchar(75) DEFAULT NULL,
  `server_id` tinyint(1) NOT NULL DEFAULT '0',
  `total_comment` int(10) unsigned NOT NULL DEFAULT '0',
  `total_like` int(10) unsigned NOT NULL DEFAULT '0',
  `total_dislike` int(10) unsigned NOT NULL DEFAULT '0',
  `mass_email` int(10) unsigned NOT NULL DEFAULT '0',
  `start_gmt_offset` varchar(15) DEFAULT NULL,
  `end_gmt_offset` varchar(15) DEFAULT NULL,
  `gmap` varchar(255) DEFAULT NULL,
  `address` varchar(255) DEFAULT NULL
) ENGINE=InnoDB AUTO_INCREMENT=8 DEFAULT CHARSET=latin1;

 */

/*
 * CREATE TABLE IF NOT EXISTS `phpfox_event_text` (
  `event_id` int(10) unsigned NOT NULL,
  `description` mediumtext,
  `description_parsed` mediumtext,
  KEY `event_id` (`event_id`)
) ENGINE=MyISAM DEFAULT CHARSET=latin1; 
 */

/*
 * CREATE TABLE IF NOT EXISTS `phpfox_event_category_data` (
  `event_id` int(10) unsigned NOT NULL,
  `category_id` int(10) unsigned NOT NULL,
  KEY `category_id` (`category_id`),
  KEY `event_id` (`event_id`)
) ENGINE=MyISAM DEFAULT CHARSET=latin1;
 */

/*
 * CREATE TABLE IF NOT EXISTS `phpfox_event_invite` (
  `invite_id` int(10) unsigned NOT NULL AUTO_INCREMENT,
  `event_id` int(10) unsigned NOT NULL,
  `type_id` tinyint(1) NOT NULL DEFAULT '0',
  `rsvp_id` tinyint(1) NOT NULL DEFAULT '0',
  `user_id` int(10) unsigned NOT NULL DEFAULT '0',
  `invited_user_id` int(10) unsigned NOT NULL DEFAULT '0',
  `invited_email` varchar(100) DEFAULT NULL,
  `time_stamp` int(10) unsigned NOT NULL,
  PRIMARY KEY (`invite_id`),
  KEY `event_id` (`event_id`),
  KEY `event_id_2` (`event_id`,`invited_user_id`),
  KEY `invited_user_id` (`invited_user_id`),
  KEY `event_id_3` (`event_id`,`rsvp_id`,`invited_user_id`),
  KEY `rsvp_id` (`rsvp_id`,`invited_user_id`)
) ENGINE=MyISAM  DEFAULT CHARSET=latin1 AUTO_INCREMENT=1 ;
 */

/*
 * 
CREATE TABLE IF NOT EXISTS `engine4_sitepageevent_events` (
`event_id` int(11) unsigned NOT NULL,
  `title` varchar(128) COLLATE utf8_unicode_ci NOT NULL,
  `description` varchar(512) COLLATE utf8_unicode_ci NOT NULL,
  `user_id` int(11) unsigned NOT NULL,
  `page_id` int(11) NOT NULL,
  `parent_type` varchar(64) COLLATE utf8_unicode_ci NOT NULL,
  `search` tinyint(1) NOT NULL DEFAULT '1',
  `creation_date` datetime NOT NULL,
  `modified_date` datetime NOT NULL,
  `starttime` datetime NOT NULL,
  `endtime` datetime NOT NULL,
  `host` varchar(115) COLLATE utf8_unicode_ci NOT NULL,
  `location` varchar(115) COLLATE utf8_unicode_ci NOT NULL,
  `view_count` int(11) unsigned NOT NULL DEFAULT '0',
  `member_count` int(11) unsigned NOT NULL DEFAULT '0',
  `approval` tinyint(1) NOT NULL DEFAULT '0',
  `invite` tinyint(1) NOT NULL DEFAULT '0',
  `photo_id` int(11) unsigned NOT NULL,
  `featured` tinyint(1) NOT NULL DEFAULT '0',
  `category_id` int(11) NOT NULL DEFAULT '0',
  `seao_locationid` int(11) NOT NULL
) ENGINE=InnoDB AUTO_INCREMENT=7 DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;

 */

/*
 * 
CREATE TABLE IF NOT EXISTS `engine4_sitepageevent_membership` (
  `resource_id` int(11) unsigned NOT NULL,
  `user_id` int(11) unsigned NOT NULL,
  `active` tinyint(1) NOT NULL DEFAULT '0',
  `resource_approved` tinyint(1) NOT NULL DEFAULT '0',
  `user_approved` tinyint(1) NOT NULL DEFAULT '0',
  `message` text COLLATE utf8_unicode_ci,
  `rsvp` tinyint(3) NOT NULL DEFAULT '3',
  `title` text COLLATE utf8_unicode_ci
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;

 */

/*
 * CREATE TABLE IF NOT EXISTS `engine4_sitepageevent_albums` (
`album_id` int(11) unsigned NOT NULL,
  `event_id` int(11) unsigned NOT NULL,
  `title` varchar(128) COLLATE utf8_unicode_ci NOT NULL,
  `description` mediumtext COLLATE utf8_unicode_ci NOT NULL,
  `creation_date` datetime NOT NULL,
  `modified_date` datetime NOT NULL,
  `search` tinyint(1) NOT NULL DEFAULT '1',
  `photo_id` int(11) unsigned NOT NULL DEFAULT '0',
  `view_count` int(11) unsigned NOT NULL DEFAULT '0',
  `comment_count` int(11) unsigned NOT NULL DEFAULT '0',
  `collectible_count` int(11) unsigned NOT NULL DEFAULT '0'
) ENGINE=InnoDB AUTO_INCREMENT=2 DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;

 */

/*
 * 

CREATE TABLE IF NOT EXISTS `engine4_sitepageevent_photos` (
`photo_id` int(11) unsigned NOT NULL,
  `album_id` int(11) unsigned NOT NULL,
  `event_id` int(11) unsigned NOT NULL,
  `user_id` int(11) unsigned NOT NULL,
  `title` varchar(128) COLLATE utf8_unicode_ci DEFAULT NULL,
  `description` varchar(255) COLLATE utf8_unicode_ci DEFAULT NULL,
  `collection_id` int(11) unsigned NOT NULL,
  `file_id` int(11) unsigned NOT NULL,
  `creation_date` datetime DEFAULT NULL,
  `modified_date` datetime DEFAULT NULL
) ENGINE=InnoDB AUTO_INCREMENT=2 DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;

 */